using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.Blogs;
using CMS.CMSHelper;

/// <summary>
/// Blog functions.
/// </summary>
public class BlogFunctions
{
    /// <summary>
    /// Returns user full name.
    /// </summary>
    /// <param name="userId">User id.</param>
    public static string GetUserFullName(object userId)
    {
        int id = ValidationHelper.GetInteger(userId, 0);

        if (id > 0)
        {
            UserInfo ui = UserInfoProvider.GetUserInfo(id);
            if (ui != null)
            {
                return ui.FullName;
            }
        }

        return "";
    }


    /// <summary>
    /// Returns link to the specified post.
    /// </summary>
    /// <param name="postDocumentId">Post document id.</param>
    public static int GetCommentsCount(object postDocumentId)
    {
        int docId = ValidationHelper.GetInteger(postDocumentId, 0);
        CurrentUserInfo currrentUser = CMSContext.CurrentUser;

        bool isOwner = false;
        bool isModerated = false;
        bool onlyApproved = false;
        bool isUserAuthorized = false;

        // Is user authorized to manage comments?
        CMS.TreeEngine.TreeNode blogNode = BlogHelper.GetParentBlog(docId);
        if (blogNode != null)
        {
            isOwner = (currrentUser.UserID == ValidationHelper.GetInteger(blogNode.GetValue("NodeOwner"), 0));
            isModerated = ValidationHelper.GetBoolean(blogNode.GetValue("BlogModerateComments"), false);
        }
        isUserAuthorized = (currrentUser.IsAuthorizedPerResource("cms.blog", "Manage") || isOwner);
        onlyApproved = (isModerated && !isUserAuthorized);


        // Get post comments
        DataSet ds = BlogCommentInfoProvider.GetPostComments(docId, onlyApproved);
        if (ds.Tables.Count > 0)
        {
            return ds.Tables[0].Rows.Count;
        }

        return 0;
    }
}
