using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;

/// <summary>
/// Class providing blog properties.
/// </summary>
public class BlogProperties
{
    public const int OPEN_COMMENTS_ALWAYS = -1;
    public const int OPEN_COMMENTS_DISABLE = 0;

    private int mOpenCommentsFor = OPEN_COMMENTS_ALWAYS;
    private bool mModerateComments = false;
    private string mSendCommentsToEmail = "";
    private bool mAllowAnonymousComments = true;
    private bool mUseCaptcha = true;
    private bool mCheckPermissions = false;
    private bool mShowEditButton = false;
    private bool mShowDeleteButton = true;
    private bool mStopProcessing = false;

    private int mUserPictureMaxWidth = 50;
    private int mUserPictureMaxHeight = 60;
    private bool mEnableUserPictures = false;

    #region " Properties " 

    /// <summary>
    /// Indicates how long are comments opened.
    /// </summary>
    public int OpenCommentsFor
    {
        get
        {
            return mOpenCommentsFor;
        }
        set
        {
            mOpenCommentsFor = value;
        }
    }


    /// <summary>
    /// Indicates whether comments are moderated before publishing.
    /// </summary>
    public bool ModerateComments
    {
        get
        {
            return mModerateComments;
        }
        set
        {
            mModerateComments = value;
        }
    }


    /// <summary>
    /// Indicates whether 'Edit' button should be displayed in comment view while editing comments on the live site.
    /// </summary>
    public bool ShowEditButton
    {
        get
        {
            return mShowEditButton;
        }
        set
        {
            mShowEditButton = value;
        }
    }


    /// <summary>
    /// Indicates whether 'Delete' button should be displayed in comment view while editing comments on the live site.
    /// </summary>
    public bool ShowDeleteButton
    {
        get
        {
            return mShowDeleteButton;
        }
        set
        {
            mShowDeleteButton = value;
        }
    }


    /// <summary>
    /// E-mail address the comments are sent to.
    /// </summary>
    public string SendCommentsToEmail
    {
        get
        {
            return mSendCommentsToEmail;
        }
        set
        {
            mSendCommentsToEmail = value;
        }
    }


    /// <summary>
    /// Indicates whether anonymous comments are allowed.
    /// </summary>
    public bool AllowAnonymousComments
    {
        get
        {
            return mAllowAnonymousComments;
        }
        set
        {
            mAllowAnonymousComments = value;
        }
    }


    /// <summary>
    /// Indicates whether security code should be entered when inserting new comment.
    /// </summary>
    public bool UseCaptcha
    {
        get
        {
            return mUseCaptcha;
        }
        set
        {
            mUseCaptcha = value;
        }
    }


    /// <summary>
    /// Indicates whether permissions should be checked.
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return mCheckPermissions;
        }
        set
        {
            mCheckPermissions = value;            
        }
    }


    /// <summary>
    /// Indicates whether processing should be stopped.
    /// </summary>
    public bool StopProcessing
    {
        get
        {
            return mStopProcessing;
        }
        set
        {
            mStopProcessing = value;
        }
    }


    /// <summary>
    /// Indicates whether user pictures should be displayed in comment detail.
    /// </summary>
    public bool EnableUserPictures
    {
        get
        {
            return mEnableUserPictures;
        }
        set
        {
            mEnableUserPictures = value;
        }
    }


    /// <summary>
    /// User picture max width.
    /// </summary>
    public int UserPictureMaxWidth
    {
        get
        {
            return mUserPictureMaxWidth;
        }
        set
        {
            mUserPictureMaxWidth = value;
        }
    }


    /// <summary>
    /// User picture max height.
    /// </summary>
    public int UserPictureMaxHeight
    {
        get
        {
            return mUserPictureMaxHeight;
        }
        set
        {
            mUserPictureMaxHeight = value;
        }
    }

    #endregion

    /// <summary>
    /// Empty constructor.
    /// </summary>
    public BlogProperties()
    {
    }

}
