using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.TreeEngine;

/// <summary>
/// Base page for the CMSDesk pages to apply global settings to the pages
/// </summary>
public abstract class CMSDeskPage : CMSPage
{
    /// <summary>
    /// Document link mark string
    /// </summary>
    public static string LINK_MARK
    {
        get
        {
            return "<img src=\"" + HttpContext.Current.Request.ApplicationPath.TrimEnd('/') + "/App_Themes/Default/Images/CMSDesk/Icons/link.gif" + "\" class=\"NodeLink\" />";
        }
    }


    /// <summary>
    /// Generic body class - contains the base body css class
    /// </summary>
    protected string mBodyClass = "";


    public CMSDeskPage()
    {
        this.Load += new EventHandler(BasePage_Load);
        this.PreInit += new EventHandler(CMSDeskPage_PreInit);
    }

    void CMSDeskPage_PreInit(object sender, EventArgs e)
    {
        // Set the culture
        CurrentUserInfo ui = CMSContext.CurrentUser;
        if (ui != null)
        {
            System.Threading.Thread.CurrentThread.CurrentCulture = ui.PreferredUICultureInfo;
            System.Threading.Thread.CurrentThread.CurrentUICulture = ui.PreferredUICultureInfo;
        }

        // Check parameter UILang
        if ((HttpContext.Current != null) && (HttpContext.Current.Request != null) && (ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "") != ""))
        {
            this.UICulture = ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "");
            string mCulture = ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "");

            System.Threading.Thread.CurrentThread.CurrentCulture = new System.Globalization.CultureInfo(mCulture);
            System.Threading.Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo(mCulture);
        }
    }



    protected void BasePage_Load(object sender, EventArgs e)
    {
        if (CultureHelper.IsUICultureRTL())
        {
            if (this.Header != null)
            {
                this.Header.Controls.Add(new LiteralControl("<style type=\"text/css\">* { direction: rtl; }</style>"));
                mBodyClass = "RTL";
            }
        }

        Response.Cache.SetNoStore();

        if (CMSContext.CurrentSite == null)
        {
            Response.Redirect("~/CMSMessages/invalidwebsite.aspx");
        }

        CurrentUserInfo currentUser = CMSContext.CurrentUser;
        if (currentUser == null)
        {
            Response.Redirect("~/CMSDesk/accessdenied.aspx");
        }
        else if (!(currentUser.IsGlobalAdministrator || (currentUser.IsEditor && currentUser.IsInSite(CMSContext.CurrentSite.SiteName))))
        {
            Response.Redirect("~/CMSDesk/accessdenied.aspx");
        }

        this.ClientScript.RegisterClientScriptBlock(typeof(string), "InfoScript", ScriptHelper.GetScript("function IsCMSDesk() { return true; }"));
    }


    /// <summary>
    /// Redirects the user to Access denied page
    /// </summary>
    /// <param name="resourceName">Resource name that failed</param>
    /// <param name="permissionName">Permission name that failed</param>
    public static void RedirectToAccessDenied(string resourceName, string permissionName)
    {
        if (HttpContext.Current != null)
        {
            HttpContext.Current.Response.Redirect("~/CMSDesk/accessdenied.aspx?resource=" + resourceName + "&permission=" + permissionName);
        }
    }


    /// <summary>
    /// Redirects the user to Access denied page
    /// </summary>
    /// <param name="nodeId">Node ID that failed</param>
    /// <param name="permissionName">Permission name that failed</param>
    public static void RedirectToAccessDenied(int nodeId, string permissionName)
    {
        if (HttpContext.Current != null)
        {
            HttpContext.Current.Response.Redirect("~/CMSDesk/accessdenied.aspx?nodeid=" + nodeId.ToString() + "&permission=" + permissionName);
        }
    }

    /// <summary>
    /// Redirects the user to Access denied page
    /// </summary>
    /// <param name="message">Displayed access denied message.</param>
    public static void RedirectToAccessDenied(string message)
    {
        if (HttpContext.Current != null)
        {
            HttpContext.Current.Response.Redirect("~/CMSDesk/accessdenied.aspx?message=" + message);
        }
    }

    /// <summary>Returns the absolute URL representation for the given relative URL</summary>
    /// <param name="relativeUrl">Relative URL to convert to absolute</param>
    public string AbsoluteUrl(string relativeUrl)
    {
        relativeUrl = ResolveUrl(relativeUrl);

        // Then add the base URL to the beginning of the URL where necessary
        if (relativeUrl.StartsWith("/"))
        {
            string webUrl = "";

            if (HttpContext.Current != null)
            {
                webUrl = CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri().Substring(0, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri().Length - HttpContext.Current.Request.Url.PathAndQuery.Length);
            }
            if (!webUrl.EndsWith("/"))
            {
                webUrl += "/";
            }
            return webUrl + relativeUrl.TrimStart('/');
        }
        else
        {
            return relativeUrl;
        }
    }


    /// <summary>
    /// Signs the user out
    /// </summary>
    public void SignOut()
    {
        CMSContext.CurrentUser.ViewMode = ViewModeEnum.LiveSite;
        CMSContext.CurrentUser.MenuItemViewMode = ViewModeEnum.LiveSite;
        CMSContext.CurrentUser = null;
        FormsAuthentication.SignOut();
        CookieHelper.Remove("RememberMeName");
    }


    /// <summary>
    /// Sets the current view mode based on the given node
    /// </summary>
    /// <param name="node">Document node</param>
    /// <param name="baseMode">Current base mode (edit/preview/livesite)</param>
    public ViewModeEnum UpdateViewMode(CMS.TreeEngine.TreeNode node, ViewModeEnum baseMode)
    {
        // Set mode if given
        string mode = "";

        // Get current mode
        ViewModeEnum currentMode = ViewModeEnum.Edit;
        ViewModeEnum currentMenuItemMode = ViewModeEnum.Edit;

        currentMode = CMSContext.CurrentUser.ViewMode;
        currentMenuItemMode = CMSContext.CurrentUser.MenuItemViewMode;

        ViewModeEnum newMode = currentMode;
        ViewModeEnum newMenuItemMode = currentMenuItemMode;

        // If mode within querystring, set mode
        if (Request.QueryString["mode"] != null)
        {
            mode = Request.QueryString["mode"].ToLower();
            if (TreePathUtils.IsMenuItemType(node.NodeClassName))
            {
                switch (mode)
                {
                    case "editform":
                        newMenuItemMode = ViewModeEnum.EditForm;
                        break;
                    case "edit":
                        newMenuItemMode = ViewModeEnum.Edit;
                        break;
                    case "design":
                        if (CMSContext.CurrentUser.IsGlobalAdministrator)
                        {
                            newMenuItemMode = ViewModeEnum.Design;
                        }
                        break;
                }
            }
            else
            {
                switch (mode)
                {
                    case "editform":
                        newMode = ViewModeEnum.EditForm;
                        break;
                    case "edit":
                        newMode = ViewModeEnum.Edit;
                        break;
                    case "design":
                        if (CMSContext.CurrentUser.IsGlobalAdministrator)
                        {
                            newMode = ViewModeEnum.Design;
                        }
                        break;
                }
            }
        }
        else
        {
            // Switch to the base mode if wrong mode
            switch (baseMode)
            {
                case ViewModeEnum.Edit:
                    // Get the new mode
                    if ((currentMode == ViewModeEnum.LiveSite) || (currentMode == ViewModeEnum.Preview))
                    {
                        newMode = ViewModeEnum.Edit;
                    }

                    // Get the new MenuItemMode
                    if ((currentMenuItemMode == ViewModeEnum.LiveSite) || (currentMenuItemMode == ViewModeEnum.Preview))
                    {
                        newMenuItemMode = ViewModeEnum.Edit;
                    }

                    break;
            }
        }

        // Set the mode
        CMSContext.CurrentUser.ViewMode = newMode;
        CMSContext.CurrentUser.MenuItemViewMode = newMenuItemMode;

        if (!TreePathUtils.IsMenuItemType(node.NodeClassName))
        {
            return newMode;
        }
        else
        {
            return newMenuItemMode;
        }
    }


    /// <summary>
    /// Determines whether current user is authorized to access cms.content
    /// </summary>
    /// <returns></returns>
    public static bool IsUserAuthorizedPerContent()
    {
        TreeProvider tp = new TreeProvider();
        bool userHasExploreTreePermission = false;

        if (CMSContext.CurrentUser.IsAuthorizedPerResource("cms.content", "exploretree"))
        {
            return true;
        }

        SiteInfo currentSite = CMSContext.CurrentSite;
        if (currentSite != null)
        {
            CMS.TreeEngine.TreeNode rootNode = tp.SelectSingleNode(currentSite.SiteName, "/", TreeProvider.ALL_CULTURES, false, null, false);
            if (rootNode != null)
            {                
                // check 'exploretree' permission for cms.content
                userHasExploreTreePermission = (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(rootNode.NodeID, NodePermissionsEnum.ExploreTree) == AuthorizationResultEnum.Allowed) ? true : false;         
            }
        }        
        return userHasExploreTreePermission;
    }

}
