using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;

/// <summary>
/// Summary description for Functions
/// </summary>
public static class EcommerceFunctions
{
    /// <summary>
    /// Return formated price
    /// </summary>
    /// <param name="SKUPrice">SKU price</param>
    public static string GetFormatedPrice(object SKUPrice)
    {
        double price = ValidationHelper.GetDouble(SKUPrice, 0);

        ShoppingCartInfo currentShoppingCart = CMSContext.CurrentShoppingCart;
        CurrentUserInfo currentUser = CMSContext.CurrentUser;
        CurrentSiteInfo currentSite = CMSContext.CurrentSite;

        // Get customer object
        if (!currentUser.IsPublic())
        {
            CustomerInfo ci = currentUser.CustomerInfo;
            if (ci != null)
            {
                // Get discount level
                int discountLevelId = ci.CustomerDiscountLevelID;
                if (discountLevelId > 0)
                {
                    // Get discount level info
                    DiscountLevelInfo dli = DiscountLevelInfoProvider.GetDiscountLevelInfo(discountLevelId);

                    // Apply discount to product price 
                    if ((dli != null) && (dli.IsValid) && (dli.DiscountLevelValue > 0))
                    {
                        price = price * (1 - dli.DiscountLevelValue / 100);
                        if (price < 0)
                        {
                            price = 0;
                        }
                    }
                }
            }
        }

        string formatedPrice = "";
        if ((price > 0) && (currentSite != null))
        {
            // Get main currency
            CurrencyInfo mainCurrency = CurrencyInfoProvider.GetMainCurrency();
            CurrencyInfo currentCurrency = mainCurrency;

            // Try to get from the shopping cart
            if ((currentShoppingCart != null) && (currentShoppingCart.CurrencyInfoObj != null))
            {
                currentCurrency = currentShoppingCart.CurrencyInfoObj;
            }
            else
            {
                // Get default currency for site
                int currencyId = currentSite.SiteDefaultCurrencyID;
                if (currencyId != mainCurrency.CurrencyID)
                {
                    currentCurrency = CurrencyInfoProvider.GetCurrencyInfo(currencyId);
                }
            }


            // Get exchange rate
            double rate = 1.0;
            if (currentCurrency.CurrencyID != mainCurrency.CurrencyID)
            {
                rate = CurrencyInfoProvider.GetLastValidExchangeRate(currentCurrency.CurrencyID);
                if (rate <= 0)
                {
                    rate = 1.0;
                }
            }

            // Format the price
            price = CurrencyInfoProvider.RoundTo(price / rate, currentCurrency);
            formatedPrice = CurrencyInfoProvider.GetFormatedPrice(price, currentCurrency);
        }

        return formatedPrice;
    }


    /// <summary>
    /// Return link to "add to shoppingcart"
    /// </summary>
    /// <param name="productId">Product ID.</param>
    /// <param name="enabled">Indicates whether product is enabled or not.</param>
    public static string GetAddToShoppingCartLink(object productId, object enabled)
    {
        if (ValidationHelper.GetBoolean(enabled, false) && (ValidationHelper.GetInteger(productId, 0) != 0))
        {
            return "<img src=\"~/App_Themes/Default/Images/CMSDesk/Tools/Ecommerce/Orders/addorder.gif\" alt=\"Add to cart\" /><a href=\"" + ShoppingCartURL(CMSContext.CurrentSiteName) + "?productId=" + Convert.ToString(productId) + "&quantity=1\">" + ResHelper.GetString("EcommerceFunctions.AddToShoppingCart") + "</a>";
        }
        else
        {
            return "";
        }
    }


    /// <summary>
    /// Return link to "add to shoppingcart"
    /// </summary>
    /// <param name="productId">Product ID.</param>
    public static string GetAddToShoppingCartLink(object productId)
    {
        return GetAddToShoppingCartLink(productId, true);
    }


    /// <summary>
    /// Returns link to add specified product to the user's wishlist.
    /// </summary>
    /// <param name="productId">Product ID.</param>
    public static string GetAddToWishListLink(object productId)
    {
        if (ValidationHelper.GetInteger(productId,0) != 0)
        {
            return "<img src=\"~/App_Themes/Default/Images/CMSDesk/Tools/Ecommerce/Products/Wishlist/addtowishlist.gif\" alt=\"Add to wishlist\" /><a href=\"" + WishlistURL(CMSContext.CurrentSiteName) + "?productId=" + Convert.ToString(productId) + "\">" + ResHelper.GetString("EcommerceFunctions.AddToWishlist") + "</a>";
        }
        else
        {
            return "";
        }
    }

    /// <summary>
    /// Returns link to remove specified product from the user's wishlist.
    /// </summary>
    /// <param name="productId">Product ID.</param>
    public static string GetRemoveFromWishListLink(object productId)
    {
        if ((productId != DBNull.Value) && (!CMSContext.CurrentUser.IsPublic()))
        {
            return "<img src=\"~/App_Themes/Default/Images/CMSDesk/Tools/Ecommerce/Products/Wishlist/removefromwishlist.gif\" alt=\"Remove from wishlist\" style=\"cursor: pointer;border:0px\" onclick=\"RemoveFromWishlist(" + Convert.ToString(productId) + ")\"/>";
        }
        else
        {
            return "";
        }
    }


    /// <summary>
    /// Returns the public SKU status display name
    /// </summary>
    /// <param name="statusId">Status ID</param>
    public static string GetPublicStatusName(object statusId)
    {
        int sid = ValidationHelper.GetInteger(statusId, 0);
        if (sid > 0)
        {
            PublicStatusInfo si = PublicStatusInfoProvider.GetPublicStatusInfo(sid);
            if (si != null)
            {
                return si.PublicStatusDisplayName;
            }
        }
        return "";
    }


    /// <summary>
    /// Returns URL to the shopping cart.
    /// </summary>
    /// <param name="siteName">Site name.</param>
    public static string ShoppingCartURL(string siteName)
    {
        string settingsKey = "CMSShoppingCartURL";

        // Create settingkey
        if (ValidationHelper.GetString(siteName, "") != "")
        {
            settingsKey = siteName + "." + settingsKey;
        }

        return GetURL(settingsKey);
    }


    /// <summary>
    /// Returns URL to the wish list.
    /// </summary>
    /// <param name="siteName">Site name</param>
    public static string WishlistURL(string siteName)
    {
        string settingsKey = "CMSWishlistURL";

        // Create settingkey
        if (ValidationHelper.GetString(siteName, "") != "")
        {
            settingsKey = siteName + "." + settingsKey;
        }

        return GetURL(settingsKey);
    }


    /// <summary>
    /// Get URL based on value from settings.
    /// </summary>
    /// <param name="key">Settings key</param>
    private static string GetURL(string key)
    {
        string url = "";
        string appPath = "";
        // Get application path
        if ((HttpContext.Current != null) && (HttpContext.Current.Request != null))
        {
            appPath = HttpContext.Current.Request.ApplicationPath.Trim();
        }

        // Get value from settingkey
        url = SettingsKeyProvider.GetStringValue(key);

        if (url.StartsWith("~/"))
        {
            url = url.Remove(0, 2);
        }

        // Combine application path with relative url
        if (appPath.EndsWith("/"))
        {
            url = appPath + url;
        }
        else
        {
            url = appPath + "/" + url;
        }

        return url;
    }


    /// <summary>
    /// Sets different css styles to enabled and disabled dropdownlist items.
    /// </summary>
    /// <param name="drpTemp">Dropdownlist control.</param>
    /// <param name="valueFieldName">Field name with ID value.</param>
    /// <param name="statusFieldName">Field name with status value.</param>
    /// <param name="itemEnabledStyle">Enabled item style.</param>
    /// <param name="itemDisabledStyle">Disabled item style.</param>
    public static void MarkEnabledAndDisabledItems(DropDownList drpTemp, string valueFieldName, string statusFieldName, string itemEnabledStyle, string itemDisabledStyle)
    {
        itemEnabledStyle = (itemEnabledStyle == "") ? "DropDownItemEnabled" : itemEnabledStyle;
        itemDisabledStyle = (itemDisabledStyle == "") ? "DropDownItemDisabled" : itemDisabledStyle;

        if (!DataHelper.DataSourceIsEmpty(drpTemp.DataSource))
        {
            if (drpTemp.DataSource is DataSet)
            {                
                ListItem li = null;                

                foreach (DataRow row in ((DataSet)drpTemp.DataSource).Tables[0].Rows)
                {
                    li = drpTemp.Items.FindByValue(Convert.ToString(row[valueFieldName]));
                    if ((li != null) && (li.Value != "0"))
                    {
                        // Item is enabled
                        if (ValidationHelper.GetBoolean(row[statusFieldName], false))
                        {
                            li.Attributes.Add("class", itemEnabledStyle);
                        }
                        // Item is disabled
                        else
                        {
                            li.Attributes.Add("class", itemDisabledStyle);
                        }
                    }
                }
            }
        }
    }


    /// <summary>
    /// Sets different css styles to enabled and disabled dropdownlist items.
    /// </summary>
    /// <param name="drpTemp">Dropdownlist control.</param>
    /// <param name="valueFieldName">Field name with ID value.</param>
    /// <param name="statusFieldName">Field name with status value.</param>
    public static void MarkEnabledAndDisabledItems(DropDownList drpTemp, string valueFieldName, string statusFieldName)
    {
        MarkEnabledAndDisabledItems(drpTemp, valueFieldName, statusFieldName, "", ""); 
    }

}
