using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI.WebControls;

using CMS.Ecommerce;
using CMS.CMSHelper;
using CMS.SiteProvider;

public class ShoppingCartStep : System.Web.UI.UserControl
{
    private bool mIsInternalOrder = false;
    private string mTitleText = "";    
    private int mCurrentStepIndex = 0;
    private int mPreviousStepIndex = -1;
    private int mNextStepIndex = -1;
    private bool mLoadStepInfo = false;
    private Button mButtonBack = null;
    private Button mButtonNext = null;
    private bool mIsCreatedFromOrder = false;
    private ShoppingCartInfo mShoppingCart = null;
    private bool mPasswordRetrieval = false;
    private string mRegistrationTrackConversionName = "";

    #region "Public properties"

    /// <summary>
    /// Shopping cart info object.
    /// </summary>
    public ShoppingCartInfo ShoppingCartInfoObj
    {
        get
        {
            if (mShoppingCart == null)
            {
                mShoppingCart = CMSContext.CurrentShoppingCart;
            }
            return mShoppingCart;
        }
        set
        {
            mShoppingCart = value;
        }
    }


    /// <summary>
    /// User info
    /// </summary>
    public UserInfo UserInfo
    {
        get
        {
            ShoppingCartInfo currentCart = this.ShoppingCartInfoObj;
            if ((currentCart == null) || (currentCart.UserInfoObj == null))
            {
                return CMSContext.CurrentUser;
            }
            else
            {
                return currentCart.UserInfoObj;
            }
        }
    }


    /// <summary>
    /// Shopping cart step "Back" button.
    /// </summary>
    public Button ButtonBack
    {
        get
        {
            return mButtonBack;
        }
        set
        {
            mButtonBack = value;
        }
    }


    /// <summary>
    /// Shopping cart step "Next" button.
    /// </summary>
    public Button ButtonNext
    {
        get
        {
            return mButtonNext;
        }
        set
        {
            mButtonNext = value;
        }
    }


    /// <summary>
    /// Indicates whether it is an internal order (made in CMSDesk) or external order (made by customer on the web).
    /// </summary>
    public bool IsInternalOrder 
    {
        get
        {
            return mIsInternalOrder;
        }
        set
        {
            mIsInternalOrder = value;
        }
    }

    
    /// <summary>
    /// Indicates whether shopping cart is created from order info or not.
    /// </summary>
    public bool IsShoppingCartCreatedFromOrder
    {
        get
        {
            return mIsCreatedFromOrder;
        }
        set
        {
            mIsCreatedFromOrder = value;
        }
    }


    /// <summary>
    /// Current step title text.
    /// </summary>
    public string TitleText
    {
        get
        {
            return mTitleText;
        }
        set
        {
            mTitleText = value;
        }
    }


    /// <summary>
    /// Conversion track name used after successful registration.
    /// </summary>
    public string RegistrationTrackConversionName
    {
        get
        {
            return mRegistrationTrackConversionName;
        }
        set
        {
            mRegistrationTrackConversionName = value;
        }
    }


    /// <summary>
    /// Validates current step information before processing. If succeeded returns true, otherwise returns false.
    /// </summary>
    /// <returns></returns>
    public virtual bool IsValid()
    {
        return true;
    }

    
    /// <summary>
    /// Previous step index. (If you want to load another step with index different from CurrentStepIndex - 1)
    /// </summary>
    public int PreviousStepIndex
    {
        get
        {
            // previous index is not set in wizard step
            if (mPreviousStepIndex == -1)
            {
                if (mCurrentStepIndex > 0)
                {
                    return mCurrentStepIndex - 1;
                }
                else
                {
                    return 0;
                }
            }
            // previous index is set in wizard step
            else
            {
                return mPreviousStepIndex;
            }
        }
        set
        {
            mPreviousStepIndex = value;
        }
    }
    

    /// <summary>
    /// Next step index. (If you want to load another step with index different from CurrentStepIndex + 1)
    /// </summary>
    public int NextStepIndex
    {
        get
        {            
            return (mNextStepIndex == -1) ? mCurrentStepIndex + 1 : mNextStepIndex;            
        }
        set
        {
            mNextStepIndex = value;
        }
    }


    /// <summary>
    /// Current step index.
    /// </summary>
    public int CurrentStepIndex
    {
        get
        {
            return mCurrentStepIndex;
        }
        set
        {
            mCurrentStepIndex = value;
        }
    }


    /// <summary>
    /// Indicates whether step information should be loaded from the shopping cart info object.
    /// </summary>
    public bool LoadStepInfo
    {
        get
        {
            return mLoadStepInfo;
        }
        set
        {
            mLoadStepInfo = value;
        }
    }

    /// <summary>
    /// True if password retrieval is enabled.
    /// </summary>
    public bool PasswordRetrieval
    {
        get
        {
            return mPasswordRetrieval;
        }
        set
        {
            mPasswordRetrieval = value;
        }
    }

    #endregion


    /// <summary>
    /// Process current step information. If succeeded returns true, otherwise returns false.
    /// </summary>
    /// <returns></returns>
    public virtual bool ProcessStep()
    {
        return true;
    }


}

