using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.DataEngine;
using CMS.IDataConnectionLibrary;
using CMS.EventLog;

/// <summary>
/// Class carying the code to perform the upgrade procedure
/// </summary>
public static class UpgradeProcedure
{
    /// <summary>
    /// Runs the update procedure
    /// </summary>
    public static void Update()
    {
        if (InstallerFunctions.ConnectionStringIsSet())
        {
            try
            {
                string version = SettingsKeyProvider.GetStringValue("CMSDataVersion");
                switch (version.ToLower())
                {
                    case "2.2":
                        Update23();
                        break;
                }
            }
            catch
            {
            }
        }
    }


    /// <summary>
    /// CMS 2.3 update procedure
    /// </summary>
    private static void Update23()
    {
        // Recreate the search queries
        DataSet ds = DataClassInfoProvider.GetAllDataClass();
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                // All document type classes
                bool isDocumentType = ValidationHelper.GetBoolean(dr["ClassIsDocumentType"], false);
                if (isDocumentType)
                {
                    // Generate the search query
                    string className = ValidationHelper.GetString(dr["ClassName"], "");
                    SqlGenerator.GenerateQuery(className, "searchtree", SqlOperationTypeEnum.SearchTree, false);
                }
            }
        }

        // Add new columns to the system table CMS_User
        try
        {
            DataClassInfo dci = DataClassInfoProvider.GetDataClass("cms.user");
            if (dci != null)
            {
                CMS.FormEngine.FormInfo fi = new CMS.FormEngine.FormInfo(dci.ClassFormDefinition);
                if (fi != null)
                {
                    // UserURLReferrer
                    CMS.FormEngine.FormFieldInfo ffi = new CMS.FormEngine.FormFieldInfo();
                    ffi.Name = "UserURLReferrer";
                    ffi.DataType = CMS.FormEngine.FormFieldDataTypeEnum.Text;
                    ffi.AllowEmpty = true;
                    ffi.PublicField = false;
                    ffi.System = true;
                    ffi.Size = 200;
                    ffi.FieldType = CMS.FormEngine.FormFieldControlTypeEnum.LabelControl;
                    ffi.Visible = false;
                    ffi.Caption = "";
                    ffi.DefaultValue = "";
                    ffi.Description = "";
                    ffi.RegularExpression = "";
                    ffi.FileExtensions = "";


                    fi.AddFormField(ffi);

                    //UserCampaign
                    ffi = new CMS.FormEngine.FormFieldInfo();
                    ffi.Name = "UserCampaign";
                    ffi.DataType = CMS.FormEngine.FormFieldDataTypeEnum.Text;
                    ffi.AllowEmpty = true;
                    ffi.PublicField = false;
                    ffi.System = true;
                    ffi.Size = 100;
                    ffi.FieldType = CMS.FormEngine.FormFieldControlTypeEnum.LabelControl;
                    ffi.Visible = false;
                    ffi.Caption = "";
                    ffi.DefaultValue = "";
                    ffi.Description = "";
                    ffi.RegularExpression = "";
                    ffi.FileExtensions = "";

                    fi.AddFormField(ffi);

                    dci.ClassFormDefinition = fi.GetXmlDefinition();
                    dci.ClassXmlSchema = CMS.DataEngine.TableManager.GetXmlSchema("CMS_User");
                    
                    DataClassInfoProvider.SetDataClass(dci);

                    // Generate queries
                    SqlGenerator.GenerateDefaultQueries(dci, true, false);
                }
            }
        }
        catch (Exception ex)
        {
            EventLogProvider evp = new EventLogProvider();
            evp.LogEvent("Update to version 2.3", "Update", ex);
        }

        try
        {
            // Import blog document types and templates
            CMS.ImportExport.SiteImportSettings set = new CMS.ImportExport.SiteImportSettings();
            set.ImportOnlySettings = true;
            set.OverwriteAll = true;
            set.OverwriteAllowed = true;
            set.SourceFilePath = HttpContext.Current.Server.MapPath("~/CMSSiteUtils/Import/blogs.zip");
            CMS.ImportExport.ImportProvider.ImportSite(set);

            // Clear hashtables
            Functions.ClearHashtables();


            // Set blog as child classes and set blog enabled child classes
            DataClassInfo dciBlog = DataClassInfoProvider.GetDataClass("cms.blog");
            DataClassInfo dciPost = DataClassInfoProvider.GetDataClass("cms.blogpost");
            DataClassInfo dciMonth = DataClassInfoProvider.GetDataClass("cms.blogmonth");

            DataClassInfo dcRoot = DataClassInfoProvider.GetDataClass("cms.root");
            DataClassInfo dcMenuItem = DataClassInfoProvider.GetDataClass("cms.MenuItem");

            if (dciBlog != null)
            {
                if (dcRoot != null)
                {
                    DataClassInfoProvider.AllowChildClass(dcRoot.ClassID, dciBlog.ClassID);
                }

                if (dcMenuItem != null)
                {
                    DataClassInfoProvider.AllowChildClass(dcMenuItem.ClassID, dciBlog.ClassID);
                }

                if (dciMonth != null)
                {
                    DataClassInfoProvider.AllowChildClass(dciBlog.ClassID, dciMonth.ClassID);

                    if (dciPost != null)
                    {
                        DataClassInfoProvider.AllowChildClass(dciBlog.ClassID, dciPost.ClassID);
                        DataClassInfoProvider.AllowChildClass(dciMonth.ClassID, dciPost.ClassID);
                    }
                }
            }

            CMS.PortalEngine.PageTemplateInfo ptiBlog = CMS.PortalEngine.PageTemplateInfoProvider.GetPageTemplateInfo("blog");

            // Add blogs to all available sites
            ds = CMS.SiteProvider.SiteInfoProvider.GetAllSites();
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    int site = ValidationHelper.GetInteger(dr["SiteID"], 0);

                    if (site != 0)
                    {
                        if (dciBlog != null)
                        {
                            DataClassInfoProvider.AddClassToSite(dciBlog.ClassID, site);
                        }

                        if (dciMonth != null)
                        {
                            DataClassInfoProvider.AddClassToSite(dciMonth.ClassID, site);
                        }

                        if (dciPost != null)
                        {
                            DataClassInfoProvider.AddClassToSite(dciPost.ClassID, site);
                        }
                    }

                    if (ptiBlog != null)
                    {
                        CMS.PortalEngine.PageTemplateInfoProvider.AddPageTemplateToSite(ptiBlog.PageTemplateId, site);
                    }
                }
            }
        }
        catch (Exception ex)
        {
            EventLogProvider evp = new EventLogProvider();
            evp.LogEvent("Update to version 2.3", "Update", ex);
        }


        try
        {
            if (CMS.SiteProvider.InlineControlInfoProvider.GetInlineControlInfo("PollControl") == null)
            {
                // Add poll inline control
                CMS.SiteProvider.InlineControlInfo ic = new CMS.SiteProvider.InlineControlInfo();
                ic.ControlDisplayName = "Poll";
                ic.ControlDescription = "Displays the Poll";
                ic.ControlParameterName = "Poll name";
                ic.ControlName = "PollControl";

                CMS.SiteProvider.InlineControlInfoProvider.SetInlineControlInfo(ic);

                ds = CMS.SiteProvider.SiteInfoProvider.GetAllSites();
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    foreach (DataRow dr in ds.Tables[0].Rows)
                    {
                        int site = ValidationHelper.GetInteger(dr["SiteID"], 0);

                        if (site != 0)
                        {
                            CMS.SiteProvider.InlineControlInfoProvider.AddInlineControlToSite(ic.ControlID, site);
                        }
                    }
                }
            }
        }
        catch (Exception ex)
        {
            EventLogProvider evp = new EventLogProvider();
            evp.LogEvent("Update to version 2.3", "Update", ex);
        }


        SettingsKeyProvider.SetValue("CMSDataVersion", "2.3");
    }
}
