using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.FileManager;
using CMS.TreeEngine;

/// <summary>
/// Summary description for CMSOutputFile
/// </summary>
public class CMSOutputFile
{
    private AttachmentInfo mAttachment = null;
    private byte[] mOutputData = null;
    private DateTime mLastModified = DateTime.Now;
    private bool mIsSecured = false;
    private string mAliasPath = "";
    private string mCultureCode = "";
    private CMS.TreeEngine.TreeNode mFileNode = null;


    /// <summary>
    /// AttachmentInfo without AttachmentBinary.
    /// </summary>
    public AttachmentInfo Attachment
    {
        get
        {
            return mAttachment;
        }
        set
        {
            mAttachment = value;
            mAttachment.AttachmentBinary = null;
        }
    }


    /// <summary>
    /// Output file data.
    /// </summary>
    public byte[] OutputData
    {
        get
        {
            return mOutputData;
        }
        set
        {
            mOutputData = value;
        }
    }


    /// <summary>
    /// Time when the file was last modified
    /// </summary>
    public DateTime LastModified
    {
        get
        {
            return mLastModified;
        }
        set 
        {
            mLastModified = value;
        }
    }


    /// <summary>
    /// File is secured (located within the secured area document)
    /// </summary>
    public bool IsSecured
    {
        get
        {
            return mIsSecured;
        }
        set
        {
            mIsSecured = value;
        }
    }


    /// <summary>
    /// Document alias path
    /// </summary>
    public string AliasPath
    {
        get
        {
            return mAliasPath;
        }
        set
        {
            mAliasPath = value;
        }
    }


    /// <summary>
    /// Document culture
    /// </summary>
    public string CultureCode
    {
        get
        {
            return mCultureCode;
        }
        set
        {
            mCultureCode = value;
        }
    }


    /// <summary>
    /// File document node
    /// </summary>
    public CMS.TreeEngine.TreeNode FileNode
    {
        get
        {
            return mFileNode;
        }
        set
        {
            mFileNode = value;
        }
    }


    /// <summary>
    /// Constructor.
    /// </summary>
    public CMSOutputFile()
    {
    }


    /// <summary>
    /// Constructor.
    /// </summary>
    /// <param name="ai">AttachmentInfo.</param>
    /// <param name="data">Output file data.</param>
    public CMSOutputFile(AttachmentInfo ai, byte[] data)
    {
        this.Attachment = ai;
        this.OutputData = data;
    }
}
