using System;
using System.Data;
using System.Collections;
using System.IO;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.Controls;
using CMS.SettingsProvider;
using CMS.URLRewritingEngine;
using CMS.FCKeditorV2;
using CMS.WebAnalytics;

/// <summary>
/// Base class for the template pages
/// </summary>
public class TemplatePage : System.Web.UI.Page
{
    #region "Variables"

    /// <summary>
    /// Document base
    /// </summary>
    protected DocumentBase mDocumentBase = null;


    /// <summary>
    /// Generic body class - contains the base body css class
    /// </summary>
    protected string mBodyClass = "";

    /// <summary>
    /// Other parameters in body tag
    /// </summary>
    protected string mBodyParameters = "";


    /// <summary>
    /// Page CSS file link
    /// </summary>
    protected string mCssFile = null;


    /// <summary>
    /// Page title
    /// </summary>
    protected string mTitle = null;

    /// <summary>
    /// Page keywords
    /// </summary>
    protected string mKeyWords = null;

    /// <summary>
    /// Page description
    /// </summary>
    protected string mDescription = null;


    /// <summary>
    /// Extended page tags
    /// </summary>
    protected string mExtendedTags = null;


    /// <summary>
    /// DOCTYPE definition
    /// </summary>
    protected string mDocType = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">";

    /// <summary>
    /// If false, default layout rendering is disabled
    /// </summary>
    protected bool renderLayout = true;


    /// <summary>
    /// Page portal manager
    /// </summary>
    protected CMSPageManager manager = null;


    /// <summary>
    /// List of the toolbar controls
    /// </summary>
    private ArrayList ToolbarControls = null;


    private CurrentSiteInfo currentSite = null;
    private PageInfo currentPage = null;
    private CurrentUserInfo currentUser = null;

    #endregion


    /// <summary>
    /// Document base
    /// </summary>
    public DocumentBase DocumentBase
    {
        get
        {
            if (mDocumentBase == null)
            {
                mDocumentBase = new DocumentBase();
            }
            return mDocumentBase;
        }
    }


    /// <summary>
    /// Constructor
    /// </summary>
    public TemplatePage()
    {
        this.Load += new EventHandler(TemplatePage_Load);
        this.PreInit += new EventHandler(TemplatePage_PreInit);
        this.Init += new EventHandler(TemplatePage_Init);
        this.PreRender += new EventHandler(TemplatePage_PreRender);
    }


    void TemplatePage_PreInit(object sender, EventArgs e)
    {
        currentSite = CMSContext.CurrentSite;
        currentPage = CMSContext.CurrentPageInfo;
        currentUser = CMSContext.CurrentUser;

        // Page initialization
        if (currentPage != null)
        {
            URLRewriter.RequestSecurePage(currentPage, false);
            URLRewriter.CheckSecuredAreas(currentPage, false);

            // Set caching
            this.DocumentBase.SetCaching();

            // Set culture
            this.DocumentBase.SetCulture();

            if (currentUser.ViewMode != ViewModeEnum.LiveSite)
            {
                this.MaintainScrollPositionOnPostBack = true;
            }

            // If no master page, load stylesheet
            if (this.Master == null)
            {
                CssStylesheetInfo csi = null;
                if (currentPage.DocumentStylesheetID > 0)
                {
                    csi = CssStylesheetInfoProvider.GetCssStylesheetInfo(currentPage.DocumentStylesheetID);
                }
                // If not found, get default stylesheet from the current site
                if ((csi == null) && (currentSite.SiteDefaultStylesheetID > 0))
                {
                    csi = CssStylesheetInfoProvider.GetCssStylesheetInfo(currentSite.SiteDefaultStylesheetID);
                }
                // If stylesheet found, get the URL
                if (csi != null)
                {
                    mCssFile = CssStylesheetInfoProvider.GetStylesheetUrl(csi.StylesheetName);
                    if (Directory.Exists(Server.MapPath("~/App_Themes/") + csi.StylesheetName))
                    {
                        this.Page.Theme = csi.StylesheetName;
                    }
                }
            }
            else if (this.Master is TemplateMasterPage)
            {
                ((TemplateMasterPage)this.Master).PreInit();
            }
        }
    }


    /// <summary>
    /// Init event handler
    /// </summary>
    void TemplatePage_Init(object sender, EventArgs e)
    {
        if (this.Master == null)
        {
            // Load page information
            if (currentPage != null)
            {
                // Log the hit
                DocumentBase.LogHit();

                // Set campaign
                DocumentBase.SetCampaign();

                mDescription = CMSContext.CurrentDescription;
                mKeyWords = CMSContext.CurrentKeyWords;
                mTitle = CMSContext.CurrentTitle;
                mBodyClass = CMSContext.CurrentBodyClass;
                mDocType = CMSContext.CurrentDocType;

                // Create the manager envelope
                if (!FCKeditor.UseFrameForToolbar && !FCKeditor.UseIFrameForToolbar)
                {
                    if (manager == null)
                    {
                        manager = CMSEditableRegion.FindPageManager(this.Page.Form);
                    }
                    if (manager != null)
                    {
                        int managerIndex = this.Page.Form.Controls.IndexOf(manager);

                        // Create the layout
                        if (renderLayout)
                        {
                            bool isMenuItem = TreePathUtils.IsMenuItemType(currentPage.ClassName);

                            if ((isMenuItem && CMSContext.CurrentUser.MenuItemViewMode == ViewModeEnum.Edit) || (!isMenuItem && CMSContext.CurrentUser.ViewMode == ViewModeEnum.Edit))
                            {
                                this.ToolbarControls = new ArrayList();

                                // Toolbar container start
                                LiteralControl tc = new LiteralControl("<div class=\"PortalEditorToolbar\" id=\"CMSEditorToolbar\" style=\"height: 76px;\"><div id=\"FCKToolbar\" style=\"height: 76px;\"></div>");
                                this.Page.Form.Controls.AddAt(managerIndex, tc);
                                this.ToolbarControls.Add(tc);
                                managerIndex += 1;

                                // Portal manager
                                tc = new LiteralControl("<div class=\"PortalManager\" id=\"CMSManager\">");
                                this.Page.Form.Controls.AddAt(managerIndex, tc);
                                managerIndex += 1;

                                // <MANAGER>

                                // Portal manager end
                                tc = new LiteralControl("</div>");
                                this.Page.Form.Controls.AddAt(managerIndex + 1, tc);

                                // Toolbar container end
                                tc = new LiteralControl("</div>");
                                this.Page.Form.Controls.AddAt(managerIndex + 2, tc);
                                this.ToolbarControls.Add(tc);

                                // Content area start
                                this.Page.Form.Controls.AddAt(managerIndex + 3, new LiteralControl("<div class=\"PortalEditArea\" id=\"CMSEditArea\">"));

                                // <CONTENT>

                                // Content area end
                                this.Page.Form.Controls.Add(new LiteralControl("</div>" + ScriptHelper.GetScript(
                                    "var editAreaElem = document.getElementById('CMSEditArea'); " +
                                    "var toolbarElem = document.getElementById('CMSEditorToolbar'); " +
                                    "function ResizeEditArea() { " +
                                        "if ( !document.all ) { editAreaElem.style.position = 'absolute'; }" +
                                        "if ( toolbarElem != null ) { editAreaElem.style.height = (document.body.clientHeight - toolbarElem.clientHeight) + 'px'; } " +
                                        "else { editAreaElem.style.height = '100%'; } " +
                                    "}"
                                )));

                                mBodyParameters += "onresize=\"ResizeEditArea();\" onload=\"ResizeEditArea();\" ";
                            }
                            else
                            {
                                //this.Form.Controls.AddAt(0, new LiteralControl("<div class=\"TemplateContentArea\">"));
                                //this.Form.Controls.Add(new LiteralControl("</div>"));
                            }
                        }
                    }
                }
            }
        }
    }


    /// <summary>
    /// Load event handler
    /// </summary>
    void TemplatePage_Load(object sender, EventArgs e)
    {
        if (this.Master == null)
        {
            if (currentPage != null)
            {
                // Log the page view hit in live site mode
                if (currentUser.ViewMode == ViewModeEnum.LiveSite)
                {
                    if (AnalyticsHelper.AnalyticsEnabled(currentSite.SiteName) && !AnalyticsHelper.IsURLExcluded(currentSite.SiteName, currentPage.NodeAliasPath) && !AnalyticsHelper.IsIPExcluded(currentSite.SiteName, HttpContext.Current.Request.UserHostAddress) && !AnalyticsHelper.IsSearchEngineExcluded(currentSite.SiteName))
                    {
                        HitLogProvider.LogHit(HitLogProvider.PAGE_VIEWS, currentSite.SiteName, currentUser.PreferredCultureCode, "", currentPage.NodeId);
                    }
                }

                // Set campaign
                DocumentBase.SetCampaign();

                //Response.Cache.SetNoStore();

                if (CultureHelper.IsPreferredCultureRTL())
                {
                    this.mExtendedTags += "<style type=\"text/css\">* { direction: rtl; }</style>";
                }

                // Initialize the design styles
                bool useDesignStyles = false;
                bool useEditStyle = false;
                // Get mode
                if (TreePathUtils.IsMenuItemType(currentPage.ClassName))
                {
                    useDesignStyles = (currentUser.MenuItemViewMode != ViewModeEnum.LiveSite);
                    useEditStyle = (currentUser.MenuItemViewMode == ViewModeEnum.Edit);
                }
                else
                {
                    useDesignStyles = (currentUser.ViewMode != ViewModeEnum.LiveSite);
                    useEditStyle = (currentUser.ViewMode == ViewModeEnum.Edit);
                }

                if (useDesignStyles)
                {
                    if ((this.Page.Theme != "") && File.Exists(Server.MapPath("~/App_Themes/" + this.Page.Theme + "/DesignMode.css")))
                    {
                        this.mExtendedTags += HTMLHelper.GetCSSFileLink(ResolveUrl("~/App_Themes/" + this.Page.Theme + "/DesignMode.css"));
                    }
                    else
                    {
                        this.mExtendedTags += HTMLHelper.GetCSSFileLink(ResolveUrl("~/App_Themes/Default/DesignMode.css"));
                    }
                }

                // Edit / Design body style
                if (!FCKeditor.UseFrameForToolbar && !FCKeditor.UseIFrameForToolbar)
                {
                    if (useEditStyle)
                    {
                        this.mExtendedTags += "<style type=\"text/css\"> \n" +
                                                "html, body { margin: 0px; padding: 0px; height: 100%; width: 100%; overflow: hidden; } \n" +
                            //".PortalContentArea { height: 100%; width: 100%; position: absolute; z-index: 1; overflow: auto; } \n" +
                                              "</style>";
                    }
                    else if (useDesignStyles)
                    {
                        this.mExtendedTags += "<style type=\"text/css\"> \n" +
                                                "html, body {  margin: 0px; padding: 0px; } \n" +
                                              "</style>";
                    }
                }

                // Page template header tags
                if (currentPage.PageTemplateInfo != null)
                {
                    this.mExtendedTags += currentPage.PageTemplateInfo.PageTemplateHeader;
                }

                // Document header tags
                if (ValidationHelper.GetString(currentPage.NodeHeadTags, "") != "")
                {
                    this.mExtendedTags += currentPage.NodeHeadTags;
                }
            }
        }
    }


    void TemplatePage_PreRender(object sender, EventArgs e)
    {
        if (this.Master == null)
        {
            // Add CMS tags
            DocumentBase.AddCMSTags(this);

            if (((manager == null) || (!manager.UsesHtmlEditor(null))) && (ToolbarControls != null))
            {
                foreach (Control tc in this.ToolbarControls)
                {
                    tc.Visible = false;
                }
            }
        }
    }

}
