using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.GlobalHelper;

/// <summary>
/// Base page for the CMSSiteManager pages to apply global settings to the pages
/// </summary>
public abstract class SiteManagerPage : CMSPage
{
    /// <summary>
    /// Generic body class - contains the base body css class
    /// </summary>
    protected string mBodyClass = "";
    
    
    public SiteManagerPage()
    {
        this.Load += new EventHandler(BasePage_Load);
        this.PreInit += new EventHandler(SiteManagerPage_PreInit);
    }

    /// <summary>
    /// Redirects the user to Access denied page
    /// </summary>
    /// <param name="resourceName">Resource name that failed</param>
    /// <param name="permissionName">Permission name that failed</param>
    protected void RedirectToAccessDenied(string resourceName, string permissionName)
    {
        Response.Redirect("~/CMSSiteManager/accessdenied.aspx?resource=" + resourceName + "&permission=" + permissionName);
    }


    /// <summary>
    /// Redirects the user to Access denied page
    /// </summary>
    /// <param name="nodeId">Node ID that failed</param>
    /// <param name="permissionName">Permission name that failed</param>
    protected void RedirectToAccessDenied(int nodeId, string permissionName)
    {
        Response.Redirect("~/CMSSiteManager/accessdenied.aspx?nodeid=" + nodeId.ToString() + "&permission=" + permissionName);
    }


    void SiteManagerPage_PreInit(object sender, EventArgs e)
    {
        // Set the culture
        CurrentUserInfo ui = CMSContext.CurrentUser;
        if (ui != null)
        {
            System.Threading.Thread.CurrentThread.CurrentCulture = ui.PreferredUICultureInfo;
            System.Threading.Thread.CurrentThread.CurrentUICulture = ui.PreferredUICultureInfo;
        }

        // Check partameter UILang
        if ((HttpContext.Current != null) && (HttpContext.Current.Request != null) && (ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "") != ""))
        {
            this.UICulture = ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "");
            string mCulture = ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "");

            System.Threading.Thread.CurrentThread.CurrentCulture = new System.Globalization.CultureInfo(mCulture);
            System.Threading.Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo(mCulture);
        }
    }


    protected void BasePage_Load(object sender, EventArgs e)
    {
        if (CultureHelper.IsUICultureRTL())
        {
            if (this.Header != null)
            {
                this.Header.Controls.Add(new LiteralControl("<style type=\"text/css\">* { direction: rtl; }</style>"));
                mBodyClass = "RTL";
            }
        }
        
        Response.Cache.SetNoStore();

        CurrentUserInfo currentUser = CMSContext.CurrentUser;
        if (currentUser == null)
        {
            Response.Redirect("~/CMSSiteManager/accessdenied.aspx");
        }
        else if (!currentUser.IsGlobalAdministrator)
        {
            Response.Redirect("~/CMSSiteManager/accessdenied.aspx");
        }
    }
}
