using System.Web;
using System.IO;
using System.Web.SessionState;
using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Drawing;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.Configuration;
using System.Reflection;
using System.Diagnostics;

using CMS.GlobalEventHelper;
using CMS.URLRewritingEngine;
using CMS.CMSHelper;
using CMS.CMSOutputFilter;
using CMS.Scheduler;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.EventLog;
using CMS.EmailEngine;
using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.DataEngine;
using CMS.VirtualPathHelper;
using CMS.WebFarmSyncHelper;
using CMS.WebAnalytics;
using CMS.Newsletter;
using CMS.LicenseProvider;

public class Global : System.Web.HttpApplication
{
    #region " Component Designer Generated Code "

    public Global()
        : base()
    {
        // This call is required by the Component Designer.
        InitializeComponent();
    }

    // Required by the Component Designer
    private System.ComponentModel.IContainer components;

    // NOTE: The following procedure is required by the Component Designer
    // It can be modified using the Component Designer.
    // Do not modify it using the code editor.
    [System.Diagnostics.DebuggerStepThrough()]
    private void InitializeComponent()
    {
        components = new System.ComponentModel.Container();
        // events handled by Application_AcquireRequestState
        base.AcquireRequestState += new System.EventHandler(Application_AcquireRequestState);
    }

    #endregion


    private static DateTime mApplicationStart = DateTime.Now;
    private static bool firstEndRequestAfterStart = true;

    /// <summary>
    /// Date and time of the application start.
    /// </summary>
    public static DateTime ApplicationStart
    {
        get
        {
            return mApplicationStart;
        }
    }


    public void Application_Start(object sender, EventArgs e)
    {
        //ConnectionHelper.UseContextConnection = true;
        //CacheHelper.CacheItemPriority = System.Web.Caching.CacheItemPriority.NotRemovable;
        if (SqlHelperClass.IsConnectionStringInitialized)
        {
            try
            {
                // Remember date and time of the applicatin start
                mApplicationStart = DateTime.Now;

                // Write "Application start" event to the event log
                EventLogProvider eProvider = new EventLogProvider();
                eProvider.LogEvent("I", DateTime.Now, "Application_Start", "INFORMATION", 0, "", 0, "", "", "", 0, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
            }
            catch
            {
                // can't write to log, do not process any code
            }

            // Update the system
            UpgradeProcedure.Update();

            // Process web farm tasks
            WebSyncHelper.ProcessMyTasks();

            // Re-inicialize scheduler tasks if application was aborted during task execute
            SchedulingExecutor.ReInitCorruptedTasks();
        }

        // Register virtual path provider
        if (ValidationHelper.GetBoolean(ConfigurationManager.AppSettings["CMSUseVirtualPathProvider"], true))
        {
            VirtualPathHelper.RegisterVirtualPathProvider();
        }
    }


    public void Session_Start(object sender, EventArgs e)
    {
        if (SqlHelperClass.IsConnectionStringInitialized)
        {
            // Prepare data
            CurrentUserInfo currentUser = CMSContext.CurrentUser;
            CurrentSiteInfo currentSite = CMSContext.CurrentSite;
            if ((currentUser != null) && (currentSite != null))
            {
                Uri referrer = HttpContext.Current.Request.UrlReferrer;

                if ((referrer != null) && (currentUser.ViewMode == ViewModeEnum.LiveSite))
                {
                    if (!referrer.AbsoluteUri.StartsWith("/") && !referrer.IsLoopback && (referrer.Host.ToLower() != HttpContext.Current.Request.Url.Host))
                    {
                        // Check other site domains
                        SiteInfo rsi = SiteInfoProvider.GetRunningSiteInfo(referrer.Host);
                        if ((rsi == null) || (rsi.SiteID != currentSite.SiteID))
                        {
                            string path = UrlHelper.RemoveQuery(referrer.AbsoluteUri);

                            // Save the referrer value
                            currentUser.URLReferrer = path;

                            // Log referral
                            string ip = HttpContext.Current.Request.UserHostAddress;
                            if (AnalyticsHelper.AnalyticsEnabled(currentSite.SiteName) && !AnalyticsHelper.IsIPExcluded(currentSite.SiteName, ip) && !AnalyticsHelper.IsSearchEngineExcluded(currentSite.SiteName))
                            {
                                HitLogProvider.LogHit(HitLogProvider.URL_REFERRALS, currentSite.SiteName, null, path, 0);
                            }
                        }
                    }
                }

                // Initialize current visit status
                switch (currentUser.CurrentVisitStatus)
                {
                    case VisitorStatusEnum.Unknown:
                        // First today's visit
                        currentUser.CurrentVisitStatus = VisitorStatusEnum.FirstVisit;
                        break;

                    case VisitorStatusEnum.FirstVisit:
                    case VisitorStatusEnum.MoreVisits:
                        // More today's visits, keep the status
                        break;
                }
            }
        }
    }


    public void Application_BeginRequest(object sender, EventArgs e)
    {
        // Check if Database installation needed
        if (InstallerFunctions.InstallRedirect())
        {
            return;
        }

        // Rewrite the path to get to the proper page
        switch (URLRewriter.RewriteUrl())
        {
            case URLRewritingResultEnum.PathRewritten:
                // Apply output filter
                OutputFilter.ApplyOutputFilter = true;
                //Response.Filter = new CMS.CMSOutputFilter.OutputFilter(Response.Filter);
                break;

            case URLRewritingResultEnum.PageNotFound:
                // Page not found - Log hit
                string url = URLRewriter.CurrentURL;
                int queryIndex = url.IndexOf("?");
                if (queryIndex >= 0)
                {
                    url = url.Substring(0, queryIndex);
                }

                string siteName = CMSContext.CurrentSiteName;
                string ip = HttpContext.Current.Request.UserHostAddress;
                if (AnalyticsHelper.AnalyticsEnabled(siteName) && !AnalyticsHelper.IsIPExcluded(siteName, ip) && !AnalyticsHelper.IsSearchEngineExcluded(siteName))
                {
                    HitLogProvider.LogHit(HitLogProvider.PAGE_NOT_FOUND, siteName, CMSContext.CurrentUser.PreferredCultureCode, url, 0);
                }
                break;
        }

        // Run scheduler if not running yet and automatic scheduler set
        SiteInfo currentSite = CMSContext.CurrentSite;
        if (currentSite != null)
        {
            if (SchedulingHelper.UseAutomaticScheduler)
            {
                if (InstallerFunctions.ConnectionStringIsSet() && !SchedulingTimer.TimerExists(currentSite.SiteName))
                {
                    SchedulingTimer.CreateTimer(currentSite.SiteName);
                }
            }

            // Log user visit
            CurrentUserInfo currentUser = CMSContext.CurrentUser;
            if (currentUser != null)
            {
                switch (currentUser.CurrentVisitStatus)
                {
                    case VisitorStatusEnum.FirstVisit:

                        currentUser.CurrentVisitStatus = VisitorStatusEnum.MoreVisits;
                        // Check overall visitor status
                        switch (currentUser.VisitorStatus)
                        {
                            case VisitorStatusEnum.Unknown:
                                {
                                    // First visit
                                    currentUser.VisitorStatus = VisitorStatusEnum.FirstVisit;
                                    string ip = HttpContext.Current.Request.UserHostAddress;
                                    if (AnalyticsHelper.AnalyticsEnabled(currentSite.SiteName) && !AnalyticsHelper.IsIPExcluded(currentSite.SiteName, ip) && !AnalyticsHelper.IsSearchEngineExcluded(currentSite.SiteName))
                                    {
                                        HitLogProvider.LogHit(HitLogProvider.VISITORS_FIRST, currentSite.SiteName, null, currentSite.SiteName, 0);
                                    }
                                    break;
                                }

                            case VisitorStatusEnum.FirstVisit:
                                {
                                    // Next user visit
                                    currentUser.VisitorStatus = VisitorStatusEnum.MoreVisits;
                                    string ip = HttpContext.Current.Request.UserHostAddress;
                                    if (AnalyticsHelper.AnalyticsEnabled(currentSite.SiteName) && !AnalyticsHelper.IsIPExcluded(currentSite.SiteName, ip) && !AnalyticsHelper.IsSearchEngineExcluded(currentSite.SiteName))
                                    {
                                        HitLogProvider.LogHit(HitLogProvider.VISITORS_RETURNING, currentSite.SiteName, null, currentSite.SiteName, 0);
                                    }
                                    break;
                                }

                            case VisitorStatusEnum.MoreVisits:
                                // Do nothing, already visited
                                break;
                        }
                        break;
                }
            }
        }
    }


    protected void Application_EndRequest(Object sender, EventArgs e)
    {
        // If not using automatic scheduler, run scheduler from the request
        if (InstallerFunctions.ConnectionStringIsSet())
        {
            if (!SchedulingHelper.UseAutomaticScheduler)
            {
                SiteInfo currentSite = CMSContext.CurrentSite;
                if (currentSite != null)
                {
                    // If scheduler run request acquired, run the actions
                    if (SchedulingTimer.RequestRun(currentSite.SiteName))
                    {
                        SchedulingExecutor.ExecuteScheduledTasks(currentSite.SiteName, ConfigurationManager.AppSettings["CMSWebFarmServerName"]);
                    }
                }
            }

            // Additional tasks within first request end
            if (firstEndRequestAfterStart)
            {
                firstEndRequestAfterStart = false;

                // Process synchronization tasks
                WebSyncHelper.ProcessMyTasks();

                // Send all the remaining queued e-mails
                string domain = DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "");
                if (domain != "")
                {
                    if (LicenseHelper.CheckFeature(UrlHelper.GetCurrentDomain(), FeatureEnum.Newsletters))
                    {
                        EmailQueueManager.SendAllEmails(false);
                    }
                }
            }
        }
    }


    public void Application_AcquireRequestState(object sender, EventArgs e)
    {
        // Set the UI culture
        if ((HttpContext.Current != null) && (HttpContext.Current.Session != null) && (InstallerFunctions.ConnectionStringIsSet()))
        {
            string relativePath = HttpContext.Current.Request.AppRelativeCurrentExecutionFilePath.ToLower();
            relativePath = relativePath.Remove(0, 1); //'~/path' -> '/path'

            string customExcludedPaths = "";
            SiteInfo currentSite = CMSContext.CurrentSite;
            // Get Custom excluded Urls path
            if (currentSite != null)
            {
                customExcludedPaths = SettingsKeyProvider.GetStringValue(currentSite.SiteName + ".CMSExcludedURLs");
            }

            if (!UrlHelper.IsExcluded(relativePath, customExcludedPaths))
            {
                if ((!HttpContext.Current.Request.Url.ToString().ToLower().Contains("/cmspages/getcss")) &&
                    (!HttpContext.Current.Request.Url.ToString().ToLower().Contains("/cmspages/getfile")))
                {
                    // Check SSL Require
                    URLRewriter.RequestSecurePage(CMSContext.CurrentPageInfo, true);

                    // Check secured areas
                    URLRewriter.CheckSecuredAreas(CMSContext.CurrentPageInfo, true);
                }
            }
            else
            {
                string aliasPath = ValidationHelper.GetString(Request.QueryString["aliaspath"], "");
                // Check default alias path
                if ((aliasPath == "/") && (CMSContext.CurrentUser.ViewMode == ViewModeEnum.LiveSite))
                {
                    string defaultAliasPath = SettingsKeyProvider.GetStringValue(currentSite.SiteName + ".CMSDefaultAliasPath");
                    if ((defaultAliasPath != "") && (defaultAliasPath.ToLower() != aliasPath.ToLower()))
                    {
                        Response.Redirect(CMSContext.GetUrl(defaultAliasPath));
                    }
                }
            }
        }
    }


    public void Application_AuthenticateRequest(object sender, EventArgs e)
    {
    }


    public void Application_AuthorizeRequest(object sender, EventArgs e)
    {
    }


    public void Application_Error(object sender, EventArgs e)
    {
        if (HttpContext.Current != null)
        {
            // Run custom exception event handler
            if (EventHelper.UseCustomHandlers())
            {
                EventHelper.GetExceptionHandler().OnException(HttpContext.Current.Server.GetLastError());
            }

            Exception ex = HttpContext.Current.Server.GetLastError();

            // Write error to Event log
            try
            {
                EventLogProvider eProvider = new EventLogProvider();
                eProvider.LogEvent("E", DateTime.Now, "Application_Error", "EXCEPTION", CMSContext.CurrentUser != null ? CMSContext.CurrentUser.UserID : 0, CMSContext.CurrentUser != null ? CMSContext.CurrentUser.UserName : "", CMSContext.CurrentDocument != null ? CMSContext.CurrentDocument.NodeID : 0, CMSContext.CurrentDocument != null ? CMSContext.CurrentDocument.DocumentName : "", CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), "EXCEPTION MESSAGE: " + ex.Message + "; STACK TRACE: " + ex.StackTrace, CMSContext.CurrentSite != null ? CMSContext.CurrentSite.SiteID : 0, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
            }
            catch
            {
                // can't write to log, do not process any code
            }
            // Send e-mail
            try
            {
                Configuration config = WebConfigurationManager.OpenWebConfiguration("~");
                // if key exists
                if ((config.AppSettings.Settings["CMSSendErrorsToEmail"] != null) && (config.AppSettings.Settings["CMSSendErrorsFromEmail"] != null))
                {
                    // if values are not empty
                    if ((ValidationHelper.GetString(config.AppSettings.Settings["CMSSendErrorsFromEmail"].Value, "") != "") && (ValidationHelper.GetString(config.AppSettings.Settings["CMSSendErrorsToEmail"].Value, "") != ""))
                    {
                        EmailMessage msg = new EmailMessage();
                        msg.From = config.AppSettings.Settings["CMSSendErrorsFromEmail"].Value;
                        msg.Recipients = config.AppSettings.Settings["CMSSendErrorsToEmail"].Value;
                        msg.Subject = "Web site exception:" + CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri();
                        msg.Body = "Error message: " + ex.Message + "\n Stack trace: " + ex.StackTrace + "\n URL: " + CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri() + "\n Date and time: " + DateTime.Now.ToString() + "\n IP adress: " + CMS.GlobalHelper.HTTPHelper.GetUserHostAddress() + "\n User name: " + (CMSContext.CurrentUser != null ? CMSContext.CurrentUser.UserName : "");
                        EmailSender.SendEmail(msg);
                    }
                }
            }
            catch
            {
                // can't send e-mail, do not process any code
            }
        }
    }


    public void Session_End(object sender, EventArgs e)
    {
    }


    public void Application_End(object sender, EventArgs e)
    {
        try
        {
            EventLogProvider eventLog = new EventLogProvider();
            System.Web.HttpRuntime runtime = (System.Web.HttpRuntime)typeof(System.Web.HttpRuntime).InvokeMember("_theRuntime", BindingFlags.NonPublic | BindingFlags.Static | BindingFlags.GetField, null, null, null);
            if (runtime != null)
            {
                string shutDownMessage = Convert.ToString(runtime.GetType().InvokeMember("_shutDownMessage", BindingFlags.NonPublic | BindingFlags.Instance | BindingFlags.GetField, null, runtime, null));
                string shutDownStack = Convert.ToString(runtime.GetType().InvokeMember("_shutDownStack", BindingFlags.NonPublic | BindingFlags.Instance | BindingFlags.GetField, null, runtime, null));
                StackTrace stack = new StackTrace();
                string callStack = stack.ToString();
                string logMessage = "Message: " + shutDownMessage + "<br/>Shutdown stack: " + shutDownStack + "<br/>Call stack: " + callStack;
                eventLog.LogEvent("E", DateTime.Now, "Application_End", "EXCEPTION", 0, HTTPHelper.GetUserName(), 0, "", "", logMessage, 0, "");
            }
            else
            {
                eventLog.LogEvent("E", DateTime.Now, "Application_End", "EXCEPTION", 0, HTTPHelper.GetUserName(), 0, "", "", "", 0, "");
            }
        }
        catch
        {
        }
    }


    /// <summary>
    /// Custom cache parameters processing
    /// </summary>
    public override string GetVaryByCustomString(HttpContext context, string custom)
    {
        if ((HttpContext.Current == null) || (context == null))
        {
            return "";
        }
        // Do not cache on postback
        if (HttpContext.Current.Request.HttpMethod.ToLower() == "post")
        {
            Response.Cache.SetNoStore();
            return Guid.NewGuid().ToString();
        }

        PageInfo currentPage = CMSContext.CurrentPageInfo;
        string siteName = CMSContext.CurrentSiteName;
        CurrentUserInfo currentUser = CMSContext.CurrentUser; // Get current user / (WARNING: No Session - user is always public, only to retrieve cookie based properties)
        string result = null;
        if (currentPage != null)
        {
            // Cache control
            int cacheMinutes = currentPage.NodeCacheMinutes;
            if (cacheMinutes < 0)
            {
                cacheMinutes = SettingsKeyProvider.GetIntValue(siteName + ".CMSCacheMinutes");
            }
            if (cacheMinutes <= 0)
            {
                Response.Cache.SetNoStore();
                return Guid.NewGuid().ToString();
            }

            string[] customs = custom.Split(';');
            result = "cached";
            foreach (string cust in customs)
            {
                switch (cust.ToLower())
                {
                    case "viewmode":
                        if (currentUser.ViewMode != ViewModeEnum.LiveSite)
                        {
                            Response.Cache.SetNoStore();
                            return Guid.NewGuid().ToString();
                        }
                        break;

                    case "username":
                        result += "|username=" + HTTPHelper.GetUserName();
                        break;

                    case "sitename":
                        result += "|sitename=" + siteName;
                        break;

                    case "domain":
                        result += "|domain=" + UrlHelper.GetFullDomain();
                        break;

                    case "lang":
                        result += "|lang=" + CultureHelper.GetPreferredCulture();
                        break;
                }
            }
        }

        return result + base.GetVaryByCustomString(context, custom);
    }

}

