using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Threading;

using CMS.GlobalHelper;

public partial class AdminControls_AsyncControl : System.Web.UI.UserControl, ICallbackEventHandler
{
    private AsyncWorker mWorker = null;
    private string mCallbackResult = null;

    private string mLog = null;

    /// <summary>
    /// Gets the current log
    /// </summary>
    public string Log
    {
        get
        {
            if ((mLog == null) && (OnRequestLog != null))
            {
                OnRequestLog(this, new EventArgs());
            }

            return mLog;
        }
        set
        {
            mLog = value;
        }
    }


    /// <summary>
    /// Asynchronous worker
    /// </summary>
    public AsyncWorker Worker
    {
        get
        {
            if (mWorker == null)
            {
                string key = "AsyncWorker_" + Request.Url.AbsolutePath + "_" + this.ClientID;
                mWorker = (AsyncWorker)Session[key];
                if (mWorker == null)
                {
                    mWorker = new AsyncWorker();

                    mWorker.OnError += new EventHandler(this.RaiseError);
                    mWorker.OnFinished += new EventHandler(this.RaiseFinished);

                    Session[key] = mWorker;
                }
            }

            return mWorker;
        }
    }


    /// <summary>
    /// Runs the asynchronous action
    /// </summary>
    /// <param name="action">Action to run</param>
    public void RunAsync(AsyncAction action)
    {
        this.Worker.Stop();
        this.Worker.Reset();
        this.Worker.RunAsync(action);
    }


    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);

        this.btnFinished.Attributes.Add("style", "display: none;");
        this.btnError.Attributes.Add("style", "display: none;");
    }


    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        switch (this.Worker.Status)
        {
            // Running, cyclic check the status
            case AsyncWorkerStatusEnum.Running:
                this.ltlScript.Text += ScriptHelper.GetScript(
                    "function GetAsyncStatus() { " + this.Page.ClientScript.GetCallbackEventReference(this, null, "ReceiveAsyncStatus", null) + "; } \n" +
                    "function ReceiveAsyncStatus(rvalue, context) { \n" +
                        "values = rvalue.split('|'); \n" + 
                        "code = values[0]; SetLog(values[1]); \n" +
                        "if ( code == 'finished' ){ " + this.Page.ClientScript.GetPostBackEventReference(this.btnFinished, null) + " } \n" +
                        "else if ( code == 'running'){} \n" +
                        "else if ( code == 'error' ){ " + this.Page.ClientScript.GetPostBackEventReference(this.btnError, null) + " } \n" + 
                    "} \n" + 
                    "function SetLog(text) { document.getElementById('AsyncLog').innerHTML = text; } \n" + 
                    "setInterval('GetAsyncStatus()', 200); \n"
                    );
                break;
        }
    }


    #region "Callback handling"

    /// <summary>
    /// Raises the callback event
    /// </summary>
    /// <param name="eventArgument">Event argument</param>
    public void RaiseCallbackEvent(string eventArgument)
    {
        mCallbackResult = "";

        switch (this.Worker.Status)
        {
            case AsyncWorkerStatusEnum.Finished:
                mCallbackResult = "finished";
                break;

            case AsyncWorkerStatusEnum.Running:
                mCallbackResult = "running";
                break;

            case AsyncWorkerStatusEnum.Error:
                mCallbackResult = "error";
                break;
        }

        mCallbackResult += "|" + this.Log;
    }


    /// <summary>
    /// Returns the result of a callback
    /// </summary>
    public string GetCallbackResult()
    {
        return mCallbackResult;
    }

    #endregion


    #region "Events"

    /// <summary>
    /// Finished event handler
    /// </summary>
    public event EventHandler OnFinished;

    /// <summary>
    /// Raises the finished event
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Event args</param>
    public void RaiseFinished(object sender, EventArgs e)
    {
        if (OnFinished != null)
        {
            OnFinished(this, e);
        }
    }


    /// <summary>
    /// Error event handler
    /// </summary>
    public new event EventHandler OnError;

    /// <summary>
    /// Raises the Error event
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Event args</param>
    public void RaiseError(object sender, EventArgs e)
    {
        if (OnError != null)
        {
            OnError(this, e);
        }
    }


    /// <summary>
    /// Error event handler
    /// </summary>
    public event EventHandler OnRequestLog;


    protected void btnFinished_Click(object sender, EventArgs e)
    {
        RaiseFinished(this, e);
    }


    protected void btnError_Click(object sender, EventArgs e)
    {
        RaiseError(this, e);
    }

    #endregion
}
