using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class AdminControls_PageTitle : System.Web.UI.UserControl
{
    private string mTitleText = "";
    /// <summary>
    /// Text of title label.
    /// </summary>
    public string TitleText
    {
        get
        {
            return mTitleText;
        }
        set
        {
            mTitleText = value;
        }
    }


    private string mTitleImage = "";
    /// <summary>
    /// URL of the title image.
    /// </summary>
    public string TitleImage
    {
        get
        {
            return mTitleImage;
        }
        set
        {
            mTitleImage = value;
        }
    }


    private string[,] mBreadcrumbs = null;
    /// <summary>
    /// 3-dimensional array of breadcrumbs. (0, 0) contains the caption, (0, 1) contains URL, (0, 2) contains target.
    /// </summary>
    public string[,] Breadcrumbs
    {
        get
        {
            return mBreadcrumbs;
        }
        set
        {
            mBreadcrumbs = value;
        }
    }


    private string mSeparatorText = "";
    /// <summary>
    /// Text of the BreadCrumbs separator.
    /// </summary>
    public string SeparatorText
    {
        get
        {
            return mSeparatorText;
        }
        set
        {
            mSeparatorText = value;
        }
    }


    private string mHelpTopicName = "";
    /// <summary>
    /// Not implemented yet.
    /// </summary>
    public string HelpTopicName
    {
        get
        {
            return mHelpTopicName;
        }
        set
        {
            mHelpTopicName = value;
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
      
    }

    protected void Page_PreRender(object sender, EventArgs e)
    { 

      // Create the breadcrumbs
        if (Breadcrumbs != null)
        {
            this.pnlBreadCrumbs.Visible = true;
            // Generate the breadcrumbs controls
            for (int i = 0; i <= Breadcrumbs.GetUpperBound(0); i++)
            {
                // Add separator
                if ( i > 0 )
                {
                    Label sepLabel = new Label();
                    if ((this.SeparatorText != null) && (this.SeparatorText != ""))
                    {
                        sepLabel.Text = this.SeparatorText;
                    }
                    else
                    {
                        sepLabel.Text = "&nbsp;";
                    }
                    sepLabel.SkinID = "TitleBreadCrumbSeparator";
                    plcBreadcrumbs.Controls.Add(sepLabel);
                }
                // Make link if URL specified
                if ((Breadcrumbs[i, 1] != null) && (Breadcrumbs[i, 1] != "") && (i != Breadcrumbs.GetUpperBound(0)))
                {
                    HyperLink newLink = new HyperLink();
                    newLink.Text = Breadcrumbs[i, 0];
                    newLink.NavigateUrl = Breadcrumbs[i, 1];
                    newLink.Target = Breadcrumbs[i, 2];
                    if (i != Breadcrumbs.GetUpperBound(0))
                    {
                        newLink.SkinID = "TitleBreadCrumb";
                    }
                    else
                    {
                        newLink.SkinID = "TitleBreadCrumbLast";
                    }
                    plcBreadcrumbs.Controls.Add(newLink);
                }
                else // Make label if last item or URL not specified
                {
                    Label newLabel = new Label();
                    newLabel.Text = Breadcrumbs[i, 0];
                    if (i != Breadcrumbs.GetUpperBound(0))
                    {
                        newLabel.SkinID = "TitleBreadCrumb";
                    }
                    else
                    {
                        newLabel.SkinID = "TitleBreadCrumbLast";
                    }
                    plcBreadcrumbs.Controls.Add(newLabel);
                }
            }
        }

        // Set the title text if set
        if ((this.TitleText != null) && (this.TitleText != ""))
        {
            this.pnlTitle.Visible = true;
            lblTitle.Text = TitleText;
        }
        else
        {
            this.pnlTitle.Visible = false;
        }

        if ((this.TitleImage != null) && (this.TitleImage != ""))
        {
            this.imgTitle.Visible = true;
            this.imgTitle.ImageUrl = this.TitleImage;
        }
        else
        {
            this.imgTitle.Visible = false;
        }
    }

    /// <summary>
    /// Creates the breadcrumbs array from the given parameters
    /// </summary>
    /// <param name="namepath"></param>
    /// <param name="urlpath"></param>
    /// <param name="target"></param>
    public void CreateStaticBreadCrumbs(string namepath)
    {
        if ((namepath == null) || (namepath.Trim().Trim('/') == ""))
        {
            this.Breadcrumbs = null;
            return;
        }
        string[] names = namepath.Trim('/').Split('/');
        string[,] bc = new string[names.Length, 3];
        //
        int index = 0;
        foreach (string name in names)
        {
            bc[index, 0] = name;
            bc[index, 1] = "";
            bc[index, 2] = "";
            index++;
        }
        this.Breadcrumbs = bc;
    }

}
