using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Caching;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using NetSpell.SpellChecker;
using NetSpell.SpellChecker.Dictionary;

using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class Check : Page
{
    private bool mDictExists = false;
    private Spelling SpellChecker;
    private WordDictionary WordDictionary;
    private string wordCounterString = ResHelper.GetString("SpellCheck.wordCounterString");

    protected void Page_Load(object sender, EventArgs e)
    {
        // Control initialization
        IgnoreButton.Text = ResHelper.GetString("SpellCheck.IgnoreButton");
        IgnoreAllButton.Text = ResHelper.GetString("SpellCheck.IgnoreAllButton");
        AddButton.Text = ResHelper.GetString("SpellCheck.AddButton");
        ReplaceButton.Text = ResHelper.GetString("SpellCheck.ReplaceButton");
        ReplaceAllButton.Text = ResHelper.GetString("SpellCheck.ReplaceAllButton");
        StatusText.Text = ResHelper.GetString("SpellCheck.StatusText");

        lblNotInDictionary.Text = ResHelper.GetString("SpellCheck.lblNotInDictionary");
        lblChangeTo.Text = ResHelper.GetString("SpellCheck.lblChangeTo");
        lblSuggestions.Text = ResHelper.GetString("SpellCheck.lblSuggestions");
        btnCancel.Text = ResHelper.GetString("SpellCheck.btnCancel");
        
        

        this.titleElem.TitleText = ResHelper.GetString("SpellCheck.Title");
        this.titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSAdminControls/SpellChecker/spellcheck.gif";

        // if modal frame, quit
        if (this.ModalFrame.Visible)
            return;

        if (mDictExists)
        {

            // add client side events
            this.Suggestions.Attributes.Add("onChange", "javascript: changeWord(this);");
            this.SpellingBody.Attributes.Add("onLoad", "javascript: initialize();");

            // load spell checker settings
            this.LoadValues();
            switch (this.SpellMode.Value)
            {
                case "start":
                    this.EnableButtons();
                    this.SpellChecker.SpellCheck();
                    break;

                case "suggest":
                    this.EnableButtons();
                    break;

                case "load":
                case "end":
                default:
                    this.DisableButtons();
                    break;
            }
        }
    }


    protected void Page_Init(object sender, EventArgs e)
    {
        // show iframe for modal support
        if (Request.Params["Modal"] != null)
        {
            this.ModalFrame.Visible = true;
            this.SuggestionForm.Visible = false;
            this.pnlTitle.Visible = false;
            return;
        }

        string cacheName = "WordDictionary|" + CMSContext.CurrentUser.PreferredCultureCode;
        // get dictionary from cache
        this.WordDictionary = (WordDictionary)HttpContext.Current.Cache[cacheName];
        if (this.WordDictionary == null)
        {
            // if not in cache, create new
            this.WordDictionary = new NetSpell.SpellChecker.Dictionary.WordDictionary();
            this.WordDictionary.EnableUserFile = false;

            //getting folder for dictionaries
            string folderName = "~/CMSAdminControls/SpellChecker/dic";
            folderName = this.MapPath(folderName);

            string culture = CMSContext.CurrentUser.PreferredCultureCode;
            string dictFile = culture + ".dic";
            string dictPath = Path.Combine(folderName, dictFile);
            if (!File.Exists(dictPath))
            {
                // Get default culture
                string defaultCulture = ValidationHelper.GetString(ConfigurationManager.AppSettings["CMSDefaultSpellCheckerCulture"], "");
                if (defaultCulture != "")
                {
                    culture = defaultCulture;
                    dictFile = defaultCulture + ".dic";
                    dictPath = Path.Combine(folderName, dictFile);
                }
            }

            if (!File.Exists(dictPath))
            {
                this.lblError.Text = string.Format(ResHelper.GetString("SpellCheck.DictionaryNotExists"), culture);
                this.lblError.Visible = true;
                return;
            }

            mDictExists = true;
            this.WordDictionary.DictionaryFolder = folderName;
            this.WordDictionary.DictionaryFile = dictFile;


            //load and initialize the dictionary
            this.WordDictionary.Initialize();

            // Store the Dictionary in cache
            HttpContext.Current.Cache.Insert(cacheName, this.WordDictionary, new CacheDependency(Path.Combine(folderName, this.WordDictionary.DictionaryFile)));
        }
        else
        {
            mDictExists = true;
        }

        // create spell checker
        this.SpellChecker = new NetSpell.SpellChecker.Spelling();
        this.SpellChecker.ShowDialog = false;
        this.SpellChecker.Dictionary = this.WordDictionary;

        // adding events
        this.SpellChecker.MisspelledWord += new NetSpell.SpellChecker.Spelling.MisspelledWordEventHandler(this.SpellChecker_MisspelledWord);
        this.SpellChecker.EndOfText += new NetSpell.SpellChecker.Spelling.EndOfTextEventHandler(this.SpellChecker_EndOfText);
        this.SpellChecker.DoubledWord += new NetSpell.SpellChecker.Spelling.DoubledWordEventHandler(this.SpellChecker_DoubledWord);
    }

    protected void SpellChecker_DoubledWord(object sender, NetSpell.SpellChecker.SpellingEventArgs e)
    {
        this.SaveValues();
        this.CurrentWord.Text = this.SpellChecker.CurrentWord;
        this.Suggestions.Items.Clear();
        this.ReplacementWord.Text = string.Empty;
        this.SpellMode.Value = "suggest";
        this.StatusText.Text = string.Format(wordCounterString, this.SpellChecker.WordIndex + 1, this.SpellChecker.WordCount);
    }

    protected void SpellChecker_EndOfText(object sender, System.EventArgs e)
    {
        this.SaveValues();
        this.SpellMode.Value = "end";
        this.DisableButtons();
        this.StatusText.Text = string.Format(wordCounterString, this.SpellChecker.WordIndex + 1, this.SpellChecker.WordCount);
    }

    protected void SpellChecker_MisspelledWord(object sender, NetSpell.SpellChecker.SpellingEventArgs e)
    {
        this.SaveValues();
        this.CurrentWord.Text = this.SpellChecker.CurrentWord;
        this.SpellChecker.Suggest();
        this.Suggestions.DataSource = this.SpellChecker.Suggestions;
        this.Suggestions.DataBind();
        this.ReplacementWord.Text = string.Empty;
        this.SpellMode.Value = "suggest";
        this.StatusText.Text = string.Format(wordCounterString, this.SpellChecker.WordIndex + 1, this.SpellChecker.WordCount);
    }

    protected void EnableButtons()
    {
        this.IgnoreButton.Enabled = true;
        this.IgnoreAllButton.Enabled = true;
        this.AddButton.Enabled = true;
        this.ReplaceButton.Enabled = true;
        this.ReplaceAllButton.Enabled = true;
        this.ReplacementWord.Enabled = true;
        this.Suggestions.Enabled = true;
    }

    protected void DisableButtons()
    {
        this.IgnoreButton.Enabled = false;
        this.IgnoreAllButton.Enabled = false;
        this.AddButton.Enabled = false;
        this.ReplaceButton.Enabled = false;
        this.ReplaceAllButton.Enabled = false;
        this.ReplacementWord.Enabled = false;
        this.Suggestions.Enabled = false;
    }

    protected void SaveValues()
    {
        this.CurrentText.Value = this.SpellChecker.Text;
        this.WordIndex.Value = this.SpellChecker.WordIndex.ToString();

        // save ignore words
        string[] ignore = (string[])this.SpellChecker.IgnoreList.ToArray(typeof(string));

        this.IgnoreList.Value = String.Join("|", ignore);

        // save replace words
        ArrayList tempArray = new ArrayList(this.SpellChecker.ReplaceList.Keys);
        string[] replaceKey = (string[])tempArray.ToArray(typeof(string));

        this.ReplaceKeyList.Value = String.Join("|", replaceKey);
        tempArray = new ArrayList(this.SpellChecker.ReplaceList.Values);

        string[] replaceValue = (string[])tempArray.ToArray(typeof(string));

        this.ReplaceValueList.Value = String.Join("|", replaceValue);

        // saving user words
        tempArray = new ArrayList(this.SpellChecker.Dictionary.UserWords.Keys);

        string[] userWords = (string[])tempArray.ToArray(typeof(string));

        Response.Cookies["UserWords"].Value = String.Join("|", userWords); ;
        Response.Cookies["UserWords"].Path = "/";
        Response.Cookies["UserWords"].Expires = DateTime.Now.AddMonths(1);
    }

    protected void LoadValues()
    {
        if (this.CurrentText.Value.Length > 0)
            this.SpellChecker.Text = Server.HtmlDecode(this.CurrentText.Value);

        if (this.WordIndex.Value.Length > 0)
            this.SpellChecker.WordIndex = int.Parse(this.WordIndex.Value);

        // restore ignore list
        if (this.IgnoreList.Value.Length > 0)
        {
            this.SpellChecker.IgnoreList.Clear();
            this.SpellChecker.IgnoreList.AddRange(this.IgnoreList.Value.Split('|'));
        }

        // restore replace list
        if (this.ReplaceKeyList.Value.Length > 0 && this.ReplaceValueList.Value.Length > 0)
        {
            string[] replaceKeys = this.ReplaceKeyList.Value.Split('|');
            string[] replaceValues = this.ReplaceValueList.Value.Split('|');

            this.SpellChecker.ReplaceList.Clear();
            if (replaceKeys.Length == replaceValues.Length)
            {
                for (int i = 0; i < replaceKeys.Length; i++)
                {
                    if (replaceKeys[i].Length > 0)
                        this.SpellChecker.ReplaceList.Add(replaceKeys[i], replaceValues[i]);
                }
            }
        }

        // restore user words
        this.SpellChecker.Dictionary.UserWords.Clear();
        if (Request.Cookies["UserWords"] != null)
        {
            string[] userWords = Request.Cookies["UserWords"].Value.Split('|');

            for (int i = 0; i < userWords.Length; i++)
            {
                if (userWords[i].Length > 0)
                    this.SpellChecker.Dictionary.UserWords.Add(userWords[i], userWords[i]);
            }
        }
    }

    protected void IgnoreButton_Click(object sender, EventArgs e)
    {
        this.SpellChecker.IgnoreWord();
        this.SpellChecker.SpellCheck();
    }

    protected void IgnoreAllButton_Click(object sender, EventArgs e)
    {
        this.SpellChecker.IgnoreAllWord();
        this.SpellChecker.SpellCheck();
    }

    protected void AddButton_Click(object sender, EventArgs e)
    {
        this.SpellChecker.Dictionary.Add(this.SpellChecker.CurrentWord);
        this.SpellChecker.SpellCheck();
    }

    protected void ReplaceButton_Click(object sender, EventArgs e)
    {
        this.SpellChecker.ReplaceWord(this.ReplacementWord.Text);
        this.CurrentText.Value = this.SpellChecker.Text;
        this.SpellChecker.SpellCheck();
    }

    protected void ReplaceAllButton_Click(object sender, EventArgs e)
    {
        this.SpellChecker.ReplaceAllWord(this.ReplacementWord.Text);
        this.CurrentText.Value = this.SpellChecker.Text;
        this.SpellChecker.SpellCheck();
    }
}
