using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.GlobalHelper;
using CMS.Controls;
using CMS.SettingsProvider;

public partial class CMSAdminControls_UserContributions_ContributionList : System.Web.UI.UserControl
{
    CurrentUserInfo currentUser = CMSContext.CurrentUser;
    CurrentSiteInfo currentSite = CMSContext.CurrentSite;

    private bool mAllowInsert = true;
    private bool mAllowDelete = true;
    private bool mAllowEdit = true;
    private string mNewItemPageTemplate = "";
    private string mAllowedChildClasses = "";
    private bool mCheckPermissions = false;
    private UserContributionAllowUserEnum mAllowUsers = UserContributionAllowUserEnum.DocumentOwner;
    private bool mStopProcessing = false;
    private int mParentNodeId = 0;


    /// <summary>
    /// Data properties variable
    /// </summary>
    public CMSDataProperties mProperties = new CMSDataProperties();


    #region "Document properties"

    /// <summary>
    /// Class names
    /// </summary>
    public string ClassNames
    {
        get
        {
            return this.mProperties.ClassNames;
        }
        set
        {
            this.mProperties.ClassNames = value;
        }
    }


    /// <summary>
    /// Combine with default culture
    /// </summary>
    public bool CombineWithDefaultCulture
    {
        get
        {
            return this.mProperties.CombineWithDefaultCulture;
        }
        set
        {
            this.mProperties.CombineWithDefaultCulture = value;
        }
    }


    /// <summary>
    /// Culture code
    /// </summary>
    public string CultureCode
    {
        get
        {
            return this.mProperties.CultureCode;
        }
        set
        {
            this.mProperties.CultureCode = value;
        }
    }


    /// <summary>
    /// Maximal relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get
        {
            return this.mProperties.MaxRelativeLevel;
        }
        set
        {
            this.mProperties.MaxRelativeLevel = value;
        }
    }


    /// <summary>
    /// Order by clause
    /// </summary>
    public string OrderBy
    {
        get
        {
            return this.mProperties.OrderBy;
        }
        set
        {
            this.mProperties.OrderBy = value;
        }
    }


    /// <summary>
    /// Nodes path 
    /// </summary>
    public string Path
    {
        get
        {
            return this.mProperties.Path;
        }
        set
        {
            this.mProperties.Path = value;
        }
    }


    /// <summary>
    /// Select only published nodes
    /// </summary>
    public bool SelectOnlyPublished
    {
        get
        {
            return this.mProperties.SelectOnlyPublished;
        }
        set
        {
            this.mProperties.SelectOnlyPublished = value;
        }
    }


    /// <summary>
    /// Site name
    /// </summary>
    public string SiteName
    {
        get
        {
            return this.mProperties.SiteName;
        }
        set
        {
            this.mProperties.SiteName = value;
        }
    }

    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get
        {
            return this.mProperties.WhereCondition;
        }
        set
        {
            this.mProperties.WhereCondition = value;
        }
    }

    #endregion


    #region " Public properties "

    /// <summary>
    /// Indicates whether the list of documents should be displayed.
    /// </summary>
    public bool DisplayList
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["DisplayList"], true);
        }
        set
        {
            ViewState["DisplayList"] = value;
        }
    }


    /// <summary>
    /// Path for new created documents.
    /// </summary>
    public string NewDocumentPath
    {
        get
        {
            string newDocPath = ValidationHelper.GetString(ViewState["NewDocumentPath"], "");
            // If new document path is not set, use source path
            if (newDocPath.Trim() == "")
            {
                newDocPath = Path;
            }

            // Ensure correct format of the path
            if (newDocPath.EndsWith("/%"))
            {
                newDocPath = newDocPath.Remove(newDocPath.Length - 2);
            }

            if (newDocPath == "")
            {
                newDocPath = "/";
            }

            return newDocPath;
        }
        set
        {
            ViewState["NewDocumentPath"] = value;
        }
    }


    /// <summary>
    /// Indicates whether inserting new document is allowed.
    /// </summary>
    public bool AllowInsert
    {
        get
        {
            return mAllowInsert;
        }
        set
        {
            mAllowInsert = value;
        }
    }


    /// <summary>
    /// Indicates whether editing document is allowed.
    /// </summary>
    public bool AllowEdit
    {
        get
        {
            return mAllowEdit;
        }
        set
        {
            mAllowEdit = value;
        }
    }


    /// <summary>
    /// Indicates whether deleting document is allowed.
    /// </summary>
    public bool AllowDelete
    {
        get
        {
            return mAllowDelete;
        }
        set
        {
            mAllowDelete = value;
            this.editDoc.AllowDelete = value;
        }
    }


    /// <summary>
    /// Page template the new items are assigned to.
    /// </summary>
    public string NewItemPageTemplate
    {
        get
        {
            return mNewItemPageTemplate;
        }
        set
        {
            mNewItemPageTemplate = value;
        }
    }


    /// <summary>
    /// Type of the child documents that are allowed to be created.
    /// </summary>
    public string AllowedChildClasses
    {
        get
        {
            return mAllowedChildClasses;
        }
        set
        {
            mAllowedChildClasses = value;
        }
    }


    /// <summary>
    /// Indicates whether permissions should be checked.
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return mCheckPermissions;
        }
        set
        {
            mCheckPermissions = value;
        }
    }


    /// <summary>
    /// Which group of users can work with the documents
    /// </summary>
    public UserContributionAllowUserEnum AllowUsers
    {
        get
        {
            return this.mAllowUsers;
        }
        set
        {
            this.mAllowUsers = value;
        }
    }


    /// <summary> Stop processing.</summary>
    public bool StopProcessing
    {
        get
        {
            return mStopProcessing;
        }
        set
        {
            mStopProcessing = value;
        }
    }



    #endregion


    #region " Private properties"


    /// <summary>
    /// Parent node id
    /// </summary>
    private int ParentNodeId
    {
        get
        {
            if (mParentNodeId == 0)
            {
                mParentNodeId = GetParentNodeId();
            }
            return mParentNodeId;
        }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {
        this.mProperties.ParentControl = this;

        ReloadData();

        // Control initialization
        gridDocs.OnExternalDataBound += new OnExternalDataBoundEventHandler(gridDocs_OnExternalDataBound);
        gridDocs.OnAction += new OnActionEventHandler(gridDocs_OnAction);
        gridDocs.ImageDirectoryPath = "~/App_Themes/Default/Images/CMSAdminControls/UniGrid/";
        btnNewDoc.Text = ResHelper.GetString("ContributionList.lnkNewDoc");
        btnList.Text = ResHelper.GetString("ContributionList.lnkDocs");

        // Hide/Show edit document form
        pnlEdit.Visible = (editDoc.NodeID > 0);
    }


    private void ReloadData()
    {
        if ((this.AllowUsers == UserContributionAllowUserEnum.Authenticated) && !currentUser.IsAuthenticated())
        {
            // Not authenticated, do not display anything
            pnlList.Visible = false;
            pnlEdit.Visible = false;
        }
        else
        {
            // If the list of documents should be displayed
            if (this.DisplayList)
            {
                gridDocs.Visible = true;

                // Get all documents of the current user
                TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);

                // Generate additional where condition
                string classWhere = null;
                if (this.ClassNames != "")
                {
                    string[] names = this.ClassNames.Split(';');
                    foreach (string name in names)
                    {
                        if (name != "")
                        {
                            if (classWhere != null)
                            {
                                classWhere += ", ";
                            }
                        }
                        classWhere += "'" + name.Replace("'", "''") + "'";
                    }
                    if (classWhere != null)
                    {
                        classWhere = "ClassName IN (" + classWhere + ")";
                    }
                }

                string where = SqlHelperClass.AddWhereCondition(this.WhereCondition, classWhere);

                // Add user condition
                if (this.AllowUsers == UserContributionAllowUserEnum.DocumentOwner)
                {
                    where = SqlHelperClass.AddWhereCondition(where, "NodeOwner = " + currentUser.UserID);
                }

                // Get the documents
                DataSet ds = DocumentHelper.GetDocuments(SiteName, Path, CultureCode, CombineWithDefaultCulture, null, where, OrderBy, MaxRelativeLevel, SelectOnlyPublished, tree);
                if (this.CheckPermissions)
                {
                    ds = TreeSecurityProvider.FilterDataSetByPermissions(ds, NodePermissionsEnum.Read, currentUser);
                }

                gridDocs.DataSource = ds;
                gridDocs.OrderBy = this.OrderBy;

            }
            else
            {
                // Hide document list only
                gridDocs.Visible = false;
            }

            bool isAuthorizedToCreateDoc = !this.CheckPermissions || currentUser.IsAuthorizedToCreateNewDocument(this.ParentNodeId, null);

            // Enable/disable inserting new document
            btnNewDoc.Visible = (isAuthorizedToCreateDoc && this.AllowInsert);
        }
    }


    protected void btnNewDoc_Click(object sender, EventArgs e)
    {
        editDoc.AllowDelete = this.AllowDelete;
        editDoc.AllowedChildClasses = this.AllowedChildClasses;
        editDoc.NewItemPageTemplate = this.NewItemPageTemplate;
        editDoc.CheckPermissions = this.CheckPermissions;
        editDoc.Action = "new";
        // Set parent nodeId
        editDoc.NodeID = this.ParentNodeId;
        editDoc.ClassID = 0;
        editDoc.ReloadData();

        pnlEdit.Visible = true;
        pnlList.Visible = false;
    }


    /// <summary>
    /// Get parent node ID
    /// </summary>
    /// <returns></returns>
    private int GetParentNodeId()
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(SiteName, NewDocumentPath, CultureCode);
        if (node != null)
        {
            return node.NodeID;
        }
        return 0;
    }


    protected void btnList_Click(object sender, EventArgs e)
    {
        pnlList.Visible = true;
        pnlEdit.Visible = false;
        editDoc.NodeID = 0;
    }


    void gridDocs_OnAction(string actionName, object actionArgument)
    {

        TreeProvider tree = null;
        CMS.TreeEngine.TreeNode node = null;

        switch (actionName.ToLower())
        {
            case "edit":
                editDoc.NodeID = ValidationHelper.GetInteger(actionArgument, 0);
                editDoc.Action = "edit";
                pnlEdit.Visible = true;
                pnlList.Visible = false;
                editDoc.ReloadData();

                break;

            case "delete":

                tree = new TreeProvider(CMSContext.CurrentUser);

                // Delete specified node
                int documentId = ValidationHelper.GetInteger(actionArgument, 0);
                node = DocumentHelper.GetDocument(documentId, tree);
                if (node != null)
                {
                    DocumentHelper.DeleteDocument(node, tree, false, false);
                    ReloadData();
                }
                break;

        }
    }


    object gridDocs_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        switch (sourceName.ToLower())
        {
            // Column 'DocumentWorkflowStepID'
            case "documentworkflowstepid":
                int stepId = ValidationHelper.GetInteger(parameter, 0);
                if (stepId > 0)
                {
                    // Get workflow step display name
                    WorkflowStepInfo wsi = WorkflowInfoProvider.GetWorkflowStepInfo(stepId);
                    if (wsi != null)
                    {
                        return wsi.StepDisplayName;
                    }
                }
                break;

            // Column 'Published'
            case "published":
                bool published = ValidationHelper.GetBoolean(parameter, true);
                return (published ? ResHelper.GetString("General.Yes") : ResHelper.GetString("General.No"));

            // Action 'edit'
            case "edit":
                ((Control)sender).Visible = this.AllowEdit;
                break;

            // Action 'delete'
            case "delete":
                ((Control)sender).Visible = this.AllowDelete;
                break;
        }

        return parameter;
    }
}
