using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.FormEngine;
using CMS.WorkflowEngine;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.FCKeditorV2;
using CMS.ExtendedControls;
using CMS.PortalEngine;
using CMS.EventLog;
using CMS.DataEngine;

public partial class CMSAdminControls_UserContributions_EditForm : System.Web.UI.UserControl
{
    private bool confirmChanges = false;
    private CMS.TreeEngine.TreeNode node = null;
    private TreeProvider tree = null;
    private DataClassInfo ci = null;


    #region "Public properties"

    /// <summary>
    /// Returns true if new document mode
    /// </summary>
    public bool NewDocument
    {
        get
        {
            return (this.Action.ToLower() == "new");
        }
    }


    /// <summary>
    /// Returns true if new culture mode
    /// </summary>
    public bool NewCulture
    {
        get
        {
            return (this.Action.ToLower() == "newculture");
        }
    }


    /// <summary>
    /// Returns true in delete mode
    /// </summary>
    public bool Delete
    {
        get
        {
            return (this.Action.ToLower() == "delete");
        }
    }


    /// <summary>
    /// Node ID
    /// </summary>
    public int NodeID
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["NodeID"], 0);
        }
        set
        {
            ViewState["NodeID"] = value;
            this.menuElem.NodeID = value;
        }
    }


    /// <summary>
    /// Form Action (mode)
    /// </summary>
    public string Action
    {
        get
        {
            return ValidationHelper.GetString(ViewState["Action"], "");
        }
        set
        {
            ViewState["Action"] = value;
        }
    }


    /// <summary>
    /// Class ID
    /// </summary>
    public int ClassID
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["ClassID"], 0);
        }
        set
        {
            ViewState["ClassID"] = value;
        }
    }


    /// <summary>
    /// Template ID
    /// </summary>
    public int TemplateID
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["TemplateID"], 0);
        }
        set
        {
            ViewState["TemplateID"] = value;
        }
    }


    /// <summary>
    /// Owner ID
    /// </summary>
    public int OwnerID
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["OwnerID"], 0);
        }
        set
        {
            ViewState["OwnerID"] = value;
        }
    }


    /// <summary>
    /// New item page template code name
    /// </summary>
    public string NewItemPageTemplate
    {
        get
        {
            return ValidationHelper.GetString(ViewState["NewItemPageTemplate"], "");
        }
        set
        {
            ViewState["NewItemPageTemplate"] = value;

            // Get template and set template ID
            PageTemplateInfo pti = PageTemplateInfoProvider.GetPageTemplateInfo(value);
            if (pti != null)
            {
                this.TemplateID = pti.PageTemplateId;
            }
        }
    }


    /// <summary>
    /// Returns true if the changes should be saved
    /// </summary>
    public bool SaveChanges
    {
        get
        {
            return ValidationHelper.GetBoolean(HttpContext.Current.Request.Params["saveChanges"], false);
        }
    }


    /// <summary>
    /// List of allowed child classes separated by semicolon
    /// </summary>
    public string AllowedChildClasses
    {
        get
        {
            return ValidationHelper.GetString(ViewState["AllowedChildClasses"], "");
        }
        set
        {
            ViewState["AllowedChildClasses"] = value;
        }
    }


    /// <summary>
    /// Document ID to use for default data of new culture version
    /// </summary>
    public int CopyDefaultDataFromDocumentID
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["CopyDefaultDataFromDocumentID"], 0);
        }
        set
        {
            ViewState["CopyDefaultDataFromDocumentID"] = value;
        }
    }


    /// <summary>
    /// If true, form allows deleting the document
    /// </summary>
    public bool AllowDelete
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["AllowDelete"], true);
        }
        set
        {
            ViewState["AllowDelete"] = value;
        }
    }


    /// <summary>
    /// If true, form allows deleting the document
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["CheckPermissions"], false);
        }
        set
        {
            ViewState["CheckPermissions"] = value;
            this.menuElem.CheckPermissions = value;
        }
    }


    /// <summary>
    /// Prefix of the action functions
    /// </summary>
    public string FunctionsPrefix
    {
        get
        {
            return ValidationHelper.GetString(ViewState["FunctionsPrefix"], "");
        }
        set
        {
            ViewState["FunctionsPrefix"] = value;
            this.menuElem.FunctionsPrefix = value;
        }
    }


    /// <summary>
    /// Editing form
    /// </summary>
    public CMSForm CMSForm
    {
        get
        {
            return formElem;
        }
    }

    #endregion


    #region "Methods"

    public void ReloadData()
    {
        this.titleElem.TitleImage = "";
        this.titleElem.TitleText = "";

        // Get the node
        if (NewCulture || NewDocument)
        {
            node = DocumentHelper.GetDocument(NodeID, TreeProvider.ALL_CULTURES, tree);
            if (NewCulture)
            {
                DocumentHelper.ClearWorkflowInformation(node);
            }
        }
        else
        {
            node = DocumentHelper.GetDocument(NodeID, CMSContext.CurrentUser.PreferredCultureCode, tree);
        }

        this.plcSaveChanges.Visible = confirmChanges;

        this.pnlSelectClass.Visible = false;
        this.pnlEdit.Visible = false;
        this.pnlInfo.Visible = false;
        this.pnlNewCulture.Visible = false;
        this.pnlDelete.Visible = false;

        // If node found, init the form
        if (node != null)
        {
            if (Delete)
            {
                // Delete document
                this.pnlDelete.Visible = true;

                this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitle");
                this.titleElem.TitleImage = "~/App_Themes/Default/Images/CMSDesk/Content/delete.gif";

                this.chkAllCultures.Text = ResHelper.GetString("ContentDelete.AllCultures");
                this.chkDestroy.Text = ResHelper.GetString("ContentDelete.Destroy");

                this.lblQuestion.Text = ResHelper.GetString("ContentDelete.Question");
                this.btnYes.Text = ResHelper.GetString("ContentDelete.Yes");
                this.btnNo.Text = ResHelper.GetString("ContentDelete.No");

                DataSet culturesDS = CultureInfoProvider.GetSiteCultures(CMSContext.CurrentSite.SiteName);
                if ((DataHelper.DataSourceIsEmpty(culturesDS)) || (culturesDS.Tables[0].Rows.Count <= 1))
                {
                    this.chkAllCultures.Visible = false;
                    this.chkAllCultures.Checked = true;
                }

                if (node.IsLink)
                {
                    this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitleLink") + " \"" + node.NodeName + "\"";
                    this.lblQuestion.Text = ResHelper.GetString("ContentDelete.QuestionLink");
                    this.chkAllCultures.Checked = true;
                    this.plcCheck.Visible = false;
                }
                else
                {
                    this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitle") + " \"" + node.NodeName + "\"";
                }
            }
            else
            {

                if (NewDocument)
                {
                    this.titleElem.TitleImage = "~/App_Themes/Default/Images/CMSDesk/Content/new.gif";
                    this.titleElem.TitleText = ResHelper.GetString("Content.NewTitle");
                }

                if (NewDocument && (ClassID <= 0))
                {
                    // Select document type
                    this.pnlSelectClass.Visible = true;

                    // Get the allowed child classes
                    DataSet ds = DataClassInfoProvider.GetAllowedChildClasses(ValidationHelper.GetInteger(node.GetValue("NodeClassID"), 0), CMSContext.CurrentSite.SiteID);

                    ArrayList deleteRows = new ArrayList();

                    if (!DataHelper.DataSourceIsEmpty(ds))
                    {
                        // Get the unwanted classes
                        string allowed = this.AllowedChildClasses.Trim().ToLower();
                        if (allowed != "")
                        {
                            allowed = ";" + allowed + ";";
                        }

                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            string className = ValidationHelper.GetString(DataHelper.GetDataRowValue(dr, "ClassName"), "").ToLower();
                            if ((allowed != "") && (!allowed.Contains(";" + className + ";")))
                            {
                                deleteRows.Add(dr);
                            }
                        }

                        // Remove the rows
                        foreach (DataRow dr in deleteRows)
                        {
                            ds.Tables[0].Rows.Remove(dr);
                        }
                    }

                    // Check if some classes are available
                    if (!DataHelper.DataSourceIsEmpty(ds))
                    {
                        ds.Tables[0].DefaultView.Sort = "ClassDisplayName";
                        lblError.Visible = false;
                        lblInfo.Visible = true;
                    }
                    else
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("Content.NoAllowedChildDocuments");
                        lblInfo.Visible = false;
                    }

                    this.gridClasses.DataSource = ds.Tables[0].DefaultView.Table;
                    this.gridClasses.DataBind();

                    this.lblInfo.Text = ResHelper.GetString("Content.NewInfo");
                }
                else
                {
                    // Display the form
                    this.pnlEdit.Visible = true;

                    this.ltlScript.Text += ScriptHelper.GetScript(
                        "function " + this.FunctionsPrefix + "SaveDocument(NodeID) { " + (confirmChanges ? "AllowSubmit(); " : "") + this.Page.ClientScript.GetPostBackEventReference(this.btnSave, null) + "; } \n" +
                        "function " + this.FunctionsPrefix + "Approve(NodeID) { " + this.Page.ClientScript.GetPostBackEventReference(this.btnApprove, null) + "; } \n" +
                        "function " + this.FunctionsPrefix + "Reject(NodeID) { " + this.Page.ClientScript.GetPostBackEventReference(this.btnReject, null) + "; } \n" +
                        "function " + this.FunctionsPrefix + "CheckIn(NodeID) { " + this.Page.ClientScript.GetPostBackEventReference(this.btnCheckIn, null) + "; } \n" +
                            (this.plcSaveChanges.Visible ? "var confirmSave='" + ResHelper.GetString("Content.ConfirmSave") + "'; var confirmLeave='" + ResHelper.GetString("Content.ConfirmLeave") + "'; \n" : "") +
                        "function " + this.FunctionsPrefix + "CheckOut(NodeID) { " + this.Page.ClientScript.GetPostBackEventReference(this.btnCheckOut, null) + "; } \n" +
                        "function " + this.FunctionsPrefix + "UndoCheckOut(NodeID) { " + this.Page.ClientScript.GetPostBackEventReference(this.btnUndoCheckOut, null) + "; } \n" +
                        "function " + this.FunctionsPrefix + "Delete(NodeID) { " + this.Page.ClientScript.GetPostBackEventReference(this.btnDelete, null) + "; } \n" +
                        ((this.FunctionsPrefix != "") ? "function " + this.FunctionsPrefix + "SpellCheck() { SpellCheck(); } \n" : "") +
                        "var spellURL = '" + ResolveUrl("~/CMSAdminControls/SpellChecker/SpellCheck.aspx") + "'; \n"
                    );

                    this.btnApprove.Attributes.Add("style", "display: none;");
                    this.btnCheckIn.Attributes.Add("style", "display: none;");
                    this.btnCheckOut.Attributes.Add("style", "display: none;");
                    this.btnReject.Attributes.Add("style", "display: none;");
                    this.btnSave.Attributes.Add("style", "display: none;");
                    this.btnUndoCheckOut.Attributes.Add("style", "display: none;");
                    this.btnDelete.Attributes.Add("style", "display: none;");

                    // CMSForm initialization
                    int oldNodeId = formElem.NodeId;
                    formElem.NodeId = node.NodeID;

                    string oldCulture = formElem.CultureCode;
                    formElem.CultureCode = CMSContext.CurrentUser.PreferredCultureCode; //node.DocumentCulture;

                    // Set the form mode
                    if (NewDocument)
                    {
                        ci = DataClassInfoProvider.GetDataClass(ClassID);
                        if (ci == null)
                        {
                            throw new Exception("[CMSAdminControls/EditForm.aspx]: Class ID '" + ClassID + "' not found.");
                        }

                        this.titleElem.TitleText = ResHelper.GetString("Content.NewTitle") + ": " + ci.ClassDisplayName;

                        // Set default template ID
                        if (TemplateID > 0)
                        {
                            formElem.DefaultPageTemplateID = TemplateID;
                        }
                        else
                        {
                            formElem.DefaultPageTemplateID = ci.ClassDefaultPageTemplateID;
                        }

                        // Set document owner
                        formElem.OwnerID = this.OwnerID;

                        formElem.FormMode = FormModeEnum.Insert;
                        string newClassName = ci.ClassName;
                        string newFormName = newClassName + ".default";
                        if (newFormName.ToLower() != formElem.FormName.ToLower())
                        {
                            formElem.FormName = newFormName;
                            formElem.LoadForm();
                        }
                    }
                    else if (NewCulture)
                    {
                        formElem.FormMode = FormModeEnum.InsertNewCultureVersion;
                        // Default data document ID
                        formElem.CopyDefaultDataFromDocumentId = this.CopyDefaultDataFromDocumentID;

                        ci = DataClassInfoProvider.GetDataClass(node.NodeClassName);
                        formElem.FormName = node.NodeClassName + ".default";
                    }
                    else
                    {
                        formElem.FormMode = FormModeEnum.Update;
                        ci = DataClassInfoProvider.GetDataClass(node.NodeClassName);
                        formElem.FormName = "";
                        if ((oldNodeId != this.NodeID) || (oldCulture.ToLower() != formElem.CultureCode.ToLower()))
                        {
                            formElem.LoadForm();
                        }
                    }
                    formElem.Visible = true;

                    ReloadForm();
                }
            }
        }
        else
        {
            // Try to get any culture of the document
            node = DocumentHelper.GetDocument(this.NodeID, TreeProvider.ALL_CULTURES, tree);
            if (node != null)
            {
                // Offer a new culture creation
                this.pnlNewCulture.Visible = true;

                this.titleElem.TitleText = ResHelper.GetString("Content.NewCultureVersionTitle") + " (" + CMSContext.CurrentUser.PreferredCultureCode + ")";
                this.titleElem.TitleImage = "~/App_Themes/Default/Images/CMSDesk/Content/new.gif";

                this.lblNewCultureInfo.Text = ResHelper.GetString("ContentNewCultureVersion.Info");
                this.radCopy.Text = ResHelper.GetString("ContentNewCultureVersion.Copy");
                this.radEmpty.Text = ResHelper.GetString("ContentNewCultureVersion.Empty");

                radCopy.Attributes.Add("onclick", "ShowSelection();");
                radEmpty.Attributes.Add("onclick", "ShowSelection()");

                this.ltlScript.Text += ScriptHelper.GetScript(
                    "function ShowSelection() { \n" +
                    "   if (document.getElementById('" + this.radCopy.ClientID + "').checked) { document.getElementById('divCultures').style.display = 'block'; } \n" +
                    "   else { document.getElementById('divCultures').style.display = 'none'; } \n" +
                    "} \n"
                );

                this.btnOK.Text = ResHelper.GetString("ContentNewCultureVersion.Create");

                // Load culture versions
                SiteInfo si = SiteInfoProvider.GetSiteInfo(node.NodeSiteID);
                if (si != null)
                {
                    lstCultures.Items.Clear();

                    DataSet nodes = tree.SelectNodes(si.SiteName, node.NodeAliasPath, TreeProvider.ALL_CULTURES, false, null, null, null, 1, false);
                    foreach (DataRow nodeCulture in nodes.Tables[0].Rows)
                    {
                        ListItem li = new ListItem();
                        li.Text = CultureInfoProvider.GetCultureInfo(nodeCulture["DocumentCulture"].ToString()).CultureName;
                        li.Value = nodeCulture["DocumentID"].ToString();
                        lstCultures.Items.Add(li);
                    }
                    if (lstCultures.Items.Count > 0)
                    {
                        lstCultures.SelectedIndex = 0;
                    }
                }
            }
            else
            {
                this.pnlInfo.Visible = true;
                this.lblFormInfo.Text = ResHelper.GetString("EditForm.DocumentNotFound");
            }
        }
    }


    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        confirmChanges = SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSConfirmChanges");

        tree = new TreeProvider(CMSContext.CurrentUser);
        formElem.TreeProvider = tree;
    }


    private void ReloadForm()
    {
        this.lblWorkflowInfo.Text = "";
        formElem.Enabled = true;
        if ((node != null) && !NewDocument && !NewCulture)
        {
            bool authorized = true;

            // Check the permissions
            if (this.CheckPermissions)
            {
                // Check read permissions
                if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(NodeID, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
                {
                    CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
                }
                // Check modify permissions
                else if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(NodeID, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                {
                    formElem.Enabled = false;
                    lblWorkflowInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                    authorized = false;
                }
            }

            // If authorized
            if(authorized)
            {

                // Setup the workflow information
                WorkflowManager wm = new WorkflowManager(tree);
                WorkflowInfo wi = wm.GetNodeWorkflow(node);
                if ((wi != null) && (!NewCulture))
                {
                    // Get current step info
                    WorkflowStepInfo si = wm.GetStepInfo(node);
                    if (si != null)
                    {
                        bool allowApproval = true;
                        bool canApprove = wm.CanUserApprove(node, CMSContext.CurrentUser);
                        if (!(canApprove || (si.StepName.ToLower() == "edit") || (si.StepName.ToLower() == "published") || (si.StepName.ToLower() == "archived")))
                        {
                            formElem.Enabled = false;
                        }

                        // Check-in, Check-out
                        if (VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName))
                        {
                            if (node.GetValue("DocumentCheckedOutByUserID") == null)
                            {
                                // If not checked out, add the check-out information
                                if (canApprove || (si.StepName.ToLower() == "edit") || (si.StepName.ToLower() == "published") || (si.StepName.ToLower() == "archived"))
                                {
                                    this.lblWorkflowInfo.Text = ResHelper.GetString("EditContent.DocumentCheckedIn");
                                }
                                this.formElem.Enabled = NewCulture;
                            }
                            else
                            {
                                // If checked out by current user, add the check-in button
                                int checkedOutBy = ValidationHelper.GetInteger(node.GetValue("DocumentCheckedOutByUserID"), 0);
                                if (checkedOutBy == CMSContext.CurrentUser.UserID)
                                {
                                    // Document is checked out
                                    this.lblWorkflowInfo.Text = ResHelper.GetString("EditContent.DocumentCheckedOut");
                                }
                                else
                                {
                                    // Checked out by somebody else
                                    this.lblWorkflowInfo.Text = ResHelper.GetString("EditContent.DocumentCheckedOutByAnother");
                                    this.formElem.Enabled = NewCulture;
                                }
                                allowApproval = false;
                            }
                        }

                        // Document approval
                        if (allowApproval)
                        {
                            switch (si.StepName.ToLower())
                            {
                                case "edit":
                                case "published":
                                case "archived":
                                    break;

                                default:
                                    // If the user is authorized to perform the step, display the approve and reject buttons
                                    if (!canApprove)
                                    {
                                        this.lblWorkflowInfo.Text += " " + ResHelper.GetString("EditContent.NotAuthorizedToApprove");
                                    }
                                    break;
                            }
                            this.lblWorkflowInfo.Text += " " + String.Format(ResHelper.GetString("EditContent.CurrentStepInfo"), si.StepDisplayName);

                        }

                    }
                }
            }
        }

        this.pnlWorkflowInfo.Visible = (this.lblWorkflowInfo.Text != "");

        this.menuElem.ShowDelete = this.AllowDelete && (this.Action.ToLower() == "edit");
        this.menuElem.NodeID = this.NodeID;
        this.CheckPermissions = this.CheckPermissions;

        this.menuElem.ReloadMenu();
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        // Reload the form data
        ReloadData();
    }


    /// <summary>
    /// Adds the alert message to the output request window
    /// </summary>
    /// <param name="message">Message to display</param>
    private void AddAlert(string message)
    {
        this.ltlScript.Text += ScriptHelper.GetAlertScript(message);
    }


    /// <summary>
    /// Adds the script to the output request window
    /// </summary>
    /// <param name="script">Script to add</param>
    private void AddScript(string script)
    {
        this.ltlScript.Text += ScriptHelper.GetScript(script);
    }


    protected void btnSave_Click(object sender, EventArgs e)
    {
        SaveDocument();
    }


    private void SaveDocument()
    {
        if (NodeID > 0)
        {
            bool createAnother = NewDocument && ValidationHelper.GetBoolean(Request.Params["hidAnother"], false);
            bool autoCheck = false;
            bool useWorkflow = false;
            VersionManager vm = null;
            if (!NewDocument && !NewCulture)
            {
                autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
                WorkflowManager workflowMan = new WorkflowManager();

                // Get the document
                node = DocumentHelper.GetDocument(NodeID, CMSContext.CurrentUser.PreferredCultureCode, tree);

                //test if the document uses workflow
                if (workflowMan.GetNodeWorkflow(node) != null)
                {
                    useWorkflow = true;
                }
            }

            try
            {
                // If not using check-in/check-out, check out automatically
                if (autoCheck & useWorkflow)
                {
                    if (node != null)
                    {
                        // Check out
                        vm = new VersionManager(tree);
                        vm.CheckOut(node);

                    }
                }

                // tree node is returned from CMSForm.Save method
                if ((node != null) && !NewDocument && !NewCulture)
                {
                    formElem.Save(node);
                    //CMS.TreeEngine.TreeNode nodeData = 
                    //if (nodeData != null)
                    //{
                    //    DocumentHelper.CopyNodeData(nodeData, node, false, true, true, true, false);
                    //}
                }
                else
                {
                    // Special treatment for blog post (ensure parent month)
                    if (NewDocument && (ci != null) && (ci.ClassName.ToLower() == "cms.blogpost"))
                    {
                        // Get parent node
                        node = tree.SelectSingleNode(NodeID, TreeProvider.ALL_CULTURES);
                        if ((node != null) && (node.NodeClassName.ToLower() != "cms.blogmonth"))
                        {
                            // Validate the form first
                            if (formElem.BasicForm.ValidateData())
                            {
                                // Prepare the data
                                DateTime startDate = ValidationHelper.GetDateTime(formElem.BasicForm.GetFieldValue("BlogPostDate"), DateTimePicker.NOT_SELECTED);
                                string monthName = startDate.ToString("MMMM") + " " + startDate.Year.ToString();
                                startDate = new DateTime(startDate.Year, startDate.Month, 1);

                                // Check existing
                                DataSet existingDS = tree.SelectNodes(CMSContext.CurrentSite.SiteName, node.NodeAliasPath + "/%", TreeProvider.ALL_CULTURES, true, "cms.blogmonth", "BlogMonthStartingDate = '" + TableManager.GetDateTimeString(startDate) + "'", null, -1, false);
                                if (DataHelper.DataSourceIsEmpty(existingDS))
                                {
                                    // Create the month node
                                    node = new CMS.TreeEngine.TreeNode("CMS.BlogMonth", tree);
                                    node.DocumentCulture = CMSContext.CurrentUser.PreferredCultureCode;

                                    // Insert the month
                                    node.SetValue("BlogMonthName", monthName);
                                    node.SetValue("BlogMonthStartingDate", startDate);
                                    node.DocumentName = monthName;
                                    node.Insert(NodeID);

                                    this.formElem.NodeId = node.NodeID;
                                }
                                else
                                {
                                    // Set existing
                                    this.formElem.NodeId = ValidationHelper.GetInteger(existingDS.Tables[0].Rows[0]["NodeID"], 0);
                                }
                            }
                        }
                    }
                    node = formElem.Save();

                    // Set the edit mode
                    if (node != null)
                    {
                        this.NodeID = node.NodeID;
                        this.Action = "edit";
                        this.ReloadData();
                    }
                }

                if (node != null)
                {
                    // Check in the document
                    if (autoCheck & useWorkflow)
                    {
                        vm.CheckIn(node, null, null);
                    }
                }

                ReloadForm();
            }
            catch (Exception ex)
            {
                AddAlert(ResHelper.GetString("ContentRequest.SaveFailed") + " : " + ex.Message);
            }
        }
    }


    protected void btnApprove_Click(object sender, EventArgs e)
    {
        if (node != null)
        {
            // Save the changes first
            bool autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
            if (autoCheck)
            {
                if (this.SaveChanges)
                {
                    SaveDocument();
                }
                else
                {
                    this.formElem.BasicForm.LoadControlValues();
                }
            }

            // Approve the document - Go to next workflow step
            WorkflowManager wm = new WorkflowManager(tree);

            // Get original step
            WorkflowStepInfo originalStep = wm.GetStepInfo(node);

            // Approve the document
            WorkflowStepInfo nextStep = wm.MoveToNextStep(node, "");
            if (nextStep != null)
            {

                // Send workflow e-mails
                if (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSSendWorkflowEmails"))
                {
                    if (nextStep.StepName.ToLower() == "published")
                    {
                        // Publish e-mails
                        wm.SendWorkflowEmails(node, CMSContext.CurrentUser, originalStep, nextStep, WorkflowActionEnum.Published, "");
                    }
                    else
                    {
                        // Approve e-mails
                        wm.SendWorkflowEmails(node, CMSContext.CurrentUser, originalStep, nextStep, WorkflowActionEnum.Approved, "");
                    }
                }
                this.ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + NodeID + ", " + node.NodeParentID + ");");
            }
            else
            {
                // Workflow has been removed
                this.AddScript("     SelectNode(" + NodeID + ");");
            }

            this.formElem.lblInfo.Text += " " + ResHelper.GetString("ContentEdit.WasApproved");
        }
        ReloadForm();
    }


    protected void btnReject_Click(object sender, EventArgs e)
    {
        // Reject the document - Go to previous workflow step
        if (node != null)
        {
            // Save the document first
            bool autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
            if (autoCheck)
            {
                if (this.SaveChanges)
                {
                    SaveDocument();
                }
                else
                {
                    this.formElem.BasicForm.LoadControlValues();
                }
            }

            WorkflowManager wm = new WorkflowManager(tree);

            // Get original step
            WorkflowStepInfo originalStep = wm.GetStepInfo(node);

            // Reject the document
            WorkflowStepInfo previousStep = wm.MoveToPreviousStep(node, "");

            // Send workflow e-mails
            if (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSSendWorkflowEmails"))
            {
                wm.SendWorkflowEmails(node, CMSContext.CurrentUser, originalStep, previousStep, WorkflowActionEnum.Rejected, "");
            }

            this.formElem.lblInfo.Text += " " + ResHelper.GetString("ContentEdit.WasRejected");

            ReloadForm();
        }
    }


    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        // Save the document first
        if (this.SaveChanges || !confirmChanges)
        {
            SaveDocument();
        }
        else
        {
            this.formElem.BasicForm.LoadControlValues();
        }

        // Check in the document
        if (node != null)
        {
            VersionManager verMan = new VersionManager(tree);

            // Check in the document        
            verMan.CheckIn(node, null, null);

            this.formElem.lblInfo.Text += " " + ResHelper.GetString("ContentEdit.WasCheckedIn");
        }

        ReloadForm();
    }


    protected void btnCheckOut_Click(object sender, EventArgs e)
    {
        // Check out the document
        if (node != null)
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            VersionManager verMan = new VersionManager(tree);

            verMan.EnsureVersion(node);

            // Check out the document
            verMan.CheckOut(node);
        }

        ReloadForm();
    }


    protected void btnUndoCheckOut_Click(object sender, EventArgs e)
    {
        // Check out the document
        if (node != null)
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            VersionManager verMan = new VersionManager(tree);

            // Undo check out
            verMan.UndoCheckOut(node);
        }

        ReloadForm();
    }


    protected void btnClass_Command(object sender, CommandEventArgs e)
    {
        int newClassId = ValidationHelper.GetInteger(e.CommandArgument, 0);
        if (newClassId > 0)
        {
            this.ClassID = newClassId;
            this.ReloadData();
        }
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {
        this.Action = "newculture";
        if (this.radCopy.Checked)
        {
            this.CopyDefaultDataFromDocumentID = ValidationHelper.GetInteger(this.lstCultures.SelectedValue, 0);
        }
        else
        {
            this.CopyDefaultDataFromDocumentID = 0;
        }

        this.ReloadData();
    }


    protected void btnYes_Click(object sender, EventArgs e)
    {
        // Prepare the where condition
        string where = "NodeID = " + this.NodeID;

        // Get the documents
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        DataSet ds = null;
        if (chkAllCultures.Checked)
        {
            ds = tree.SelectNodes(CMSContext.CurrentSite.SiteName, "/%", TreeProvider.ALL_CULTURES, true, null, where, null, -1, false);
        }
        else
        {
            ds = tree.SelectNodes(CMSContext.CurrentSite.SiteName, "/%", CMSContext.CurrentUser.PreferredCultureCode, false, null, where, null, -1, false);
        }


        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            // Get parent alias path
            string parentAliasPath = TreePathUtils.GetParentPath(ValidationHelper.GetString(DataHelper.GetDataRowValue(ds.Tables[0].Rows[0], "NodeAliasPath"), ""));

            // Delete the documents
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                string aliasPath = ValidationHelper.GetString(dr["NodeAliasPath"], "");
                string culture = ValidationHelper.GetString(dr["DocumentCulture"], "");
                string className = ValidationHelper.GetString(dr["ClassName"], "");

                // Get the node
                CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(CMSContext.CurrentSite.SiteName, aliasPath, culture, false, className, false);

                if (node != null)
                {
                    // Delete the document
                    try
                    {
                        int parentId = node.NodeParentID;
                        if (parentId <= 0)
                        {
                            parentId = node.NodeID;
                        }
                        if (!DocumentHelper.DeleteDocument(node, tree, this.chkAllCultures.Checked, this.chkDestroy.Checked))
                        {
                            parentId = node.NodeID;
                        }

                        this.Action = "edit";
                        this.ReloadData();
                    }
                    catch (Exception ex)
                    {
                        EventLogProvider log = new EventLogProvider(tree.Connection);
                        log.LogEvent("E", DateTime.Now, "Content", "DELETEDOC", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, node.NodeID, node.DocumentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());
                        AddAlert(ResHelper.GetString("ContentRequest.DeleteFailed") + " : " + ex.Message);
                        return;
                    }
                }
                else
                {
                    AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingSource"));
                    return;
                }
            }

            // Redirect to the parent url
            Response.Redirect(this.ResolveUrl(CMSContext.GetUrl(parentAliasPath.TrimStart('/'))));
        }
        else
        {
            AddAlert(ResHelper.GetString("DeleteDocument.CultureNotExists"));
            return;
        }
    }


    protected void btnNo_Click(object sender, EventArgs e)
    {
        this.Action = "edit";
        this.ReloadData();
    }


    protected void btnDelete_Click(object sender, EventArgs e)
    {
        this.Action = "delete";
        this.ReloadData();
    }


    protected override void OnPreRender(EventArgs e)
    {
        // Render the styles link if live site mode
        if (this.Visible && (CMSContext.CurrentUser.ViewMode == ViewModeEnum.LiveSite))
        {
            string tag = "";
            if ((this.Page.Theme != "") && File.Exists(Server.MapPath("~/App_Themes/" + this.Page.Theme + "/DesignMode.css")))
            {
                tag = HTMLHelper.GetCSSFileLink(ResolveUrl("~/App_Themes/" + this.Page.Theme + "/DesignMode.css"));
            }
            else
            {
                tag = HTMLHelper.GetCSSFileLink(ResolveUrl("~/App_Themes/Default/DesignMode.css"));
            }

            this.Page.Header.Controls.Add(new LiteralControl(tag));
        }

        base.OnPreRender(e);
    }

    #endregion

}
