using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Drawing;
using System.Drawing.Imaging;
using System.Drawing.Drawing2D;
using System.IO;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;

public partial class CMSAdminControls_UserPicture : System.Web.UI.UserControl
{
    private string mUserPictDir = "/UserPictures/";

    private int mWidth = 0;
    private int mHeight = 0;
    private bool mDisplayPicture = true;
    private int mUserId = 0;

    public string imgUrl = "";
    public string width = "";
    public string height = "";

    #region "Public properties"

    /// <summary>
    /// Max picture width
    /// </summary>
    public int Width
    {
        get { return mWidth; }
        set { mWidth = value; }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int Height
    {
        get { return mHeight; }
        set { mHeight = value; }
    }

    /// <summary>
    /// Enable/disable display picture
    /// </summary>
    public bool DisplayPicture
    {
        get { return mDisplayPicture; }
        set { mDisplayPicture = value; }
    }

    /// <summary>
    /// User ID
    /// </summary>
    public int UserID
    {
        get { return mUserId; }
        set { mUserId = value; }

    }

    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
    }

    /// <summary>
    /// Set image  url, width and height
    /// </summary>
    protected void SetImage()
    {
        // Only if display picture is allowed
        if (this.DisplayPicture)
        {
            // Get user info
            UserInfo ui = UserInfoProvider.GetUserInfo(mUserId);
            if (ui != null)
            {
                // Picture must be defined
                if (ui.UserPicture != "")
                {
                    // Get picture filename
                    string filename = ui.UserPicture.Remove(ui.UserPicture.IndexOf('/'));

                    // Check if picture exists
                    if (File.Exists(HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/"  + mUserPictDir) + filename))
                    {
                        // Load image
                        System.Drawing.Image img = new Bitmap(HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/" + mUserPictDir) + filename);

                        // Set width, height if are some max values defined
                        if (img != null)
                        {
                            filename = ResolveUrl("~/CMSGlobalFiles/"  + mUserPictDir + filename);
                            imgUrl = filename;

                            if ((this.Width > 0) && (img.Width > this.Width))
                            {
                                width = this.Width.ToString();
                            }
                            else
                            {
                                width = img.Width.ToString();
                            }

                            if ((this.Height > 0) && (img.Height > this.Height))
                            {
                                height = this.Height.ToString();
                            }
                            else
                            {
                                height = img.Height.ToString();
                            }
                            img.Dispose();
                        }
                        else
                        {
                            this.Visible = false;
                        }
                    }
                    else
                    {
                        this.Visible = false;
                    }

                }
                else
                {
                    this.Visible = false;
                }
            }
            else
            {
                this.Visible = false;
            }
        }
    }

    /// <summary>
    /// Render
    /// </summary>
    /// <param name="writer"></param>
    protected override void Render(HtmlTextWriter writer)
    {
        if (DisplayPicture)
        {
            SetImage();
        }
        else
        {
            this.Visible = false;
        }

        base.Render(writer);
    }

}
