using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.GlobalHelper;
using CMS.FormEngine;
using CMS.FCKeditorV2;

public partial class CMSDesk_Content_EditFrameset : CMSDeskPage
{
    protected string viewpage = null;
    protected string menupage = null;
    protected string toolbarpage = null;

    protected string toolbarSize = "78";
    protected string menuSize = "43";
    int nodeId = 0;
    int classId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        // Get current node
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);

        //   current nodeID
        if (node != null)
        {            
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }          
        }
        //   classID, used when creating new document
        classId = ValidationHelper.GetInteger(Request.QueryString["classid"], 0);
        
        if (classId > 0)
        {
            DataClassInfo ci = DataClassInfoProvider.GetDataClass(classId);
            if (ci != null)
            {
                // check permission to create new document
                if (CMSContext.CurrentUser.IsAuthorizedToCreateNewDocument(nodeId, ci.ClassName))
                {
                    InitPage();
                }
                else
                {
                    RedirectToAccessDenied(ResHelper.GetString("cmsdesk.notauthorizedtocreatedocument"));
                }
            }
        }
        else
        {
            InitPage();
        }
    }


    protected void InitPage()
    {
        menupage = "editmenu.aspx" + Request.Url.Query;
        toolbarpage = "edittoolbar.aspx" + Request.Url.Query;

        DataClassInfo ci = null;
        if (classId > 0)
        {
            ci = DataClassInfoProvider.GetDataClass(classId);
        }
        else
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            if (node != null)
            {
                // Set view mode to edit if new document
                string action = ValidationHelper.GetString(Request.QueryString["action"], "");
                switch (action.ToLower())
                {
                    case "new":
                    case "newlink":
                        CMSContext.CurrentUser.MenuItemViewMode = ViewModeEnum.Edit;
                        CMSContext.CurrentUser.ViewMode = ViewModeEnum.Edit;
                        break;
                }

                ci = DataClassInfoProvider.GetDataClass(node.NodeClassName);

                switch (UpdateViewMode(node, ViewModeEnum.Edit))
                {
                    case ViewModeEnum.Design:
                        menuSize = "6";
                        menupage = "../separator.aspx";
                        break;

                    case ViewModeEnum.Edit:
                        if (node.NodeClassName.ToLower() == "cms.file")
                        {
                            menuSize = "6";
                            menupage = "../blank.htm";
                        }
                        break;
                }
            }
        }

        if (FCKeditor.UseIFrameForToolbar)
        {
            toolbarpage = "../blank.htm";
            viewpage = "editpage.aspx" + Request.Url.Query;
        }

        toolbarSize = "0";
    }
}
