using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.TreeEngine;
using CMS.CMSHelper;

public partial class CMSDesk_Content_EditToolbar : CMSDeskPage
{
    protected string viewpage = null;
    protected CMS.TreeEngine.TreeNode node = null;
    protected string controlFrame = "editview";

    protected void Page_Load(object sender, EventArgs e)
    {
        // Get the node ID
        int nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        if ( !this.IsPostBack )
        {
            try
            {
                viewpage = "edit.aspx" + Request.Url.Query;

                string action = ValidationHelper.GetString(Request.QueryString["action"], "").ToLower();

                switch (action)
                {
                    case "newlink":
                        viewpage = "NewLink.aspx" + Request.Url.Query;
                        break;

                    default:
                        // Check if new document desired
                        bool newdocument = (action == "new");
                        DataClassInfo classInfo = null;
                        if (newdocument)
                        {
                            // Get the class ID
                            int classId = ValidationHelper.GetInteger(Request.QueryString["classid"], 0);
                            classInfo = DataClassInfoProvider.GetDataClass(classId);
                        }
                        else
                        {
                            // Get the document
                            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                            node = tree.SelectSingleNode(nodeId);
                            if (node != null)
                            {
                                classInfo = DataClassInfoProvider.GetDataClass(node.NodeClassName);
                            }
                        }

                        // Check the editing page change
                        if (classInfo != null)
                        {
                            bool isMenuItem = TreePathUtils.IsMenuItemType(classInfo.ClassName);
                            if ((isMenuItem && CMSContext.CurrentUser.MenuItemViewMode == ViewModeEnum.EditForm) || (!isMenuItem && CMSContext.CurrentUser.ViewMode == ViewModeEnum.EditForm) || newdocument)
                            {
                                // If new document, check if new page URL is set
                                if (newdocument)
                                {
                                    if ((classInfo.ClassNewPageURL != null) && (classInfo.ClassNewPageURL != ""))
                                    {
                                        viewpage = ResolveUrl(classInfo.ClassNewPageURL) + Request.Url.Query;
                                    }
                                }
                                // If existing document, check if editing page URL is set
                                else if ((classInfo.ClassEditingPageURL != null) && (classInfo.ClassEditingPageURL != ""))
                                {
                                    viewpage = ResolveUrl(classInfo.ClassEditingPageURL) + Request.Url.Query;
                                }
                            }
                            else if ((isMenuItem && CMSContext.CurrentUser.MenuItemViewMode == ViewModeEnum.Edit) || (!isMenuItem && CMSContext.CurrentUser.ViewMode == ViewModeEnum.Edit))
                            {
                                // Check if view page URL is set
                                if ((classInfo.ClassViewPageUrl != null) && (classInfo.ClassViewPageUrl != ""))
                                {
                                    viewpage = ResolveUrl(classInfo.ClassViewPageUrl) + Request.Url.Query;
                                }
                                else
                                {
                                    viewpage = ResolveUrl(CMSContext.GetUrl(node.NodeAliasPath, node.DocumentUrlPath));
                                }
                            }
                            else
                            {
                                viewpage = ResolveUrl(CMSContext.GetUrl(node.NodeAliasPath, node.DocumentUrlPath));
                            }
                        }
                        break;
                }

                this.ltlScript.Text += ScriptHelper.GetScript("parent.frames['editview'].location.replace('" + viewpage + "');");
            }
            catch (Exception ex)
            {
                this.ltlScript.Text += ScriptHelper.GetAlertScript("[EditToolbar.aspx]: " + ex.Message);
            }
        }

        this.ClientScript.RegisterClientScriptBlock(typeof(string), "ControlFunctions", ScriptHelper.GetScript(
                "function SaveDocument(nodeId, createAnother) { " + this.ClientScript.GetPostBackEventReference(this.btnSave, null) + "; }\n" +
                "function Approve(nodeId) { " + this.ClientScript.GetPostBackEventReference(this.btnApprove, null) + "; }\n" +
                "function CheckIn(nodeId) { " + this.ClientScript.GetPostBackEventReference(this.btnCheckIn, null) + "; }\n"
            ));
    }
    
    protected void btnSave_Click(object sender, EventArgs e)
    {
        this.ltlScript.Text += ScriptHelper.GetScript("parent.frames['" + controlFrame + "'].SaveDocument();");
    }

    protected void btnApprove_Click(object sender, EventArgs e)
    {
        this.ltlScript.Text += ScriptHelper.GetScript("parent.frames['" + controlFrame + "'].Approve();");
    }

    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        this.ltlScript.Text += ScriptHelper.GetScript("parent.frames['" + controlFrame + "'].CheckIn();");
    }
}
