using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.FileManager;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.DataEngine;
using CMS.SettingsProvider;
using CMS.FormEngine;
using CMS.SiteProvider;

public partial class CMSDesk_Content_NewLink : CMSDeskPage
{
    int nodeId = 0;
    int currentNodeId = 0;

    protected override void OnPreInit(EventArgs e)
    {
        base.OnPreInit(e);

        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        // Set current node ID
        currentNodeId = ValidationHelper.GetInteger(Request.Params["currentNode"], 0);
        if (currentNodeId > 0)
        {
            // Current Node ID
            this.treeElem.NodeID = currentNodeId;
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {        
        this.lblInfo.Text = ResHelper.GetString("NewLink.Info");
        this.lblSite.Text = ResHelper.GetString("NewLink.Site");
            
        this.treeElem.SiteName = CMSContext.CurrentSite.SiteName;
        this.treeElem.NodeTextTemplate = "<span class=\"ContentTreeItem\" onclick=\"SelectTreeNode(##NODEID##, this); return false;\">##ICON##<span class=\"Name\">##NODENAME##</span></span>";
        this.treeElem.SelectedNodeTextTemplate = "<span id=\"treeSelectedNode\" class=\"ContentTreeSelectedItem\" onclick=\"SelectTreeNode(##NODEID##, this); return false;\">##ICON##<span class=\"Name\">##NODENAME##</span></span>";
        this.treeElem.MaxTreeNodeText = "<span class=\"ContentTreeItem\" onclick=\"Listing(##PARENTNODEID##, this); return false;\"><span class=\"Name\" style=\"font-style: italic;\">" + ResHelper.GetString("ContentTree.SeeListing") + "</span></span>";

        ltlScript.Text = ScriptHelper.GetScript("function SaveDocument(nodeId, createAnother) { document.getElementById('hidAnother').value = createAnother; " + ClientScript.GetPostBackEventReference(this.btnOk, null) + "; }");

        // Fill in the site list
        if (drpSites.Items.Count == 0)
        {
            // If actual user is global administrator, get all sites
            if (CMSContext.CurrentUser.IsGlobalAdministrator)
            {
                DataSet ds = SiteInfoProvider.GetAllSites();
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    drpSites.DataSource = ds.Tables[0];
                    drpSites.DataBind();
                }
            }
            // Else get only user's sites.
            else
            {
                DataTable ds = UserInfoProvider.GetUserSites(CMSContext.CurrentUser.UserID);

                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    drpSites.DataSource = ds;
                    drpSites.DataBind();
                }
            }

            try
            {
                drpSites.SelectedValue = CMSContext.CurrentSite.SiteName;
            }
            catch
            {
            }
        }

        this.treeElem.SiteName = drpSites.SelectedValue;
    }


    protected void btnOk_Click(object sender, EventArgs e)
    {
        if (currentNodeId > 0)
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);

            // Get parent node
            CMS.TreeEngine.TreeNode parentNode = tree.SelectSingleNode(nodeId);

            // Get current node
            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(currentNodeId, TreeProvider.ALL_CULTURES);
            if ((node != null) && (parentNode != null))
            {
                // Check the allowed child classes
                int childClassId = ValidationHelper.GetInteger(node.GetValue("NodeClassID"), 0);
                int parentClassId = ValidationHelper.GetInteger(parentNode.GetValue("NodeClassID"), 0);

                if (!DataClassInfoProvider.IsChildClassAllowed(parentClassId, childClassId))
                {
                    this.lblError.Text = ResHelper.GetString("NewLink.ChildClassNotAllowed") + "<br /><br />";
                }
                else
                {
                    node.InsertAsLink(nodeId);

                    bool createAnother = ValidationHelper.GetBoolean(Request.Params["hidAnother"], false);

                    if (createAnother)
                    {
                        ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + node.NodeParentID + ", " + node.NodeParentID + "); CreateAnother();");
                    }
                    else
                    {
                        ltlScript.Text += ScriptHelper.GetScript("RefreshNode(" + node.NodeID + ", " + node.NodeID + ");");
                        ltlScript.Text += ScriptHelper.GetScript("SelectNode(" + node.NodeID + ");");
                    }
                }
            }
        }
        else
        {
            this.lblError.Text = ResHelper.GetString("NewLink.ErrorSelectDocument");
        }
    }

    protected void drpSites_SelectedIndexChanged(object sender, EventArgs e)
    {
        this.treeElem.SiteName = this.drpSites.SelectedValue;
        this.treeElem.ReloadData();
    }
}
