using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.Ecommerce;

public partial class CMSDesk_Content_Product_Product_Edit_General : CMSDeskPage
{
    protected int nodeId = 0;
    protected int productId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        CurrentUserInfo currentUser = CMSContext.CurrentUser;

        if (currentUser != null)
        {

            // check 'EcommerceRead' permission
            if (!currentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
            {
                CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
            }

            productId = ValidationHelper.GetInteger(Request.QueryString["productID"], 0);
            nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeID"], 0);

            TreeProvider tree = new TreeProvider(currentUser);
            CMS.TreeEngine.TreeNode node = null;
            node = DocumentHelper.GetDocument(nodeId, currentUser.PreferredCultureCode, tree);
            if (node != null)
            {
                // Check read permissions
                if (currentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
                {
                    CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
                }
                else
                {
                    // Check modify permissions
                    if (currentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                    {
                        // disable form editing                                                            
                        DisableFormEditing();

                        // show access denied message
                        lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                    }
                    // check User - Department association
                    else if (!currentUser.IsGlobalAdministrator)
                    {

                        SKUInfo skuObj = SKUInfoProvider.GetSKUInfo(productId);
                        if (skuObj != null)
                        {
                            if (!DepartmentInfoProvider.IsUserInDepartment(skuObj.SKUDepartmentID, currentUser.UserID))
                            {
                                // disable form editing                                                            
                                DisableFormEditing();

                                DepartmentInfo departmentObj = DepartmentInfoProvider.GetDepartmentInfo(skuObj.SKUDepartmentID);
                                if (departmentObj != null)
                                {
                                    // show access denied message
                                    lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtperdepartment"), departmentObj.DepartmentName);
                                }
                            }

                        }
                    }


                    ctrlProduct.ProductID = productId;
                    ctrlProduct.NodeID = nodeId;
                    ctrlProduct.OnOkClickHandler += new EventHandler(NewProduct1_OnOkClickHandler);

                    BasicTabControlMenu.Tabs = new string[3, 4];
                    BasicTabControlMenu.Tabs[0, 0] = ResHelper.GetString("Product_Edit_Header.General");
                    BasicTabControlMenu.Tabs[0, 2] = "Product_Edit_General.aspx?productId=" + ctrlProduct.ProductID + "&nodeId=" + ctrlProduct.NodeID;
                    BasicTabControlMenu.Tabs[1, 0] = ResHelper.GetString("Product_Edit_Header.Tax");
                    BasicTabControlMenu.Tabs[1, 2] = "Product_Edit_Tax.aspx?productId=" + ctrlProduct.ProductID + "&nodeId=" + ctrlProduct.NodeID;
                    BasicTabControlMenu.Tabs[2, 0] = ResHelper.GetString("Product_Edit_Header.VolumeDiscounts");
                    BasicTabControlMenu.Tabs[2, 2] = "Product_Edit_VolumeDiscounts.aspx?productId=" + ctrlProduct.ProductID + "&nodeId=" + ctrlProduct.NodeID;
                    BasicTabControlMenu.UrlTarget = "_self";

                    chkMarkDocAsProd.Text = ResHelper.GetString("Product_Selection.DocIsAsProd");
                }
            }
        }
    }


    protected void chkMarkDocAsProd_CheckedChanged(object sender, EventArgs e)
    {
        ctrlProduct.FormEnabled = chkMarkDocAsProd.Checked;
    }


    /// <summary>
    /// On OK click redirect to edit page
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void NewProduct1_OnOkClickHandler(object sender, EventArgs e)
    {
        //int nodeId = ValidationHelper.GetInteger(((CMSFormControls_NewProduct)sender).NodeID, 0);
        //int productId = ValidationHelper.GetInteger(((CMSFormControls_NewProduct)sender).ProductID, 0);

        if (!chkMarkDocAsProd.Checked)
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            node.NodeSKUID = 0;
            node.Update();
            Response.Redirect("Product_Selection.aspx?nodeid=" + nodeId);
        }
        else
        {
            Response.Redirect("Product_Edit_General.aspx?productID=" + productId + "&saved=1&nodeID=" + nodeId);
        }
    }


    /// <summary>
    /// Disables form editing.
    /// </summary>
    protected void DisableFormEditing()
    {
        this.chkMarkDocAsProd.Enabled = false;
        this.ctrlProduct.FormEnabled = false;
        this.ctrlProduct.ButtonEnabled = false;
    }

}
