using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.Ecommerce;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.WorkflowEngine;

public partial class CMSDesk_Content_Product_Edit_Tax : CMSDeskPage
{
    protected int productId = 0;
    protected int nodeId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        CurrentUserInfo currentUser = CMSContext.CurrentUser;
        if (currentUser != null)
        {
            // check 'EcommerceRead' permission
            if (!currentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
            {
                CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
            }

            nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
            productId = ValidationHelper.GetInteger(Request.QueryString["productID"], 0);

            TreeProvider tree = new TreeProvider(currentUser);
            CMS.TreeEngine.TreeNode node = null;
            node = DocumentHelper.GetDocument(nodeId, currentUser.PreferredCultureCode, tree);
            if (node != null)
            {
                // Check read permissions
                if (currentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
                {
                    CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
                }
                else
                {
                    // Check modify permissions
                    if (currentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                    {
                        // disable form editing                                                            
                        DisableFormEditing();

                        // show access denied message
                        lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                    }
                    // check User - Department association
                    else if (!currentUser.IsGlobalAdministrator)
                    {
                        SKUInfo skuObj = SKUInfoProvider.GetSKUInfo(productId);
                        if (skuObj != null)
                        {
                            if (!DepartmentInfoProvider.IsUserInDepartment(skuObj.SKUDepartmentID, currentUser.UserID))
                            {
                                // disable form editing                                                            
                                DisableFormEditing();

                                DepartmentInfo departmentObj = DepartmentInfoProvider.GetDepartmentInfo(skuObj.SKUDepartmentID);
                                if (departmentObj != null)
                                {
                                    // show access denied message
                                    lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtperdepartment"), departmentObj.DepartmentName);
                                }
                            }

                        }
                    }

                    this.taxForm.ProductID = productId;

                    BasicTabControlMenu.Tabs = new string[3, 4];
                    BasicTabControlMenu.Tabs[0, 0] = ResHelper.GetString("Product_Edit_Header.General");
                    BasicTabControlMenu.Tabs[0, 2] = "Product_Edit_General.aspx?productId=" + productId.ToString() + "&nodeId=" + nodeId.ToString();
                    BasicTabControlMenu.Tabs[1, 0] = ResHelper.GetString("Product_Edit_Header.Tax");
                    BasicTabControlMenu.Tabs[1, 2] = "Product_Edit_Tax.aspx?productId=" + productId.ToString() + "&nodeId=" + nodeId.ToString();
                    BasicTabControlMenu.Tabs[2, 0] = ResHelper.GetString("Product_Edit_Header.VolumeDiscounts");
                    BasicTabControlMenu.Tabs[2, 2] = "Product_Edit_VolumeDiscounts.aspx?productId=" + productId.ToString() + "&nodeId=" + nodeId.ToString();
                    BasicTabControlMenu.UrlTarget = "_self";
                    BasicTabControlMenu.SelectedTab = 1;

                    chkMarkDocAsProd.Text = ResHelper.GetString("Product_Selection.DocIsAsProd");
                    btnOK.Text = ResHelper.GetString("Product_Edit_Tax.OK");
                }
            }
        }
    }


    protected void chkMarkDocAsProd_CheckedChanged(object sender, EventArgs e)
    {
        this.taxForm.Enabled = chkMarkDocAsProd.Checked;
    }


    /// <summary>
    /// Updates tax classes for SKU
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }
        
        
        if (!chkMarkDocAsProd.Checked)
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            node.NodeSKUID = 0;
            node.Update();
            Response.Redirect("Product_Selection.aspx?nodeid=" + nodeId);
        }
        else
        {
            this.taxForm.Save();
        }
    }


    /// <summary>
    /// Disables form editing.
    /// </summary>
    protected void DisableFormEditing()
    {
        chkMarkDocAsProd.Enabled = false;
        taxForm.Enabled = false;
        btnOK.Enabled = false;
    }
}
