using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Content_Product_Product_Edit_VolumeDiscounts : CMSDeskPage
{
    protected int productId = 0;
    protected int nodeId = 0;
    
    protected void Page_Load(object sender, EventArgs e)
	{

        CurrentUserInfo currentUser = CMSContext.CurrentUser;

        if (currentUser != null)
        {

            // check 'EcommerceRead' permission
            if (!currentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
            {
                CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
            }

            // Get parameters from URL
            productId = ValidationHelper.GetInteger(Request.QueryString["productID"], 0);
            nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeID"], 0);

            // Set unigrid properties
            SetUnigridProperties();

            // Set URL of new volume discount editing page
            lnkNewItem.NavigateUrl = "javascript: modalDialog('" + ResolveUrl("~/CMSDesk/Tools/Ecommerce/Products/Product_Edit_VolumeDiscount_Edit.aspx") + "?ProductID=" + productId + "&dialog=1', 'Volume discounts', 500, 260);";
            lnkNewItem.Text = ResHelper.GetString("Product_Edit_VolumeDiscount_List.NewItemCaption");
            imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Products/addvolumediscount.gif";

            // Register modal dialog script
            this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);


            BasicTabControlMenu.Tabs = new string[3, 4];
            BasicTabControlMenu.Tabs[0, 0] = ResHelper.GetString("Product_Edit_Header.General");
            BasicTabControlMenu.Tabs[0, 2] = "Product_Edit_General.aspx?productId=" + productId + "&nodeId=" + nodeId;
            BasicTabControlMenu.Tabs[1, 0] = ResHelper.GetString("Product_Edit_Header.Tax");
            BasicTabControlMenu.Tabs[1, 2] = "Product_Edit_Tax.aspx?productId=" + productId + "&nodeId=" + nodeId;
            BasicTabControlMenu.Tabs[2, 0] = ResHelper.GetString("Product_Edit_Header.VolumeDiscounts");
            BasicTabControlMenu.Tabs[2, 2] = "Product_Edit_VolumeDiscounts.aspx?productId=" + productId + "&nodeId=" + nodeId;
            BasicTabControlMenu.UrlTarget = "_self";
            BasicTabControlMenu.SelectedTab = 2;

            chkMarkDocAsProd.Text = ResHelper.GetString("Product_Selection.DocIsAsProd");
        }
     
   	}


	/// <summary>
	/// Handles the UniGrid's OnAction event.
	/// </summary>
	/// <param name="actionName">Name of item (button) that throws event.</param>
	/// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
	protected void UniGrid_OnAction(string actionName, object actionArgument)
	{
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        } 
        
        if (actionName.ToLower()  == "edit")
		{
            // javascript			
		}
		else if (actionName.ToLower() == "delete")
		{
            if (chkMarkDocAsProd.Checked)
            {
                // delete VolumeDiscountInfo object from database
                VolumeDiscountInfoProvider.DeleteVolumeDiscountInfo(Convert.ToInt32(actionArgument));
            }
		}
	}


    /// <summary>
    /// Handles the UniGrid's OnExternalDataBound event.
    /// </summary>
    /// <param name="sender">Sender.</param>
    /// <param name="sourceName">Source name.</param>
    /// <param name="parameter">Parameter.</param>
    protected object UniGrid_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        switch (sourceName.ToLower())
        {
            case "discountvalue":
                DataRowView row = (DataRowView)parameter;
                double value = ValidationHelper.GetDouble(row["VolumeDiscountValue"], 0);
                bool isFlat = ValidationHelper.GetBoolean(row["VolumeDiscountIsFlatValue"], false);
                // If value is relative, add "%" next to the value.
                if (isFlat)
                {
                    CurrencyInfo ci = CurrencyInfoProvider.GetMainCurrency();
                    return CurrencyInfoProvider.GetFormatedPrice(value, ci);
                }
                else
                {
                    return value.ToString() + "%";
                }

            case "edit":
                if (!chkMarkDocAsProd.Checked)
                {
                    // Disable editing
                    ((WebControl)sender).Attributes["onclick"] = "return false;";
                }
                else
                {
                    // Open modal dialog with volume discount edit form
                    int volumeDiscountId = ValidationHelper.GetInteger(((DataRowView)((GridViewRow)parameter).DataItem)[0], 0);
                    ((WebControl)sender).Attributes["onclick"] = "modalDialog('" + ResolveUrl("~/CMSDesk/Tools/Ecommerce/Products/Product_Edit_VolumeDiscount_Edit.aspx") + "?ProductID=" + productId + "&VolumeDiscountID=" + volumeDiscountId + "&dialog=1', 'Volume discounts', 500, 260); return false;";
                }
                break;

            case "delete":
                if (!chkMarkDocAsProd.Checked)
                {
                    // Disable deleting
                    ((WebControl)sender).Attributes["onclick"] = "return false;";
                }
                break;

        }
        return parameter;
    }


    protected void SetUnigridProperties()
    {
        // Set action handler
        UniGrid.OnAction += new OnActionEventHandler(UniGrid_OnAction);

        // Set ExternalDataBound handler
        UniGrid.OnExternalDataBound += new OnExternalDataBoundEventHandler(UniGrid_OnExternalDataBound);
        UniGrid.GridView.GridLines = GridLines.Horizontal;

        // Set Unigrid query parameters
        object[,] parameters = new object[1, 3];
        parameters[0, 0] = "@VolumeDiscountSKUID";
        parameters[0, 1] = productId;
        UniGrid.QueryParameters = parameters;

        // Set query condition
        UniGrid.WhereCondition = "VolumeDiscountSKUID=@VolumeDiscountSKUID";
    }


    protected void chkMarkDocAsProd_CheckedChanged(object sender, EventArgs e)
    {
        lnkNewItem.Enabled = chkMarkDocAsProd.Checked;
    }
}

