using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.Ecommerce;
using CMS.TreeEngine;
using CMS.LicenseProvider;
using CMS.SettingsProvider;
using CMS.WorkflowEngine;

public partial class CMSDesk_Content_Product_Product_Selection : CMSEcommercePage
{
    protected int nodeId = 0;
    CMS.TreeEngine.TreeNode node = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);
        if (node != null)
        {
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
            else
            {
                // Check modify permissions
                if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                {
                    // disable form editing                                                            
                    DisableFormEditing();

                    // show access denied message
                    lblGlobalInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                }

                ctrlProduct.NodeID = nodeId;

                if (node.NodeSKUID > 0)
                {
                    // Get the product
                    SKUInfo si = SKUInfoProvider.GetSKUInfo(node.NodeSKUID);
                    if (si != null)
                    {
                        Response.Redirect("Product_Edit_General.aspx?productid=" + node.NodeSKUID.ToString() + "&nodeid=" + nodeId.ToString());
                    }
                }

                chkMarkDocAsProd.Text = ResHelper.GetString("Product_Selection.MarkDocAsProd");
                radSelect.Text = ResHelper.GetString("Product_Selection.SelectProduct");
                lblProductName.Text = ResHelper.GetString("Product_Selection.ProductName");
                lblProductCode.Text = ResHelper.GetString("Product_Selection.ProductCode");
                lblDepartment.Text = ResHelper.GetString("Product_Selection.Department");
                radCreate.Text = ResHelper.GetString("Product_Selection.CreateProduct");
                btnOk.Text = ResHelper.GetString("General.Ok");
                btnShow.Text = ResHelper.GetString("Product_Selection.Show");

                ctrlProduct.ShowOkButton = false;

                if (ctrlProduct.ProductID > 0)
                {
                    pnlNew.Visible = true;
                    pnlSelect.Visible = false;
                    ctrlProduct.Visible = true;
                    radCreate.Visible = false;
                    radSelect.Visible = false;
                    chkMarkDocAsProd.Text = ResHelper.GetString("com_SKU_edit_general.DocumentIsProduct");
                    return;
                }

                if (!IsPostBack)
                {
                    chkMarkDocAsProd.Checked = false;
                    radSelect.Checked = true;
                    radCreate.Checked = false;
                    pnlSelect.Enabled = true;
                    pnlContent.Enabled = false;
                    InitializeDrpDepartment();
                    if ((chkMarkDocAsProd.Checked) && (radSelect.Checked))
                    {
                        InitializeListBox();
                    }
                }
            }
        }
    }

    protected void BtnShow_Click(object sender, EventArgs e)
    {
        InitializeListBox();
    }
    protected void chkMarkDocAsProd_CheckedChanged(object sender, EventArgs e)
    {

        if (ctrlProduct.ProductID > 0)
        {
            if (!chkMarkDocAsProd.Checked)
            {
                pnlNew.Enabled = false;
            }
            else
            {
                pnlNew.Enabled = true;
            }
        }
        else
        {
            if (chkMarkDocAsProd.Checked)
            {
                pnlContent.Enabled = true;
                InitializeListBox();
            }
            else
            {
                pnlContent.Enabled = false;
                lstProducts.Items.Clear();
            }
        }
    }


    protected void radSelect_CheckedChanged(object sender, EventArgs e)
    {
        if (radSelect.Checked)
        {
            pnlSelect.Enabled = true;
            InitializeListBox();
            pnlSelect.Visible = true;
            ctrlProduct.Visible = false;
            pnlNew.Visible = false;
        }
        else
        {
            pnlSelect.Enabled = false;
            pnlSelect.Visible = false;
            ctrlProduct.Visible = true;
            pnlNew.Visible = true;
            lstProducts.Items.Clear();

            // Set mappings
            if (node != null)
            {
                DataClassInfo dci = DataClassInfoProvider.GetDataClass(node.NodeClassName);
                if (dci != null)
                {
                    ctrlProduct.ProductName = ValidationHelper.GetString(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUName"])), "");
                    ctrlProduct.ProductPrice = ValidationHelper.GetDouble(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUPrice"])), 0);
                    ctrlProduct.ProductWeight = ValidationHelper.GetDouble(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUWeight"])), 0);
                    ctrlProduct.ProductHeight = ValidationHelper.GetDouble(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUHeight"])), 0);
                    ctrlProduct.ProductWidth = ValidationHelper.GetDouble(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUWidth"])), 0);
                    ctrlProduct.ProductDepth = ValidationHelper.GetDouble(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUDepth"])), 0);
                    ctrlProduct.ProductDescription = ValidationHelper.GetString(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUDescription"])), "");

                    Guid guid = ValidationHelper.GetGuid(DataHelper.GetDataRowValue(node.DataRow, Convert.ToString(dci.SKUMappings["SKUImagePath"])), Guid.Empty);
                    ctrlProduct.ProductImagePath = (guid != Guid.Empty) ? TreePathUtils.GetAttachmentUrl(guid, node.NodeAlias) : "";

                }
            }
            // prefill form with values from the document
            ctrlProduct.SetValues();
        }
    }

    protected void InitializeListBox()
    {
        GeneralConnection conn = ConnectionHelper.GetConnection();

        string productNameFilter = txtProductName.Text.Trim().Replace("'", "''");
        string productCodeFilter = txtProductCode.Text.Trim().Replace("'", "''");
        string where = "(1 = 1)";

        if (productNameFilter != "")
        {
            where += " AND (SKUName LIKE '%" + productNameFilter + "%')";
        }
        if (productCodeFilter != "")
        {
            where += " AND (SKUNumber LIKE '%" + productCodeFilter + "%')";
        }
        if ((drpDepartment.SelectedIndex > -1) && (drpDepartment.SelectedValue != "0"))
        {
            where += " AND (SKUDepartmentID = " + drpDepartment.SelectedValue + ")";
        }
        else
        {
            string departments = "(0 = 1)";
            for (int i = 1; i < drpDepartment.Items.Count; i++)
            {
                departments += " OR (SKUDepartmentID = " + drpDepartment.Items[i].Value + ") ";
            }
            where += " AND (" + departments + ")";
        }

        DataSet dsSKU = SKUInfoProvider.GetSKUs(where, "SKUName");

        lstProducts.DataValueField = "SKUID";
        lstProducts.DataTextField = "SKUName";
        lstProducts.DataSource = dsSKU;
        lstProducts.DataBind();
    }


    /// <summary>
    /// Loads list of departments from DB into DropDownList
    /// </summary>
    protected void InitializeDrpDepartment()
    {
        if (CMSContext.CurrentUser != null)
        {
            if (CMSContext.CurrentUser.IsGlobalAdministrator)
            {
                drpDepartment.DataSource = DepartmentInfoProvider.GetDepartments();
            }
            else
            {
                drpDepartment.DataSource = DepartmentInfoProvider.GetUserDepartments(CMSContext.CurrentUser.UserID);
            }
            drpDepartment.DataBind();
            drpDepartment.Items.Insert(0, new ListItem("(" + ResHelper.GetString("Product_Selection.AllMyDepartments") + ")", "0"));
            if (drpDepartment.Items.Count > 0)
            {
                drpDepartment.SelectedIndex = 0;
            }

        }
    }

    protected void btnOk_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }

        int productId = 0;
        if (ctrlProduct.ProductID > 0)
        {
            //Update
            if (chkMarkDocAsProd.Checked)
            {
                int mProductId = ctrlProduct.OnBtnOkClick();

                if (mProductId > 0)
                {
                    Response.Redirect("Product_Selection.aspx?productID=" + mProductId + "&saved=1&nodeid=" + nodeId);
                }
            }
            else //DELETE
            {
                TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
                node.NodeSKUID = 0;
                node.Update();
                Response.Redirect("Product_Selection.aspx?nodeid=" + nodeId);
            }
        }
        else
        {
            if (radSelect.Checked)
            {
                if (lstProducts.SelectedIndex > -1)
                {
                    productId = ValidationHelper.GetInteger(lstProducts.SelectedValue, 0);
                    TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                    node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
                    node.NodeSKUID = productId;
                    node.Update();
                    Response.Redirect("Product_Edit_General.aspx?productid=" + productId + "&nodeId=" + nodeId.ToString());
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Products.EmptyList");
                }
            }
            else
            {

                int mProductId = ctrlProduct.OnBtnOkClick();

                if (mProductId > 0)
                {
                    Response.Redirect("Product_Selection.aspx?productID=" + mProductId + "&saved=1&nodeid=" + nodeId);
                }
            }
        }
    }


    /// <summary>
    /// Disables form editing.
    /// </summary>
    protected void DisableFormEditing()
    {
        this.chkMarkDocAsProd.Enabled = false;
        this.radCreate.Enabled = false;
        this.radSelect.Enabled = false;
        this.txtProductCode.Enabled = false;
        this.txtProductName.Enabled = false;
        this.drpDepartment.Enabled = false;
        this.btnOk.Enabled = false;
        this.lstProducts.Enabled = false;
        this.ctrlProduct.FormEnabled = false;
    }
}
