using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.EventLog;

public partial class CMSDesk_Content_LinkedDocs : CMSDeskPage
{
    protected int nodeId = 0;
    protected SiteInfo currentSite = null;
    protected int nodeParentId = 0;
    CMS.TreeEngine.TreeNode node = null;


    protected void Page_Load(object sender, EventArgs e)
    {
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        ReloadData();

        currentSite = CMSContext.CurrentSite;
        this.gridDocs.OnExternalDataBound += new OnExternalDataBoundEventHandler(gridDocuments_OnExternalDataBound);
        this.gridDocs.OnAction += new OnActionEventHandler(gridDocs_OnAction);
    }


    protected void ReloadData()
    {
        if (nodeId > 0)
        {
            TreeProvider tree = new TreeProvider();
            node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            if (node != null)
            {
                nodeParentId = node.NodeParentID;

                SiteInfo si = SiteInfoProvider.GetSiteInfo(node.NodeSiteID);
                if (si != null)
                {
                    int linkedNodeId = nodeId;
                    if (node.IsLink)
                    {
                        linkedNodeId = ValidationHelper.GetInteger(node.GetValue("NodeLinkedNodeID"), 0);
                    }
                    DataSet nodes = tree.SelectNodes(TreeProvider.ALL_SITES, "/%", TreeProvider.ALL_CULTURES, true, null, "(NodeID = " + linkedNodeId.ToString() + " AND NodeLinkedNodeID IS NULL) OR NodeLinkedNodeID = " + linkedNodeId.ToString(), "NodeAliasPath ASC", -1, false);
                    if (!DataHelper.DataSourceIsEmpty(nodes) && (nodes.Tables[0].Rows.Count > 1))
                    {
                        this.gridDocs.DataSource = nodes;
                        this.gridDocs.Visible = true;
                        this.lblInfo.Text = ResHelper.GetString("LinkedDocs.LinkedDocs");
                    }
                    else
                    {
                        this.lblInfo.Text = ResHelper.GetString("LinkedDocs.NoLinkedDocs");
                        this.gridDocs.Visible = false;
                    }
                }
            }
        }
    }


    void gridDocs_OnAction(string actionName, object actionArgument)
    {
        switch (actionName.ToLower())
        {
            case "delete":
                int deleteNodeId = ValidationHelper.GetInteger(actionArgument, 0);
                if (deleteNodeId > 0)
                {
                    // Get the document
                    TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                    CMS.TreeEngine.TreeNode deleteNode = tree.SelectSingleNode(deleteNodeId, TreeProvider.ALL_CULTURES);
                    if ((deleteNode != null) && (node != null))
                    {
                        try
                        {
                            // Delete the document
                            DocumentHelper.DeleteDocument(deleteNode, tree, false, false);

                            if ((deleteNode.NodeSiteID == node.NodeSiteID) && (node.NodeAliasPath.StartsWith(deleteNode.NodeAliasPath, StringComparison.CurrentCulture)))
                            {
                                this.ltlScript.Text += ScriptHelper.GetScript("SelectItem(" + deleteNode.NodeParentID + ", " + deleteNode.NodeParentID + ");");
                            }
                            else
                            {
                                ReloadData();

                                this.ltlScript.Text += ScriptHelper.GetScript("RefreshNode(" + nodeParentId + ", " + nodeId + ");");
                            }
                        }
                        catch (Exception ex)
                        {
                            this.lblError.Text = ResHelper.GetString("ContentRequest.DeleteFailed") + " : " + ex.Message;
                            this.lblError.Visible = true;

                            //int parentId = deleteNode.NodeParentID;
                            //if (parentId <= 0)
                            //{
                            //    parentId = deleteNode.NodeID;
                            //}
                            //this.ltlScript.Text += ScriptHelper.GetScript("RefreshNode(" + parentId + ", " + deleteNode.NodeID + ");");
                            
                            //return;
                        }

                        // If node no longer present, refresh
                        node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
                        if (node == null)
                        {
                            if (this.lblError.Text != "")
                            {
                                this.ltlScript.Text += ScriptHelper.GetAlertScript(this.lblError.Text);
                                this.lblError.Text = "";
                                this.lblError.Visible = false;
                            }
                            this.ltlScript.Text += ScriptHelper.GetScript("SelectItem(" + nodeId + ", " + nodeId + ");");
                        }
                    }
                }
                break;
        }
    }


    /// <summary>
    /// External data binding handler
    /// </summary>
    object gridDocuments_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        switch (sourceName.ToLower())
        {
            case "documentname":
                {
                    DataRowView data = (DataRowView)parameter;

                    string name = ValidationHelper.GetString(data["NodeAliasPath"], "");
                    string siteName = ValidationHelper.GetString(data["SiteName"], "");
                    int currentNodeId = ValidationHelper.GetInteger(data["NodeID"], 0);
                    int nodeParentId = ValidationHelper.GetInteger(data["NodeParentID"], 0);

                    string result = name;
                    if (currentSite.SiteName.ToLower() == siteName.ToLower())
                    {
                        result = "<a href=\"javascript: SelectItem(" + currentNodeId + ", " + nodeParentId + ");\">" + name + "</a>";
                    }

                    bool isLink = (data["NodeLinkedNodeID"] != DBNull.Value);
                    if (isLink)
                    {
                        result += CMSDeskPage.LINK_MARK;
                    }

                    return result;
                }

            case "type":
                {
                    DataRowView data = (DataRowView)parameter;

                    int currentNodeId = ValidationHelper.GetInteger(data["NodeID"], 0);
                    int linkedNodeId = ValidationHelper.GetInteger(data["NodeLinkedNodeID"], 0);
                    if (linkedNodeId == 0)
                    {
                        return ResHelper.GetString("LinkedDocs.Original");
                    }
                    else if (currentNodeId == nodeId)
                    {
                        return ResHelper.GetString("LinkedDocs.Current");
                    }
                    else
                    {
                        return "";
                    }
                }

            case "sitename":
                {
                    string siteName = (string)parameter;
                    SiteInfo si = SiteInfoProvider.GetSiteInfo(siteName);
                    if (si != null)
                    {
                        return si.DisplayName;
                    }
                    else
                    {
                        return parameter;
                    }
                }

            case "deleteaction":
                {
                    GridViewRow container = (GridViewRow)parameter;
                    int currentNodeId = ValidationHelper.GetInteger(((DataRowView)container.DataItem)["NodeID"], 0);
                    string currentPath = ValidationHelper.GetString(((DataRowView)container.DataItem)["NodeAliasPath"], "");

                    bool current = (nodeId == currentNodeId);
                    bool parent = false;//(node.NodeAliasPath.StartsWith(currentPath, StringComparison.CurrentCultureIgnoreCase));

                    ((Control)sender).Visible = ((((DataRowView)container.DataItem)["NodeLinkedNodeID"] != DBNull.Value) && !current && !parent);
                    ((ImageButton)sender).CommandArgument = currentNodeId.ToString();
                    break;
                }
        }
        return parameter;
    }

}
