using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.WorkflowEngine;
using CMS.DataEngine;
using CMS.SettingsProvider;
using CMS.FormEngine;
using CMS.FileManager;
using CMS.PortalEngine;

public partial class CMSDesk_Content_Properties_ViewVersion : CMSDeskPage
{
    FormInfo fi = null;
    TreeProvider tree = null;
    AttachmentManager am = null;
    VersionManager vm = null;
    int versionHistoryId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        this.titleElem.TitleText = ResHelper.GetString("Content.ViewVersion");
        this.titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Content/Properties/viewversion.gif";

        this.btnClose.Text = ResHelper.GetString("General.Close");

        tree = new TreeProvider(CMSContext.CurrentUser);
        am = new AttachmentManager(tree.Connection);

        versionHistoryId = ValidationHelper.GetInteger(Request.QueryString["versionhistoryid"], 0);
        if (versionHistoryId > 0)
        {
            vm = new VersionManager(tree);
            CMS.TreeEngine.TreeNode node = vm.GetVersion(versionHistoryId, null);
            if (node != null)
            {
                DataClassInfo ci = DataClassInfoProvider.GetDataClass(node.NodeClassName);
                fi = new FormInfo();
                fi.LoadXmlDefinition(ci.ClassFormDefinition);

                if ((ci != null) && (ci.ClassIsCoupledClass))
                {
                    // Add coupled class fields
                    DataClass coupleClass = new DataClass(node.NodeClassName);
                    foreach (DataColumn col in coupleClass.DataRow.Table.Columns)
                    {
                        string colName = col.ColumnName;
                        AddField(node, colName);
                    }
                }

                tblDocument.Rows.Add(new TableRow());

                // Add versioned document class fields
                DataClass docClass = new DataClass("cms.document");
                foreach (DataColumn col in docClass.DataRow.Table.Columns)
                {
                    string colName = col.ColumnName;
                    if (VersionManager.IsVersionedDocumentColumn(colName))
                    {
                        AddField(node, colName);
                    }
                }
            }
        }
    }


    /// <summary>
    /// Adds the field to the form
    /// </summary>
    /// <param name="node">Document node</param>
    /// <param name="columnName">Column name</param>
    private void AddField(CMS.TreeEngine.TreeNode node, string columnName)
    {
        FormFieldInfo ffi = null;
        if (fi != null)
        {
            ffi = fi.GetFormField(columnName);
        }

        TableRow newRow = new TableRow();

        TableCell labelCell = new TableCell();
        labelCell.VerticalAlign = VerticalAlign.Top;
        newRow.Cells.Add(labelCell);

        TableCell valueCell = new TableCell();
        bool loadValue = true;

        // Get the caption
        if (ffi != null)
        {
            labelCell.Text = ffi.Caption + ":";
            AttachmentInfo ai = null;
            if (ffi.DataType == FormFieldDataTypeEnum.File)
            {
                // Get the attachment
                ai = DocumentHelper.GetAttachment(ValidationHelper.GetGuid(node.GetValue(columnName), Guid.Empty), versionHistoryId, tree);
            }

            if (ai != null)
            {
                HyperLink lnkFile = new HyperLink();
                lnkFile.Text = ai.AttachmentName;
                string url = DocumentHelper.GetAttachmentUrl(ai, versionHistoryId);

                lnkFile.NavigateUrl = "#";
                lnkFile.Attributes.Add("onclick", "modalDialog('" + ResolveUrl(url) + "', 'file', 900, 600);");

                //lnkFile.NavigateUrl = url;
                //lnkFile.Target = "_blank";

                valueCell.Controls.Add(lnkFile);
                loadValue = false;
            }
        }
        else
        {
            labelCell.Text = columnName + ":";
        }

        if (loadValue)
        {
            switch (columnName.ToLower())
            {
                // Document content - display content of editable regions and editable web parts
                case "documentcontent":
                    PageInfo pi = new PageInfo();
                    pi.LoadContentXml(ValidationHelper.GetString(node.GetValue(columnName), ""));

                    foreach (DictionaryEntry region in pi.EditableRegions)
                    {
                        Label lblTitle = new Label();
                        lblTitle.Text = (string)region.Key;
                        lblTitle.EnableViewState = false;
                        lblTitle.SkinID = "VersionEditableRegionTitle";

                        valueCell.Controls.Add(lblTitle);

                        Label lblText = new Label();
                        lblText.Text = HTMLHelper.ResolveUrls((string)region.Value, Request.ApplicationPath);
                        lblText.EnableViewState = false;
                        lblText.SkinID = "VersionEditableRegionText";

                        valueCell.Controls.Add(lblText);
                    }

                    foreach (DictionaryEntry part in pi.EditableWebParts)
                    {
                        Label lblTitle = new Label();
                        lblTitle.Text = (string)part.Key;
                        lblTitle.EnableViewState = false;
                        lblTitle.SkinID = "VersionEditableWebPartTitle";

                        valueCell.Controls.Add(lblTitle);

                        Label lblText = new Label();
                        lblText.Text = HTMLHelper.ResolveUrls((string)part.Value, Request.ApplicationPath);
                        lblText.EnableViewState = false;
                        lblText.SkinID = "VersionEditableWebPartText";

                        valueCell.Controls.Add(lblText);
                    }

                    break;

                // Others, display the string value
                default:
                    valueCell.Text = ValidationHelper.GetString(node.GetValue(columnName), "<NULL>");
                    break;
            }
        }
        newRow.Cells.Add(valueCell);
        
        tblDocument.Rows.Add(newRow);
    }
}
