using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.ExtendedControls;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.SettingsProvider;

public partial class CMSDesk_Content_Properties_default : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        int nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        // Get current node
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
        if (node != null)
        {
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
        }

        CurrentUserInfo curUser = CMSContext.CurrentUser;
        // Get sub page
        string page = GetSubPage(curUser);

        // Check the user interface permissions
        if ((CMSContext.CurrentSite != null) && (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSPersonalizeUserInterface")) &&
            ((!curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesTab")) ||
            (page == null)))
        {
            CMSDeskPage.RedirectToAccessDenied(ResHelper.GetString("cmsdesk.nouserintefacepermissions"));
        }

        this.frameHeader.Attributes.Add("src", "header.aspx" + Request.Url.Query);
        this.frameEdit.Attributes.Add("src", page + Request.Url.Query);

        if (CultureHelper.IsUICultureRTL())
        {
            ControlsHelper.ReverseFrames(this.colsFrameset);
        }
    }


    /// <summary>
    /// Get sub page for the properties tab
    /// </summary>
    /// <param name="curUser">Current user info</param>
    /// <returns></returns>
    private string GetSubPage(CurrentUserInfo curUser)
    {
        string page = null;

        // Order of the conditions is mandatory
        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesSecurity"))
        {
            page = "security.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesRelatedDocs"))
        {
            page = "Relateddocs_List.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesVersions"))
        {
            page = "versions.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesWorkflow"))
        {
            page = "workflow.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesMenu"))
        {
            page = "menu.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesMetaData"))
        {
            page = "metadata.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesTemplate"))
        {
            page = "template.aspx";
        }

        if (curUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesGeneral"))
        {
            page = "general.aspx";
        }

        return page;
    }
}
