using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.ExtendedControls;
using CMS.WorkflowEngine;
using CMS.PortalEngine;
using CMS.DataEngine;

public partial class CMSDesk_Content_Properties_metadata : CMSDeskPage
{
    int nodeId = 0;
    CMS.TreeEngine.TreeNode node = null;
    TreeProvider tree = null;
    protected bool hasModifyPermission = true;

    protected void Page_Load(object sender, EventArgs e)
    {
        this.PreRender += new EventHandler(Page_PreRender);

        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        // Get the document
        tree = new TreeProvider(CMSContext.CurrentUser);
        node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);

        if (!IsPostBack)
        {
            ReloadData();
        }

        ltlScript.Text = "";

        lblPageDescription.Text = ResHelper.GetString("PageProperties.Decription");
        lblPageKeywords.Text = ResHelper.GetString("PageProperties.Keywords");
        lblPageTitle.Text = ResHelper.GetString("PageProperties.Title");
        chkDescription.Text = ResHelper.GetString("Metadata.Inherit");
        chkKeyWords.Text = ResHelper.GetString("Metadata.Inherit");
        chkTitle.Text = ResHelper.GetString("Metadata.Inherit");

        btnOK.Text = ResHelper.GetString("PageProperties.OK");

        SetCheckBoxes();

    }

    protected void SetCheckBoxes()
    {
        if (IsPostBack)
        {
            return;
        }

        if ((node != null) && (node.NodeAliasPath == "/"))
        {
            chkDescription.Visible = false;
            chkKeyWords.Visible = false;
            chkTitle.Visible = false;
        }

    }


    protected void Page_PreRender(object sender, EventArgs e)
    {
        if (hasModifyPermission)
        {
            this.pnlForm.Enabled = this.menuElem.AllowEdit;
        }
        this.lblWorkflowInfo.Text = this.menuElem.WorkflowInfo;
        this.lblWorkflowInfo.Visible = (this.lblWorkflowInfo.Text != "");
    }


    private void ReloadData()
    {
        if (node != null)
        {
            GeneralConnection conn = ConnectionHelper.GetConnection();
            bool isRoot = (node.NodeAliasPath == "/");

            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
            // Check modify permissions
            else if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
            {
                hasModifyPermission = false;
                this.pnlForm.Enabled = false;
                this.lblWorkflowInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
            }

            if (node.GetValue("DocumentPageTitle") != null)
            {
                this.txtTitle.Text = node.GetValue("DocumentPageTitle").ToString();
            }
            else
            {
                if (!isRoot)
                {
                    txtTitle.Enabled = false;
                    chkTitle.Checked = true;
                    txtTitle.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentPageTitle IS NOT NULL", "DocumentPageTitle", conn);
                }

            }

            if (node.GetValue("DocumentPageKeyWords") != null)
            {
                this.txtKeywords.Text = node.GetValue("DocumentPageKeyWords").ToString();
            }
            else
            {
                if (!isRoot)
                {
                    txtKeywords.Enabled = false;
                    chkKeyWords.Checked = true;
                    txtKeywords.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentPageKeyWords IS NOT NULL", "DocumentPageKeyWords", conn);
                }
            }

            if (node.GetValue("DocumentPageDescription") != null)
            {
                this.txtDescription.Text = node.GetValue("DocumentPageDescription").ToString();
            }
            else
            {
                if (!isRoot)
                {
                    txtDescription.Enabled = false;
                    chkDescription.Checked = true;
                    txtDescription.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentPageDescription IS NOT NULL", "DocumentPageDescription", conn);
                }
            }
        }
    }


    /// <summary>
    /// Updates node properties in database
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (node != null)
        {
            bool autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
            VersionManager vm = null;
            bool useWorkflow = false;
            WorkflowManager workflowMan = new WorkflowManager();

            // Get the document
            node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);

            //test if the document uses workflow
            if (workflowMan.GetNodeWorkflowScope(node) != null)
            {
                useWorkflow = true;
            }

            // If not using check-in/check-out, check out automatically
            if (autoCheck & useWorkflow)
            {
                if (node != null)
                {
                    // Check out
                    vm = new VersionManager(tree);
                    vm.CheckOut(node);

                }
            }

            // Update the data
            node.SetValue("DocumentPageTitle", null);
            if (!chkTitle.Checked)
            {
                node.SetValue("DocumentPageTitle", this.txtTitle.Text);
            }


            node.SetValue("DocumentPageKeyWords", null);
            if (!chkKeyWords.Checked)
            {
                node.SetValue("DocumentPageKeyWords", this.txtKeywords.Text);
            }

            node.SetValue("DocumentPageDescription", null);
            if (!chkDescription.Checked)
            {
                node.SetValue("DocumentPageDescription", this.txtDescription.Text);
            }

            DocumentHelper.UpdateDocument(node, tree);

            // Check in the document
            if (autoCheck & useWorkflow)
            {
                vm.CheckIn(node, null, null);
            }

            this.menuElem.ReloadMenu();

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
        }
    }

    protected void chkTitle_CheckedChanged(object sender, EventArgs e)
    {
        if (chkTitle.Checked)
        {
            txtTitle.Enabled = false;
            txtTitle.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentPageTitle IS NOT NULL", "DocumentPageTitle", null);
        }
        else
        {
            txtTitle.Enabled = true;
        }
    }

    protected void chkDescription_CheckedChanged(object sender, EventArgs e)
    {
        if (chkDescription.Checked)
        {
            txtDescription.Enabled = false;
            txtDescription.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentPageDescription IS NOT NULL", "DocumentPageDescription", null);
        }
        else
        {
            txtDescription.Enabled = true;
        }
    }

    protected void chkKeyWords_CheckedChanged(object sender, EventArgs e)
    {
        if (chkKeyWords.Checked)
        {
            txtKeywords.Enabled = false;
            txtKeywords.Text = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentPageKeyWords IS NOT NULL", "DocumentPageKeyWords", null);
        }
        else
        {
            txtKeywords.Enabled = true;
        }
    }
    
}
