using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.TreeEngine;
using CMS.SiteProvider;
using CMS.Forums;
using CMS.Polls;

public partial class CMSDesk_Content_Properties_securityAddOperator : CMSModalPage
{
    protected int nodeId = 0;
    protected string mtitle;
    protected bool showOnlyRoles = false;
    protected bool showOnlyUsers = false;
    protected int forumId = 0;
    protected int pollId = 0;


    protected void Page_Load(Object sender, EventArgs e)
    {
        if ((Request.QueryString["nodeid"] != null) && (Request.QueryString["nodeid"] != ""))
        {
            nodeId = Convert.ToInt32(Request.QueryString["nodeid"]);
        }

        forumId = ValidationHelper.GetInteger(Request.QueryString["forumid"], 0);
        pollId = ValidationHelper.GetInteger(Request.QueryString["pollid"], 0);

        if ((showOnlyRoles) && (forumId > 0))
        {
            btnOK.Enabled = false;
            return;
        }

        showOnlyRoles = ValidationHelper.GetBoolean(Request.QueryString["onlyroles"], false);
        showOnlyUsers = ValidationHelper.GetBoolean(Request.QueryString["onlyusers"], false);

        lblSite.Text = ResHelper.GetString("SecurityAddOperator.Site");
        lblUserName.Text = ResHelper.GetString("SecurityAddOperator.UserName");

        
        titleElem.TitleText = ResHelper.GetString("SecurityAddOperator.Header");

        if (showOnlyRoles)
        {
            titleElem.TitleText = ResHelper.GetString("SecurityAddOperator.OnlyRolesHeader");
        }

        if (showOnlyUsers)
        {
            titleElem.TitleText = ResHelper.GetString("SecurityAddOperator.OnlyUsersHeader");
        }

        titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/Roles/selectuser.gif";
        btnSearch.Text = ResHelper.GetString("SecurityAddOperator.SearchButton");
        btnOK.Text = ResHelper.GetString("SecurityAddOperator.OK");
        btnCancel.Text = ResHelper.GetString("SecurityAddOperator.Cancel");
        mtitle = ResHelper.GetString("SecurityAddOperator.Title");

        if (((showOnlyRoles)||(showOnlyUsers)) && (CMSContext.CurrentSite != null))
        {
            dropSites.Items.Add(new ListItem(CMSContext.CurrentSite.SiteName, CMSContext.CurrentSite.SiteID.ToString()));
            dropSites.SelectedValue = CMSContext.CurrentSite.SiteID.ToString();
            this.dropSites.Enabled = false;
        }
        else
        {
            // fill in the site list
            if (this.dropSites.Items.Count == 0)
            {
                if (CMSContext.CurrentUser.IsGlobalAdministrator)
                {
                    this.dropSites.DataSource = SiteInfoProvider.GetAllSites();
                }
                else
                {
                    this.dropSites.DataSource = UserInfoProvider.GetUserSites(CMSContext.CurrentUser.UserID);
                }
                this.dropSites.DataBind();
                try
                {
                    this.dropSites.SelectedValue = CMSContext.CurrentSite.SiteID.ToString();
                }
                catch
                {
                }
            }
        }

        // check permissions
        if ((!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.content", "ModifyPermissions")) && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.ModifyPermissions)!=AuthorizationResultEnum.Allowed))
        {
            RedirectToAccessDenied(nodeId, "Modify permissions (security.aspx)");
            return;
        }
    }


    protected void btnSearch_Click(Object sender, EventArgs e)
    {
        GeneralConnection cn = ConnectionHelper.GetConnection();
        DataSet ds = null;
        object[,] searchParams = new object[2, 3];
        searchParams[0, 0] = "@search";
        searchParams[0, 1] = "%" + txtSearch.Text + "%";
        searchParams[1, 0] = "@siteID";
        searchParams[1, 1] = Convert.ToInt32(dropSites.SelectedValue);

        if (showOnlyRoles)
        {
            // find all roles whose name contains specified string
            ds = cn.ExecuteQuery("cms.role.SelectRolesForSite", searchParams);
            lstItems.DataSource = ds.Tables[0];
            lstItems.DataTextField = "OperatorName";
            lstItems.DataValueField = "OperatorID";
            lstItems.DataBind();
        }
        else  
        {
            if (showOnlyUsers)
            {
                // find all users whose name contains specified string
                ds = cn.ExecuteQuery("cms.role.SelectUsersForSite", searchParams);
                lstItems.DataSource = ds.Tables[0];
                lstItems.DataTextField = "OperatorName";
                lstItems.DataValueField = "OperatorID";
                lstItems.DataBind();
            }
            else
            {
                // find all users and roles whose name contains specified string
                ds = cn.ExecuteQuery("cms.role.SelectRolesAndUsersForSite", searchParams);
                lstItems.DataSource = ds.Tables[0];
                lstItems.DataTextField = "OperatorName";
                lstItems.DataValueField = "OperatorID";
                lstItems.DataBind();
            }
        }
    }



    protected void btnOK_Click(Object sender, EventArgs e)
    {
        object[,] queryParams = new object[2, 3];
        TreeProvider treeProvider = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = treeProvider.SelectSingleNode(nodeId);
        AclProvider aclProv = new AclProvider(treeProvider);
        int roleId = 0;
        int userId = 0;

        // get IDs of the selected users/roles and save changes
        foreach (ListItem item in lstItems.Items)
        {
            if (item.Selected)
            {
                if (showOnlyRoles)
                {
                    roleId = ValidationHelper.GetInteger(item.Value.Substring(1), 0);
                    if ((roleId > 0) && (forumId > 0))
                    {
                        if (!ForumInfoProvider.IsRoleAllowedForForum(roleId, forumId))
                        {
                            ForumInfoProvider.AddRoleToForum(roleId, forumId);
                        }
                    }
                    else if ((roleId > 0) && (pollId > 0))
                    {
                        RoleInfo ri = RoleInfoProvider.GetRoleInfo(roleId);
                        if (ri != null)
                        {
                            if (!PollInfoProvider.IsRoleAllowedForPoll(pollId, ri.RoleName))
                            {
                                PollInfoProvider.AddRoleToPoll(roleId, pollId);
                            }
                        }
                    }
                }
                else if (showOnlyUsers)
                {
                    userId = ValidationHelper.GetInteger(item.Value.Substring(1), 0);
                    if (userId > 0)
                    {
                        ForumInfoProvider.AddModerator(userId, forumId);
                    }

                }
                else if (item.Value.StartsWith("U"))
                {
                    UserInfo ui = UserInfoProvider.GetUserInfo(int.Parse(item.Value.Substring(1)));
                    aclProv.SetUserPermissions(node, 0, 0, ui);
                }
                else
                {
                    aclProv.SetRolePermissions(node, 0, 0, int.Parse(item.Value.Substring(1)));
                }
            }
        }
        CloseWindow();
    }



    protected void btnCancel_Click(System.Object sender, System.EventArgs e)
    {
        CloseWindow();
    }



    // ''<summary>Generates script that closes the window and refreshes the parent page.</summary>
    private void CloseWindow()
    {
        ltlScript.Text = @"<script type=""text/javascript"" language=""javascript"">";
        ltlScript.Text += " CloseAndRefresh(); ";
        ltlScript.Text += "</script>";
    }
}
