using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.GlobalHelper;
using CMS.ExtendedControls;
using CMS.SiteProvider;

public partial class CMSDesk_Content_default : CMSDeskPage
{
    protected string treeUrl = "tree.aspx";
    protected string contentUrl = "contenteditframeset.aspx";
    protected string menuUrl = "menu.aspx";

    protected void Page_Load(object sender, EventArgs e)
    {
        if (CultureHelper.IsUICultureRTL())
        {
            ControlsHelper.ReverseFrames(this.colsFrameset);
        }

        CurrentUserInfo currentUser = CMSContext.CurrentUser;
        CurrentSiteInfo currentSite = CMSContext.CurrentSite;
        
        if (!IsUserAuthorizedPerContent())
        {
            RedirectToAccessDenied("cms.content", "read;exploretree");
        }

        // Set the culture if specified
        string culture = ValidationHelper.GetString(Request.QueryString["culture"], "");
        if (culture != "")
        {
            currentUser.PreferredCultureCode = culture;
        }

        // Check (and ensure) the proper content culture
        if (!CultureInfoProvider.IsCultureOnSite(currentUser.PreferredCultureCode, currentSite.SiteName))
        {
            string defaultCulture = CultureHelper.GetDefaultCulture(currentSite.SiteName);
            if (CultureInfoProvider.IsCultureOnSite(defaultCulture, currentSite.SiteName))
            {
                currentUser.PreferredCultureCode = defaultCulture;
            }
            else
            {
                DataSet ds = CultureInfoProvider.GetSiteCultures(currentSite.SiteName);
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    currentUser.PreferredCultureCode = ValidationHelper.GetString(ds.Tables[0].Rows[0]["CultureCode"], "en-us");
                }
            }
        }

        // Process the action
        switch (ValidationHelper.GetString(Request.QueryString["action"], "").ToLower() )
        {
            case "new":
                contentUrl = "documentframeset.aspx";
                break;
        }

        treeUrl += Request.Url.Query;
        contentUrl += Request.Url.Query;
        menuUrl += Request.Url.Query;

        // If no node specified, add the root node id
        int nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        if (nodeId <= 0)
        {
            // Get the root node
            TreeProvider tree = new TreeProvider();
            CMS.TreeEngine.TreeNode rootNode = tree.SelectSingleNode(CMSContext.CurrentSite.SiteName, "/", TreeProvider.ALL_CULTURES, false, null, false);
            if (rootNode != null)
            {
                string nodeString = null;
                if (Request.Url.Query != "")
                {
                    nodeString = "&nodeid=" + rootNode.NodeID.ToString();
                }
                else
                {
                    nodeString = "?nodeid=" + rootNode.NodeID.ToString();
                }
                treeUrl += nodeString;
                contentUrl += nodeString;
                menuUrl += nodeString;
            }
        }

        this.frameTree.Attributes.Add("src", treeUrl);
        this.frameView.Attributes.Add("src", contentUrl);
    }
}
