using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.EventLog;

public partial class CMSDesk_Content_delete : CMSDeskPage
{
    protected string[] nodeIDs = null;
    protected int cancelNodeId = 0;
    protected CurrentUserInfo currentUser = null;
    protected bool canDestroyContent = false;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Current Node ID to delete                        
        nodeIDs = Request.QueryString["nodeid"].Trim(';').Split(';');

        this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitle");
        this.titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Content/delete.gif";

        this.chkAllCultures.Text = ResHelper.GetString("ContentDelete.AllCultures");
        this.chkDestroy.Text = ResHelper.GetString("ContentDelete.Destroy");

        this.lblQuestion.Text = ResHelper.GetString("ContentDelete.Question");
        this.btnOK.Text = ResHelper.GetString("ContentDelete.Yes");
        this.btnCancel.Text = ResHelper.GetString("ContentDelete.No");

        // Hide checkboxes by default
        this.chkDestroy.Visible = false;
        this.chkAllCultures.Visible = false;
        
        DataSet culturesDS = CultureInfoProvider.GetSiteCultures(CMSContext.CurrentSite.SiteName);
        if ((DataHelper.DataSourceIsEmpty(culturesDS)) || (culturesDS.Tables[0].Rows.Count <= 1))
        {           
            this.chkAllCultures.Checked = true;
        }

        // Initialize current user
        currentUser = CMSContext.CurrentUser;

        // Check current user destroy permission to the "cms.content" document
        canDestroyContent = currentUser.IsAuthorizedPerResource("CMS.Content", "Destroy");
        
        if (nodeIDs.Length == 1)
        {
            int nodeId = ValidationHelper.GetInteger(nodeIDs[0], 0);
            // Get the node name
            TreeProvider tree = new TreeProvider(currentUser);

            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, currentUser.PreferredCultureCode);
            // Get any culture if current not found
            if (node == null)
            {
                node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            }

            if (node != null)
            {
                if (node.IsLink)
                {
                    this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitleLink") + " \"" + node.DocumentName + "\"";
                    this.lblQuestion.Text = ResHelper.GetString("ContentDelete.QuestionLink");
                    this.chkAllCultures.Checked = true;
                    this.plcCheck.Visible = false;
                }
                else
                {
                    this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitle") + " \"" + node.DocumentName + "\"";
                }

                // Show/Hide checkboxes                
                if (CanDestroy(node))
                {
                    chkDestroy.Visible = true;
                    chkAllCultures.Visible = !chkAllCultures.Checked;
                }

                cancelNodeId = node.NodeID;
            }
        }
        else if ( nodeIDs.Length > 1 )
        {
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
            string where = "NodeID IN (";
            foreach (string id in nodeIDs)
            {
                where += id + ",";
            }
            where = where.TrimEnd(',') + ")";
            
            CMS.TreeEngine.TreeNode node = null;

            DataSet ds = tree.SelectNodes(CMSContext.CurrentSite.SiteName, "/%", TreeProvider.ALL_CULTURES, true, null, where, null, -1, false);
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    cancelNodeId = ValidationHelper.GetInteger(dr["NodeParentID"], 0);
                    bool isLink = (dr["NodeLinkedNodeID"] != DBNull.Value);
                    string name = (string)dr["DocumentName"];
                    if (isLink)
                    {
                        name += "*";
                    }
                    this.lblDocuments.Text += name + "<br />";

                    // Show/Hide checkboxes   
                    node = new CMS.TreeEngine.TreeNode(dr, ValidationHelper.GetString(dr["ClassName"], ""));
                    if (CanDestroy(node))
                    {
                        chkDestroy.Visible = true;
                        chkAllCultures.Visible = !chkAllCultures.Checked;
                    }
                }
            }

            this.lblQuestion.Text = ResHelper.GetString("ContentDelete.QuestionMultiple") + "<br />";
            this.titleElem.TitleText = ResHelper.GetString("Content.DeleteTitleMultiple");
            this.chkAllCultures.Text = ResHelper.GetString("ContentDelete.AllCulturesMultiple");
            this.chkDestroy.Text = ResHelper.GetString("ContentDelete.DestroyMultiple");
        }
    }


    /// <summary>
    /// Indicates whether specified node can be destroyed by current user.
    /// </summary>
    /// <param name="node">Tree node to check.</param>
    /// <returns></returns>
    private bool CanDestroy(CMS.TreeEngine.TreeNode node)
    {
        return ((canDestroyContent && (currentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Destroy) != AuthorizationResultEnum.Denied)) || ((!canDestroyContent) && (currentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Destroy) == AuthorizationResultEnum.Allowed)));
    }



    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Prepare the where condition
        string where = "NodeID IN (";
        foreach (string id in nodeIDs)
        {
            where += id + ",";
        }
        where = where.TrimEnd(',') + ")";

        // Get the documents
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        DataSet ds = null;
        if (chkAllCultures.Checked)
        {
            ds = tree.SelectNodes(CMSContext.CurrentSite.SiteName, "/%", TreeProvider.ALL_CULTURES, true, null, where, null, -1, false);
        }
        else
        {
            ds = tree.SelectNodes(CMSContext.CurrentSite.SiteName, "/%", CMSContext.CurrentUser.PreferredCultureCode, false, null, where, null, -1, false);
        }

        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            // Delete the documents
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                string aliasPath = ValidationHelper.GetString(dr["NodeAliasPath"], "");
                string culture = ValidationHelper.GetString(dr["DocumentCulture"], "");
                string className = ValidationHelper.GetString(dr["ClassName"], "");

                // Get the node
                CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(CMSContext.CurrentSite.SiteName, aliasPath, culture, false, className, false);

                if (node != null)
                {
                    // Check delete permissions
                    bool hasUserDeletePermission = IsUserAuthorizedToDeleteDocument(node.NodeID, chkDestroy.Checked, chkAllCultures.Checked);

                    if (hasUserDeletePermission)
                    {
                        // Delete the document
                        try
                        {
                            int parentId = node.NodeParentID;
                            if (parentId <= 0)
                            {
                                parentId = node.NodeID;
                            }
                            if (!DocumentHelper.DeleteDocument(node, tree, this.chkAllCultures.Checked, this.chkDestroy.Checked))
                            {
                                parentId = node.NodeID;
                            }
                            this.AddScript("     RefreshNode(" + parentId + ", " + parentId + ");");
                            this.AddScript("     DisplayDocument(" + parentId + ");");
                        }
                        catch (Exception ex)
                        {
                            EventLogProvider log = new EventLogProvider(tree.Connection);
                            log.LogEvent("E", DateTime.Now, "Content", "DELETEDOC", CMSContext.CurrentUser.UserID, CMSContext.CurrentUser.UserName, node.NodeID, node.DocumentName, CMS.GlobalHelper.HTTPHelper.GetUserHostAddress(), ex.Message + ": " + ex.StackTrace, CMSContext.CurrentSite.SiteID, CMS.GlobalHelper.HTTPHelper.GetAbsoluteUri());

                            AddAlert(ResHelper.GetString("ContentRequest.DeleteFailed") + " : " + ex.Message);
                            int parentId = node.NodeParentID;
                            if (parentId <= 0)
                            {
                                parentId = node.NodeID;
                            }
                            this.AddScript("     RefreshNode(" + parentId + ", " + node.NodeID + ");");
                            this.AddScript("     DisplayDocument(" + node.NodeID + ");");
                            return;
                        }
                    }
                    // Access denied - not authorized to delete the document
                    else
                    {
                        RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtodeletedocument"), node.NodeAliasPath));
                        return;
                    }
                }
                else
                {
                    AddAlert(ResHelper.GetString("ContentRequest.ErrorMissingSource"));
                    return;
                }
            }
        }
        else
        {
            AddAlert(ResHelper.GetString("DeleteDocument.CultureNotExists"));
            return;
        }
    }


    /// <summary>
    /// Adds the alert message to the output request window
    /// </summary>
    /// <param name="message">Message to display</param>
    private void AddAlert(string message)
    {
        this.ltlScript.Text += ScriptHelper.GetAlertScript(message);
    }


    /// <summary>
    /// Adds the script to the output request window
    /// </summary>
    /// <param name="script">Script to add</param>
    private void AddScript(string script)
    {
        this.ltlScript.Text += ScriptHelper.GetScript(script);
    }


    protected void btnCancel_Click(object sender, EventArgs e)
    {
        this.AddScript("     DisplayDocument(" + cancelNodeId.ToString() + ");");
    }


    /// <summary>
    /// Checks whether the user is authorized to delete document.
    /// </summary>
    /// <param name="nodeId">Node id.</param>
    /// <param name="destroyDocHistory">Delete document history?</param>
    /// <param name="deleteAllCultureVersions">Delete all culture versions?</param>
    /// <returns></returns>
    protected bool IsUserAuthorizedToDeleteDocument(int nodeId, bool deleteDocHistory, bool deleteAllCultureVersions)
    {
        bool isAuthorized = true;

        CMS.TreeEngine.TreeNode node = null;
        TreeProvider tree = null;
        WorkflowManager wm = null;
        WorkflowStepInfo wsi = null;

        // Check delete permission
        if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Delete) == AuthorizationResultEnum.Allowed)
        {

            if (deleteDocHistory)
            {
                // Check destroy permisson
                if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Destroy) == AuthorizationResultEnum.Denied)
                {
                    isAuthorized = false;
                }
            }

            if (isAuthorized)
            {

                tree = new TreeProvider();
                node = tree.SelectSingleNode(nodeId);
                wm = new WorkflowManager(tree);


                // delete only current culture version
                //------------------------------------
                if (!deleteAllCultureVersions)
                {
                    // Check whether workflow is set
                    WorkflowInfo wi = wm.GetNodeWorkflow(node);
                    bool isWorkflow = (wi == null) ? false : true;

                    if (isWorkflow)
                    {
                        // Get current step info
                        wsi = wm.GetStepInfo(node);
                        if (wsi != null)
                        {
                            // Current step is 'edit', 'published', or 'archived'
                            if ((wsi.StepName.ToLower() == "edit") || (wsi.StepName.ToLower() == "published") || (wsi.StepName.ToLower() == "archived"))
                            {
                            }
                            // Another current step
                            else
                            {
                                bool canApprove = wm.CanUserApprove(node, CMSContext.CurrentUser);
                                if (!canApprove)
                                {
                                    isAuthorized = false;
                                }
                            }
                        }
                    }
                }
                // delete all culture versions
                //------------------------------------
                else
                {
                    if (node != null)
                    {
                        // Get the site info
                        SiteInfo si = SiteInfoProvider.GetSiteInfo(node.NodeSiteID);
                        if (si != null)
                        {
                            // Get all node culture versions
                            DataSet cultureNodes = tree.SelectNodes(si.SiteName, node.NodeAliasPath, TreeProvider.ALL_CULTURES, false, node.NodeClassName, null, null, -1, false);
                            if (!DataHelper.DataSourceIsEmpty(cultureNodes))
                            {
                                foreach (DataRow dr in cultureNodes.Tables[0].Rows)
                                {
                                    CMS.TreeEngine.TreeNode cultureNode = new CMS.TreeEngine.TreeNode(dr, node.NodeClassName, tree);

                                    // Check whether workflow is set
                                    WorkflowInfo wi = wm.GetNodeWorkflow(cultureNode);
                                    bool isWorkflow = (wi == null) ? false : true;

                                    if (isWorkflow)
                                    {
                                        // Get current step info
                                        wsi = wm.GetStepInfo(cultureNode);
                                        if (wsi != null)
                                        {
                                            // Current step is 'edit', 'published', or 'archived'
                                            if ((wsi.StepName.ToLower() == "edit") || (wsi.StepName.ToLower() == "published") || (wsi.StepName.ToLower() == "archived"))
                                            {
                                            }
                                            // Another current step
                                            else
                                            {
                                                bool canApprove = wm.CanUserApprove(cultureNode, CMSContext.CurrentUser);
                                                if (!canApprove)
                                                {
                                                    isAuthorized = false;
                                                    break;
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        else
        {
            isAuthorized = false;
        }

        return isAuthorized;
    }

}
