using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Globalization;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.FormEngine;
using CMS.FCKeditorV2;
using CMS.ExtendedControls;
using CMS.DataEngine;

public partial class CMSDesk_Content_edit : CMSDeskPage
{
    int nodeId = 0;
    bool newdocument = false;
    bool newculture = false;
    CMS.TreeEngine.TreeNode node = null;
    TreeProvider tree = null;
    int templateId = 0;
    int classId = 0;

    bool mShowToolbar = false;
    bool confirmChanges = false;

    DataClassInfo ci = null;

            
    /// <summary>
    /// Returns true if the changes should be saved
    /// </summary>
    public bool SaveChanges
    {
        get
        {
            return ValidationHelper.GetBoolean(HttpContext.Current.Request.Params["saveChanges"], false);
        }
    }


    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);
        
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        confirmChanges = SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSConfirmChanges");

        tree = new TreeProvider(CMSContext.CurrentUser);
        formElem.TreeProvider = tree;
        
        //   current nodeID
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        //   classID, used when creating new document                
        classId = ValidationHelper.GetInteger(Request.QueryString["classid"], 0);

        // templateID, used when Use template selection is enabled in actual class
        templateId = ValidationHelper.GetInteger(Request.QueryString["templateid"], 0);

        // Analyze the action parameter
        switch (ValidationHelper.GetString(Request.QueryString["action"], "").ToLower())
        {
            case "new":
                newdocument = true;
                break;

            case "newculture":
                newculture = true;
                break;

        }

        // Get the node
        if (newculture || newdocument)
        {
            node = DocumentHelper.GetDocument(nodeId, TreeProvider.ALL_CULTURES, tree);
            if (newculture)
            {
                DocumentHelper.ClearWorkflowInformation(node);
            }
        }
        else
        {
            node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);
        }

        this.plcSaveChanges.Visible = confirmChanges;

        // If node found, init the form
        if (node != null)
        {
            // CMSForm initialization
            formElem.NodeId = node.NodeID;
            formElem.CultureCode = CMSContext.CurrentUser.PreferredCultureCode; //node.DocumentCulture;

            // Set the form mode
            if (newdocument)
            {
                ci = DataClassInfoProvider.GetDataClass(classId);
                if (ci == null)
                {
                    throw new Exception("[Content/Edit.aspx]: Class ID '" + classId + "' not found.");
                }

                // Check if need template selection, if so, then redirect to template selection page
                if ((ci.ClassShowTemplateSelection) && (templateId == 0) && (ci.ClassName.ToLower() != "cms.menuitem"))
                {
                    Response.Redirect("TemplateSelection.aspx" + HttpContext.Current.Request.Url.Query);
                }

                // Set default template ID
                if (templateId > 0)
                {
                    formElem.DefaultPageTemplateID = templateId;
                }
                else
                {
                    formElem.DefaultPageTemplateID = ci.ClassDefaultPageTemplateID;
                }

                formElem.FormMode = FormModeEnum.Insert;
                string newClassName = ci.ClassName;
                formElem.FormName = newClassName + ".default";
            }
            else if (newculture)
            {
                formElem.FormMode = FormModeEnum.InsertNewCultureVersion;
                // Default data document ID
                formElem.CopyDefaultDataFromDocumentId = ValidationHelper.GetInteger(Request.QueryString["sourcedocumentid"], 0);

                ci = DataClassInfoProvider.GetDataClass(node.NodeClassName);
                formElem.FormName = node.NodeClassName + ".default";
            }
            else
            {
                formElem.FormMode = FormModeEnum.Update;
                ci = DataClassInfoProvider.GetDataClass(node.NodeClassName);
            }
            formElem.Visible = true;

            // Display / hide the FCK toolbar area
            FormInfo fi = new FormInfo();
            fi.LoadXmlDefinition(ci.ClassFormDefinition);

            if (fi.UsesHtmlArea())
            {
                // Add script to display toolbar
                if (FCKeditor.UseFrameForToolbar || FCKeditor.UseIFrameForToolbar)
                {
                    if (this.formElem.HtmlAreaToolbarLocation.ToLower() == "out:fcktoolbar")
                    {
                        mShowToolbar = true;

                        if (FCKeditor.UseIFrameForToolbar)
                        {
                            this.formElem.HtmlAreaToolbarLocation = "Out:parent(FCKToolbar)";
                        }
                        else
                        {
                            this.formElem.HtmlAreaToolbarLocation = "Out:parent.frames['edittoolbar'](FCKToolbar)";
                        }
                    }
                }
                else
                {
                    this.plcToolbar.Visible = true;
                    this.pnlToolbarHeight.Visible = true;
                }
            }

            ReloadForm();
        }

        this.ltlScript.Text += ScriptHelper.GetScript(
            "function SaveDocument(nodeId, createAnother) { document.getElementById('hidAnother').value = createAnother; " + (confirmChanges ? "AllowSubmit(); " : "") + ClientScript.GetPostBackEventReference(this.btnSave, null) + "; } \n" +
            "function Approve(nodeId) { " + ClientScript.GetPostBackEventReference(this.btnApprove, null) + "; } \n" +
            "function Reject(nodeId) { " + ClientScript.GetPostBackEventReference(this.btnReject, null) + "; } \n" +
            "function CheckIn(nodeId) { " + ClientScript.GetPostBackEventReference(this.btnCheckIn, null) + "; } \n" +
            (this.plcSaveChanges.Visible ? "var confirmSave='" + ResHelper.GetString("Content.ConfirmSave") + "'; var confirmLeave='" + ResHelper.GetString("Content.ConfirmLeave") + "'; \n" : "")
            );
    }


    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);

        this.formElem.lblInfo.Text = "";
    }


    private void ReloadForm()
    {
        this.lblWorkflowInfo.Text = "";
        
        formElem.Enabled = true;
        if ((node != null) && !newdocument && !newculture)
        {
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                CMSDeskPage.RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
            // Check modify permissions
            else if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
            {
                formElem.Enabled = false;
                pnlToolbarHeight.Visible = false;
                lblWorkflowInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
            }
            else
            {

                // Setup the workflow information
                WorkflowManager wm = new WorkflowManager(tree);
                WorkflowInfo wi = wm.GetNodeWorkflow(node);
                if ((wi != null) && (!newculture))
                {
                    // Get current step info
                    WorkflowStepInfo si = wm.GetStepInfo(node);
                    if (si != null)
                    {
                        bool allowApproval = true;
                        bool canApprove = wm.CanUserApprove(node, CMSContext.CurrentUser);
                        if (!(canApprove || (si.StepName.ToLower() == "edit") || (si.StepName.ToLower() == "published") || (si.StepName.ToLower() == "archived")))
                        {
                            formElem.Enabled = false;
                        }

                        // Check-in, Check-out
                        if (VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName))
                        {
                            if (node.GetValue("DocumentCheckedOutByUserID") == null)
                            {
                                // If not checked out, add the check-out information
                                if (canApprove || (si.StepName.ToLower() == "edit") || (si.StepName.ToLower() == "published") || (si.StepName.ToLower() == "archived"))
                                {
                                    this.lblWorkflowInfo.Text = ResHelper.GetString("EditContent.DocumentCheckedIn");
                                }
                                this.formElem.Enabled = newculture;
                                this.pnlToolbarHeight.Visible = false;
                            }
                            else
                            {
                                // If checked out by current user, add the check-in button
                                int checkedOutBy = ValidationHelper.GetInteger(node.GetValue("DocumentCheckedOutByUserID"), 0);
                                if (checkedOutBy == CMSContext.CurrentUser.UserID)
                                {
                                    // Document is checked out
                                    this.lblWorkflowInfo.Text = ResHelper.GetString("EditContent.DocumentCheckedOut");
                                }
                                else
                                {
                                    // Checked out by somebody else
                                    this.lblWorkflowInfo.Text = ResHelper.GetString("EditContent.DocumentCheckedOutByAnother");
                                    this.formElem.Enabled = newculture;
                                    this.pnlToolbarHeight.Visible = false;
                                }
                                allowApproval = false;
                            }
                        }

                        // Document approval
                        if (allowApproval)
                        {
                            switch (si.StepName.ToLower())
                            {
                                case "edit":
                                case "published":
                                case "archived":
                                    break;

                                default:
                                    // If the user is authorized to perform the step, display the approve and reject buttons
                                    if (!canApprove)
                                    {
                                        this.lblWorkflowInfo.Text += " " + ResHelper.GetString("EditContent.NotAuthorizedToApprove");
                                    }
                                    break;
                            }
                            this.lblWorkflowInfo.Text += " " + String.Format(ResHelper.GetString("EditContent.CurrentStepInfo"), si.StepDisplayName);

                        }

                    }
                }
            }
        }
        this.pnlWorkflowInfo.Visible = (this.lblWorkflowInfo.Text != "");
    }


    /// <summary>
    /// Adds the alert message to the output request window
    /// </summary>
    /// <param name="message">Message to display</param>
    private void AddAlert(string message)
    {
        this.ltlScript.Text += ScriptHelper.GetAlertScript(message);
    }


    /// <summary>
    /// Adds the script to the output request window
    /// </summary>
    /// <param name="script">Script to add</param>
    private void AddScript(string script)
    {
        this.ltlScript.Text += ScriptHelper.GetScript(script);
    }


    protected void btnSave_Click(object sender, EventArgs e)
    {
        SaveDocument();
    }


    private void SaveDocument()
    {
        if (nodeId > 0)
        {
            bool createAnother = newdocument && ValidationHelper.GetBoolean(Request.Params["hidAnother"], false);
            bool autoCheck = false;
            bool useWorkflow = false;
            VersionManager vm = null;
            if (!newdocument && !newculture)
            {
                autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
                WorkflowManager workflowMan = new WorkflowManager();

                // Get the document
                node = DocumentHelper.GetDocument(nodeId, CMSContext.CurrentUser.PreferredCultureCode, tree);

                //test if the document uses workflow
                if (workflowMan.GetNodeWorkflow(node) != null)
                {
                    useWorkflow = true;
                }
            }

            try
            {
                // If not using check-in/check-out, check out automatically
                if (autoCheck & useWorkflow)
                {
                    if (node != null)
                    {
                        // Check out
                        vm = new VersionManager(tree);
                        vm.CheckOut(node);

                    }
                }

                // tree node is returned from CMSForm.Save method
                if ((node != null) && !newdocument && !newculture)
                {
                    formElem.Save(node);
                }
                else
                {
                    int parentId = 0;

                    // Special treatment for blog post (ensure parent month)
                    if (newdocument && (ci != null) && (ci.ClassName.ToLower() == "cms.blogpost"))
                    {
                        // Get parent node
                        node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
                        if (node != null)
                        {
                            // Get parent blog ID when inserting post under blog month
                            if (node.NodeClassName.ToLower() == "cms.blogmonth")
                            {
                                node = tree.SelectSingleNode(node.NodeParentID, TreeProvider.ALL_CULTURES);
                                if (node != null)
                                {
                                    parentId = node.NodeID;
                                }
                            }
                            // Get parent blog ID when inserting post under blog
                            else
                            {
                                parentId = nodeId;
                            }

                            if (node != null)
                            {
                                // Validate the form first
                                if (formElem.BasicForm.ValidateData())
                                {
                                    CultureInfo cultureInfo = new CultureInfo(CMSContext.CurrentUser.PreferredCultureCode);

                                    // Prepare the data
                                    DateTime startDate = ValidationHelper.GetDateTime(formElem.BasicForm.GetFieldValue("BlogPostDate"), DateTimePicker.NOT_SELECTED);
                                    string monthName = startDate.ToString("MMMM", cultureInfo.DateTimeFormat) + " " + startDate.Year.ToString();
                                    // UpperCase first letter
                                    monthName = monthName.Substring(0, 1).ToUpper() + monthName.Substring(1);
                                    startDate = new DateTime(startDate.Year, startDate.Month, 1);

                                    // Check existing
                                    DataSet existingDS = tree.SelectNodes(CMSContext.CurrentSite.SiteName, node.NodeAliasPath + "/%", TreeProvider.ALL_CULTURES, true, "cms.blogmonth", "BlogMonthStartingDate = '" + TableManager.GetDateTimeString(startDate) + "'", null, -1, false);
                                    if (DataHelper.DataSourceIsEmpty(existingDS))
                                    {
                                        // Create the month node
                                        node = new CMS.TreeEngine.TreeNode("CMS.BlogMonth", tree);
                                        node.DocumentCulture = CMSContext.CurrentUser.PreferredCultureCode;

                                        // Insert the month
                                        node.SetValue("BlogMonthName", monthName);
                                        node.SetValue("BlogMonthStartingDate", startDate);
                                        node.DocumentName = monthName;
                                        node.Insert(parentId);

                                        this.formElem.NodeId = node.NodeID;
                                    }
                                    else
                                    {
                                        // Set existing
                                        this.formElem.NodeId = ValidationHelper.GetInteger(existingDS.Tables[0].Rows[0]["NodeID"], 0);
                                    }
                                }
                            }
                        }
                    }
                    node = formElem.Save();
                }

                if (node != null)
                {
                    // Check in the document
                    if (autoCheck & useWorkflow)
                    {
                        vm.CheckIn(node, null, null);
                        ReloadForm();
                    }

                    int newNodeId = node.NodeID;
                    if (newdocument || newculture)
                    {
                        if (createAnother)
                        {
                            this.AddScript("     PassiveRefresh(" + node.NodeParentID + ", " + node.NodeParentID + "); CreateAnother();");
                        }
                        else
                        {
                            // document tree is refreshed and new document is displayed
                            this.AddScript("     RefreshNode(" + newNodeId + "," + newNodeId + "); SelectNode(" + newNodeId + ");");
                        }
                    }
                    else
                    {
                        this.AddScript("     PassiveRefresh(" + nodeId + ", " + node.NodeParentID + ");");
                        this.formElem.lblInfo.Text += "<br />";
                        // displays - "Changes saved"
                        //lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }

                    // If not menuitem type, switch to form mode to keep editing the form
                    if (!TreePathUtils.IsMenuItemType(node.NodeClassName))
                    {
                        CMSContext.CurrentUser.ViewMode = ViewModeEnum.EditForm;
                    }
                }
            }
            catch (Exception ex)
            {
                AddAlert(ResHelper.GetString("ContentRequest.SaveFailed") + " : " + ex.Message);
            }
        }
    }


    protected void btnApprove_Click(object sender, EventArgs e)
    {
        if (node != null)
        {
            // Save the changes first
            bool autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
            if (autoCheck)
            {
                if (this.SaveChanges)
                {
                    SaveDocument();
                }
                else
                {
                    this.formElem.BasicForm.LoadControlValues();
                }
            }

            // Approve the document - Go to next workflow step
            WorkflowManager wm = new WorkflowManager(tree);

            // Get original step
            WorkflowStepInfo originalStep = wm.GetStepInfo(node);

            // Approve the document
            WorkflowStepInfo nextStep = wm.MoveToNextStep(node, "");
            if (nextStep != null)
            {
                // Send workflow e-mails
                if (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSSendWorkflowEmails"))
                {
                    if (nextStep.StepName.ToLower() == "published")
                    {
                        // Publish e-mails
                        wm.SendWorkflowEmails(node, CMSContext.CurrentUser, originalStep, nextStep, WorkflowActionEnum.Published, "");
                    }
                    else
                    {
                        // Approve e-mails
                        wm.SendWorkflowEmails(node, CMSContext.CurrentUser, originalStep, nextStep, WorkflowActionEnum.Approved, "");
                    }
                }
                this.ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + nodeId + ", " + node.NodeParentID + ");");
            }
            else
            {
                // Workflow has been removed
                this.AddScript("     SelectNode(" + nodeId + ");");
            }

            this.formElem.lblInfo.Text += " " + ResHelper.GetString("ContentEdit.WasApproved");
        }
        ReloadForm();
    }


    protected void btnReject_Click(object sender, EventArgs e)
    {
        // Reject the document - Go to previous workflow step
        if (node != null)
        {
            // Save the document first
            bool autoCheck = !VersionManager.UseCheckInCheckOut(CMSContext.CurrentSite.SiteName);
            if (autoCheck)
            {
                if (this.SaveChanges)
                {
                    SaveDocument();
                }
                else
                {
                    this.formElem.BasicForm.LoadControlValues();
                    this.ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + nodeId + ", " + node.NodeParentID + ");");
                }
            }

            WorkflowManager wm = new WorkflowManager(tree);

            // Get original step
            WorkflowStepInfo originalStep = wm.GetStepInfo(node);

            // Reject the document
            WorkflowStepInfo previousStep = wm.MoveToPreviousStep(node, "");

            if (previousStep != null)
            {
                // Send workflow e-mails
                if (SettingsKeyProvider.GetBoolValue(CMSContext.CurrentSite.SiteName + ".CMSSendWorkflowEmails"))
                {
                    wm.SendWorkflowEmails(node, CMSContext.CurrentUser, originalStep, previousStep, WorkflowActionEnum.Rejected, "");
                }

                this.ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + nodeId + ", " + node.NodeParentID + ");");
            }
            else
            {
                // Workflow has been removed
                this.AddScript("     SelectNode(" + nodeId + ");");
            }

            this.formElem.lblInfo.Text += " " + ResHelper.GetString("ContentEdit.WasRejected");
        }
        ReloadForm();
    }


    protected void btnCheckIn_Click(object sender, EventArgs e)
    {
        // Save the document first
        if (this.SaveChanges || !confirmChanges)
        {
            SaveDocument();
        }
        else
        {
            this.formElem.BasicForm.LoadControlValues();
            this.ltlScript.Text += ScriptHelper.GetScript("PassiveRefresh(" + nodeId + ", " + node.NodeParentID + ");");
        }

        // Check in the document
        if (node != null)
        {
            VersionManager verMan = new VersionManager(tree);

            // Check in the document        
            verMan.CheckIn(node, null, null);

            this.formElem.lblInfo.Text += " " + ResHelper.GetString("ContentEdit.WasCheckedIn");
        }

        ReloadForm();
    }


    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if (this.formElem.Enabled && mShowToolbar)
        {
            this.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.TOOLBAR_SCRIPT_KEY, ScriptHelper.ToolbarScript);
        }
    }

}

