using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.TreeEngine;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.PortalEngine;

public partial class CMSDesk_Content_edittabs : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Process the page mode
        CurrentUserInfo currentUser = CMSContext.CurrentUser;

        // Current Node ID
        int nodeId = 0;
        if (Request.QueryString["nodeid"] != null)
        {
            nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        }

        TreeProvider tree = new TreeProvider();
        CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId);

        int tabsRange = 4;

        bool showProductTab = false;

        string[,] tabs;

        if (CMSContext.CurrentSite != null)
        {
            string keyName = CMSContext.CurrentSite.SiteName + ".ProductTabEnabled";
            showProductTab = SettingsKeyProvider.GetBoolValue(keyName);
            if (showProductTab)
            {
                tabsRange++;
            }
        }


        if ((currentUser.IsGlobalAdministrator) && (node != null) && (node.NodeAliasPath != null) && (node.NodeAliasPath == "/"))
        {
            tabsRange++;
        }

        tabs = new string[tabsRange, 4];

        int isMastDisplayed = 0;

        PageInfo pi = null;
        PageTemplateInfo pti = null;

        if (node != null)
        {
            pi = PageInfoProvider.GetPageInfo(CMSContext.CurrentSite.SiteName, node.NodeAliasPath, node.DocumentCulture, node.DocumentUrlPath, false, null);
        }

        if (pi != null)
        {
            pti = pi.PageTemplateInfo;
        }

        if ((currentUser.IsGlobalAdministrator) && (node != null) && (node.NodeAliasPath != null) && (node.NodeAliasPath == "/"))
        {
            if (pti != null)
            {
                if (pti.IsPortal)
                {
                    isMastDisplayed = 1;

                    tabs[tabsRange - 2, 0] = "&nbsp;" + ResHelper.GetString("edittabs.masterpage") + "&nbsp;";
                    tabs[tabsRange - 2, 2] = "MasterPage/PageEditFrameset.aspx?nodeid=" + nodeId.ToString();
                }
            }
        }


        if ((CMSContext.CurrentSite != null) && (showProductTab) && (tabsRange > 4))
        {
            tabs[tabsRange - 2 - isMastDisplayed, 0] = "&nbsp;" + ResHelper.GetString("edittabs.product") + "&nbsp;";
            tabs[tabsRange - 2 - isMastDisplayed, 2] = "Product/Product_Selection.aspx?nodeid=" + nodeId.ToString();
        }

        tabs[0, 0] = "&nbsp;" + ResHelper.GetString("EditTabs.Page") + "&nbsp;";
        tabs[0, 2] = "editframeset.aspx?mode=edit&nodeid=" + Request.QueryString["nodeid"];

        if ((currentUser.IsGlobalAdministrator) && (pti != null) && (pti.IsPortal))
        {
            tabs[1, 0] = "&nbsp;" + ResHelper.GetString("EditTabs.Design") + "&nbsp;";
            tabs[1, 2] = "editframeset.aspx?mode=design&nodeid=" + Request.QueryString["nodeid"];
        }

        tabs[2, 0] = "&nbsp;" + ResHelper.GetString("EditTabs.Form") + "&nbsp;";
        tabs[2, 2] = "editframeset.aspx?mode=editform&nodeid=" + Request.QueryString["nodeid"];


        if (CMSContext.CurrentSite != null)
        {
            string keyName = CMSContext.CurrentSite.SiteName + ".CMSPersonalizeUserInterface";
            bool personalize = SettingsKeyProvider.GetBoolValue(keyName);

            if ((personalize && CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.UserInterface", "PropertiesTab")) || (!personalize))
            {
                tabs[tabsRange - 1, 0] = "&nbsp;" + ResHelper.GetString("EditTabs.Properties") + "&nbsp;";
                tabs[tabsRange - 1, 2] = "Properties/default.aspx?nodeid=" + Request.QueryString["nodeid"];
            }
        }

        tabsModes.Tabs = tabs;
        tabsModes.SelectedTab = 0;
        tabsModes.UrlTarget = "contenteditview";


        // Get the node

        if (node != null)
        {
            string path = ValidationHelper.GetString(node.GetValue("DocumentNamePath"), node.NodeAliasPath).Trim('/');
            if (path == "")
            {
                SiteInfo si = SiteInfoProvider.GetSiteInfo(node.NodeSiteID);
                if (si != null)
                {
                    path = si.SiteName;
                }
            }
            //this.titleElem.CreateStaticBreadCrumbs(path);
            UpdateViewMode(node, ViewModeEnum.Edit);

            bool isPageItem = TreePathUtils.IsMenuItemType(node.NodeClassName);

            // Get the page mode
            ViewModeEnum currentMode = ViewModeEnum.Edit;
            if (isPageItem)
            {
                currentMode = currentUser.MenuItemViewMode;
            }
            else
            {
                currentMode = currentUser.ViewMode;
            }

            // If not global administrator, do not allow design mode
            if (!currentUser.IsGlobalAdministrator && (currentMode == ViewModeEnum.Design))
            {
                if (isPageItem)
                {
                    currentUser.MenuItemViewMode = ViewModeEnum.Edit;
                }
                else
                {
                    currentUser.ViewMode = ViewModeEnum.Edit;
                }
            }

            // Set the radio buttons
            switch (currentMode)
            {
                case ViewModeEnum.Edit:
                    this.tabsModes.SelectedTab = 0;
                    break;
                case ViewModeEnum.Design:
                    this.tabsModes.SelectedTab = 1;
                    break;
                case ViewModeEnum.EditForm:
                    this.tabsModes.SelectedTab = 2;
                    break;
            }
        }
    }
}
