using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.Blogs;
using CMS.WorkflowEngine;
using CMS.LicenseProvider;


public partial class CMSDesk_MyDesk_MyBlogs_myblogs : CMSDeskPage
{
    protected SiteInfo currentSite = null;
    protected CurrentUserInfo currentUser = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check license
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Blogs);
        }

        currentSite = CMSContext.CurrentSite;
        currentUser = CMSContext.CurrentUser;
        if ((currentSite == null) || (currentUser == null))
        {
            return;
        }

        DataClassInfo dci = null;
        string classId = "";
        string script = "";

        this.titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/MyDesk/MyBlogs/Blogs.gif";
        this.titleElem.TitleText = ResHelper.GetString("MyDesk.MyBlogs.Title");
        lblComments.Text = ResHelper.GetString("MyBlogs.CommentsWaitingForApproval");
        


        // MY BLOGS
        
        // Get current user blogs
        TreeProvider tree = new TreeProvider();     
        gridBlogs.DataSource = DocumentHelper.GetDocuments(currentSite.SiteName, "/%", TreeProvider.ALL_CULTURES, false, "cms.blog", "NodeOwner = " + currentUser.UserID, "BlogName ASC", -1, false, tree);

        // Get ClassID of the 'cms.blogpost' class        
        dci = DataClassInfoProvider.GetDataClass("cms.blogpost");
        if (dci != null)
        {
            classId = dci.ClassID.ToString();
        }

        // Get scritp to redirect to new blog post page        
        script += "function NewPost(parentId){";
        script += " if(parentId != 0){";
        script += "  parent.parent.location.href = \"../../default.aspx?section=content&action=new&nodeid=\" + parentId + \"&classid=" + classId + "\";";
        script += " }}\n";


        // COMMENTS WAITING FRO APPROVAL

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);
        gridComments.OnAction += new OnActionEventHandler(gridComments_OnAction);
        gridComments.OnDataReload += new OnDataReload(gridComments_OnDataReload);
        gridComments.HideControlForZeroRows = true;

        script += "function EditComment(commentId){";
        script += " modalDialog('" + ResolveUrl("~/CMSBlog/Comment_Edit.aspx") + "?commentID=' + commentId, 'Comment Edit', 400, 320);";
        script += "}";        

        // Generate javascript code
        ltlScript.Text = ScriptHelper.GetScript(script);

        // Show/Hide label "Comments waiting for my approval"
        lblComments.Visible = !((DataHelper.DataSourceIsEmpty(gridComments.DataSource) && DataHelper.DataSourceIsEmpty(gridBlogs.DataSource)));
    }


    DataSet gridComments_OnDataReload(string completeWhere)
    {
        return BlogCommentInfoProvider.GetCommentsWaitingForApproval(currentSite.SiteName, currentUser.UserID);
    }


    void gridComments_OnAction(string actionName, object actionArgument)
    {
        int commentId = ValidationHelper.GetInteger(actionArgument, 0);
        CMS.TreeEngine.TreeNode blogNode = null;
        bool isOwner = false;

        switch (actionName.ToLower())
        {

            case "delete":

                // Is user authorized to manage comments?
                blogNode = BlogHelper.GetCommentParentBlog(commentId);
                if (blogNode != null)
                {
                    isOwner = (currentUser.UserID == ValidationHelper.GetInteger(blogNode.GetValue("NodeOwner"), 0));                    
                }

                // check 'Manage' permission
                if (!currentUser.IsAuthorizedPerResource("cms.blog", "Manage") && !isOwner)
                {
                    CMSDeskPage.RedirectToAccessDenied("cms.blog", "Manage");
                }
                // Delete specified comment
                BlogCommentInfoProvider.DeleteBlogCommentInfo(commentId);
                gridComments.ReloadData();
                break;

            case "approve":
                // Is user authorized to manage comments?
                blogNode = BlogHelper.GetCommentParentBlog(commentId);
                if (blogNode != null)
                {
                    isOwner = (currentUser.UserID == ValidationHelper.GetInteger(blogNode.GetValue("NodeOwner"), 0));
                }

                // check 'Manage' permission
                if (!currentUser.IsAuthorizedPerResource("cms.blog", "Manage") && !isOwner)
                {
                    CMSDeskPage.RedirectToAccessDenied("cms.blog", "Manage");
                }
                BlogCommentInfo bci = BlogCommentInfoProvider.GetBlogCommentInfo(commentId);
                if (bci != null)
                {
                    // Set comment as 'approved'
                    bci.CommentApprovedByUserID = currentUser.UserID;                    
                    BlogCommentInfoProvider.SetBlogCommentInfo(bci);
                    gridComments.ReloadData();
                }                
                break;
            
            case "edit":
                // Javascript - EditComment();
                break;
        }
    }
    
}
