using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;

public partial class CMSDesk_MyDesk_myprofile : CMSDeskPage
{
    protected string myCulture = "";
    protected string myUICulture = "";
    
    protected void Page_Load(object sender, EventArgs e)
    {
        
        
        this.titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/MyDesk/MyProfile/myprofile.gif";
        this.titleElem.TitleText = ResHelper.GetString("MyDesk.MyProfileTitle");

        lblMyUserName.Text = ResHelper.GetString("MyDesk.MyProfile.UserName");
        lblMyFullName.Text = ResHelper.GetString("MyDesk.MyProfile.FullName");
        lblEmail.Text = ResHelper.GetString("MyDesk.MyProfile.Email");
        lblCulture.Text = ResHelper.GetString("MyDesk.MyProfile.Culture");
        lblUICulture.Text = ResHelper.GetString("MyDesk.MyProfile.UICulture");
        btnOK.Text = ResHelper.GetString("MyDesk.MyProfile.btnOK");

        LoadData();
    }

    /// <summary>
    /// Loads data of actual user from DB into TextBoxes.
    /// </summary>
    protected void LoadData()
    {
        if (!IsPostBack)
        {
            // Fill lstCulture
            DataSet ds = new DataSet();
            ds = CultureInfoProvider.GetSiteCultures(CMSContext.CurrentSite.SiteName);
            lstCulture.DataSource = ds.Tables[0];
            lstCulture.DataTextField = ds.Tables[0].Columns["CultureName"].ColumnName.ToString();
            lstCulture.DataValueField = ds.Tables[0].Columns["CultureID"].ColumnName.ToString();
            lstCulture.DataBind();

            lstCulture.Items.Insert(0, ResHelper.GetString("Administration-User_Edit.Default"));
            lstCulture.Items[0].Value = "0";

            // Fill lstUICulture
            ds = UICultureInfoProvider.GetAllUICultures();
            lstUICulture.DataSource = ds.Tables[0];
            lstUICulture.DataTextField = ds.Tables[0].Columns["UICultureName"].ColumnName.ToString();
            lstUICulture.DataValueField = ds.Tables[0].Columns["UICultureID"].ColumnName.ToString();
            lstUICulture.DataBind();

            lstUICulture.Items.Insert(0, ResHelper.GetString("Administration-User_Edit.Default"));
            lstUICulture.Items[0].Value = "0";
        }

        UserInfo ui = UserInfoProvider.GetUserInfo(CMSContext.CurrentUser.UserName);

        // Load data 
        lblUserName.Text = ui.UserName;
        lblFullName.Text = ui.FullName;
        
        if (!IsPostBack)
        {   // Load no-postback data
            txtEmail.Text = ui.Email;
            myCulture = ui.PreferredCultureCode;
            myUICulture = ui.PreferredUICultureCode;

            // select cultures for actual user or set default
            if ((myCulture != null) && (myCulture != ""))
            {
                try
                {
                    CultureInfo ci = CultureInfoProvider.GetCultureInfo(myCulture);
                    lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue(ci.CultureID.ToString()));
                }
                catch
                {
                    lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue("0"));
                }
            }
            else
                lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue("0"));

            if ((myUICulture != null) && (myUICulture != ""))
            {
                try
                {
                    UICultureInfo ciUI = UICultureInfoProvider.GetUICultureInfo(myUICulture);
                    lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue(ciUI.UICultureID.ToString()));
                }
                catch
                {
                    lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue("0"));
                }
            }
            else
                lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue("0"));
        }
    }
    /// <summary>
    /// Update information in DB from MyDesk->Myprofile
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {

        UserInfo ui = UserInfoProvider.GetUserInfo(CMSContext.CurrentUser.UserID);
        
        // set email
        ui.Email = txtEmail.Text;

        // email format validation
        if ((ui.Email.Trim() != "") && (!ValidationHelper.IsEmail(ui.Email)))
        {
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("MyDesk.MyProfile.WrongEmailFormat");
            return;
        }

        
        // Set values of cultures.
        if (lstCulture.SelectedValue == "0")
            ui.PreferredCultureCode = "";
        else
        {
            CultureInfo ci = CultureInfoProvider.GetCultureInfo(Convert.ToInt32(lstCulture.SelectedValue));
            ui.PreferredCultureCode = ci.CultureCode;

            CMSContext.CurrentUser.PreferredCultureCode = ci.CultureCode;
        }
        
        if (lstUICulture.SelectedValue == "0")
            ui.PreferredUICultureCode = "";
        else
        {
            UICultureInfo ciUI = UICultureInfoProvider.GetUICultureInfo(Convert.ToInt32(lstUICulture.SelectedValue));
            ui.PreferredUICultureCode = ciUI.UICultureCode;

            CMSContext.CurrentUser.PreferredUICultureCode = ciUI.UICultureCode;
        }
        
        UserInfoProvider.SetUserInfo(ui);

        CMSContext.CurrentUser.Email = ui.Email;

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
   }

}
