using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.FormEngine;
using CMS.CMSHelper;
using CMS.SiteProvider;

public partial class CMSDesk_PortalEngine_WebpartBinding : System.Web.UI.UserControl
{
    protected string mAliasPath = null;
    protected string mZoneId = null;
    protected string mWebpartId = null;

    #region "Public properties"

    /// <summary>
    /// Page alias path
    /// </summary>
    public string AliasPath
    {
        get
        {
            return mAliasPath;
        }
        set
        {
            mAliasPath = value;
        }
    }


    /// <summary>
    /// Zone ID
    /// </summary>
    public string ZoneId
    {
        get
        {
            return mZoneId;
        }
        set
        {
            mZoneId = value;
        }
    }


    /// <summary>
    /// Web part ID
    /// </summary>
    public string WebpartId
    {
        get
        {
            return mWebpartId;
        }
        set
        {
            mWebpartId = value;
        }
    }

    #endregion

    /// <summary>
    /// Current page info
    /// </summary>
    PageInfo pi = null;

    /// <summary>
    /// Current zone
    /// </summary>
    WebPartZoneInstance zone = null;

    /// <summary>
    /// Current bindings
    /// </summary>
    Hashtable bindings = null;

    /// <summary>
    /// Current web part
    /// </summary>
    WebPartInstance webPart = null;


    protected override void OnInit(EventArgs e)
    {
        gvBinding.RowDataBound += new GridViewRowEventHandler(gvBinding_RowDataBound);

        base.OnInit(e);

        gvBinding.Columns[0].HeaderText = ResHelper.GetString("WebPartBinding.HeaderAction");
        gvBinding.Columns[1].HeaderText = ResHelper.GetString("WebPartBinding.HeaderLocalProperty");
        gvBinding.Columns[2].HeaderText = ResHelper.GetString("WebPartBinding.HeaderSourceProperty");
        gvBinding.GridLines = GridLines.Horizontal;

        BindData();
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // delete confirmation
        ltlScript.Text = ScriptHelper.GetScript("var deleteConfirmation = '" + ResHelper.GetString("WebPartBinding.DeleteConfirmation") + "';");

        btnOK.Click += new EventHandler(btnOK_Click);
        gvBinding.RowDeleting += new GridViewDeleteEventHandler(gvBinding_RowDeleting);

        btnOnOK.Click += new EventHandler(btnOnOK_Click);
        btnOnApply.Click += new EventHandler(btnOnApply_Click);

        Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ApplyButton", ScriptHelper.GetScript("function OnApplyButton(){" + Page.ClientScript.GetPostBackEventReference(btnOnApply, "") + "}"));
        Page.ClientScript.RegisterClientScriptBlock(typeof(string), "OKButton", ScriptHelper.GetScript("function OnOKButton(){" + Page.ClientScript.GetPostBackEventReference(btnOnOK, "") + "}"));

        lblCaption.Text = ResHelper.GetString("WebPartBinding.Caption");
        lblProperty.Text = ResHelper.GetString("WebPartBinding.lblProperty");
        lblSourceId.Text = ResHelper.GetString("WebPartBinding.lblSourceId");
        lblSourceProprety.Text = ResHelper.GetString("WebPartBinding.lblSourceProperty");
        rfvSourceId.ErrorMessage = ResHelper.GetString("WebPartBinding.rfvSourceId");
        rfvSourceProperty.ErrorMessage = ResHelper.GetString("WebPartBinding.rfvSourceProperty");
        btnOK.Text = ResHelper.GetString("WebPartBinding.btnOK");
    }

    void gvBinding_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        ImageButton btn = (ImageButton)e.Row.FindControl("lnkDelete");
        if (btn != null)
        {
          btn.ImageUrl = "~/App_Themes/" + this.Page.Theme + "/Images/CMSAdminControls/UniGrid/delete.gif";
        }
    }

    void gvBinding_RowDeleting(object sender, GridViewDeleteEventArgs e)
    {
        BindData();
    }

    void btnOK_Click(object sender, EventArgs e)
    {
        WebPartBindingInfo bi = new WebPartBindingInfo();
        bi.SourceProperty = txtSourceProperty.Text;
        bi.SourceWebPart = txtSourceId.Text;
        bi.TargetProperty = drpProperty.SelectedValue;
        webPart.Bindings[drpProperty.SelectedValue.ToLower()] = bi;
        Save();
        BindData();
    }

    void btnOnApply_Click(object sender, EventArgs e)
    {
        Save();
        this.Response.Redirect(Request.Url.AbsoluteUri);
    }

    void btnOnOK_Click(object sender, EventArgs e)
    {
        Save();
        string script = "";
        // Close the window
        ltlScript.Text = ScriptHelper.GetScript(script + "top.window.close();");
    }


    /// <summary>
    /// Saves webpart properties.
    /// </summary>
    public void Save()
    {
        // Update page template
        PageTemplateInfoProvider.SetPageTemplateInfo(pi.PageTemplateInfo);
        txtSourceId.Text = "";
        txtSourceProperty.Text = "";
        drpProperty.SelectedIndex = 0;
    }

    public void BindData()
    {
        if ((WebpartId != "") && (ZoneId != "") && (AliasPath != ""))
        {
            // get pageinfo
            pi = PageInfoProvider.GetPageInfo(CMSContext.CurrentSite.SiteName, AliasPath, CMSContext.CurrentUser.PreferredCultureCode, null, CMSContext.CurrentSite.CombineWithDefaultCulture, null);
            // get zone instance
            zone = pi.PageTemplateInfo.GetZone(ZoneId);

            // if zone not found try find upper zone
            if (zone == null)
            {
                string tmpAlias = AliasPath;

                while ((zone == null) && (tmpAlias != null) && (tmpAlias != ""))
                {
                    if (tmpAlias.IndexOf('/') >= 0)
                    {
                        tmpAlias = tmpAlias.Remove(tmpAlias.LastIndexOf('/'));
                    }
                    else
                    {
                        tmpAlias = "";
                    }

                    if (tmpAlias != "")
                    {
                        pi = PageInfoProvider.GetPageInfo(CMSContext.CurrentSite.SiteName, tmpAlias, CMSContext.CurrentUser.PreferredCultureCode, null, CMSContext.CurrentSite.CombineWithDefaultCulture, null);
                        zone = pi.PageTemplateInfo.GetZone(ZoneId);
                    }
                }
            }

            // get webpart
            webPart = zone.GetWebPart(WebpartId);
            // get webpart properties (XML)
            string wpProperties = WebPartInfoProvider.GetWebPartInfo(webPart.WebPartType).WebPartProperties;

            FormInfo fi = new FormInfo();
            fi.LoadXmlDefinition(wpProperties);
            // get datarow with required columns
            DataRow dr = fi.GetDataRow();

            // Bind drop down list
            if (!IsPostBack)
            {
                DataTable dropTable = new DataTable();
                dropTable.Columns.Add("name");
                
                foreach(DataColumn column in dr.Table.Columns)
                {
                    dropTable.Rows.Add(column.ColumnName);
                }

                dropTable.DefaultView.Sort = "name";
                drpProperty.DataTextField = "name";
                drpProperty.DataValueField = "name";
                drpProperty.DataSource = dropTable.DefaultView;
                drpProperty.DataBind();
            }

            // Bind grid view
            DataTable table = new DataTable();
            table.Columns.Add("LocalProperty");
            table.Columns.Add("SourceProperty");
            bindings = webPart.Bindings;

            foreach (DataColumn column in dr.Table.Columns)
            {
                string propertyName = column.ColumnName.ToLower();
                if (bindings.ContainsKey(propertyName))
                {
                    WebPartBindingInfo bi = (WebPartBindingInfo)bindings[propertyName];
                    table.Rows.Add(column.ColumnName, bi.SourceWebPart + "." + bi.SourceProperty);
                }
            }

            gvBinding.DataSource = table;
            gvBinding.DataBind();
        }
    }

    /// <summary>
    /// Delete selected item
    /// </summary>
    protected void lnkDelete_OnCommand(object sender, CommandEventArgs e)
    {
        string propertyName = e.CommandArgument.ToString().ToLower();
        if (bindings.ContainsKey(propertyName))
        {
            bindings.Remove(propertyName);
            Save();
        }
    }
}
