using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.FormEngine;
using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.WorkflowEngine;

public partial class CMSDesk_PortalEngine_WebpartPropertiesControl : System.Web.UI.UserControl
{
    protected string mAliasPath = null;
    protected string mZoneId = null;
    protected string mWebpartId = null;
    protected bool mWebPartIdChanged = false;

    #region "Public properties"

    /// <summary>
    /// Page alias path
    /// </summary>
    public string AliasPath
    {
        get
        {
            return mAliasPath;
        }
        set
        {
            mAliasPath = value;
        }
    }


    /// <summary>
    /// Zone ID
    /// </summary>
    public string ZoneId
    {
        get
        {
            return mZoneId;
        }
        set
        {
            mZoneId = value;
        }
    }


    /// <summary>
    /// Web part ID
    /// </summary>
    public string WebpartId
    {
        get
        {
            return mWebpartId;
        }
        set
        {
            mWebpartId = value;
        }
    }


    /// <summary>
    /// True if the web part ID has changed
    /// </summary>
    public bool WebPartIdChanged
    {
        get
        {
            return mWebPartIdChanged;
        }
    }

    #endregion


    /// <summary>
    /// Current page info
    /// </summary>
    PageInfo pi = null;

    /// <summary>
    /// Current zone
    /// </summary>
    WebPartZoneInstance zone = null;

    /// <summary>
    /// Current web part
    /// </summary>
    WebPartInstance webPart = null;


    protected override void OnInit(EventArgs e)
    {
        base.OnInit(e);

        if ((WebpartId != "") && (ZoneId != "") && (AliasPath != ""))
        {
            // get pageinfo
            pi = PageInfoProvider.GetPageInfo(CMSContext.CurrentSite.SiteName, AliasPath, CMSContext.CurrentUser.PreferredCultureCode, null, CMSContext.CurrentSite.CombineWithDefaultCulture, null);
            // get zone instance
            zone = pi.PageTemplateInfo.GetZone(ZoneId);

            // if zone not found try find upper zone
            if (zone == null)
            {
                string tmpAlias = AliasPath;

                while ((zone == null) && (tmpAlias != null)&&(tmpAlias != ""))
                {
                    if (tmpAlias.IndexOf('/') >= 0)
                    {
                        tmpAlias = tmpAlias.Remove(tmpAlias.LastIndexOf('/'));
                    }
                    else
                    {
                        tmpAlias = "";
                    }

                    if (tmpAlias != "")
                    {
                        pi = PageInfoProvider.GetPageInfo(CMSContext.CurrentSite.SiteName, tmpAlias, CMSContext.CurrentUser.PreferredCultureCode, null, CMSContext.CurrentSite.CombineWithDefaultCulture, null);
                        zone = pi.PageTemplateInfo.GetZone(ZoneId);
                    }
                }
            }

            // get webpart
            webPart = zone.GetWebPart(WebpartId);
            // get webpart properties (XML)
            string wpProperties = WebPartInfoProvider.GetWebPartInfo(webPart.WebPartType).WebPartProperties;

            FormInfo fi = new FormInfo();
            fi.LoadXmlDefinition(wpProperties);
            // get datarow with required columns
            DataRow dr = fi.GetDataRow();
            // fill the data row
            foreach (DataColumn column in dr.Table.Columns)
            {
                try
                {
                    DataHelper.SetDataRowValue(dr, column.ColumnName, webPart.GetValue(column.ColumnName));
                }
                catch
                {
                }
            }
            // Display / hide the FCK toolbar area
            if (fi.UsesHtmlArea())
            {
                this.plcToolbar.Visible = true;
                this.pnlFormArea.Height = 285;
            }

            // initialize Form
            formElem.DataRow = dr;
            formElem.SubmitButton.Visible = false;
            formElem.SiteName = CMSContext.CurrentSite.SiteName;
            formElem.FormInformation = fi;
            formElem.ShowPrivateFields = true;
            formElem.OnItemValidation += new BasicForm.OnItemValidationEventHandler(formElem_OnItemValidation);
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        btnOnOK.Click += new EventHandler(btnOnOK_Click);
        btnOnApply.Click += new EventHandler(btnOnApply_Click);

        Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ApplyButton", ScriptHelper.GetScript("function OnApplyButton(){" + Page.ClientScript.GetPostBackEventReference(btnOnApply, "") + "}"
                                                                                                         + "function OnOKButton(){" + Page.ClientScript.GetPostBackEventReference(btnOnOK, "") + "}"));
    }


    /// <summary>
    /// Control ID validation
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="errorMessage"></param>
    void formElem_OnItemValidation(object sender, ref string errorMessage)
    {
        Control ctrl = (Control)sender;
        if (ctrl.ID.ToLower() == "webpartcontrolid")
        {
            TextBox ctrlTextbox = (TextBox)ctrl;
            string newId = ctrlTextbox.Text;
            // Validate unique ID
            WebPartInstance existingPart = pi.PageTemplateInfo.GetWebPart(newId);
            if ((existingPart != null) && (existingPart != webPart))
            {
                // Error - duplicit IDs
                errorMessage = ResHelper.GetString("WebPartProperties.ErrorUniqueID");
            }
        }
    }


    /// <summary>
    /// Saves webpart properties.
    /// </summary>
    public bool Save()
    {
        // Save the data
        if (formElem.SaveData(""))
        {
            string oldId = webPart.ControlID.ToLower();
            // Get basicform's datarow and update webpart
            DataRow dr = formElem.DataRow;
            foreach (DataColumn column in dr.Table.Columns)
            {
                webPart.SetValue(column.ColumnName, dr[column]);
                // If name changed, move the content
                if (column.ColumnName.ToLower() == "webpartcontrolid")
                {
                    try
                    {
                        string newId = ValidationHelper.GetString(dr[column], "").ToLower();
                        // Name changed, move the document content if present
                        if ((newId != "") && (newId != oldId))
                        {
                            this.mWebPartIdChanged = true;
                            this.WebpartId = newId;
                            // Get the content
                            string currentContent = Convert.ToString(pi.EditableWebParts[oldId]);
                            if (currentContent != null)
                            {
                                TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
                                CMS.TreeEngine.TreeNode node = DocumentHelper.GetDocument(pi.DocumentId, tree);
                                // Move the content
                                pi.EditableWebParts[oldId] = null;
                                pi.EditableWebParts[newId] = currentContent;

                                // Save the document
                                node.SetValue("DocumentContent", pi.GetContentXml());
                                DocumentHelper.UpdateDocument(node, tree);
                            }
                        }
                    }
                    catch
                    {
                    }
                }
            }
            // Update page template
            PageTemplateInfoProvider.SetPageTemplateInfo(pi.PageTemplateInfo);

            return true;
        }
        else
        {
            return false;
        }
    }


    /// <summary>
    /// Saves the webpart properties and closes the window.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOnOK_Click(object sender, EventArgs e)
    {
        // Save webpart properties
        if (Save())
        {
            string script = "";
            if (WebPartIdChanged)
            {
                script = "RefreshPage(); \n";
            }
            // Close the window
            ltlScript.Text += ScriptHelper.GetScript(script + "top.window.close();");
        }
    }


    /// <summary>
    /// Saves the webpart properties
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOnApply_Click(object sender, EventArgs e)
    {
        if (Save())
        {
            if (WebPartIdChanged)
            {
                ltlScript.Text += ScriptHelper.GetScript("ChangeWebPart('" + ZoneId + "', '" + WebpartId + "', '" + AliasPath + "');RefreshPage();");
            }
        }
    }

}
