using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.WebAnalytics;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Analytics_Analytics_Days : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Get values from querystring
        string statCodeName = ValidationHelper.GetString(Request.QueryString["statCodeName"], "");
        string dataCodeName = ValidationHelper.GetString(Request.QueryString["dataCodeName"], "");
        string reportCodeName = ValidationHelper.GetString(Request.QueryString["reportCodeName"], "");
        string additionalCodeName = ValidationHelper.GetString(Request.QueryString["additionalCodeName"], "");
        int year = ValidationHelper.GetInteger(Request.QueryString["year"], DateTime.Today.Year);
        int month = ValidationHelper.GetInteger(Request.QueryString["month"], DateTime.Today.Month);

        if (!IsPostBack)
        {
            GUIInit(year, month);
        }

        // Week and day graphs
        ucGraphDays.AddGraph(25, "WeekGraph");
        LoadWeekData(year, month, statCodeName, dataCodeName, reportCodeName, additionalCodeName);
        ucGraphDays.AddGraph(40, "DayGraph");
        LoadDayData(year, month, statCodeName, dataCodeName, reportCodeName, additionalCodeName);

        ucGraphDays.RenderGraph();
    }


    /// <summary>
    /// Page title initialization.
    /// </summary>
    /// <param name="year">Current (selected) year.</param>
    /// <param name="month">Current (selected) month.</param>
    public void GUIInit(int year, int month)
    {
        string title = ResHelper.GetString(DateTimeHelper.GetMonthName(month, CMSContext.CurrentUser.PreferredUICultureCode) + " " + year);
        title = title[0].ToString().ToUpper() + title.Substring(1);

        PageTitle.TitleText = title;
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Analytics/month.gif";
    }


    /// <summary>
    /// Loads days statistics and creates graph.
    /// </summary>
    /// <param name="year">Year</param>
    /// <param name="month">Month</param>
    /// <param name="statCodeName">Analytics code name (pageviews, pageviews.multilingual...)</param>
    /// <param name="dataCodeName">Data code name (pageviews...)</param>
    /// <param name="reportCodeName">Report code name list (pageviews.yearreport, pageviews.monthreport...)</param>
    /// <param name="additionalCodeName">Additional code name (for visitors stats)</param>
    protected void LoadDayData(int year, int month, string statCodeName, string dataCodeName, string reportCodeName, string additionalCodeName)
    {
        int sum = 0;

        DateTime dt = new DateTime(year, month, 1, 12, 0, 0);
        for (int i = 0; i < DateTime.DaysInMonth(year, month); i++)
        {
            DataSet ds = HitsInfoProvider.GetAllHitsInfo(
                CMSContext.CurrentSite.SiteID,
                HitsIntervalEnum.Day, new string[] { dataCodeName, additionalCodeName }, dt);

            sum = 0;
            if (ds != null)
            {
                foreach (DataRow row in ds.Tables[0].Rows)
                {
                    sum += ValidationHelper.GetInteger(row["HitsCount"], 0);
                }
            }

            ucGraphDays.AddGraphData(sum,
                dt.Day + "", sum + "",
                "Analytics_Report.aspx?statCodeName=" + statCodeName + "&dataCodeName=" + dataCodeName + "&reportCodeName=" + reportCodeName + "&year=" + year + "&month=" + dt.Month + "&day=" + dt.Day,
                "",
                1);

            dt = dt.AddDays(1);
        }
    }


    /// <summary>
    /// Loads days statistics and creates graph.
    /// </summary>
    /// <param name="year">Year</param>
    /// <param name="month">Month</param>
    /// <param name="statCodeName">Analytics code name (pageviews, pageviews.multilingual...)</param>
    /// <param name="dataCodeName">Data code name (pageviews...)</param>
    /// <param name="reportCodeName">Report code name list (pageviews.yearreport, pageviews.monthreport...)</param>
    /// <param name="additionalCodeName">Additional code name (for visitors stats)</param>
    protected void LoadWeekData(int year, int month, string statCodeName, string dataCodeName, string reportCodeName, string additionalCodeName)
    {
        int numOfWeeks = DateTimeHelper.NumberOfWeeks(
            new DateTime(year, month, 1),
            new DateTime(year, month, DateTime.DaysInMonth(year, month)),
            AnalyticsHelper.AnalyticsCulture);

        int sum;

        DateTime dt = new DateTime(year, month, 1, 12, 0, 0);
        TimeSpan span = dt.Subtract(DateTimeHelper.GetWeekStart(dt, AnalyticsHelper.AnalyticsCulture));
        int increment = 7 - span.Days;
        for (int i = 0; i < numOfWeeks; i++)
        {
            DataSet ds = HitsInfoProvider.GetAllHitsInfo(
                CMSContext.CurrentSite.SiteID, HitsIntervalEnum.Week,
                new string[] { dataCodeName, additionalCodeName }, dt);

            sum = 0;
            if (ds != null)
            {
                foreach (DataRow row in ds.Tables[0].Rows)
                {
                    sum += ValidationHelper.GetInteger(row["HitsCount"], 0);
                }
            }

            ucGraphDays.AddGraphData(sum,
                DateTimeHelper.GetWeekOfYear(dt, AnalyticsHelper.AnalyticsCulture) + "",
                sum + "",
                "Analytics_Report.aspx?statCodeName=" + statCodeName + "&dataCodeName=" + dataCodeName + "&reportCodeName=" + reportCodeName + "&year=" + year + "&month=" + dt.Month + "&week=" + DateTimeHelper.GetWeekOfYear(dt, AnalyticsHelper.AnalyticsCulture) + "&day=" + dt.Day,
                "",
                // "Analytics_Report.aspx?year=" + year + "&month=" + dt.Month + "&week=" + DateTimeHelper.GetWeekOfYear(dt) + "&day=" + dt.Day,
                increment);

            dt = dt.AddDays(increment);
            increment = 7;
        }
    }
}
