using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Globalization;

using CMS.GlobalHelper;
using CMS.WebAnalytics;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.LicenseProvider;


public partial class CMSDesk_Tools_Analytics_Analytics_Months : CMSDeskPage
{
    const string ANAL_CODE_PREFIX = "analytics_codename.";
    const string ANAL_CODE_VISITS = "visits";
    const string ANAL_CODE_VISIT_LIST = "visitfirst;visitreturn;";


    protected void Page_Load(object sender, EventArgs e)
    {
        // Check license
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.WebAnalytics);
        }

        // Display disabled information
        if (!AnalyticsHelper.AnalyticsEnabled(CMSContext.CurrentSiteName))
        {
            this.pnlDisabled.Visible = true;
            this.lblDisabled.Text = ResHelper.GetString("WebAnalytics.Disabled");
        }

        string statCodeName = ValidationHelper.GetString(Request.QueryString["statCodeName"], "");
        string dataCodeName = ValidationHelper.GetString(Request.QueryString["dataCodeName"], "");
        string reportCodeName = ValidationHelper.GetString(Request.QueryString["reportCodeName"], "");
        string additionalCodeName = ValidationHelper.GetString(Request.QueryString["additionalCodeName"], "");

        if (!IsPostBack)
        {
            imgTitle.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Analytics/analytics.gif";

            if ((statCodeName != String.Empty && ANAL_CODE_VISIT_LIST.Contains(statCodeName.ToLower() + ";")) ||
                (additionalCodeName != String.Empty && ANAL_CODE_VISIT_LIST.Contains(additionalCodeName.ToLower() + ";")))
            {
                lblTitle.Text = ResHelper.GetString(ANAL_CODE_PREFIX + ANAL_CODE_VISITS);
            }
            else
            {
                lblTitle.Text = ResHelper.GetString(ANAL_CODE_PREFIX + statCodeName);
            }


            lblYears.Text = ResHelper.GetString("Analytics_Months.lblyears");
            btnShow.Text = ResHelper.GetString("Analytics_Months.btnShow");
        }

        int year = DateTime.Today.Year;
        if (drpYears.SelectedItem != null)
        {
            year = ValidationHelper.GetInteger(drpYears.SelectedItem.ToString(), year);
        }

        // Dropdownlist initialization
        // Insert current year (or selected year), 2 years before and 2 years after
        drpYears.Items.Clear();
        for (int i = -2; i < 3; i++)
        {
            drpYears.Items.Add((year + i) + "");
        }
        drpYears.SelectedValue = year.ToString();

        LoadMonthData(year, statCodeName, dataCodeName, reportCodeName, additionalCodeName, DateTime.Now.Month - 1);

        ltlScript.Text = ScriptHelper.GetScript("ucGraphMonths_ShowDesktopContent('', 'Analytics_Report.aspx?statCodeName=" + statCodeName + "&dataCodeName=" + dataCodeName + "&reportCodeName=" + reportCodeName + "&additionalCodeName=" + additionalCodeName + "&year=" + year + "'); ");
        //        if (!IsPostBack)
        //        {
        ltlScript.Text = ltlScript.Text + ScriptHelper.GetScript("ucGraphMonths_ShowDesktopContent('Analytics_Days.aspx?statCodeName=" + statCodeName + "&dataCodeName=" + dataCodeName + "&reportCodeName=" + reportCodeName + "&additionalCodeName=" + additionalCodeName + "&year=" + year + "&month=" + DateTime.Now.Month + "', ''); ");
        //        }
        //        ucGraphMonths.SetData(ds);
    }


    /// <summary>
    /// Loads month statistics and creates graph.
    /// </summary>
    /// <param name="year">Current year.</param>
    /// <param name="statCodeName">Statistics code name (visitors, pageviews...).</param>
    /// <param name="dataCodeName">Database code name.</param>
    /// <param name="reportCodeName">Report code name.</param>
    /// <param name="additionalCodeName">Additional stats code name.</param>
    /// <param name="selectedMonth">Selected month.</param>
    protected void LoadMonthData(int year, string statCodeName, string dataCodeName, string reportCodeName, string additionalCodeName, int selectedMonth)
    {
        string tmp;
        string monthName = "";
        int maxsum = 0;

        ucGraphMonths.AddGraph(40, "MonthGraph");

        DateTime dt = new DateTime(year, 1, 15);
        for (int i = 0; i < 12; i++)
        {
            DataSet ds = HitsInfoProvider.GetAllHitsInfo(
                CMSContext.CurrentSite.SiteID,
                HitsIntervalEnum.Month, new string[] { dataCodeName, additionalCodeName }, dt);

            int sum = 0;
            if (ds != null)
            {
                foreach (DataRow row in ds.Tables[0].Rows)
                {
                    sum += ValidationHelper.GetInteger(row["HitsCount"], 0);
                }
            }

            monthName = DateTimeHelper.GetMonthName(dt.Month, CMSContext.CurrentUser.PreferredUICultureCode);
            monthName = monthName[0].ToString().ToUpper() + monthName.Substring(1);

            tmp = "?statCodeName=" + statCodeName + "&dataCodeName=" + dataCodeName + "&reportCodeName=" + reportCodeName + "&year=" + year + "&month=" + dt.Month;
            ucGraphMonths.AddGraphData(sum,
                DateTimeHelper.GetMonthAbbrevName(dt.Month, CMSContext.CurrentUser.PreferredUICultureCode),
                monthName + " (" + sum + ")",
                "Analytics_Days.aspx" + tmp + "&additionalCodeName=" + additionalCodeName,
                "Analytics_Report.aspx" + tmp,
                1);

            if (sum > maxsum)
            {
                maxsum = sum;
            }
            dt = dt.AddMonths(1);
        }

        ucGraphMonths.SelectBar(0, selectedMonth, true);
        ucGraphMonths.RenderGraph();
    }

}
