using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.FormEngine;
using CMS.CMSHelper;


public partial class CMSDesk_Tools_BizForms_BizForm_Edit_Autoresponder : CMSDeskPage
{
    private int formId = 0;    
    private DataClassInfo formClassObj = null;

    #region " Private properties "

    /// <summary>
    /// Indicates whether custom form layout is set or not
    /// </summary>
    private bool IsLayoutSet
    {
        get
        {
            object obj = ViewState["IsLayoutSet"];
            return (obj == null) ? false : (bool)obj;
        }

        set
        {
            ViewState["IsLayoutSet"] = value;
        }

    }

    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {

        // Check 'ReadForm' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "ReadForm"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.form", "ReadForm");
        }

        // Get form id from url;
        formId = ValidationHelper.GetInteger(Request.QueryString["formID"], 0);


        // Control initialization
        lblAvailableFields.Text = ResHelper.GetString("Bizform_Edit_Autoresponder.AvailableFields");
        btnGenerateLayout.Text = ResHelper.GetString("Bizform_Edit_Autoresponder.btnGenerateLayout");
        btnInsertLabel.Text = ResHelper.GetString("Bizform_Edit_Autoresponder.btnInsertLabel");
        btnInsertInput.Text = ResHelper.GetString("Bizform_Edit_Autoresponder.btnInsertInput");
        btnOK.Text = ResHelper.GetString("Bizform_Edit_Autoresponder.btnOK");

        ltlAlertExist.Text = "<input type=\"hidden\" id=\"alertexist\" value=\"" + ResHelper.GetString("Bizform_Edit_Autoresponder.AlertExist") + "\">";
        ltlAlertExistFinal.Text = "<input type=\"hidden\" id=\"alertexistfinal\" value=\"" + ResHelper.GetString("Bizform_Edit_Autoresponder.AlertExistFinal") + "\">";
        ltlConfirmDelete.Text = "<input type=\"hidden\" id=\"confirmdelete\" value=\"" + ResHelper.GetString("Bizform_Edit_Autoresponder.ConfirmDelete") + "\">";


        lblEmailField.Text = ResHelper.GetString("bizform_edit_autoresponder.lblemailfield");
        lblEmailFrom.Text = ResHelper.GetString("bizform_edit_autoresponder.lblEmailFrom");
        lblEmailSubject.Text = ResHelper.GetString("bizform_edit_autoresponder.lblEmailSubject");

        // Validators
        //rfvEmailFrom.ErrorMessage = ResHelper.GetString("bizform_edit_autoresponder.emptyemail");
        //rfvEmailSubject.ErrorMessage = ResHelper.GetString("bizform_edit_autoresponder.emptysubject");

        drpEmailField.SelectedIndexChanged += new EventHandler(drpEmailField_SelectedIndexChanged);

        if (!IsPostBack)
        {
            // initialize FCK editor
            InitFCKeditor();

            // Get form info
            BizFormInfo bfi = BizFormInfoProvider.GetBizFormInfo(formId);

            // Get bizform class object
            formClassObj = DataClassInfoProvider.GetDataClass(bfi.FormClassID);

            if ((bfi != null) && (formClassObj != null))
            {

                // Enable or disable form
                EnableDisableForm(bfi.FormConfirmationTemplate);

                // Enable or disable OK button
                EnableDisableOKButton();

                // Fill list of available fields                    
                FillFieldsList();

                // Load dropdownlist with form text fields   
                if (formClassObj != null)
                {
                    FormInfo fi = new FormInfo(formClassObj.ClassFormDefinition);
                    drpEmailField.DataSource = fi.GetFields(FormFieldDataTypeEnum.Text);
                    drpEmailField.DataBind();
                    drpEmailField.Items.Insert(0, new ListItem(ResHelper.GetString("bizform_edit_autoresponder.emptyemailfield"), ""));

                    // Try to select specified field
                    ListItem li = drpEmailField.Items.FindByValue(bfi.FormConfirmationEmailField);
                    if (li != null)
                    {
                        li.Selected = true;
                    }
                }   
             
                // Load email subject and emailfrom address
                txtEmailFrom.Text = bfi.FormConfirmationSendFromEmail;
                txtEmailSubject.Text = bfi.FormConfirmationEmailSubject;
            }
            else
            {
                // Disable form by default
                EnableDisableForm(null);
            }
        }


 
         
    }

    void drpEmailField_SelectedIndexChanged(object sender, EventArgs e)
    {
        pnlCustomLayout.Visible = (drpEmailField.SelectedValue != "");
        pnlCustomLayoutFCK.Visible = pnlCustomLayout.Visible;

        // Remove content checking and add delete confirmation
        if (!pnlCustomLayout.Visible && IsLayoutSet)
        {
            btnOK.OnClientClick = "return ConfirmDelete();";
        }
        // Remove delete confirmation and add content checking
        else if (pnlCustomLayout.Visible)
        {
            btnOK.OnClientClick = "return CheckContent();";
        }

        // Enable or disable OK button
        EnableDisableOKButton();
    }


    /// <summary>
    /// OK button is clicked
    /// </summary>
    protected void btnOK_Clicked(object sender, EventArgs e)
    {
        string errorMessage = "";

        // check 'ReadForm' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "EditForm"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.form", "EditForm");
        }

        // Validate form
        errorMessage = new Validator().NotEmpty(txtEmailFrom.Text.Trim(), ResHelper.GetString("bizform_edit_autoresponder.emptyemail")).NotEmpty(txtEmailSubject.Text.Trim(), ResHelper.GetString("bizform_edit_autoresponder.emptysubject")).Result;

        if (errorMessage == "")
        {

            BizFormInfo bfi = BizFormInfoProvider.GetBizFormInfo(formId);
            if (bfi != null)
            {
                // Save custom layout
                if (drpEmailField.SelectedValue != "")
                {
                    bfi.FormConfirmationTemplate = fckEditor.ResolvedValue.Trim();
                    bfi.FormConfirmationEmailField = drpEmailField.SelectedValue;
                    bfi.FormConfirmationEmailSubject = txtEmailSubject.Text.Trim();
                    bfi.FormConfirmationSendFromEmail = txtEmailFrom.Text.Trim();

                    try
                    {
                        BizFormInfoProvider.SetBizFormInfo(bfi);
                        DisplayInfoMessage(ResHelper.GetString("General.ChangesSaved"));
                        EnableDisableForm(bfi.FormConfirmationTemplate);

                    }
                    catch (Exception ex)
                    {
                        errorMessage = ex.Message;
                    }
                }
                // Delete custom layout if exists
                else if (IsLayoutSet)
                {
                    bfi.FormConfirmationTemplate = null;
                    bfi.FormConfirmationEmailField = drpEmailField.SelectedValue;
                    bfi.FormConfirmationEmailSubject = "";
                    bfi.FormConfirmationSendFromEmail = "";
                    try
                    {
                        BizFormInfoProvider.SetBizFormInfo(bfi);
                        DisplayInfoMessage(ResHelper.GetString("Bizform_Edit_Autoresponder.LayoutDeleted"));
                        EnableDisableForm(bfi.FormConfirmationTemplate);
                    }
                    catch (Exception ex)
                    {
                        errorMessage = ex.Message;
                    }
                }
            }
        }

        if (errorMessage != "")
        {
            DisplayErrorMessage(errorMessage);
        }

        // enable or disable OK button
        EnableDisableOKButton();
    }


    /// <summary>
    /// Fills list of available fields
    /// </summary>
    private void FillFieldsList()
    {
        FormInfo fi = new FormInfo();
        FormFieldInfo[] visibleFields = null;        

        if (formClassObj != null)
        {
            // load form definition and get visible fields
            fi.LoadXmlDefinition(formClassObj.ClassFormDefinition);
            visibleFields = fi.GetFields(true, false);

            lstAvailableFields.Items.Clear();

            if (visibleFields != null)
            {
                // add visible fields to the list
                foreach (FormFieldInfo ffi in visibleFields)
                {
                    lstAvailableFields.Items.Add(new ListItem(ffi.Name, ffi.Name));
                }
            }
            lstAvailableFields.SelectedIndex = 0;
        }
    }


    /// <summary>
    /// Enables or disables form according to the confirmation email template text is defined or not
    /// </summary>
    protected void EnableDisableForm(string formLayout)
    {        
        
        if (formLayout != null)
        {
            //Enable layout editing                                
            pnlCustomLayout.Visible = true;
            pnlCustomLayoutFCK.Visible = true;

            // set confirmation email template text to the editable window of the FCK editor
            fckEditor.ResolvedValue = formLayout;

            // Save info to viewstate 
            IsLayoutSet = true;
        }
        else
        {
            // Layout editing is not enabled by default        
            pnlCustomLayout.Visible = false;
            pnlCustomLayoutFCK.Visible = false;

            fckEditor.ResolvedValue = "";

            // Save info to viewstate
            IsLayoutSet = false;
        }
    }


    /// <summary>
    /// Enables or disables 'OK button' according to the layout is defined or not
    /// </summary>
    protected void EnableDisableOKButton()
    {
        if ((!IsLayoutSet) && (drpEmailField.SelectedValue == ""))
        {
            btnOK.Enabled = false;
        }
        else
        {
            btnOK.Enabled = true;
        }
    }


    /// <summary>
    /// Displays specified info message and hide error message.
    /// </summary>
    /// <param name="infoMessage">Info message to display.</param>
    protected void DisplayInfoMessage(string infoMessage)
    {
        lblError.Visible = false;
        lblInfo.Visible = true;
        lblInfo.Text = infoMessage;        
    }


    /// <summary>
    /// Displays specified error message and hide info message.
    /// </summary>
    /// <param name="errorMessage">Error message to display.</param>
    protected void DisplayErrorMessage(string errorMessage)
    {
        lblInfo.Visible = false;
        lblError.Visible = true;
        lblError.Text = errorMessage;
    }


    /// <summary>
    /// Initializes FCK editor's settings
    /// </summary>
    protected void InitFCKeditor()
    {
        fckEditor.BasePath = "~/CMSAdminControls/FCKeditor/";
        fckEditor.AutoDetectLanguage = false;
        fckEditor.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
    }

} 

  
