using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.FormEngine;
using CMS.SettingsProvider;
using CMS.DataEngine;
using CMS.CMSHelper;


public partial class CMSDesk_Tools_BizForms_BizForm_Edit_General : CMSDeskPage
{
    protected int mId = 0;
    protected BizFormInfo mBizForm = null;
    
    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'ReadForm' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "ReadForm"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.form", "ReadForm");
        }

        lblDisplayName.Text = ResHelper.GetString("BizFormGeneral.DisplayName");
        lblCodeName.Text = ResHelper.GetString("BizFormGeneral.lblCodeName");
        lblTableName.Text = ResHelper.GetString("BizFormGeneral.lblTableName");
        lblAfterSubmited.Text = ResHelper.GetString("BizFormGeneral.lblAfterSubmited");
        lblButtonText.Text = ResHelper.GetString("BizFormGeneral.lblButtonText");
        lblFromEmail.Text = ResHelper.GetString("BizFormGeneral.lblFromEmail");
        lblToEmail.Text = ResHelper.GetString("BizFormGeneral.ToEmail");
        lblSubject.Text = ResHelper.GetString("BizFormGeneral.EmailSubject");        

        chkSendToEmail.Text = ResHelper.GetString("BizFormGeneral.chkSendToEmail");

        radClear.Text = ResHelper.GetString("BizFormGeneral.radClear");
        radContinue.Text = ResHelper.GetString("BizFormGeneral.radContinue");
        radDisplay.Text = ResHelper.GetString("BizFormGeneral.radDisplay");
        radRedirect.Text = ResHelper.GetString("BizFormGeneral.radRedirect");

        rfvDisplayName.Text = ResHelper.GetString("BizFormGeneral.rfvDisplayName");

        btnOk.Text = ResHelper.GetString("BizFormGeneral.btnOK");        

        if (DataHelper.GetNotEmpty(this.Request.QueryString["formid"], "") != "")
        {
            mId = Convert.ToInt32(this.Request.QueryString["formid"]);
            mBizForm = BizFormInfoProvider.GetBizFormInfo(mId);
        }

        if (!IsPostBack)
        {
            LoadData();
        }
    }
    

    /// <summary>
    /// Load data to fields
    /// </summary>
    protected void LoadData()
    {
        txtDisplayName.Text = mBizForm.FormDisplayName;
        txtCodeName.Text = mBizForm.FormName;

        DataClassInfo mDci = DataClassInfoProvider.GetDataClass(mBizForm.FormClassID);
        txtTableName.Text = mDci.ClassTableName;       

        txtFromEmail.Text = ValidationHelper.GetString(mBizForm.FormSendFromEmail, "");
        txtToEmail.Text = ValidationHelper.GetString(mBizForm.FormSendToEmail, "");
        txtSubject.Text = ValidationHelper.GetString(mBizForm.FormEmailSubject, "");
        chkSendToEmail.Checked = ((txtFromEmail.Text + txtToEmail.Text) != "");
        if (!chkSendToEmail.Checked)
        {
            txtFromEmail.Enabled = false;
            txtToEmail.Enabled = false;
            txtSubject.Enabled = false;
        }
        
        txtButtonText.Text = mBizForm.FormSubmitButtonText;

        txtDisplay.Enabled = false;
        txtRedirect.Enabled = false;

        if (mBizForm.FormDisplayText != null)
        {
            txtDisplay.Text = mBizForm.FormDisplayText;
            radDisplay.Checked = true;
            txtDisplay.Enabled = true;
        }
        else
        {
            if (mBizForm.FormRedirectToUrl != null)
            {
                txtRedirect.Text = mBizForm.FormRedirectToUrl;
                radRedirect.Checked = true;
                txtRedirect.Enabled = true;
            }
            else
            {
                if (mBizForm.FormClearAfterSave)
                {
                    radClear.Checked = true;
                }
                else
                {
                    radContinue.Checked = true;
                }
            }
        }
    }
    

    /// <summary>
    /// Save data to Database
    /// </summary>
    protected void SaveData()
    {
        if (DataHelper.GetNotEmpty(txtDisplayName.Text, "") == "")
        {
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("BizFormGeneral.rfvDisplayName");
            return;
        }

        if (chkSendToEmail.Checked)
        {
            string result = new Validator().NotEmpty(txtFromEmail.Text, ResHelper.GetString("BizFormGeneral.EmptyFromEmail"))
                .NotEmpty(txtToEmail.Text, ResHelper.GetString("BizFormGeneral.EmptyToEmail"))
                .NotEmpty(txtSubject.Text, ResHelper.GetString("BizFormGeneral.EmptyEmailSubject")).Result;
            if (result != "")
            {
                lblError.Visible = true;
                lblError.Text = result;
                return;
            }

            mBizForm.FormSendFromEmail = txtFromEmail.Text.Trim();
            mBizForm.FormSendToEmail = txtToEmail.Text.Trim();
            mBizForm.FormEmailSubject = txtSubject.Text.Trim();
        }
        else
        {
            mBizForm.FormSendFromEmail = null;
            mBizForm.FormSendToEmail = null;
            mBizForm.FormEmailSubject = null;
            this.txtToEmail.Text = "";
            this.txtFromEmail.Text = "";
            this.txtSubject.Text = "";
        }

        mBizForm.FormDisplayName = txtDisplayName.Text;
        mBizForm.FormName = txtCodeName.Text;        

        mBizForm.FormSubmitButtonText = txtButtonText.Text;       

        mBizForm.FormRedirectToUrl = null;
        mBizForm.FormDisplayText = null;

        if (radClear.Checked)
        {
            mBizForm.FormClearAfterSave = true;
        }
        else
        {
            mBizForm.FormClearAfterSave = false;
        }
        if (radDisplay.Checked)
        {
            if (txtDisplay.Text != null && txtDisplay.Text != "")
            {
                mBizForm.FormDisplayText = txtDisplay.Text;
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("BizFormGeneral.DisplayText");
                return;
            }


        }
        else
        {
            txtDisplay.Text = "";
        }

        if (radRedirect.Checked)
        {
            mBizForm.FormRedirectToUrl = txtRedirect.Text;
        }
        else
        {
            txtRedirect.Text = "";
        }

        //mBizForm.FormConfirmationEmailField = drpEmailField.SelectedValue;
        
        BizFormInfoProvider.SetBizFormInfo(mBizForm);

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");

    }
    

    protected void btnOk_Click(object sender, EventArgs e)
    {
        // check 'EditForm' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "EditForm"))               
        {
            CMSDeskPage.RedirectToAccessDenied("cms.form", "EditForm");
        }

        SaveData();
    }
    

    protected void radDisplay_CheckedChanged(object sender, EventArgs e)
    {
        txtDisplay.Enabled = false;
        txtRedirect.Enabled = false;
        if (radDisplay.Checked) txtDisplay.Enabled = true;        
    }
    

    protected void radRedirect_CheckedChanged(object sender, EventArgs e)
    {
        txtDisplay.Enabled = false;
        txtRedirect.Enabled = false;
        if (radRedirect.Checked) txtRedirect.Enabled = true;
    }
    

    protected void radClear_CheckedChanged(object sender, EventArgs e)
    {
        txtDisplay.Enabled = false;
        txtRedirect.Enabled = false;
    }


    protected void chkSendToEmail_CheckedChanged(object sender, EventArgs e)
    {
        txtFromEmail.Enabled = chkSendToEmail.Checked;
        txtToEmail.Enabled = chkSendToEmail.Checked;
        txtSubject.Enabled = chkSendToEmail.Checked;
        //drpEmailField.Enabled = chkSendToEmail.Checked;
    }
}
