using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.FormEngine;
using CMS.SettingsProvider;
using CMS.LicenseProvider;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_BizForms_BizForm_List : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'ReadForm' and 'ReadData' permissions
        if (!(CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "ReadForm") ||
               CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "ReadData")))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.form", "'ReadForm' or 'ReadData'");
        }

        if (CMSContext.CurrentSite != null)
        {
            if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
            {
                LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.BizForms);
            }
            // select bizforms for current site only
            object[,] parameters = new object[1, 3];
            parameters[0, 0] = "FormSiteID";
            parameters[0, 1] = CMSContext.CurrentSite.SiteID;

            UniGridBizForms.QueryParameters = parameters;
            UniGridBizForms.WhereCondition = "FormSiteID = @FormSiteID";
        }

        UniGridBizForms.GridView.GridLines = GridLines.Horizontal;
        UniGridBizForms.OnAction += new OnActionEventHandler(UniGridBizForms_OnAction);

        UniGridBizForms.HideControlForZeroRows = true;

        lnkNewBizForm.Text = ResHelper.GetString("BizFormList.lnkNewBizForm");

        this.PageTitleBizForm.TitleText = ResHelper.GetString("BizFormList.TitleText");
        this.PageTitleBizForm.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/BizForms/bizforms.gif";
        this.imgNewBizForm.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/BizForms/addbizform.gif";

        this.lnkNewBizForm.NavigateUrl = "BizForm_New.aspx";
    }


    void UniGridBizForms_OnAction(string actionName, object actionArgument)
    {
        if (DataHelper.GetNotEmpty(actionName, "") == "edit")
        {
            this.Response.Redirect("BizForm_Frameset.aspx?formid=" + Convert.ToString(actionArgument));
        }
        if (DataHelper.GetNotEmpty(actionName, "") == "delete")
        {
            // check 'DeleteFormAndData' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "DeleteFormAndData"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.form", "DeleteFormAndData");
            }

            BizFormInfo bzi = BizFormInfoProvider.GetBizFormInfo(System.Convert.ToInt32(actionArgument));
            if (bzi != null)
            {
                // Delete BizForm info, class and table from the database
                BizFormInfoProvider.DeleteBizFormInfo(System.Convert.ToInt32(actionArgument));
                DataClassInfoProvider.DeleteDataClass(bzi.FormClassID);
                QueryProvider.Clear();
            }

        }
    }

}
