using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.Ecommerce;

public partial class CMSDesk_Tools_Ecommerce_Configuration_Configuration_StoreSettings : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        PageTitle.TitleText = ResHelper.GetString("Store_Settings.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/storesettings.gif";

        // control initializations				
        lblAllowAnonymous.Text = ResHelper.GetString("Configuration_StoreSettings.lblAllowAnonymous");
        lblShippingFreeLimit.Text = ResHelper.GetString("Configuration_StoreSettings.lblShippingFreeLimit");
        lblDefaultCountry.Text = ResHelper.GetString("Configuration_StoreSettings.lblDefaultCountry");
        //lblDefaultCurrency.Text = ResHelper.GetString("Configuration_StoreSettings.lblDefaultCurrency");
        lblOrganizationID.Text = ResHelper.GetString("Configuration_StoreSettings.lblOrganizationID");
        lblTaxRegistrationID.Text = ResHelper.GetString("Configuration_StoreSettings.lblTaxRegistrationID");
        lblEmailFrom.Text = ResHelper.GetString("Configuration_StoreSettings.lblEmailFrom");
        lblEmailTo.Text = ResHelper.GetString("Configuration_StoreSettings.lblEmailTo");

        rvShippingFreeLimit.ErrorMessage = ResHelper.GetString("Configuration_StoreSettings.ErrorShippingFreeLimit");

        btnOK.Text = ResHelper.GetString("General.OK");

        // fill editing form
        if (!IsPostBack)
        {
            LoadData();

            // show that the currency was created or updated successfully
            if (Request.QueryString["saved"] == "1")
            {
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
        }
    }


    /// <summary>
    /// Load data of editing currency.
    /// </summary>
    /// <param name="currencyObj">Currency object.</param>
    protected void LoadData()
    {
        bool noneCountryAdded = false;

        // Load countries
        drpCountry.DataSource = CountryInfoProvider.GetAllCountries();
        drpCountry.DataBind();

        if (DataHelper.DataSourceIsEmpty(drpCountry.DataSource))
        {
            AddNoneCountrySelected();
            noneCountryAdded = true;
        }

        if (CMSContext.CurrentSite != null)
        {
            SiteInfo si = SiteInfoProvider.GetSiteInfo(CMSContext.CurrentSite.SiteName);

            // Set default country
            try
            {
                if (si.SiteDefaultCountryID > 0)
                {
                    drpCountry.SelectedValue = Convert.ToString(si.SiteDefaultCountryID);
                }
                else if (!noneCountryAdded)
                {
                    AddNoneCountrySelected();
                }
            }
            catch
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Ecommerce.SiteDefaultCountry.SelectionFailed");
            }                                 


            // Set shopping free limit
            if (si.SiteStoreShippingFreeLimit != -1)
            {
                txtShippingFreeLimit.Text = Convert.ToString(si.SiteStoreShippingFreeLimit);
            }
            // Set allow/not allow anonymous users
            chkAllowAnonymous.Checked = si.SiteStoreAllowAnonymousCustomers;
            
            // emails
            txtEmailFrom.Text = si.SiteSendStoreEmailsFrom;
            txtEmailTo.Text = si.SiteSendOrderNotificationTo;

            chkOrganizationID.Checked = si.SiteShowOrganizationID;
            chkTaxRegistrationID.Checked = si.SiteShowTaxRegistrationID;

        }

    }


    // Inserts "(none)" string to the country selection dropdownlist
    protected void AddNoneCountrySelected()
    {
        drpCountry.Items.Insert(0, new ListItem(ResHelper.GetString("Ecommerce.SiteDefaultCountry.None"), "0"));
        drpCountry.SelectedIndex = 0;
    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        string errorMessage = "";

        // Check that some country is selected
        if (drpCountry.SelectedValue == "0")
        {
            errorMessage = ResHelper.GetString("Ecommerce.DefaultCountry.NoneSelected");
        }

        // Check Shipping free limit
        if ((errorMessage == "") && (txtShippingFreeLimit.Text != ""))
        {
            errorMessage = new Validator().IsPositiveNumber(txtShippingFreeLimit.Text, ResHelper.GetString("Configuration_StoreSettings.ErrorShippingFreeLimit")).Result;
        }

        // Check email addresses
        string emailFrom = txtEmailFrom.Text.Trim();
        if ((errorMessage == "") && (emailFrom != "") && (!ValidationHelper.IsEmail(emailFrom)))
        {
            errorMessage = ResHelper.GetString("Ecommerce.Settings.ErrorFormatStoreEmail");
        }            

        string emailTo = txtEmailTo.Text.Trim();
        if ((errorMessage == "") && (emailTo != "") && (!ValidationHelper.IsEmail(emailTo)))
        {
            errorMessage = ResHelper.GetString("Ecommerce.Settings.ErrorFormatOrderNotificationEmail");
        }

        // Process form data
        if (errorMessage == "")
        {

            if (CMSContext.CurrentSite != null)
            {
                SiteInfo si = SiteInfoProvider.GetSiteInfo(CMSContext.CurrentSite.SiteID);

                if (txtShippingFreeLimit.Text == "")
                {
                    si.SiteStoreShippingFreeLimit = -1;
                }
                else
                {
                    si.SiteStoreShippingFreeLimit = ValidationHelper.GetDouble((txtShippingFreeLimit.Text), 0);
                }
                si.SiteStoreAllowAnonymousCustomers = chkAllowAnonymous.Checked;
                si.SiteDefaultCountryID = ValidationHelper.GetInteger(drpCountry.SelectedValue, 0);
               // si.SiteDefaultCurrencyID = ValidationHelper.GetInteger(drpCurrency.SelectedValue, 0);
                si.SiteShowTaxRegistrationID = chkTaxRegistrationID.Checked;
                si.SiteShowOrganizationID = chkOrganizationID.Checked;
                si.SiteSendOrderNotificationTo = emailTo;
                si.SiteSendStoreEmailsFrom = emailFrom;

                SiteInfoProvider.SetSiteInfo(si);
                Response.Redirect("Configuration_StoreSettings.aspx?saved=1");
            }

        }
        

        if (errorMessage != "")
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }

}
