using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Configuration_Currency_Edit : CMSDeskPage
{
	protected int currencyid = 0;
	
	protected void Page_Load(object sender, EventArgs e)
	{
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        rfvDisplayName.ErrorMessage = ResHelper.GetString("Currency_Edit.ErrorDisplayName");
        rfvCodeName.ErrorMessage = ResHelper.GetString("Currency_Edit.ErrorCodeName");
        rfvRoundTo.ErrorMessage = ResHelper.GetString("Currency_Edit.ErrorRoundTo");
        revRoundTo.ErrorMessage = ResHelper.GetString("Currency_Edit.ErrorRoundTo");
        rfvCurrencyCode.ErrorMessage = ResHelper.GetString("Currency_Edit.rfvCurrencyCode");
        rfvFormatString.ErrorMessage = ResHelper.GetString("Currency_Edit.rfvFormatString");

        revRoundTo.ValidationExpression = @"^([0-9])+$";
	
		// control initializations				
		lblCurrencyDisplayName.Text = ResHelper.GetString("Currency_Edit.CurrencyDisplayNameLabel");
		lblCurrencyName.Text = ResHelper.GetString("Currency_Edit.CurrencyNameLabel");
		lblCurrencyCode.Text = ResHelper.GetString("Currency_Edit.CurrencyCodeLabel");
		lblCurrencyRoundTo.Text = ResHelper.GetString("Currency_Edit.CurrencyRoundToLabel");
        lblCurrencyEnabled.Text = ResHelper.GetString("Currency_Edit.CurrencyEnabledLabel");
        lblFormatString.Text = ResHelper.GetString("Currency_Edit.lblFormatString");
        lblIsMain.Text = ResHelper.GetString("Currency_Edit.lblIsMain");
        lblFormatStringnInfo.Text = ResHelper.GetString("Currency_Edit.lblFormatStringInfo"); 

		btnOK.Text = ResHelper.GetString("General.OK");	

		string currentCurrency = ResHelper.GetString("Currency_Edit.NewItemCaption");

		// get currency id from querystring
        if ((Request.QueryString["currencyid"] != null) && (Request.QueryString["currencyid"] != ""))
        {
            currencyid = ValidationHelper.GetInteger(Request.QueryString["currencyid"], 0);
            CurrencyInfo currencyObj = CurrencyInfoProvider.GetCurrencyInfo(currencyid);
            currentCurrency = currencyObj.CurrencyDisplayName;

            // fill editing form
            if (!IsPostBack)
            {
                LoadData(currencyObj);

                // show that the currency was created or updated successfully
                if (Request.QueryString["saved"] == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
            
            PageTitle.TitleText = ResHelper.GetString("Currency_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/Currencies/currency.gif";
        }
        else
        {
            PageTitle.TitleText = ResHelper.GetString("Currency_New.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/Currencies/newcurrency.gif";
        }
        

		// initializes page title control		
		string[,] pageTitleTabs = new string[2, 3];
		pageTitleTabs[0, 0] = ResHelper.GetString("Currency_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Ecommerce/Configuration/Currencies/Currency_List.aspx";
		pageTitleTabs[0, 2] = "";
		pageTitleTabs[1, 0] = currentCurrency;
		pageTitleTabs[1, 1] = "";
		pageTitleTabs[1, 2] = "";
		PageTitle.Breadcrumbs = pageTitleTabs;
	}


	/// <summary>
	/// Load data of editing currency.
	/// </summary>
	/// <param name="currencyObj">Currency object.</param>
	protected void LoadData(CurrencyInfo currencyObj)
	{
		txtCurrencyDisplayName.Text = currencyObj.CurrencyDisplayName;
		txtCurrencyName.Text = currencyObj.CurrencyName;
        txtCurrencyCode.Text = currencyObj.CurrencyCode;
        txtFormatString.Text = currencyObj.CurrencyFormatString;
        txtCurrencyRoundTo.Text = "";
        if (currencyObj.CurrencyRoundTo != -1)
        {
            txtCurrencyRoundTo.Text = Convert.ToString(currencyObj.CurrencyRoundTo);
        }
		chkCurrencyEnabled.Checked = currencyObj.CurrencyEnabled;
        chkIsMain.Checked = currencyObj.CurrencyIsMain;
	 }

	/// <summary>
	/// Sets data to database.
	/// </summary>
	protected void btnOK_Click(object sender, EventArgs e)
	{
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        string errorMessage = new Validator()
            .NotEmpty(txtCurrencyName.Text, ResHelper.GetString("Currency_Edit.ErrorCodeName"))
            .NotEmpty(txtCurrencyDisplayName.Text, ResHelper.GetString("Currency_Edit.ErrorDisplayName"))
            .NotEmpty(txtFormatString.Text, ResHelper.GetString("Currency_Edit.ErrorFormatString"))
            .IsRegularExp(txtCurrencyRoundTo.Text, "^([0-9])+$", ResHelper.GetString("Currency_Edit.ErrorRoundTo")).Result;

        if (!ValidationHelper.IsCodeName(txtCurrencyName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }

		if (errorMessage == "")
		{
			
			// currencyName must to be unique
			CurrencyInfo currencyObj = CurrencyInfoProvider.GetCurrencyInfo(txtCurrencyName.Text.Trim());

			// if currencyName value is unique														
			if ((currencyObj == null) || (currencyObj.CurrencyID == currencyid))			
			{
				// if currencyName value is unique -> determine whether it is update or insert 
				if ((currencyObj == null))
				{
					// get CurrencyInfo object by primary key
					currencyObj = CurrencyInfoProvider.GetCurrencyInfo(currencyid);
					if (currencyObj == null)
					{
						// create new item -> insert
						currencyObj = new CurrencyInfo();                        

					}			        									
				}
															
				currencyObj.CurrencyDisplayName = txtCurrencyDisplayName.Text.Trim();
				currencyObj.CurrencyName = txtCurrencyName.Text.Trim();
				currencyObj.CurrencyCode = txtCurrencyCode.Text.Trim();
                currencyObj.CurrencyFormatString = txtFormatString.Text;
				// Set null if not specified
                currencyObj.CurrencyRoundTo = ValidationHelper.GetInteger(txtCurrencyRoundTo.Text.Trim(), -1);
				currencyObj.CurrencyEnabled = chkCurrencyEnabled.Checked;

                // Remove main currency flag
                if (chkIsMain.Checked)
                {
                    CurrencyInfoProvider.RemoveMainCurrency();
                }
                currencyObj.CurrencyIsMain = chkIsMain.Checked;
				
				CurrencyInfoProvider.SetCurrencyInfo(currencyObj);

				Response.Redirect("Currency_Edit.aspx?currencyid=" + Convert.ToString(currencyObj.CurrencyID) + "&saved=1");
			}
			else
			{
				lblError.Visible = true;
				lblError.Text = ResHelper.GetString("Currency_Edit.CurrencyNameExists");
			}

		}
		else
		{
			lblError.Visible = true;
			lblError.Text = errorMessage;
		}
	}
}
