using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Configuration_OrderStatus_OrderStatus_List : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        PageTitle.TitleText = ResHelper.GetString("OrderStatus_List.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/OrderStatus/status.gif";
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/OrderStatus/addstatus.gif";

        UniGrid.DataSource = OrderStatusInfoProvider.GetStatuses(StatusEnum.Both);
        UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
        UniGrid.GridView.GridLines = GridLines.Horizontal;
        UniGrid.OnExternalDataBound += new OnExternalDataBoundEventHandler(UniGrid_OnExternalDataBound);
        UniGrid.GridView.AllowSorting = false;

        lnkNewItem.Text = ResHelper.GetString("OrderStatus_List.NewItemCaption");
    }

    object UniGrid_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        if (sourceName.ToLower() == "statuscolor")
        {
            if (parameter != DBNull.Value)
            {
                return "<div style=\"height:13px; widht=25px; background-color:" + parameter.ToString() + "\"></div>";
            }
            else
            {
                return "-";
            }
        }
        return parameter;
    }


    private void ReloadData()
    {
        UniGrid.DataSource = OrderStatusInfoProvider.GetStatuses(StatusEnum.Both);
        UniGrid.ReloadData();
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void uniGrid_OnAction(string actionName, object actionArgument)
    {
        if (actionName == "edit")
        {
            Response.Redirect("OrderStatus_Edit.aspx?orderstatusid=" + Convert.ToString(actionArgument));
        }
        else if (actionName == "delete")
        {
            // check 'ConfigurationModify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
            {
                CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
            }

            if (OrderStatusInfoProvider.CheckDependencies(ValidationHelper.GetInteger(actionArgument, 0)))
            {

                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Ecommerce.DeleteDisabled");
                return;

            }

            // delete OrderStatusInfo object from database
            OrderStatusInfoProvider.DeleteOrderStatusInfo(ValidationHelper.GetInteger(actionArgument, 0));
            ReloadData();
        }
        else if (actionName == "moveup")
        {
            OrderStatusInfoProvider.MoveStatusUp(ValidationHelper.GetInteger(actionArgument, 0));
            ReloadData();
        }

        else if (actionName == "movedown")
        {
            OrderStatusInfoProvider.MoveStatusDown(ValidationHelper.GetInteger(actionArgument, 0));
            ReloadData();
        }
    }
}