using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;

public partial class CMSDesk_Tools_Ecommerce_Configuration_PaymentOption_Edit : CMSDeskPage
{
	protected int paymentOptionId = 0;
	
	protected void Page_Load(object sender, EventArgs e)
	{
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        // field validator error messages initialization
        rfvDisplayName.ErrorMessage = ResHelper.GetString("paymentoption_edit.errorEmptyDisplayName");
        rfvCodeName.ErrorMessage = ResHelper.GetString("paymentoption_edit.errorEmptyCodeName");
				
		// control initializations				
		lblPaymentOptionName.Text = ResHelper.GetString("PaymentOption_Edit.PaymentOptionNameLabel");
		lblPaymentOptionEnabled.Text = ResHelper.GetString("PaymentOption_Edit.PaymentOptionEnabledLabel");
		lblPaymentOptionDisplayName.Text = ResHelper.GetString("PaymentOption_Edit.PaymentOptionDisplayNameLabel");
        lblGateUrl.Text = ResHelper.GetString("PaymentOption_Edit.GateUrl");

		btnOK.Text = ResHelper.GetString("General.OK");	

		string currentPaymentOption = ResHelper.GetString("PaymentOption_Edit.NewItemCaption");

		// get paymentOption id from querystring		
        paymentOptionId = ValidationHelper.GetInteger(Request.QueryString["paymentOptionId"], 0);
        if (paymentOptionId > 0)
        {
            PaymentOptionInfo paymentOptionObj = PaymentOptionInfoProvider.GetPaymentOptionInfo(paymentOptionId);
            if (paymentOptionObj != null)
            {
                currentPaymentOption = paymentOptionObj.PaymentOptionDisplayName;

                // fill editing form
                if (!IsPostBack)
                {
                    LoadData(paymentOptionObj);

                    // show that the paymentOption was created or updated successfully
                    if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }

            PageTitle.TitleText = ResHelper.GetString("PaymentOption_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/PaymentOptions/payment.gif";
        }
        else // Add new
        {
            PageTitle.TitleText = ResHelper.GetString("PaymentOption_New.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/PaymentOptions/newpayment.gif";
        }

		// initializes page title control		
		string[,] pageTitleTabs = new string[2, 3];
		pageTitleTabs[0, 0] = ResHelper.GetString("PaymentOption_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Ecommerce/Configuration/PaymentOptions/PaymentOption_List.aspx";
		pageTitleTabs[0, 2] = "";
		pageTitleTabs[1, 0] = currentPaymentOption;
		pageTitleTabs[1, 1] = "";
		pageTitleTabs[1, 2] = "";
		PageTitle.Breadcrumbs = pageTitleTabs;
	}


	/// <summary>
	/// Load data of editing paymentOption.
	/// </summary>
	/// <param name="paymentOptionObj">PaymentOption object.</param>
	protected void LoadData(PaymentOptionInfo paymentOptionObj)
	{
	
		txtPaymentOptionName.Text = paymentOptionObj.PaymentOptionName;
		chkPaymentOptionEnabled.Checked = paymentOptionObj.PaymentOptionEnabled;
		txtPaymentOptionDisplayName.Text = paymentOptionObj.PaymentOptionDisplayName;
        txtGateUrl.Text = paymentOptionObj.PaymentOptionPaymentGateUrl;

	 }

	/// <summary>
	/// Sets data to database.
	/// </summary>
	protected void btnOK_Click(object sender, EventArgs e)
	{
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        // check input values from textboxes and other contrlos
        string errorMessage = new Validator()
            .NotEmpty(txtPaymentOptionDisplayName.Text, ResHelper.GetString("paymentoption_edit.errorEmptyDisplayName"))
            .NotEmpty(txtPaymentOptionName.Text, ResHelper.GetString("paymentoption_edit.errorEmptyCodeName")).Result;

        if (!ValidationHelper.IsCodeName(txtPaymentOptionName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }

		if (errorMessage == "")
		{
			 
			// paymentOptionName must to be unique
			PaymentOptionInfo paymentOptionObj = PaymentOptionInfoProvider.GetPaymentOptionInfo(txtPaymentOptionName.Text.Trim(), CMSContext.CurrentSite.SiteName);

			// if paymentOptionName value is unique														
			if ((paymentOptionObj == null) || (paymentOptionObj.PaymentOptionID == paymentOptionId))			
			{
				paymentOptionObj = new PaymentOptionInfo();

                paymentOptionObj.PaymentOptionID = paymentOptionId;
                paymentOptionObj.PaymentOptionDisplayName = txtPaymentOptionDisplayName.Text.Trim();											
				paymentOptionObj.PaymentOptionName = txtPaymentOptionName.Text.Trim();
				paymentOptionObj.PaymentOptionEnabled = chkPaymentOptionEnabled.Checked;
                paymentOptionObj.PaymentOptionSiteID = CMSContext.CurrentSite.SiteID;
                paymentOptionObj.PaymentOptionPaymentGateUrl = txtGateUrl.Text.Trim();

				PaymentOptionInfoProvider.SetPaymentOptionInfo(paymentOptionObj);

				Response.Redirect("PaymentOption_Edit.aspx?paymentOptionId=" + Convert.ToString(paymentOptionObj.PaymentOptionID) + "&saved=1");
			}
			else
			{
				lblError.Visible = true;
				lblError.Text = ResHelper.GetString("PaymentOption_Edit.PaymentOptionNameExists");
			}

		}
		else
		{
			lblError.Visible = true;
			lblError.Text = errorMessage;
		}
	}
}
