using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Configuration_PublicStatus_Edit : CMSDeskPage
{
	protected int publicStatusId = 0;
	
	protected void Page_Load(object sender, EventArgs e)
	{
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        // field validator error messages initialization
        rfvDisplayName.ErrorMessage = ResHelper.GetString("publicstatus_edit.errorEmptyDisplayName");
        rfvCodeName.ErrorMessage = ResHelper.GetString("publicstatus_edit.errorEmptyCodeName");
				
		// control initializations				
		lblPublicStatusName.Text = ResHelper.GetString("PublicStatus_Edit.PublicStatusNameLabel");
		lblPublicStatusEnabled.Text = ResHelper.GetString("PublicStatus_Edit.PublicStatusEnabledLabel");
		lblPublicStatusDisplayName.Text = ResHelper.GetString("PublicStatus_Edit.PublicStatusDisplayNameLabel");

		btnOK.Text = ResHelper.GetString("General.OK");	

		string currentPublicStatus = ResHelper.GetString("PublicStatus_Edit.NewItemCaption");

		// get publicStatus id from querystring		
        publicStatusId = ValidationHelper.GetInteger(Request.QueryString["publicStatusId"], 0);
        if (publicStatusId > 0)
        {
            PublicStatusInfo publicStatusObj = PublicStatusInfoProvider.GetPublicStatusInfo(publicStatusId);
            if (publicStatusObj != null)
            {
                currentPublicStatus = publicStatusObj.PublicStatusDisplayName;

                // fill editing form
                if (!IsPostBack)
                {
                    LoadData(publicStatusObj);

                    // show that the publicStatus was created or updated successfully
                    if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }

            PageTitle.TitleText = ResHelper.GetString("PublicStatus_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/PublicStatus/status.gif";
        }
        else // Add new
        {
            PageTitle.TitleText = ResHelper.GetString("PublicStatus_New.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/PublicStatus/newstatus.gif";
        }

		// initializes page title control		
		string[,] pageTitleTabs = new string[2, 3];
		pageTitleTabs[0, 0] = ResHelper.GetString("PublicStatus_Edit.ItemListLink");
		pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Ecommerce/Configuration/PublicStatus/PublicStatus_List.aspx";
		pageTitleTabs[0, 2] = "";
		pageTitleTabs[1, 0] = currentPublicStatus;
		pageTitleTabs[1, 1] = "";
		pageTitleTabs[1, 2] = "";
		PageTitle.Breadcrumbs = pageTitleTabs;
	}


	/// <summary>
	/// Load data of editing publicStatus.
	/// </summary>
	/// <param name="publicStatusObj">PublicStatus object.</param>
	protected void LoadData(PublicStatusInfo publicStatusObj)
	{
	
		txtPublicStatusName.Text = publicStatusObj.PublicStatusName;
		chkPublicStatusEnabled.Checked = publicStatusObj.PublicStatusEnabled;
		txtPublicStatusDisplayName.Text = publicStatusObj.PublicStatusDisplayName;

	 }

	/// <summary>
	/// Sets data to database.
	/// </summary>
	protected void btnOK_Click(object sender, EventArgs e)
	{
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        // check input values from textboxes and other contrlos
        string errorMessage = new Validator()
            .NotEmpty(txtPublicStatusDisplayName.Text, ResHelper.GetString("publicstatus_edit.errorEmptyDisplayName"))
            .NotEmpty(txtPublicStatusName.Text, ResHelper.GetString("publicstatus_edit.errorEmptyCodeName")).Result;

        if (!ValidationHelper.IsCodeName(txtPublicStatusName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }

		if (errorMessage == "")
		{
			
			// publicStatusName must to be unique
			PublicStatusInfo publicStatusObj = PublicStatusInfoProvider.GetPublicStatusInfo(txtPublicStatusName.Text.Trim());

			// if publicStatusName value is unique														
			if ((publicStatusObj == null) || (publicStatusObj.PublicStatusID == publicStatusId))			
			{
				publicStatusObj = new PublicStatusInfo();

                publicStatusObj.PublicStatusID = publicStatusId;
				publicStatusObj.PublicStatusName = txtPublicStatusName.Text.Trim();
				publicStatusObj.PublicStatusEnabled = chkPublicStatusEnabled.Checked;
				publicStatusObj.PublicStatusDisplayName = txtPublicStatusDisplayName.Text.Trim();
				
				PublicStatusInfoProvider.SetPublicStatusInfo(publicStatusObj);

				Response.Redirect("PublicStatus_Edit.aspx?publicStatusId=" + Convert.ToString(publicStatusObj.PublicStatusID) + "&saved=1");
			}
			else
			{
				lblError.Visible = true;
				lblError.Text = ResHelper.GetString("PublicStatus_Edit.PublicStatusNameExists");
			}

		}
		else
		{
			lblError.Visible = true;
			lblError.Text = errorMessage;
		}
	}
}
