using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.DataEngine;
using CMS.CMSHelper;



public partial class CMSDesk_Tools_Ecommerce_Configuration_ShippingOption_Edit_Payment : CMSDeskPage
{
    // Stores shippingOptionId request parameter.
    private int mShippingOptionId = 0;
    // Stores string of btnSave.
    protected string mSave = null;
    // Stores siteID
    private int mSiteId = 0;

    protected void Page_PreRender(object sender, EventArgs e)
    {
        //hide columns with payment ID and shipping ID
        gvPaymentMethods.Columns[2].Visible = false;
        gvPaymentMethods.Columns[3].Visible = false;
    }

    
    protected void Page_Load(object sender, EventArgs e)
    {
        // Check permission to read from e-commerce
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        // set siteID
        if (CMSContext.CurrentSite != null)
        {
            mSiteId = CMSContext.CurrentSite.SiteID;
        }

        mSave = ResHelper.GetString("com_shippingoption_edit.save");
        this.imgSave.ImageUrl = "~/App_Themes/" + this.Page.Theme + "/Images/CMSDesk/Content/save.gif";
        
        // Get mShippingOption from URL
        mShippingOptionId = ValidationHelper.GetInteger(Request.QueryString["shippingOptionId"], 0);
        if (mShippingOptionId == 0)
        {
            btnSave.Enabled = false;
            return;
        }

        DataSet ds = new DataSet();
        // Get payment methods for specific shipping ID.
        ds = PaymentOptionInfoProvider.GetShippingPaymentList(mShippingOptionId);

        // Check if ds is not empty
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            // Show columns payment ID and shipping ID to visible to allow binding
            gvPaymentMethods.Columns[2].Visible = true;
            gvPaymentMethods.Columns[3].Visible = true;
            gvPaymentMethods.DataSource = ds.Tables[0];
            // Set GridView properties - set headers
            gvPaymentMethods.Columns[0].HeaderText = ResHelper.GetString("ShippingOption_Edit_Payment.gvPaymentMethods.header1");
            gvPaymentMethods.Columns[1].HeaderText = ResHelper.GetString("ShippingOption_Edit_Payment.gvPaymentMethods.header0"); 
            gvPaymentMethods.Columns[2].HeaderText = "Shipping ID";
            gvPaymentMethods.Columns[3].HeaderText = "Payment ID";
            gvPaymentMethods.GridLines = GridLines.Horizontal;
            gvPaymentMethods.DataBind();
        }
    }


    


    /// <summary>
    /// Adds specific ID to each checkbox.
    /// </summary>
    protected void  GvOnDataDataBound(object sender, EventArgs e)
    {
        CheckBox chkActual;
        // Set unique ID for each checkbox in row according to paymentID (stored in cell3)
        foreach (GridViewRow gvr in gvPaymentMethods.Rows)
        {
            chkActual = (CheckBox) gvr.Cells[0].Controls[1];
            chkActual.ID = "chkPayment" + gvr.Cells[3].Text;            
        }
    }


    protected bool ConvertToBoolean(object value)
    {
       return (ValidationHelper.GetInteger(value, 0) > 0);
    }


    /// <summary>
    /// Saves changed data to database.
    /// </summary>
    protected void btnSave_Click(object sender, EventArgs e)
    {
        
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        bool presentStatus = false;
        bool pastStatus = false;
        int shippingID = 0;
        int paymentID = 0;
        CheckBox chkActual;

        foreach (GridViewRow gvr in gvPaymentMethods.Rows)
        {
            //get present state of checkbox (nowIsEnabled)
            chkActual = (CheckBox)gvr.Cells[0].Controls[1];
            presentStatus = chkActual.Checked;
            
            //get past state of checkbox
            //if ShippingID > 0 then payment was enabled  
            shippingID = ValidationHelper.GetInteger(gvr.Cells[2].Text,0);
            pastStatus = (shippingID > 0) ? true : false;
            
            shippingID = mShippingOptionId;
            paymentID = ValidationHelper.GetInteger(gvr.Cells[3].Text, 0);

            if ((paymentID > 0) && (shippingID > 0))
            {
                // When data are changed, make corresponding changes in DB 
                if ((presentStatus) && (!pastStatus))
                {
                     PaymentOptionInfoProvider.AddPaymentToShipping(paymentID, shippingID);
                }
                if ((!presentStatus) && (pastStatus))
                {
                    PaymentOptionInfoProvider.RemovePaymentFromShipping(paymentID, shippingID);
                }
            }
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
        }
    }

    

}