using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Configuration_COM_ShippingOption_List : CMSDeskPage
{
    int siteId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        PageTitle.TitleText = ResHelper.GetString("COM_ShippingOption_List.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/Shipping/shipping.gif";
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/Shipping/addshipping.gif";

        if (CMSContext.CurrentSite != null)
        {
            siteId = CMSContext.CurrentSite.SiteID;
        }

        UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
        UniGrid.GridView.GridLines = GridLines.Horizontal;
        UniGrid.DataSource = ShippingOptionInfoProvider.GetAllShippingsForSite(siteId, StatusEnum.Both);

        lnkNewItem.Text = ResHelper.GetString("COM_ShippingOption_List.NewItemCaption");
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void uniGrid_OnAction(string actionName, object actionArgument)
    {
        if (actionName == "edit")
        {
            Response.Redirect("ShippingOption_Edit_Frameset.aspx?ShippingOptionID=" + Convert.ToString(actionArgument));
        }
        else if (actionName == "delete")
        {
            // check 'ConfigurationModify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
            {
                CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
            }

            // Check dependencies
            if (ShippingOptionInfoProvider.CheckDependencies(ValidationHelper.GetInteger(actionArgument, 0)))
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Ecommerce.DeleteDisabled");
                return;
            }
            // delete ShippingOptionInfo object from database
            ShippingOptionInfoProvider.DeleteShippingOptionInfo(ValidationHelper.GetInteger(actionArgument, 0));

            UniGrid.DataSource = ShippingOptionInfoProvider.GetAllShippingsForSite(siteId, StatusEnum.Both);
            UniGrid.ReloadData();
        }
    }
}
