using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Customers_Edit_Login_Edit : CMSDeskPage
{
    protected int customerId = 0;
    protected int userId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        chkHasLogin.CheckedChanged += new EventHandler(chkHasLogin_CheckedChanged);
        rqvUserName.ErrorMessage = ResHelper.GetString("Customer_Edit_Login_Edit.rqvUserName");
        rqvPassword1.ErrorMessage = ResHelper.GetString("Customer_Edit_Login_Edit.rqvPassword1");
        rqvPassword2.ErrorMessage = ResHelper.GetString("Customer_Edit_Login_Edit.rqvPassword2");


        // control initializations				
        lblHasLogin.Text = ResHelper.GetString("Customer_Edit_Login_Edit.lblHasLogin");
        lblUserName.Text = ResHelper.GetString("Customer_Edit_Login_Edit.lblUserName");
        lblPassword1.Text = ResHelper.GetString("Customer_Edit_Login_Edit.lblPassword1");
        lblPassword2.Text = ResHelper.GetString("Customer_Edit_Login_Edit.lblPassword2");
        lblUserName1.Text = ResHelper.GetString("Customer_Edit_Login_Edit.lblUserName");
        lblHasLogin1.Text = ResHelper.GetString("Customer_Edit_Login_Edit.lblHasLogin");

        btnOK.Text = ResHelper.GetString("General.OK");

        // get customer id from querystring		
        customerId = ValidationHelper.GetInteger(Request.QueryString["customerId"], 0);

        CustomerInfo ci = CustomerInfoProvider.GetCustomerInfo(customerId);
        if (ci != null)
        {
            // If the customer already has the record in the CMS_User table, display only UserName
            userId = ci.CustomerUserID;
            if (userId != 0)
            {
                pnlEdit.Visible = false;
                pnlStatic.Visible = true;
                UserInfo ui = UserInfoProvider.GetUserInfo(userId);
                lblUserNameStaticValue.Text = ui.UserName;
            }
            else
            {
                pnlEdit.Visible = true;
                pnlStatic.Visible = false;
            }
        }

        if (!IsPostBack)
        {
            // show that the address was created or updated successfully
            if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
            {
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
        }

        // Enable or disable the controls
        ModifyControlStatus(chkHasLogin.Checked);
    }

    void chkHasLogin_CheckedChanged(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }

        if (chkHasLogin.Checked)
        {
            ModifyControlStatus(true);
        }
        else
        {
            ModifyControlStatus(false);
        }
    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }

        if (customerId != 0)
        {
            string errorMessage = new Validator().NotEmpty(txtUserName.Text, "Customer_Edit_Login_Edit.rqvUserName").NotEmpty(txtPassword1.Text, "Customer_Edit_Login_Edit.rqvPassword1").NotEmpty(txtPassword2.Text, "Customer_Edit_Login_Edit.rqvPassword2").Result;

            if (txtPassword1.Text != txtPassword2.Text)
            {
                errorMessage = ResHelper.GetString("Customer_Edit_Login_Edit.DifferentPasswords");
            }

            if (errorMessage == "")
            {
                if (chkHasLogin.Checked)
                {
                    try
                    {
                        CustomerInfo ci = CustomerInfoProvider.GetCustomerInfo(customerId);

                        UserInfo ui = new UserInfo();
                        ui.UserName = txtUserName.Text.Trim();
                        ui.FullName = ci.CustomerFirstName + " " + ci.CustomerLastName;
                        ui.SetValue("UserEnabled", true);
                        UserInfoProvider.SetUserInfo(ui);
                        UserInfoProvider.SetPassword(ui.UserName, txtPassword1.Text);
                        UserInfoProvider.AddUserToSite(ui.UserName, CMSContext.CurrentSite.SiteName);

                        ci.CustomerUserID = ui.UserID;

                        CustomerInfoProvider.SetCustomerInfo(ci);

                        Response.Redirect("Customer_Edit_Login.aspx?customerId=" + customerId + "&saved=1");
                    }
                    catch (Exception ex)
                    {
                        lblError.Visible = true;
                        lblError.Text = ex.Message;
                    }
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = errorMessage;
            }
        }
    }

    private void ModifyControlStatus(bool enabled)
    {
        txtUserName.Enabled = enabled;
        txtPassword1.Enabled = enabled;
        txtPassword2.Enabled = enabled;
        btnOK.Enabled = enabled;
    }
}
