using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.CMSHelper;
using CMS.SiteProvider;

public partial class CMSDesk_Tools_Ecommerce_Orders_Order_Edit_Billing : CMSDeskPage
{
    protected int orderId = 0;
    protected int customerId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "AddressChange", ScriptHelper.GetScript("   function AddressChange(AddressId) { if (AddressId > 0) { document.getElementById('" + hdnAddress.ClientID + "').value = AddressId; " + ClientScript.GetPostBackEventReference(btnChange, "") + " } } "));        

        orderId = ValidationHelper.GetInteger(Request.QueryString["orderId"], 0);

        lblCurrency.Text = ResHelper.GetString("OrderBilling.Currency");
        lblPayment.Text = ResHelper.GetString("OrderBilling.Payment");
        lblBillingAddress.Text = ResHelper.GetString("OrderBilling.Address");

        btnEdit.Text = ResHelper.GetString("OrderBilling.Edit");
        btnNew.Text = ResHelper.GetString("OrderBilling.New");
        btnOk.Text = ResHelper.GetString("General.OK");

        drpBillingAddress.SelectedIndexChanged += new EventHandler(drpBillingAddress_SelectedIndexChanged);

        LoadData();  

        btnNew.OnClientClick = "AddAddress('" + customerId + "'); return false;";
        btnEdit.OnClientClick = "EditAddress('" + customerId + "','" + drpBillingAddress.SelectedValue + "'); return false;";

    }

    void drpBillingAddress_SelectedIndexChanged(object sender, EventArgs e)
    {
        hdnAddress.Value = drpBillingAddress.SelectedValue;
    }


    protected void LoadData()
    {
        OrderInfo oi = OrderInfoProvider.GetOrderInfo(orderId);
        if (oi != null)
        {
            customerId = oi.OrderCustomerID;

            drpPayment.PaymentID = oi.OrderPaymentOptionID;
            drpPayment.ShippingOptionID = oi.OrderShippingOptionID;
            drpPayment.DropDownItemEnabledCss = "DropDownItemEnabled";
            drpPayment.DropDownItemDisabledCss = "DropDownItemDisabled";

            drpCurrency.CurrencyID = oi.OrderCurrencyID;
            drpCurrency.DropDownItemEnabledCss = "DropDownItemEnabled";
            drpCurrency.DropDownItemDisabledCss = "DropDownItemDisabled";

            // Remember previously selected item            
            ListItem li = drpBillingAddress.SelectedItem;

            DataSet ds = AddressInfoProvider.GetAddressesForCustomer(oi.OrderCustomerID, true, false, false);

            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                drpBillingAddress.DataSource = ds;
                drpBillingAddress.DataTextField = "AddressName";
                drpBillingAddress.DataValueField = "AddressID";
                drpBillingAddress.DataBind();

                if (drpBillingAddress.Items.FindByValue(ValidationHelper.GetInteger(hdnAddress.Value, 0).ToString()) != null)
                {
                    drpBillingAddress.SelectedValue = ValidationHelper.GetInteger(hdnAddress.Value, 0).ToString();
                    hdnAddress.Value = "";
                }
                else if ((li != null) && (drpBillingAddress.Items.FindByValue(li.Value) != null))
                {
                    drpBillingAddress.SelectedValue = li.Value;
                }
                else if (drpBillingAddress.Items.FindByValue(oi.OrderBillingAddressID.ToString()) != null)
                {
                    drpBillingAddress.SelectedValue = oi.OrderBillingAddressID.ToString();
                }

                EcommerceFunctions.MarkEnabledAndDisabledItems(drpBillingAddress, "AddressID", "AddressEnabled");
            }

        }
    }


    protected void btnOk_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }

        // Check whether some payment method is selected
        if (drpPayment.PaymentID <= 0)
        {
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Order_Edit_Billing.NoPayment");
            return;
        }

        OrderInfo oi = OrderInfoProvider.GetOrderInfo(orderId);

        if (oi != null)
        {
            oi.OrderBillingAddressID = ValidationHelper.GetInteger(drpBillingAddress.SelectedValue, 0);
            oi.OrderCurrencyID = drpCurrency.CurrencyID;
            oi.OrderPaymentOptionID = drpPayment.PaymentID;
            
            // Load the shopping cart to process the data
            ShoppingCartInfo sci = ShoppingCartInfoProvider.GetShoppingCartInfoFromOrder(orderId);
            if (sci != null)
            {
                SiteInfo si = SiteInfoProvider.GetSiteInfo(oi.OrderSiteID);
                if (si != null)
                {
                    sci.SiteName = si.SiteName;
                }
                else
                {
                    sci.SiteName = CMSContext.CurrentSite.SiteName;
                }
                sci.ExchangeRate = CurrencyInfoProvider.GetLastValidExchangeRate(oi.OrderCurrencyID);
                sci.ShoppingCartCurrencyID = oi.OrderCurrencyID;
                ShoppingCartInfoProvider.EvaluateShoppingCartContent(sci);

                // Update shipping charge, total price, total tax
                oi.OrderTotalPrice = sci.TotalPrice;
                oi.OrderTotalShipping = sci.TotalShipping;
                oi.OrderTotalTax = sci.TotalTax;

                // Delete shopping cart info (including all items) from database
                ShoppingCartInfoProvider.DeleteShoppingCartInfo(sci.ShoppingCartID);
            }

            OrderInfoProvider.SetOrderInfo(oi);

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");

        }
    }
}
