using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.Ecommerce;


public partial class CMSDesk_Tools_Ecommerce_Orders_Order_General : CMSDeskPage
{
    protected int orderId = 0;
    protected int originalStatusId = 0;
    protected int customerId = 0;
    protected string originalNote = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "RefreshPageScript", ScriptHelper.GetScript("function RefreshPage() { window.location.replace(window.location.href); }"));
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        // controls initialization
        lblOrderId.Text = ResHelper.GetString("order_edit.orderidlabel");
        lblOrderDate.Text = ResHelper.GetString("order_edit.orderdatelabel");
        lblInvoiceNumber.Text = ResHelper.GetString("order_edit.invoicenumberlabel");
        lblStatus.Text = ResHelper.GetString("order_edit.orderstatuslabel");
        lblCustomer.Text = ResHelper.GetString("order_edit.customerlabel");
        lblNotes.Text = ResHelper.GetString("order_edit.ordernotelabel");
        btnEditCustomer.Text = ResHelper.GetString("order_edit.editcustomer");
        btnOK.Text = ResHelper.GetString("general.OK");
        

        // get order ID from url
        orderId = ValidationHelper.GetInteger(Request.QueryString["orderid"], 0);
        // get order info from database and fill the form
        OrderInfo oi = OrderInfoProvider.GetOrderInfo(orderId);

        if (oi != null)
        {
            originalStatusId = oi.OrderStatusID;
            originalNote = oi.OrderNote;
            customerId = oi.OrderCustomerID;
            btnEditCustomer.OnClientClick = "EditCustomer(" + customerId + "); return false;";

            // initialize dropdown list
            InitializeStatus(originalStatusId);

            if (!IsPostBack)
            {
                // initialize form
                InitializeForm(oi);

                // show that the Order was updated successfully
                if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
        }
    }


    /// <summary>
    /// Initialize dropdown list with status infos.
    /// </summary>
    protected void InitializeStatus(int statusId)
    {
        // Remember previously selected item
        ListItem li = drpStatus.SelectedItem;

        drpStatus.DataSource = OrderStatusInfoProvider.GetStatuses(StatusEnum.Both);
        drpStatus.DataTextField = "StatusDisplayName";
        drpStatus.DataValueField = "StatusID";
        drpStatus.DataBind();

        if ((li != null) && (drpStatus.Items.FindByValue(li.Value) != null))
        {
            // Mark previously selected item
            drpStatus.SelectedValue = li.Value;            
        }
        else if (drpStatus.Items.FindByValue(statusId.ToString()) != null)
        {
            // Mark order status when loaded for the first time
            drpStatus.SelectedValue = statusId.ToString();
        }

        EcommerceFunctions.MarkEnabledAndDisabledItems(drpStatus, "StatusID", "StatusEnabled");
    }


    /// <summary>
    /// Initialize the form with order values.
    /// </summary>
    protected void InitializeForm(OrderInfo orderInfo)
    {
        lblOrderIdValue.Text = Convert.ToString(orderInfo.OrderID);
        orderDate.DateTimeTextBox.Text = Convert.ToString(orderInfo.OrderDate);
        lblInvoiceNumberValue.Text = Convert.ToString(orderInfo.OrderInvoiceNumber);        
        txtNotes.Text = orderInfo.OrderNote;

        CustomerInfo ci = CustomerInfoProvider.GetCustomerInfo(customerId);
        if (ci != null)
        {
            lblCustomerName.Text = ci.CustomerFirstName + " " + ci.CustomerLastName;
        }
    }


    /// <summary>
    /// On btnOK button click.
    /// </summary>
    /// <param name="sender">Sender.</param>
    /// <param name="e">Event argument.</param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }

        string errorMessage = ValidateForm();

        if (errorMessage == "")
        {
            OrderInfo oi = OrderInfoProvider.GetOrderInfo(orderId);
            if (oi != null)
            {
                oi.OrderDate = orderDate.SelectedDateTime;
                oi.OrderNote = txtNotes.Text;
                oi.OrderStatusID = ValidationHelper.GetInteger(drpStatus.SelectedValue, 0);
                // update orderinfo
                OrderInfoProvider.SetOrderInfo(oi);
                // make note to order history if status is changed
                if (oi.OrderStatusID != originalStatusId)
                {
                    OrderStatusUserInfo osui = new OrderStatusUserInfo();

                    osui.OrderID = oi.OrderID;
                    osui.FromStatusID = originalStatusId;
                    osui.ToStatusID = oi.OrderStatusID;
                    osui.ChangedByUserID = CMSContext.CurrentUser.UserID;
                    osui.Date = DateTime.Now;
                    osui.Note = originalNote;
                    // save new OrderStatusUserInfo
                    OrderStatusUserInfoProvider.SetOrderStatusUserInfo(osui);
                }

                Response.Redirect("Order_Edit_General.aspx?orderid=" + Convert.ToString(oi.OrderID) + "&saved=1");
            }
            else
            {
                lblError.Visible = true;
                errorMessage = ResHelper.GetString("order_edit.ordernotexist");
            }
        }
        
        // Show error message
        if (errorMessage != "")
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }


    /// <summary>
    /// Validates form input fields.
    /// </summary>
    protected string ValidateForm()
    {
        // Validate order date for emptyness
        string errorMessage = new Validator().NotEmpty(orderDate.DateTimeTextBox.Text, ResHelper.GetString("order_edit.dateerr")).Result;

        if (errorMessage == "")
        {

            // Validate order date for wrong format
            if (ValidationHelper.GetDateTime(orderDate.SelectedDateTime, DataHelper.DATETIME_NOT_SELECTED) == DataHelper.DATETIME_NOT_SELECTED)
            {
                errorMessage = ResHelper.GetString("order_edit.datewrongformat");
            }
        }

        return errorMessage;
    }
}
