using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.CMSHelper;
using CMS.SiteProvider;

public partial class CMSDesk_Tools_Ecommerce_Orders_Order_Edit_Shipping : CMSDeskPage
{
    protected int orderId = 0;
    protected int customerId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceRead");
        }

        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "AddressChange", ScriptHelper.GetScript("   function AddressChange(AddressId) { if (AddressId > 0) { document.getElementById('" + hdnAddress.ClientID + "').value = AddressId; " + ClientScript.GetPostBackEventReference(btnChange, "") + " } } "));

        lblAddress.Text = ResHelper.GetString("Order_Edit_Shipping.lblAddress");
        lblOption.Text = ResHelper.GetString("Order_Edit_Shipping.lblOption");

        btnEdit.Text = ResHelper.GetString("Order_Edit_Shipping.btnEdit");
        btnNew.Text = ResHelper.GetString("Order_Edit_Shipping.btnNew");
        btnOk.Text = ResHelper.GetString("General.OK");

        btnOk.Click += new EventHandler(btnOk_Click);
        drpAddress.SelectedIndexChanged += new EventHandler(drpAddress_SelectedIndexChanged);

        orderId = ValidationHelper.GetInteger(Request.QueryString["orderId"], 0);
        LoadData();

        btnNew.OnClientClick = "AddAddress('" + customerId + "'); return false;";
        btnEdit.OnClientClick = "EditAddress('" + customerId + "','" + drpAddress.SelectedValue + "'); return false;";
    }

    void drpAddress_SelectedIndexChanged(object sender, EventArgs e)
    {
        hdnAddress.Value = drpAddress.SelectedValue;
    }


    protected void btnOk_Click(object sender, EventArgs e)
    {
        // check 'EcommerceModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "EcommerceModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "EcommerceModify");
        }

        OrderInfo oi = OrderInfoProvider.GetOrderInfo(orderId);
        if (oi != null)
        {

            if (drpOption.ShippingID > 0)
            {

                try
                {
                    if (drpAddress.SelectedItem != null)
                    {
                        oi.OrderShippingAddressID = ValidationHelper.GetInteger(drpAddress.SelectedValue, 0);
                    }
                    oi.OrderShippingOptionID = drpOption.ShippingID;

                    // Load the shopping cart to process the data
                    ShoppingCartInfo sci = ShoppingCartInfoProvider.GetShoppingCartInfoFromOrder(orderId);
                    if (sci != null)
                    {
                        SiteInfo si = SiteInfoProvider.GetSiteInfo(oi.OrderSiteID);
                        if (si != null)
                        {
                            sci.SiteName = si.SiteName;
                        }
                        else
                        {
                            sci.SiteName = CMSContext.CurrentSite.SiteName;
                        }
                        sci.ExchangeRate = CurrencyInfoProvider.GetLastValidExchangeRate(sci.ShoppingCartCurrencyID);
                        sci.ShoppingCartShippingOptionID = oi.OrderShippingOptionID;
                        ShoppingCartInfoProvider.EvaluateShoppingCartContent(sci);

                        // Update shipping charge, total price, total tax
                        oi.OrderTotalPrice = sci.TotalPrice;
                        oi.OrderTotalShipping = sci.TotalShipping;
                        oi.OrderTotalTax = sci.TotalTax;

                        // Delete shopping cart info (including all items) from database
                        ShoppingCartInfoProvider.DeleteShoppingCartInfo(sci.ShoppingCartID);
                    }

                    // Set order info
                    OrderInfoProvider.SetOrderInfo(oi);

                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
                catch (Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = ex.Message;
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Order_Edit_Shipping.ShippingError");
            }
        }
    }

    //protected void btnChange_Click(object sender, EventArgs e)
    //{
    //    if (ValidationHelper.GetInteger(hdnAddress.Value, 0) != 0)
    //    {
    //        LoadData();
    //        drpAddress.SelectedValue = ValidationHelper.GetInteger(hdnAddress.Value, 0).ToString();
    //        hdnAddress.Value = "";
    //    }
    //}

    private void LoadData()
    {

        OrderInfo oi = OrderInfoProvider.GetOrderInfo(orderId);
        if (oi != null)
        {
            customerId = oi.OrderCustomerID;

            drpOption.ShippingID = oi.OrderShippingOptionID;
            drpOption.DropDownItemEnabledCss = "DropDownItemEnabled";
            drpOption.DropDownItemDisabledCss = "DropDownItemDisabled";

            // Remember previously selected item
            ListItem li = drpAddress.SelectedItem;

            DataSet ds = AddressInfoProvider.GetAddressesForCustomer(customerId, false, true, false);
            drpAddress.DataSource = ds;
            drpAddress.DataTextField = "AddressName";
            drpAddress.DataValueField = "AddressID";
            drpAddress.DataBind();

            if (drpAddress.Items.FindByValue(ValidationHelper.GetInteger(hdnAddress.Value, 0).ToString()) != null)
            {
                drpAddress.SelectedValue = ValidationHelper.GetInteger(hdnAddress.Value, 0).ToString();
                hdnAddress.Value = "";
            }
            else if ((li != null) && (drpAddress.Items.FindByValue(li.Value) != null))
            {
                drpAddress.SelectedValue = li.Value;
            }
            else if (drpAddress.Items.FindByValue(oi.OrderShippingAddressID.ToString()) != null)
            {
                drpAddress.SelectedValue = Convert.ToString(oi.OrderShippingAddressID);
            }

            EcommerceFunctions.MarkEnabledAndDisabledItems(drpAddress, "AddressID", "AddressEnabled");
        }
    }
}
