using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Forums;
using CMS.CMSHelper;
using CMS.LicenseProvider;


public partial class CMS_Project_CMSSolution_CMS_Forum_Edit : CMSDeskPage
{
    protected int forumId = 0;
    protected int groupId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

        // control initializations
        rfvForumDisplayName.ErrorMessage = ResHelper.GetString("Forum_General.EmptyDisplayName");
        rfvForumName.ErrorMessage = ResHelper.GetString("Forum_General.EmptyCodeName");

        lblForumOpen.Text = ResHelper.GetString("Forum_Edit.ForumOpenLabel");
        lblForumDisplayEmails.Text = ResHelper.GetString("Forum_Edit.ForumDisplayEmailsLabel");
        lblForumDescription.Text = ResHelper.GetString("Forum_Edit.ForumDescriptionLabel");
        lblForumRequireEmail.Text = ResHelper.GetString("Forum_Edit.ForumRequireEmailLabel");
        lblForumDisplayName.Text = ResHelper.GetString("Forum_Edit.ForumDisplayNameLabel");
        lblForumName.Text = ResHelper.GetString("Forum_Edit.ForumNameLabel");
        lblUseHTML.Text = ResHelper.GetString("Forum_Edit.UseHtml");
        lblBaseUrl.Text = ResHelper.GetString("Forum_Edit.lblBaseUrl");
        lblCaptcha.Text = ResHelper.GetString("Forum_Edit.useCaptcha");

        btnOK.Text = ResHelper.GetString("General.OK");

        string currentForum = ResHelper.GetString("Forum_Edit.NewItemCaption");

        // get forum id from querystring
        if ((Request.QueryString["forumid"] != null) && (Request.QueryString["forumid"] != ""))
        {
            forumId = Convert.ToInt32(Request.QueryString["forumid"]);
            ForumInfo forumObj = ForumInfoProvider.GetForumInfo(forumId);
            if (forumObj != null)
            {
                currentForum = forumObj.ForumName;
                groupId = forumObj.ForumGroupID;

                // fill editing form
                if (!IsPostBack)
                {
                    LoadData(forumObj);

                    // show that the forum was created or updated successfully
                    if (Request.QueryString["saved"] == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }
        }
    }


    /// <summary>
    /// Load data of editing forum.
    /// </summary>
    /// <param name="forumObj">Forum object.</param>
    protected void LoadData(ForumInfo forumObj)
    {
        chkForumOpen.Checked = forumObj.ForumOpen;
        chkForumDisplayEmails.Checked = forumObj.ForumDisplayEmails;
        txtForumDescription.Text = forumObj.ForumDescription;
        chkForumRequireEmail.Checked = forumObj.ForumRequireEmail;
        txtForumDisplayName.Text = forumObj.ForumDisplayName;
        txtForumName.Text = forumObj.ForumName;
        txtBaseUrl.Text = forumObj.ForumBaseUrl;
        chkUseHTML.Checked = forumObj.ForumHTMLEditor;
        chkCaptcha.Checked = forumObj.ForumUseCAPTCHA;
    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtForumDisplayName.Text, ResHelper.GetString("Forum_General.EmptyDisplayName")).NotEmpty(txtForumName.Text, ResHelper.GetString("Forum_General.EmptyCodeName")).Result;

        if (errorMessage == String.Empty && !ValidationHelper.IsCodeName(txtForumName.Text.Trim()))
        {
            errorMessage = ResHelper.GetString("general.errorcodenameinidentificatorformat");
        }

        if (errorMessage == "")
        {
            if (CMSContext.CurrentSite != null)
            {
                ForumInfo forumObj = ForumInfoProvider.GetForumInfo(txtForumName.Text.Trim(), CMSContext.CurrentSite.SiteID);

                if ((forumObj == null) || (forumObj.ForumID == forumId))
                {
                    if (forumObj == null)
                    {
                        forumObj = ForumInfoProvider.GetForumInfo(forumId);
                    }
                    if (forumObj != null)
                    {
                        forumObj.ForumOpen = chkForumOpen.Checked;
                        forumObj.ForumDisplayEmails = chkForumDisplayEmails.Checked;
                        forumObj.ForumDescription = txtForumDescription.Text.Trim();
                        forumObj.ForumRequireEmail = chkForumRequireEmail.Checked;
                        forumObj.ForumDisplayName = txtForumDisplayName.Text.Trim();
                        forumObj.ForumName = txtForumName.Text.Trim();
                        forumObj.ForumBaseUrl = txtBaseUrl.Text;
                        forumObj.ForumHTMLEditor = chkUseHTML.Checked;
                        forumObj.ForumUseCAPTCHA = chkCaptcha.Checked;

                        ForumInfoProvider.SetForumInfo(forumObj);

                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                    else
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("Forum_Edit.ForumDoesNotExist");
                    }
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Forum_Edit.ForumAlreadyExists");
                }
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
