using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Forums;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.LicenseProvider;

public partial class CMSDesk_Tools_Forums_Forums_Forum_New : CMSDeskPage
{
    protected int groupId = 0;
    
    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

        // control initializations
        rfvForumDisplayName.ErrorMessage = ResHelper.GetString("Forum_General.EmptyDisplayName");
        rfvForumName.ErrorMessage = ResHelper.GetString("Forum_General.EmptyCodeName");

        lblForumOpen.Text = ResHelper.GetString("Forum_Edit.ForumOpenLabel");
        lblForumDisplayEmails.Text = ResHelper.GetString("Forum_Edit.ForumDisplayEmailsLabel");
        lblForumDescription.Text = ResHelper.GetString("Forum_Edit.ForumDescriptionLabel");
        lblForumRequireEmail.Text = ResHelper.GetString("Forum_Edit.ForumRequireEmailLabel");
        lblForumDisplayName.Text = ResHelper.GetString("Forum_Edit.ForumDisplayNameLabel");
        lblForumName.Text = ResHelper.GetString("Forum_Edit.ForumNameLabel");
        lblForumModerated.Text = ResHelper.GetString("Forum_Edit.ForumModeratedLabel");
        lblUseHTML.Text = ResHelper.GetString("Forum_Edit.UseHtml");
        lblCaptcha.Text = ResHelper.GetString("Forum_Edit.useCaptcha");

        lblBaseUrl.Text = ResHelper.GetString("Forum_Edit.lblBaseUrl");

        btnOK.Text = ResHelper.GetString("General.OK");

        groupId = ValidationHelper.GetInteger(Request.QueryString["groupid"], 0);

        //initialize page title tabs
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("forum_list.headercaption");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Forums/Forums/Forum_List.aspx?groupid=" + groupId;
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = ResHelper.GetString("Forum_Edit.NewForum");
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("Forum_Edit.NewForum");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Forums/newforum.gif";
    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtForumDisplayName.Text, ResHelper.GetString("Forum_General.EmptyDisplayName")).NotEmpty(txtForumName.Text, ResHelper.GetString("Forum_General.EmptyCodeName")).Result;

        if (errorMessage == String.Empty && !ValidationHelper.IsCodeName(txtForumName.Text.Trim()))
        {
            errorMessage = ResHelper.GetString("general.errorcodenameinidentificatorformat");
        }

        if (errorMessage == "")
        {
            if (CMSContext.CurrentSite != null)
            {

                //if forum with given name already exists show error message
                if (ForumInfoProvider.GetForumInfo(txtForumName.Text, CMSContext.CurrentSite.SiteID) != null)
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Forum_Edit.ForumAlreadyExists");
                    return;
                }

                ForumInfo forumObj = new ForumInfo();
                forumObj.ForumOpen = chkForumOpen.Checked;
                forumObj.ForumDisplayEmails = chkForumDisplayEmails.Checked;
                forumObj.ForumDescription = txtForumDescription.Text.Trim();
                forumObj.ForumRequireEmail = chkForumRequireEmail.Checked;
                forumObj.ForumDisplayName = txtForumDisplayName.Text.Trim();
                forumObj.ForumName = txtForumName.Text.Trim();
                forumObj.ForumGroupID = groupId;
                forumObj.ForumModerated = chkForumModerated.Checked;
                forumObj.ForumAccess = 0;
                forumObj.ForumPosts = 0;
                forumObj.ForumThreads = 0;
                forumObj.ForumOrder = 0;
                forumObj.ForumHTMLEditor = chkUseHTML.Checked;
                forumObj.ForumUseCAPTCHA = chkCaptcha.Checked;

                ForumInfoProvider.SetForumInfo(forumObj);

                Response.Redirect("Forum_Frameset.aspx?forumid=" + Convert.ToString(forumObj.ForumID) + "&saved=1");
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
