using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Forums;
using CMS.CMSHelper;
using CMS.LicenseProvider;

public partial class Forums_Forums_Edit : CMSDeskPage
{
	protected int groupId = 0;
	
	protected void Page_Load(object sender, EventArgs e)
	{

        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

    	// control initializations				
		rfvGroupDisplayName.ErrorMessage = ResHelper.GetString("Group_General.EmptyDisplayName");
        rfvGroupName.ErrorMessage = ResHelper.GetString("Group_General.EmptyCodeName");
        
        
        lblGroupDescription.Text = ResHelper.GetString("Group_General.GroupDescriptionLabel");
        lblGroupDisplayName.Text = ResHelper.GetString("Group_General.GroupDisplayNameLabel");
        lblGroupName.Text = ResHelper.GetString("Group_General.GroupNameLabel");

		btnOK.Text = ResHelper.GetString("General.OK");	


		// get forumGroup id from querystring
        if ((Request.QueryString["groupid"] != null) && (Request.QueryString["groupid"] != ""))
		{
            groupId = Convert.ToInt32(Request.QueryString["groupid"]);
            ForumGroupInfo forumGroupObj = ForumGroupInfoProvider.GetForumGroupInfo(groupId);
			
			// fill editing form
			if (!IsPostBack)
			{
				LoadData(forumGroupObj);
				
				// show that the forumGroup was created or updated successfully
				if (Request.QueryString["saved"] == "1")
				{
					lblInfo.Visible = true;
					lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
				}
			}
		}


	}


	/// <summary>
	/// Load data of editing forumGroup.
	/// </summary>
	/// <param name="forumGroupObj">ForumGroup object.</param>
	protected void LoadData(ForumGroupInfo forumGroupObj)
	{
		txtGroupDescription.Text = forumGroupObj.GroupDescription;
		txtGroupDisplayName.Text = forumGroupObj.GroupDisplayName;
		txtGroupName.Text = forumGroupObj.GroupName;

	 }

	/// <summary>
	/// Sets data to database.
	/// </summary>
	protected void btnOK_Click(object sender, EventArgs e)
	{

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtGroupDisplayName.Text, ResHelper.GetString("Group_General.EmptyDisplayName")).NotEmpty(txtGroupName.Text, ResHelper.GetString("Group_General.EmptyCodeName")).Result;

        if (errorMessage == String.Empty && !ValidationHelper.IsCodeName(txtGroupName.Text.Trim()))
        {
            errorMessage = ResHelper.GetString("general.errorcodenameinidentificatorformat");
        }

		if (errorMessage == "")
		{
            string siteName = "";

            if (CMSContext.CurrentSite != null)
            {
                siteName = CMSContext.CurrentSite.SiteName;
            }

            ForumGroupInfo forumGroupObj = ForumGroupInfoProvider.GetForumGroupInfo(txtGroupName.Text.Trim(), siteName);

            if ((forumGroupObj == null) || (forumGroupObj.GroupID == groupId))
            {
                if (forumGroupObj == null)
                {
                    forumGroupObj = ForumGroupInfoProvider.GetForumGroupInfo(groupId);
                }
                if (forumGroupObj != null)
                {
                    forumGroupObj.GroupDescription = txtGroupDescription.Text.Trim();
                    forumGroupObj.GroupDisplayName = txtGroupDisplayName.Text.Trim();
                    forumGroupObj.GroupName = txtGroupName.Text.Trim();
                    ForumGroupInfoProvider.SetForumGroupInfo(forumGroupObj);
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Group_General.GroupNotFound");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Group_General.GroupAlreadyExists");
            }
		}
		else
		{
			lblError.Visible = true;
			lblError.Text = errorMessage;
		}
	}
}
