using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.Forums;
using CMS.LicenseProvider;

public partial class Forums_Forums_List : CMSDeskPage
{
    protected bool showApprove = true;

    protected void Page_Load(object sender, EventArgs e)
    {

        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        int[] forumsIds = null;

        // Get forums moderated by current user
        if (!CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            DataSet ds = ForumInfoProvider.GetModerator(CMSContext.CurrentUser.UserID);

            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                forumsIds = new int[ds.Tables[0].Rows.Count];

                int i = 0;
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    forumsIds[i] = ValidationHelper.GetInteger(dr["ForumId"], 0);
                    i++;
                }
            }
        }


        // check 'Read' permission
        if ((!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read")))
        {
            if (forumsIds != null)
            {
                pnlGroups.Visible = false;
            }
            else
            {
                CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
            }
        }

        //Hide approvals
        if ((!CMSContext.CurrentUser.IsGlobalAdministrator) && (forumsIds == null))
        {
            ApproveGrid.GridView.Enabled = false;
            pnlApprove.Visible = false;
            showApprove = false;
        }


        ApproveTitle.TitleText = ResHelper.GetString("Forums.WaitingApprove");
        ApproveTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Groups/WaitingForApproval.gif";

        ApproveGrid.OnAction += new OnActionEventHandler(ApproveGrid_OnAction);
        ApproveGrid.GridView.GridLines = GridLines.Horizontal;
        ApproveGrid.GridView.AllowSorting = false;
        ApproveGrid.GridView.DataBound += new EventHandler(GridView_DataBound);

        ApproveGrid.HideControlForZeroRows = true;

        //Get post for GlobalAdministrator and moderators
        if (CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            ApproveGrid.WhereCondition = "(PostApprovedByUserID IS NULL) AND (PostForumID IN  (SELECT ForumID FROM [Forums_Forum] WHERE (ForumModerated = 1)AND(ForumGroupID IN(SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = " + CMSContext.CurrentSite.SiteID + "))))";
        }
        else
        {
            if (forumsIds != null)
            {

                string ids = "";
                for (int i = 0; i < forumsIds.Length; i++)
                {
                    ids += forumsIds[i].ToString();
                    if (i < forumsIds.Length - 1)
                    {
                        ids += ", ";
                    }
                }

                ApproveGrid.WhereCondition = "(PostApprovedByUserID IS NULL) AND (PostForumID IN  (SELECT ForumID FROM [Forums_Forum] WHERE (ForumModerated = 1)AND(ForumID IN (" +
                    ids +
                    ")) AND(ForumGroupID IN(SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = " + CMSContext.CurrentSite.SiteID + "))))";
            }
        }

        if (CMSContext.CurrentSite != null)
        {
            // select forum groups for current site only
            object[,] parameters = new object[1, 3];
            parameters[0, 0] = "GroupSiteID";
            parameters[0, 1] = CMSContext.CurrentSite.SiteID;

            UniGrid.QueryParameters = parameters;
            UniGrid.WhereCondition = "GroupSiteID = @GroupSiteID";
        }

        PageTitle.TitleText = ResHelper.GetString("Group_List.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Groups/Groups.gif";
        imgNewDoctype.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Groups/addgroup.gif";



        UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
        UniGrid.GridView.GridLines = GridLines.Horizontal;
        UniGrid.GridView.AllowSorting = false;

        lnkNewDoctype.Text = ResHelper.GetString("Group_List.NewItemCaption");
    }


    void GridView_DataBound(object sender, EventArgs e)
    {

        if (showApprove)
        {

            if (!DataHelper.DataSourceIsEmpty(ApproveGrid.GridView.DataSource))
            {
                DataRowCollection drc = null;

                if (ApproveGrid.GridView.DataSource is DataTable)
                {
                    drc = ((DataTable)ApproveGrid.GridView.DataSource).Rows;                
                }

                if (ApproveGrid.GridView.DataSource is DataSet)
                {
                    drc = ((DataSet)ApproveGrid.GridView.DataSource).Tables[0].Rows;
                }

                int rowsBefore = (ApproveGrid.GridView.PageIndex) * ApproveGrid.GridView.PageSize;

                int i = 0;
                foreach (DataRow dr in drc)
                {
                    if (((i - rowsBefore) < ApproveGrid.GridView.Rows.Count) && (i >= rowsBefore))
                    {
                        if (((i - rowsBefore) < ApproveGrid.GridView.Rows.Count) && (i >= rowsBefore))
                        {
                            ForumInfo fi = ForumInfoProvider.GetForumInfo(ValidationHelper.GetInteger(DataHelper.GetDataRowValue(dr, "PostForumId"), 0));
                            if (fi != null)
                            {
                                ApproveGrid.GridView.Rows[i - rowsBefore].Cells[1].Text = fi.ForumDisplayName;

                            }

                            ApproveGrid.GridView.Rows[i - rowsBefore].Cells[2].Text = "<b>" + Server.HtmlEncode(ValidationHelper.GetString(dr["PostUserName"], "")) + ":</b> " +
                                Server.HtmlEncode(ValidationHelper.GetString(dr["PostSubject"], "")) + "<br />" +
                                Server.HtmlEncode(ValidationHelper.GetString(dr["PostText"], ""));
                        }
                    }
                    i++;
                }
            }
        }
    }

    /// <summary>
    /// Approve, reject or delete post
    /// </summary>
    /// <param name="actionName"></param>
    /// <param name="actionArgument"></param>
    void ApproveGrid_OnAction(string actionName, object actionArgument)
    {
        if (actionName.ToLower() == "deletepost")
        {
            ForumPostInfoProvider.DeleteForumPostInfo(ValidationHelper.GetInteger(actionArgument, 0));
        }

        if (actionName.ToLower() == "approve")
        {
            ForumPostInfo fpi = ForumPostInfoProvider.GetForumPostInfo(ValidationHelper.GetInteger(actionArgument, 0));
            if (fpi != null)
            {
                fpi.PostApprovedByUserID = CMSContext.CurrentUser.UserID;
                ForumPostInfoProvider.SetForumPostInfo(fpi);
            }
        }
        
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void uniGrid_OnAction(string actionName, object actionArgument)
    {

        if (actionName == "edit")
        {
            Response.Redirect("Group_Frameset.aspx?groupId=" + Convert.ToString(actionArgument));
        }
        else if (actionName == "delete")
        {
            // check 'Read' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
            }

            // delete ForumGroupInfo object from database
            ForumGroupInfoProvider.DeleteForumGroupInfo(Convert.ToInt32(actionArgument));
            Response.Redirect("Group_List.aspx");
        }
        else if (actionName == "up")
        {
            // check 'Read' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
            }
            ForumGroupInfoProvider.MoveGroupUp(Convert.ToInt32(actionArgument));
        }
        else if (actionName == "down")
        {
            // check 'Read' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
            }
            ForumGroupInfoProvider.MoveGroupDown(Convert.ToInt32(actionArgument));
        }
    }
}
