using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Forums;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.LicenseProvider;

public partial class CMSDesk_Tools_Forums_Groups_Group_New : CMSDeskPage
{
    protected int groupId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

        // control initializations				
        rfvGroupDisplayName.ErrorMessage = ResHelper.GetString("Group_General.EmptyDisplayName");
        rfvGroupName.ErrorMessage = ResHelper.GetString("Group_General.EmptyCodeName");


        lblGroupDescription.Text = ResHelper.GetString("Group_General.GroupDescriptionLabel");
        lblGroupDisplayName.Text = ResHelper.GetString("Group_General.GroupDisplayNameLabel");
        lblGroupName.Text = ResHelper.GetString("Group_General.GroupNameLabel");

        btnOK.Text = ResHelper.GetString("General.OK");

        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Groups/newgroup.gif";

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Group_General.GroupList");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Forums/Groups/Group_List.aspx";
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = ResHelper.GetString("Group_General.NewGroup");
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("Group_General.NewGroup");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Groups/Group.gif";

    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtGroupDisplayName.Text, ResHelper.GetString("Group_General.EmptyDisplayName")).NotEmpty(txtGroupName.Text, ResHelper.GetString("Group_General.EmptyCodeName")).Result;

        if (errorMessage == String.Empty && !ValidationHelper.IsCodeName(txtGroupName.Text.Trim()))
        {
            errorMessage = ResHelper.GetString("general.errorcodenameinidentificatorformat");
        }

        if (errorMessage == "")
        {
            string siteName = "";
           
            if (CMSContext.CurrentSite != null)
            {
                siteName = CMSContext.CurrentSite.SiteName;
            }
            
            //if forum group with given name already exists show error message
            if (ForumGroupInfoProvider.GetForumGroupInfo(txtGroupName.Text, siteName) != null)
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Group_General.GroupAlreadyExists");
                return;
            }
            ForumGroupInfo forumGroupObj = new ForumGroupInfo();

            forumGroupObj.GroupDescription = txtGroupDescription.Text.Trim();
            forumGroupObj.GroupDisplayName = txtGroupDisplayName.Text.Trim();
            forumGroupObj.GroupName = txtGroupName.Text.Trim();
            forumGroupObj.GroupOrder = 0;
            if (CMSContext.CurrentSite != null)
            {
                forumGroupObj.GroupSiteID = CMSContext.CurrentSite.SiteID;
            }
            ForumGroupInfoProvider.SetForumGroupInfo(forumGroupObj);

            Response.Redirect("Group_Frameset.aspx?groupId=" + Convert.ToString(forumGroupObj.GroupID) + "&saved=1");
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
