using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Forums;
using CMS.CMSHelper;

public partial class Project_CMSSolution_CMS_ForumPost_Edit : CMSDeskPage
{
    protected int postId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

        fckTemplateBody.BasePath = "~/CMSAdminControls/FCKeditor/";
        fckTemplateBody.AutoDetectLanguage = false;
        fckTemplateBody.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
        fckTemplateBody.EditorAreaCSS = "";
        fckTemplateBody.ToolbarSet = "Forum";

        lblPostUserMail.Text = ResHelper.GetString("ForumPost_Edit.PostUserMailLabel");
        lblPostText.Text = ResHelper.GetString("ForumPost_Edit.PostTextLabel");
        lblPostSubject.Text = ResHelper.GetString("ForumPost_Edit.PostSubjectLabel");
        lblPostUserName.Text = ResHelper.GetString("ForumPost_Edit.PostUserNameLabel");
        lblSignature.Text = ResHelper.GetString("ForumPost_Edit.Signature");

        btnOK.Text = ResHelper.GetString("General.OK");

        string currentForumPost = "";

        // get forumPost id from querystring
        if ((Request.QueryString["postid"] != null) && (Request.QueryString["postid"] != ""))
        {
            postId = Convert.ToInt32(Request.QueryString["postid"]);
            ForumPostInfo forumPostObj = ForumPostInfoProvider.GetForumPostInfo(postId);
            if (forumPostObj != null)
            {
                currentForumPost = Server.HtmlEncode(forumPostObj.PostSubject);

                // fill editing form
                if (!IsPostBack)
                {
                    LoadData(forumPostObj);
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("ForumPost_Edit.NoPostFound");
            }
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("ForumPost_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Forums/Posts/ForumPost_View.aspx?postid=" + postId.ToString();
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = currentForumPost;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("ForumPost_Edit.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Posts/post.gif";
    }


    /// <summary>
    /// Load data of editing forumPost.
    /// </summary>
    /// <param name="forumPostObj">ForumPost object.</param>
    protected void LoadData(ForumPostInfo forumPostObj)
    {
        txtPostUserMail.Text = Server.HtmlDecode(forumPostObj.PostUserMail);
        txtPostText.Text = Server.HtmlDecode(forumPostObj.PostText);

        ForumInfo fi = ForumInfoProvider.GetForumInfo(forumPostObj.PostForumID);
        if ((fi != null) && (fi.ForumHTMLEditor))
        {
            ForumProperties fp = new ForumProperties();
            fckTemplateBody.Visible = true;
            txtPostText.Visible = false;
            fckTemplateBody.ResolvedValue = fp.ForumHtmlEncode(forumPostObj.PostText, forumPostObj.PostForumID);
        }
        txtPostSubject.Text = Server.HtmlDecode(forumPostObj.PostSubject);
        txtPostUserName.Text = Server.HtmlDecode(forumPostObj.PostUserName);
        txtSignature.Text = forumPostObj.PostUserSignature;

    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        string errorMessage = "";
        if (fckTemplateBody.Visible)
        {
            errorMessage = new Validator().NotEmpty(txtPostSubject.Text.Trim(), ResHelper.GetString("ForumPost_Edit.ErrSubject")).NotEmpty(fckTemplateBody.ResolvedValue, ResHelper.GetString("ForumPost_Edit.ErrPostText")).Result;

        }
        else
        {
            errorMessage = new Validator().NotEmpty(txtPostSubject.Text.Trim(), ResHelper.GetString("ForumPost_Edit.ErrSubject")).NotEmpty(txtPostText.Text, ResHelper.GetString("ForumPost_Edit.ErrPostText")).Result;
        }


        if (errorMessage == "")
        {
            ForumPostInfo forumPostObj = ForumPostInfoProvider.GetForumPostInfo(postId);

            if (forumPostObj != null)
            {
                forumPostObj.PostUserMail = Server.HtmlEncode(txtPostUserMail.Text.Trim());
                forumPostObj.PostText = Server.HtmlEncode(txtPostText.Text.Trim().Replace("&", "##AND_MACRO##"));
                forumPostObj.PostText = forumPostObj.PostText.Replace("##AND_MACRO##", "&");

                ForumInfo fi = ForumInfoProvider.GetForumInfo(forumPostObj.PostForumID);
                if ((fi != null) && (fi.ForumHTMLEditor))
                {
                    // Check email validity
                    if (((!ValidationHelper.IsEmail(txtPostUserMail.Text.Trim())) && (txtPostUserMail.Text.Trim() != "")) || ((txtPostUserMail.Text.Trim() == "") && (fi.ForumRequireEmail)))
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("ForumPost_Edit.ErrEmail");

                        return;
                    }

                    ForumProperties fp = new ForumProperties();
                    forumPostObj.PostText = fp.ForumHtmlEncode(fckTemplateBody.ResolvedValue, forumPostObj.PostForumID);
                }

                forumPostObj.PostSubject = Server.HtmlEncode(txtPostSubject.Text.Trim());
                forumPostObj.PostUserName = Server.HtmlEncode(txtPostUserName.Text.Trim());

                ForumPostInfoProvider.SetForumPostInfo(forumPostObj);

                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");

                ltlScript.Text += ScriptHelper.GetScript("parent.frames['posts_tree'].location.href = 'ForumPost_Tree.aspx?postid=" + forumPostObj.PostId.ToString() + "&forumid=" + forumPostObj.PostForumID + "';");
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("ForumPost_Edit.NoPostFound");
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
