using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Forums;
using CMS.CMSHelper;
using CMS.LicenseProvider;

public partial class CMS_Project_CMSSolution_CMS_ForumSubscription_Edit : CMSDeskPage
{
	protected int subscriptionId = 0;
    protected int forumId = 0;
	
	protected void Page_Load(object sender, EventArgs e)
	{
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        }

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Read");
        }

        rfvSubscriptionEmail.ErrorMessage = ResHelper.GetString("ForumSubscription_Edit.EnterSomeEmail");
		rfvEmail.ValidationExpression = @"^([a-z0-9_-]+(\.[a-z0-9_-]+)*@[a-z0-9_-]+(\.[a-z0-9_-]+)+)*$";
        rfvEmail.ErrorMessage = ResHelper.GetString("ForumSubscription_Edit.emailErrorMsg");

        // control initializations				
		lblSubscriptionEmail.Text = ResHelper.GetString("ForumSubscription_Edit.SubscriptionEmailLabel");

		btnOK.Text = ResHelper.GetString("General.OK");
        
        string currentForumSubscription = "";
        ForumSubscriptionInfo forumSubscriptionObj = new ForumSubscriptionInfo();

		// get forumSubscription id from querystring
        if ((Request.QueryString["subscriptionid"] != null) && (Request.QueryString["subscriptionid"] != ""))
        {
            subscriptionId = Convert.ToInt32(Request.QueryString["subscriptionid"]);
            forumSubscriptionObj = ForumSubscriptionInfoProvider.GetForumSubscriptionInfo(subscriptionId);
            currentForumSubscription = Server.HtmlEncode(forumSubscriptionObj.SubscriptionEmail);

            // fill editing form
            if (!IsPostBack)
            {
                LoadData(forumSubscriptionObj);

                // show that the forumSubscription was created or updated successfully
                if (Request.QueryString["saved"] == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }


            // initializes page title control		
            string[,] pageTitleTabs = new string[2, 3];
            pageTitleTabs[0, 0] = ResHelper.GetString("ForumSubscription_Edit.ItemListLink");
            pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Forums/Subscriptions/ForumSubscription_List.aspx?forumid=" + forumSubscriptionObj.SubscriptionForumID;
            pageTitleTabs[0, 2] = "";
            pageTitleTabs[1, 0] = currentForumSubscription;
            pageTitleTabs[1, 1] = "";
            pageTitleTabs[1, 2] = "";
            PageTitle.Breadcrumbs = pageTitleTabs;
            PageTitle.TitleText = ResHelper.GetString("ForumSubscription_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Subscriptions/subscription.gif";
        }
        else
        {
            forumId = ValidationHelper.GetInteger(Request.QueryString["forumid"], 0);
            if (forumId == 0)
            {
                btnOK.Enabled = false;
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("ForumSubscription_Edit.NoForumIdGiven");
                return;
            }

            rfvSubscriptionEmail.ErrorMessage = ResHelper.GetString("ForumSubscription_Edit.EnterSomeEmail");

            // control initializations				
            lblSubscriptionEmail.Text = ResHelper.GetString("ForumSubscription_Edit.SubscriptionEmailLabel");

            btnOK.Text = ResHelper.GetString("General.OK");

            currentForumSubscription = ResHelper.GetString("ForumSubscription_Edit.NewItemCaption");

            // initializes page title control		
            string[,] pageTitleTabs = new string[2, 3];
            pageTitleTabs[0, 0] = ResHelper.GetString("ForumSubscription_Edit.ItemListLink");
            pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Forums/Subscriptions/ForumSubscription_List.aspx?forumid=" + forumId.ToString();
            pageTitleTabs[0, 2] = "";
            pageTitleTabs[1, 0] = currentForumSubscription;
            pageTitleTabs[1, 1] = "";
            pageTitleTabs[1, 2] = "";
            PageTitle.Breadcrumbs = pageTitleTabs;
            PageTitle.TitleText = ResHelper.GetString("ForumSubscription_Edit.HeaderCaption");
            PageTitle.TitleImage = PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Forums/Subscriptions/newsubscription.gif";
        }
        }


	/// <summary>
	/// Load data of editing forumSubscription.
	/// </summary>
	/// <param name="forumSubscriptionObj">ForumSubscription object.</param>
	protected void LoadData(ForumSubscriptionInfo forumSubscriptionObj)
	{
		txtSubscriptionEmail.Text = Server.HtmlEncode(forumSubscriptionObj.SubscriptionEmail);
	}

	/// <summary>
	/// Sets data to database.
	/// </summary>
	protected void btnOK_Click(object sender, EventArgs e)
	{

        // check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.forums", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.forums", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtSubscriptionEmail.Text, ResHelper.GetString("ForumSubscription_Edit.EnterSomeEmail")).Result;

		if (errorMessage == "")
		{
            ForumSubscriptionInfo forumSubscriptionObj = ForumSubscriptionInfoProvider.GetForumSubscriptionInfo(subscriptionId);
			
			if (forumSubscriptionObj == null)
			{

                forumSubscriptionObj = new ForumSubscriptionInfo();
                forumSubscriptionObj.SubscriptionForumID = forumId;
                forumSubscriptionObj.SubscriptionGUID = Guid.NewGuid();

                if (forumSubscriptionObj == null)
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("ForumSubscription_Edit.SubscriptionDoesNotExist");
                    return;
                }
            }

 		    forumSubscriptionObj.SubscriptionEmail = txtSubscriptionEmail.Text.Trim();
            if (ValidationHelper.IsEmail(forumSubscriptionObj.SubscriptionEmail))
            {

                
                int redirect = forumSubscriptionObj.SubscriptionID;
               
                ForumSubscriptionInfoProvider.SetForumSubscriptionInfo(forumSubscriptionObj);

                if (redirect == 0)
                {
                    Response.Redirect("ForumSubscription_Edit.aspx?subscriptionid=" + Convert.ToString(forumSubscriptionObj.SubscriptionID) + "&saved=1");
                }

                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("ForumSubscription_Edit.EmailIsNotValid");
            }
		}
		else
		{
			lblError.Visible = true;
			lblError.Text = errorMessage;
		}
	}
}
