using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using System.Collections;

using CMS.GlobalHelper;
using CMS.Newsletter;
using CMS.CMSHelper;
using CMS.DataEngine;

public partial class CMSDesk_Tools_Newsletters_Subscribers_Export : CMSDeskPage
{
    protected int siteId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        btnExport.Click += new EventHandler(btnExport_Click);

        siteId = CMSContext.CurrentSite.SiteID;
        PageTitle.TitleText = ResHelper.GetString("Subscriber_Export.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Newsletters/ImportExportSubscribers/exportsubscriber.gif";

        // Initialize texts
        lblExportedSub.Text = ResHelper.GetString("Subscriber_Export.lblExportedSub");
        lblSelectSub.Text = ResHelper.GetString("Subscriber_Export.lblSelectSub");
        btnExport.Text = ResHelper.GetString("Subscriber_Export.btnExport");

        // get current site
        CurrentSiteInfo currentSite = CMSContext.CurrentSite;

        if ((!IsPostBack) && (currentSite != null))
        {
            gvNewsletters.Columns[2].Visible = true;
            DataSet ds = NewsletterProvider.GetAllNewsletersForSite(currentSite.SiteID);

            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                gvNewsletters.DataSource = ds;
                gvNewsletters.DataBind();

                // Initialize the headers
                gvNewsletters.HeaderRow.Cells[0].Text = ResHelper.GetString("Subscriber_Export.ExportHeader");
                gvNewsletters.HeaderRow.Cells[0].Width = Unit.Pixel(20);
                gvNewsletters.HeaderRow.Cells[1].Text = ResHelper.GetString("Subscriber_Export.NewsletterHeader");
            }
            gvNewsletters.Columns[2].Visible = false;
        }
    }


    /// <summary>
    /// Handle export button click
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Event arguments</param>
    void btnExport_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "managesubscribers"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "managesubscribers");
        }

        ArrayList newsletterIds = new ArrayList();

        // Get checked newsletters
        foreach (GridViewRow row in gvNewsletters.Rows)
        {
            // Get the checkbox
            CheckBox checkbox = (CheckBox)row.Cells[0].FindControl("chkNewsletter");
            int id = ValidationHelper.GetInteger(row.Cells[2].Text, 0);

            // If newsletter is checked, get the subscribers
            if ((id != 0) && (checkbox != null) && (checkbox.Checked))
            {
                newsletterIds.Add(id);
            }
        }

        // Export subscribers
        string subscribers = "";
        if (CMSContext.CurrentSite != null)
        {
            subscribers = SubscriberProvider.ExportSubscribersFromSite(newsletterIds, CMSContext.CurrentSite.SiteID, true);
        }

        // No subscribers exported
        if (subscribers == "")
        {
            lblInfo.Text = ResHelper.GetString("Subscriber_Export.noSubscribersExported");
            txtExportSub.Enabled = false;
        }
        else
        {
            lblInfo.Text = ResHelper.GetString("Subscriber_Export.subscribersExported");
            txtExportSub.Enabled = true;
        }

        txtExportSub.Text = subscribers;
    }
}