using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;

using CMS.GlobalHelper;
using CMS.Newsletter;
using CMS.CMSHelper;
using System.Collections;


public partial class CMSDesk_Tools_Newsletters_Subscribers_Import : CMSDeskPage
{
    protected int siteId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        btnImport.Click += new EventHandler(btnImport_Click);

        siteId = CMSContext.CurrentSite.SiteID;
        PageTitle.TitleText = ResHelper.GetString("Subscriber_Import.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Newsletters/ImportExportSubscribers/Importsubscriber.gif";

        // Initialize texts
        lblImportedSub.Text = ResHelper.GetString("Subscriber_Import.lblImportedSub");
        lblSelectSub.Text = ResHelper.GetString("Subscriber_Import.lblSelectSub");
        btnImport.Text = ResHelper.GetString("Subscriber_Import.btnImport");
        lblNote.Text = ResHelper.GetString("Subscriber_Import.lblNote");
        chkSendConfirmation.Text = ResHelper.GetString("Subscriber_Edit.SendConfirmation");

        // Get current site
        CurrentSiteInfo currentSite = CMSContext.CurrentSite;

        if ((!IsPostBack) && (currentSite != null))
        {
            gvNewsletters.Columns[2].Visible = true;
            DataSet ds = NewsletterProvider.GetAllNewsletersForSite(currentSite.SiteID);

            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                gvNewsletters.DataSource = ds;
                gvNewsletters.DataBind();

                // Initialize the headers
                gvNewsletters.HeaderRow.Cells[0].Text = ResHelper.GetString("Subscriber_Import.ImportHeader");
                gvNewsletters.HeaderRow.Cells[0].Width = Unit.Pixel(20);
                gvNewsletters.HeaderRow.Cells[1].Text = ResHelper.GetString("Subscriber_Import.NewsletterHeader");
            }
            gvNewsletters.Columns[2].Visible = false;
        }
    }


    /// <summary>
    /// Handle import button click
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Event arguments</param>
    void btnImport_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "managesubscribers"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "managesubscribers");
        }

        ArrayList newsletterIds = new ArrayList();

        // Get checked newsletters
        foreach (GridViewRow row in gvNewsletters.Rows)
        {
            // Get the checkbox
            CheckBox checkbox = (CheckBox)row.Cells[0].FindControl("chkNewsletter");
            int id = ValidationHelper.GetInteger(row.Cells[2].Text, 0);

            // If newsletter is checked, get the subscribers
            if ((id != 0) && (checkbox != null) && (checkbox.Checked))
            {
                newsletterIds.Add(id);
            }
        }

        // Import subscribers
        try
        {
            if (CMSContext.CurrentSite != null)
            {
                ArrayList errors = SubscriberProvider.ImportSubscribersToSite(txtImportSub.Text, newsletterIds, CMSContext.CurrentSite.SiteID, true, chkSendConfirmation.Checked);
                if (errors.Count == 0)
                {
                    lblInfo.Text = ResHelper.GetString("Subscriber_Import.SubscribersImported");
                    lblError.Text = "";
                }
                else
                {
                    lblInfo.Text = "";
                    lblError.Text = CreateErrorString(errors);
                }
            }
        }
        catch(Exception ex)
        {
            lblInfo.Text = "";
            lblError.Text = ex.Message;
        }
    }

    private string CreateErrorString(ArrayList errors)
    {
        string value = "";

        foreach (string error in errors)
        {
            value += error + "<br />";
        }

        return value;
    }
}