using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Newsletter;
using CMS.CMSHelper;


public partial class CMSDesk_Tools_Newsletters_Newsletters_Newsletter_Issue_New_Edit : CMSDeskPage
{
    protected int newsletterId = 0;
    protected int templateId = 0;
    protected Issue issue = null;


    private int IssueId
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["IssueID"], 0);
        }
        set
        {
            ViewState["IssueID"] = value;
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        btnSave.Attributes.Add("onclick", "ClearToolbar();frames[0].SaveContent(false);return false;");
        btnNext.Attributes.Add("onclick", "ClearToolbar();frames[0].SaveContent(true);return false;");

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "NextFunction", ScriptHelper.GetScript("" +
        "function NextClick(issueId){" +
        "document.getElementById('" + hdnNext.ClientID + "').value = issueId; " +
        this.Page.ClientScript.GetPostBackEventReference(btnNextHidden, null) +
        " }"));

        newsletterId = ValidationHelper.GetInteger(Request.QueryString["newsletterid"], 0);
        IssueId = ValidationHelper.GetInteger(Request.QueryString["issueid"], IssueId);
        if ((newsletterId == 0) && (IssueId == 0))
        {
            return;
        }

        if (IssueId > 0) //user comes back from Newsletter_Issue_New_Preview.aspx page
        {
            contentBody.IssueID = IssueId;
            contentHeader.IssueID = IssueId;

            issue = IssueProvider.GetIssue(IssueId);
            if (newsletterId == 0)
            {
                newsletterId = issue.IssueNewsletterID;
            }

            contentBody.NewsletterID = newsletterId;
        }
        else //user is creating new issue
        {
            contentBody.NewsletterID = newsletterId;
            Newsletter newsletter = NewsletterProvider.GetNewsletter(newsletterId);
            if (newsletter != null)
            {
                templateId = newsletter.NewsletterTemplateID;
            }
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("newsletter_issue_list.headercaption");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Newsletters/Newsletters/Newsletter_Issue_List.aspx?newsletterid=" + newsletterId.ToString();
        pageTitleTabs[0, 2] = "newsletterContent";
        pageTitleTabs[1, 0] = ResHelper.GetString("newsletter_issue_list.newitemcaption");
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("newsletter_issue_list.title");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Newsletters/Newsletters/newissue.gif";

        lblStep1.Text = ResHelper.GetString("newsletter_issue_list.step1");
        btnNext.Text = ResHelper.GetString("newsletter_issue_list.next");
        btnSave.Text = ResHelper.GetString("newsletter_issue_list.save");
    }


    protected void btnSave_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "authorissues"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "authorissues");
        }

        if (issue == null)
        {
            issue = new Issue();
            issue.IssueNewsletterID = newsletterId;
            issue.IssueUnsubscribed = 0;
            issue.IssueTemplateID = templateId;
            issue.IssueSentEmails = 0;
        }

        string res = contentHeader.SaveContent(issue);
        if (res == "")
        {
            //res = contentBody.SaveContent(issue);
            if (res == "")
            {
                IssueProvider.SetIssue(issue);
                IssueId = issue.IssueID;
                this.lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
        }

        if (res != "")
        {
            this.lblError.Text = res;
        }
    }


    protected override void OnPreRender(EventArgs e)
    {
        this.lblInfo.Visible = (this.lblInfo.Text != "");
        this.lblError.Visible = (this.lblError.Text != "");
        this.pnlInfo.Visible = (this.lblInfo.Text != "") || (this.lblError.Text != "");
        base.OnPreRender(e);
    }


    protected void btnNext_Click(object sender, EventArgs e)
    {
        //btnSave_Click(null, null);

        Response.Redirect("Newsletter_Issue_New_Preview.aspx?issueid=" + hdnNext.Value + "&newsletterid=" + newsletterId.ToString());
    }
}
