using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Xml;

using CMS.GlobalHelper;
using CMS.Newsletter;
using CMS.CMSHelper;
using System.Text.RegularExpressions;
using CMS.SiteProvider;

public partial class CMSDesk_Tools_Newsletters_Newsletters_Newsletter_Issue_ShowPreview : CMSDeskPage
{
    protected int port = 0;
    protected Guid subscriberGuid = Guid.Empty;
    protected int newsletterIssueId = 0;
    private Hashtable regionsContents = new Hashtable();
    private Hashtable dynamicFields = new Hashtable();
    private Issue issue = null;
    
    /// <summary>
    /// Regular expression to search the dynamic field macro
    /// </summary>
    private static Regex mDynamicFieldRegEx = new Regex("\\{%([-\\w]+)%}");

    /// <summary>
    /// Regular expression to search the editable region macro
    /// </summary>
    private static Regex mEditableRegionRegEx = new Regex("\\$\\$(\\w+):(\\w*):(\\w*)\\$\\$");

    
    protected void Page_Load(object sender, EventArgs e)
    {
        port = Request.Url.Port;
        subscriberGuid = ValidationHelper.GetGuid(Request.QueryString["subscriberguid"], Guid.Empty);
        newsletterIssueId = ValidationHelper.GetInteger(Request.QueryString["issueid"], 0);

        issue = IssueProvider.GetIssue(newsletterIssueId);
        if (issue == null)
        {
            return;
        }

        Subscriber subscriber = SubscriberProvider.GetSubscriber(subscriberGuid);

        // Get the newsletter
        Newsletter news = NewsletterProvider.GetNewsletter(issue.IssueNewsletterID);
        if (news == null)
        {
            throw new Exception("[IssueProvider.SendIssue]: Newsletter not found.");
        }

        // Get the site
        SiteInfo si = SiteInfoProvider.GetSiteInfo(news.NewsletterSiteID);
        if (si == null)
        {
            throw new Exception("[IssueProvider.SendIssue]: Newsletter site not found.");
        }
        string culture = CultureHelper.GetDefaultCulture(si.SiteName);


        string htmlPage = "";
        if (subscriber != null)
        {
            htmlPage = IssueHelper.ResolveMacros(IssueProvider.GetEmailBody(issue, subscriber.SubscriberID, true), culture);
//            htmlPage = ResHelper.LocalizeString(IssueProvider.GetEmailBody(issue, subscriber.SubscriberID, true));
        }
        else
        {
            htmlPage = IssueHelper.ResolveMacros(IssueProvider.GetEmailBody(issue, true), culture);
//            htmlPage = ResHelper.LocalizeString(IssueProvider.GetEmailBody(issue, true));
        }

        Response.Clear();

        Response.Write(htmlPage);

        Response.End();
    }

/* TODO - remove ASAP
    /// <summary>
    /// Loads values of editable regions into hashtable
    /// </summary>
    /// <returns>Returns true if the loading succeeds</returns>
    protected bool LoadRegionsContents()
    {
        regionsContents.Clear();
        string contentXml = issue.IssueText;
        if (contentXml != "")
        {
            XmlDocument xml = new XmlDocument();
            xml.LoadXml(contentXml);
            XmlNode docElem = xml.DocumentElement;

            // Load editable regions
            XmlNodeList regions = docElem.SelectNodes("region");
            if (regions != null)
            {
                foreach (XmlNode region in regions)
                {
                    string id = region.Attributes["id"].Value;
                    string value = region.InnerText;
                    regionsContents[id.ToLower()] = value;
                }
                return true;
            }
            return false;
        }
        return false;
    }

    /// <summary>
    /// Loads values of dynamic fields into hashtable
    /// </summary>
    /// <returns>Returns true if the loading succeeds</returns>
    protected bool LoadDynamicFields()
    {
        Subscriber subscriber = SubscriberProvider.GetSubscriber(subscriberGuid);
        if (subscriber != null)
        {
            dynamicFields[IssueHelper.MacroEmail.ToLower()] = subscriber.SubscriberEmail;
            dynamicFields[IssueHelper.MacroE_mail.ToLower()] = subscriber.SubscriberEmail;
            dynamicFields[IssueHelper.MacroFirstName.ToLower()] = subscriber.SubscriberFirstName;
            dynamicFields[IssueHelper.MacroLastName.ToLower()] = subscriber.SubscriberLastName;
            Newsletter news = NewsletterProvider.GetNewsletter(issue.IssueNewsletterID);
            if (news != null)
            {
                string fullAplicationUrl = "http://" + UrlHelper.GetFullDomain().TrimEnd('/') + HttpContext.Current.Request.ApplicationPath.TrimEnd('/');
                dynamicFields[IssueHelper.MacroUnsubscribeLink.ToLower()] = "<a href=\"" + fullAplicationUrl + "/CMSPages/unsubscribe.aspx?subscriberguid=" + subscriber.SubscriberGUID + "&newsletterguid=" + news.NewsletterGUID + "&issueid=" + issue.IssueID + "\">" + ResHelper.GetString("Newsletter.UnsubscribeLink") + "</a>";
            }
            return true;
        }
        else
        {
            // using default values if no subscriber found
            dynamicFields[IssueHelper.MacroEmail.ToLower()] = "firstname.lastname@yourdomain.com";
            dynamicFields[IssueHelper.MacroE_mail.ToLower()] = "firstname.lastname@yourdomain.com";
            dynamicFields[IssueHelper.MacroFirstName.ToLower()] = "FirstName";
            dynamicFields[IssueHelper.MacroLastName.ToLower()] = "LastName";
            dynamicFields[IssueHelper.MacroUnsubscribeLink.ToLower()] = "<a href=\"#\" >" + ResHelper.GetString("Newsletter.UnsubscribeLink") + "</a>";
            return true;
        }
    }

    /// <summary>
    /// Resolves the dynamic field macros, replaces the {%dynamicfieldname%} macro with the dynamic field value
    /// </summary>
    /// <param name="text">Text to resolve</param>
    public string ResolveDynamicFieldMacros(string text)
    {
        if ((text == null) || (text == ""))
        {
            return text;
        }
        return mDynamicFieldRegEx.Replace(text, ReplaceDynamicField);
    }


    /// <summary>
    /// Property match evaluator to replace the found dynamic field match with the dynamic field value
    /// </summary>
    /// <param name="m">Match found</param>
    public string ReplaceDynamicField (Match m)
    {
        return ValidationHelper.GetString(dynamicFields[m.Groups[1].ToString().ToLower()], m.ToString());
    }


    /// <summary>
    /// Resolves the editable region macros, replaces the $$editableregionname:width:height$$ macro with the editable region value
    /// </summary>
    /// <param name="text">Text to resolve</param>
    public string ResolveEditableRegionMacros(string text)
    {
        if ((text == null) || (text == ""))
        {
            return text;
        }
        return mEditableRegionRegEx.Replace(text, ReplaceEditableRegion);
    }

    /// <summary>
    /// Property match evaluator to replace the found editable region match with the editable region value
    /// </summary>
    /// <param name="m">Match found</param>
    public string ReplaceEditableRegion(Match m)
    {
        return ValidationHelper.GetString(regionsContents[m.Groups[1].ToString().ToLower()], m.ToString());
    }
 */
}
