using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Newsletter;
using CMS.CMSHelper;
using System.Text.RegularExpressions;

public partial class CMSDesk_Tools_Newsletters_Subscribers_Subscriber_New : CMSDeskPage
{
    protected int subscriberid = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        rfvSubscriberEmail.ErrorMessage = ResHelper.GetString("Subscriber_Edit.ErrorEmptyEmail");

        // control initializations				
        lblSubscriberLastName.Text = ResHelper.GetString("Subscriber_Edit.SubscriberLastNameLabel");
        lblSubscriberEmail.Text = ResHelper.GetString("Subscriber_Edit.SubscriberEmailLabel");
        lblSubscriberFirstName.Text = ResHelper.GetString("Subscriber_Edit.SubscriberFirstNameLabel");

        btnOK.Text = ResHelper.GetString("General.OK");

        string currentSubscriber = ResHelper.GetString("Subscriber_Edit.NewItemCaption");

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Subscriber_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Newsletters/Subscribers/Subscriber_List.aspx";
        pageTitleTabs[0, 2] = "newslettersContent";
        pageTitleTabs[1, 0] = currentSubscriber;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("Subscriber_Edit.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Newsletters/Subscribers/newsubscriber.gif";
    }


    /// <summary>
    /// Load data of editing subscriber.
    /// </summary>
    /// <param name="subscriberObj">Subscriber object.</param>
    protected void LoadData(Subscriber subscriberObj)
    {
        txtSubscriberLastName.Text = subscriberObj.SubscriberLastName;
        txtSubscriberEmail.Text = subscriberObj.SubscriberEmail;
        txtSubscriberFirstName.Text = subscriberObj.SubscriberFirstName;
    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "managesubscribers"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "managesubscribers");
        }
        string errorMessage = new Validator().NotEmpty(txtSubscriberEmail.Text, ResHelper.GetString("Subscriber_Edit.ErrorEmptyEmail")).Result;

        if (errorMessage == "")
        {
            if (Regex.IsMatch(txtSubscriberEmail.Text, @"^[a-zA-Z0-9]([_\.\-]?[a-zA-Z0-9]+)*@[a-zA-Z0-9]([\.\-]?[a-zA-Z0-9]+)*\.[a-zA-Z]{2,6}$"))
            {
                if (!SubscriberProvider.EmailExists(txtSubscriberEmail.Text.Trim()))
                {
                    Subscriber subscriberObj = new Subscriber();

                    subscriberObj.SubscriberID = 0;
                    subscriberObj.SubscriberLastName = txtSubscriberLastName.Text.Trim();
                    subscriberObj.SubscriberEmail = txtSubscriberEmail.Text.Trim();
                    subscriberObj.SubscriberFirstName = txtSubscriberFirstName.Text.Trim();
                    subscriberObj.SubscriberSiteID = CMSContext.CurrentSite.SiteID;
                    subscriberObj.SubscriberGUID = Guid.NewGuid();

                    SubscriberProvider.SetSubscriber(subscriberObj);

                    Response.Redirect("Subscriber_Frameset.aspx?subscriberid=" + Convert.ToString(subscriberObj.SubscriberID) + "&saved=1");
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Subscriber_Edit.EmailAlreadyExists");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("NewsletterSubscription.ErrorInvalidEmail");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}