using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Newsletter;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Newsletters_Subscribers_Subscriber_Subscriptions : CMSDeskPage
{
    protected int subscriberId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        subscriberId = ValidationHelper.GetInteger(Request.QueryString["subscriberid"], 0);
        Subscriber sb = SubscriberProvider.GetSubscriber(subscriberId);
        if (sb != null)
        {
            btnOK.Text = ResHelper.GetString("General.OK");
            lblSendConfirmation.Text = ResHelper.GetString("Subscriber_Edit.SendConfirmation");
            
            DataSet ds = NewsletterProvider.GetAllNewsletersForSite(sb.SubscriberSiteID);
            if (DataHelper.DataSourceIsEmpty(ds))
            {
                btnOK.Enabled = false;
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("Subscriber_Edit.NoNewsletters");
            }
            else
            {
                grvSubscriptions.Columns[0].HeaderText = ResHelper.GetString("Subscriber_Edit.Select");
                grvSubscriptions.Columns[1].HeaderText = ResHelper.GetString("Subscriber_Edit.Newsletter");
                grvSubscriptions.Columns[2].Visible = true;
                grvSubscriptions.DataSource = ds.Tables[0];
                grvSubscriptions.DataBind();
                //after id is copied, the 3rd column it's not needed anymore
                grvSubscriptions.Columns[2].Visible = false;
                grvSubscriptions.GridLines = GridLines.Horizontal;
            }

            if (!IsPostBack)
            {
                chkSendConfirmation.Checked = false;
            }
        }
        else
        {
            btnOK.Enabled = false;
        }
    }

    protected void grvSubscriptions_DataBound(object sender, EventArgs e)
    {
        for (int i = 0; i < grvSubscriptions.Rows.Count; i++)
        {
            CheckBox isSubscribed = new CheckBox();
            isSubscribed.Checked = SubscriberProvider.IsSubscribed(subscriberId, Convert.ToInt32(grvSubscriptions.Rows[i].Cells[2].Text));
            grvSubscriptions.Rows[i].Cells[0].Controls.Add(isSubscribed);
            Label id = new Label();

            //copy id from 3rd column to invisible label in first column
            id.Text = grvSubscriptions.Rows[i].Cells[2].Text;
            id.Attributes.Add("style", "display: none;");
            grvSubscriptions.Rows[i].Cells[0].Controls.Add(id);
        }
    }

    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "managesubscribers"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "managesubscribers");
        }        
        for (int i = 0; i < grvSubscriptions.Rows.Count; i++)
        {
            CheckBox isSubscribed = (CheckBox)grvSubscriptions.Rows[i].Cells[0].Controls[0];
            Label id = (Label)grvSubscriptions.Rows[i].Cells[0].Controls[1];

            int newsletterId = Convert.ToInt32(id.Text);

            if (isSubscribed.Checked)
            {
                // if subscriber is unsubscribed, subscribe him
                if (!SubscriberProvider.IsSubscribed(subscriberId, newsletterId))
                {
                    try
                    {
                        SubscriberProvider.Subscribe(subscriberId, newsletterId, DateTime.Now, chkSendConfirmation.Checked);
                    }
                    catch { };
                }
            }
            else
            {
                // if subscriber is subscribed, unsubscribe him
                if (SubscriberProvider.IsSubscribed(subscriberId, newsletterId))
                {
                    Subscriber sb = SubscriberProvider.GetSubscriber(subscriberId);
                    if (sb != null)
                    {
                        try
                        {
                            SubscriberProvider.Unsubscribe(sb.SubscriberGUID, newsletterId, chkSendConfirmation.Checked);
                        }
                        catch { };
                    }
                }
            }
        }
        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
    }
}
