using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Newsletter;
using CMS.SettingsProvider;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Newsletters_Templates_NewsletterTemplate_Edit : CMSDeskPage
{
    protected int templateid = 0;
    private string mCMSDeskPath = null;
    protected int siteId = 0;
    EmailTemplate emailTemplateObj = null;


    /// <summary>
    /// Gets the CMS Desk virtual path
    /// </summary>
    private string CmsDeskPath
    {
        get
        {
            if (mCMSDeskPath == null)
            {
                mCMSDeskPath = SettingsKeyProvider.GetStringValue("CMSDeskVirtualPath");
                if ((mCMSDeskPath == null) || (mCMSDeskPath.Trim() == ""))
                {
                    mCMSDeskPath = "~/cmsdesk";
                }
                if (mCMSDeskPath.EndsWith("/"))
                {
                    mCMSDeskPath.TrimEnd('/');
                }
            }
            return this.ResolveUrl(mCMSDeskPath);
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        siteId = ValidationHelper.GetInteger(Request.QueryString["siteid"], 0);

        rfvTemplateDisplayName.ErrorMessage = ResHelper.GetString("NewsletterTemplate_Edit.ErrorEmptyDisplayName");
        rfvTemplateName.ErrorMessage = ResHelper.GetString("NewsletterTemplate_Edit.ErrorEmptyName");

        // control initializations				
        //lblTemplateType.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateTypeLabel");
        lblTemplateBody.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateBodyLabel");
        lblTemplateName.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateNameLabel");
        lblTemplateHeader.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateHeaderLabel");
        lblTemplateFooter.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateFooterLabel");
        lblTemplateDisplayName.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateDisplayNameLabel");
        lblTemplateStyleSheetText.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateStylesheetTextLabel");

        lblInsertField.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateInsertFieldLabel");
        lblInsertEditableRegion.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateInsertEditRegLabel");
        lblName.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateEditRegNameLabel");
        lblWidth.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateEditRegWidthLabel");
        lblHeight.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateEditRegHeightLabel");

        string setResourceStringsScript = "";
        setResourceStringsScript += "var emptyNameMsg = '" + ResHelper.GetString("NewsletterTemplate_Edit.EmptyNameMsg") + "'; \n";
        setResourceStringsScript += "var emptyWidthMsg = '" + ResHelper.GetString("NewsletterTemplate_Edit.EmptyWidthMsg") + "'; \n";
        setResourceStringsScript += "var emptyHeightMsg = '" + ResHelper.GetString("NewsletterTemplate_Edit.EmptyHeightMsg") + "'; \n";
        LtlScript.Text = ScriptHelper.GetScript(setResourceStringsScript);

        btnOK.Text = ResHelper.GetString("General.OK");
        btnInsertEditableRegion.Text = ResHelper.GetString("NewsletterTemplate_Edit.Insert");
        btnInsertField.Text = ResHelper.GetString("NewsletterTemplate_Edit.Insert");

        string currentEmailTemplate = ResHelper.GetString("NewsletterTemplate_Edit.NewItemCaption");

        // get emailTemplate id from querystring
        if ((Request.QueryString["templateid"] != null) && (Request.QueryString["templateid"] != ""))
        {
            templateid = Convert.ToInt32(Request.QueryString["templateid"]);
            emailTemplateObj = EmailTemplateProvider.GetEmailTemplate(templateid);
            currentEmailTemplate = emailTemplateObj.TemplateDisplayName;

            //Display editable region section only for e-mail templates of type "Issue template"
            if (emailTemplateObj.TemplateType == "I")
            {
                pnlEditableRegion.Visible = true;
                btnInsertEditableRegion.Visible = true;
                lblInsertEditableRegion.Visible = true;
            }

            // fill editing form
            if (!IsPostBack)
            {
                LoadData(emailTemplateObj);

                // show that the emailTemplate was created or updated successfully
                if (Request.QueryString["saved"] == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("NewsletterTemplate_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Newsletters/Templates/NewsletterTemplate_List.aspx?siteid=" + siteId.ToString();
        pageTitleTabs[0, 2] = "newslettersContent";
        pageTitleTabs[1, 0] = currentEmailTemplate;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("NewsletterTemplate_Edit.Properties");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Newsletters/Templates/template.gif";

        if (!IsPostBack)
        {
            FillFieldsList();
            // initialize FCK editor
            InitFCKeditor();
        }
    }


    /// <summary>
    /// Load data of editing emailTemplate.
    /// </summary>
    /// <param name="emailTemplateObj">EmailTemplate object.</param>
    protected void LoadData(EmailTemplate emailTemplateObj)
    {

        //txtTemplateType.Text = emailTemplateObj.TemplateType;
        fckTemplateBody.ResolvedValue = emailTemplateObj.TemplateBody;
        txtTemplateName.Text = emailTemplateObj.TemplateName;
        txtTemplateHeader.Value = emailTemplateObj.TemplateHeader;
        txtTemplateFooter.Value = emailTemplateObj.TemplateFooter;
        txtTemplateDisplayName.Text = emailTemplateObj.TemplateDisplayName;
        txtTemplateStyleSheetText.Text = emailTemplateObj.TemplateStylesheetText;
        //txtTemplateSiteID.Text = Convert.ToString(emailTemplateObj.TemplateSiteID);

    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.newsletter", "managetemplates"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.newsletter", "managetemplates");
        }


        string errorMessage = "";
        if (!ValidationHelper.IsCodeName(txtTemplateName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }
        else
        {
            errorMessage = new Validator().NotEmpty(txtTemplateDisplayName.Text, ResHelper.GetString("NewsletterTemplate_Edit.ErrorEmptyDisplayName")).NotEmpty(txtTemplateName.Text, ResHelper.GetString("NewsletterTemplate_Edit.ErrorEmptyName")).Result;
        }

        if (errorMessage == "")
        {

            // templateName must to be unique
            EmailTemplate emailTemplateObj = EmailTemplateProvider.GetEmailTemplate(txtTemplateName.Text.Trim(), CMSContext.CurrentSite.SiteID);

            // if templateName value is unique														
            if ((emailTemplateObj == null) || (emailTemplateObj.TemplateID == templateid))
            {
                // if templateName value is unique -> determine whether it is update or insert 
                if ((emailTemplateObj == null))
                {
                    // get EmailTemplate object by primary key
                    emailTemplateObj = EmailTemplateProvider.GetEmailTemplate(templateid);
                    if (emailTemplateObj == null)
                    {
                        // create new item -> insert
                        emailTemplateObj = new EmailTemplate();

                    }
                }

                // Check if template doesn't contains more editable regions with same name
                Hashtable eRegions = new Hashtable();
                bool isValid = true;
                bool isValidRegionName = true;

                int count = 0;
                int textStart = 0;
                int editRegStart = fckTemplateBody.ResolvedValue.Trim().IndexOf("$$", textStart);

                while (editRegStart >= 0)
                {
                    count++;

                    // End of region
                    editRegStart += 2;
                    textStart = editRegStart;
                    if (editRegStart < fckTemplateBody.ResolvedValue.Trim().Length - 1)
                    {
                        int editRegEnd = fckTemplateBody.ResolvedValue.Trim().IndexOf("$$", editRegStart);
                        if (editRegEnd >= 0)
                        {
                            string region = fckTemplateBody.ResolvedValue.Trim().Substring(editRegStart, editRegEnd - editRegStart);
                            string[] parts = (region + ":" + ":").Split(':');

                            textStart = editRegEnd + 2;
                            try
                            {
                                string name = parts[0];
                                if (name.Trim() != "")
                                {
                                    if (eRegions[name.ToLower()] != null)
                                    {
                                        isValid = false;
                                        break;
                                    }

                                    if (!ValidationHelper.IsCodeName(name))
                                    {
                                        isValidRegionName = false;
                                        break;
                                    }
                                    eRegions[name.ToLower()] = 1;
                                }
                            }
                            catch
                            {
                            }
                        }
                    }

                    editRegStart = fckTemplateBody.ResolvedValue.Trim().IndexOf("$$", textStart);
                }

                if (isValid)
                {
                    if (isValidRegionName)
                    {

                        emailTemplateObj.TemplateBody = fckTemplateBody.ResolvedValue.Trim();
                        emailTemplateObj.TemplateName = txtTemplateName.Text.Trim();
                        emailTemplateObj.TemplateHeader = ValidationHelper.GetString(txtTemplateHeader.Value, "").Trim();
                        emailTemplateObj.TemplateFooter = ValidationHelper.GetString(txtTemplateFooter.Value, "").Trim();
                        emailTemplateObj.TemplateDisplayName = txtTemplateDisplayName.Text.Trim();
                        emailTemplateObj.TemplateStylesheetText = txtTemplateStyleSheetText.Text.Trim();

                        EmailTemplateProvider.SetEmailTemplate(emailTemplateObj);

                        Response.Redirect("NewsletterTemplate_Edit.aspx?templateid=" + Convert.ToString(emailTemplateObj.TemplateID) + "&saved=1");
                    }
                    else
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("NewsletterTemplate_Edit.EditableRegionNameError");
                    }
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("NewsletterTemplate_Edit.EditableRegionError");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("NewsletterTemplate_Edit.TemplateNameExists");
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }


    /// <summary>
    /// Fills list of available fields
    /// </summary>
    protected void FillFieldsList()
    {
        ListItem newItem = new ListItem(ResHelper.GetString("NewsletterTemplate.MacroEmail"), IssueHelper.MacroEmail);
        lstInsertField.Items.Add(newItem);
        newItem = new ListItem(ResHelper.GetString("NewsletterTemplate.MacroFirstName"), IssueHelper.MacroFirstName);
        lstInsertField.Items.Add(newItem);
        newItem = new ListItem(ResHelper.GetString("NewsletterTemplate.MacroLastName"), IssueHelper.MacroLastName);
        lstInsertField.Items.Add(newItem);
        newItem = new ListItem(ResHelper.GetString("NewsletterTemplate.MacroUnsubscribeLink"), IssueHelper.MacroUnsubscribeLink);
        lstInsertField.Items.Add(newItem);
    }


    /// <summary>
    /// Initializes FCK editor's settings
    /// </summary>
    protected void InitFCKeditor()
    {
        fckTemplateBody.BasePath = "~/CMSAdminControls/FCKeditor/";
        fckTemplateBody.AutoDetectLanguage = false;
        fckTemplateBody.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
        if ( emailTemplateObj != null )
        {
            fckTemplateBody.EditorAreaCSS = EmailTemplateProvider.GetStylesheetUrl(emailTemplateObj.TemplateName) +"&timestamp=" + DateTime.Now.Millisecond;
        }
    }
}