using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Polls;

public partial class CMSDesk_Tools_Polls_Polls_Answer_Edit : CMSDeskPage
{
    protected int answerId = 0;
    protected int pollId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Read");
        }

        pollId = ValidationHelper.GetInteger(Request.QueryString["pollid"], 0);

        // Required field validator error messages initialization
        rfvAnswerText.ErrorMessage = ResHelper.GetString("Polls_Answer_Edit.AnswerTextError");

        // Controls initializations				
        lblAnswerText.Text = ResHelper.GetString("Polls_Answer_Edit.AnswerTextLabel");
        lblAnswerEnabled.Text = ResHelper.GetString("Polls_Answer_Edit.AnswerEnabledLabel");
        lblVotes.Text = ResHelper.GetString("Polls_Answer_Edit.Votes");

        btnOK.Text = ResHelper.GetString("General.OK");

        string currentPollAnswer = ResHelper.GetString("Polls_Answer_Edit.NewItemCaption");

        // Get AnswerID and PollID from querystring
        answerId = ValidationHelper.GetInteger(Request.QueryString["answerId"], 0);
        if (answerId > 0)
        {
            PollAnswerInfo pollAnswerObj = PollAnswerInfoProvider.GetPollAnswerInfo(answerId);
            if (pollAnswerObj != null)
            {
                currentPollAnswer = ResHelper.GetString("Polls_Answer_Edit.AnswerLabel") + " " + pollAnswerObj.AnswerOrder.ToString();

                // Fill editing form
                if (!IsPostBack)
                {
                    LoadData(pollAnswerObj);

                    // Show that the pollAnswer was created or updated successfully
                    if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
                pollId = pollAnswerObj.AnswerPollID;
            }
        }

        // Initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Polls_Answer_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Polls/Polls_Answer_List.aspx?pollId=" + pollId;
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = currentPollAnswer;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        if (answerId == 0)
        {
            PageTitle.TitleText = ResHelper.GetString("Polls_Answer_Edit.NewItemCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/newanswer.gif";
            plcVotes.Visible = false;
            txtVotes.Text = "0";
        }
        else
        {
            PageTitle.TitleText = ResHelper.GetString("Polls_Answer_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/answer.gif";
        }

        // New item link
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/addanswer.gif";
        lnkNewItem.Text = ResHelper.GetString("Polls_Answer_List.NewItemCaption");
        lnkNewItem.NavigateUrl = "Polls_Answer_Edit.aspx?pollId=" + pollId;
    }


    /// <summary>
    /// Load data of editing pollAnswer.
    /// </summary>
    /// <param name="pollAnswerObj">PollAnswer object.</param>
    protected void LoadData(PollAnswerInfo pollAnswerObj)
    {
        // Load the fields
        txtAnswerText.Text = pollAnswerObj.AnswerText;
        chkAnswerEnabled.Checked = pollAnswerObj.AnswerEnabled;
        txtVotes.Text = pollAnswerObj.AnswerCount.ToString();
    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        // Validate the input
        string errorMessage = new Validator().NotEmpty(txtAnswerText.Text, rfvAnswerText.ErrorMessage)
            .IsPositiveNumber(txtVotes.Text, ResHelper.GetString("Polls_Answer_Edit.VotesNotNumber"), true)
            .IsInteger(txtVotes.Text, ResHelper.GetString("Polls_Answer_Edit.VotesNotNumber")).Result;

        if (errorMessage == "")
        {
            PollAnswerInfo pollAnswerObj = PollAnswerInfoProvider.GetPollAnswerInfo(answerId);

            // If pollAnswer doesnt already exist, create new one
            if (pollAnswerObj == null)
            {
                pollAnswerObj = new PollAnswerInfo();
                pollAnswerObj.AnswerOrder = PollAnswerInfoProvider.GetLastAnswerOrder(pollId) + 1;
                pollAnswerObj.AnswerCount = 0;
                pollAnswerObj.AnswerPollID = pollId;
            }

            // Set the fields
            pollAnswerObj.AnswerEnabled = chkAnswerEnabled.Checked;
            pollAnswerObj.AnswerText = txtAnswerText.Text.Trim();
            pollAnswerObj.AnswerCount = ValidationHelper.GetInteger(this.txtVotes.Text, 0);

            // Save the data
            PollAnswerInfoProvider.SetPollAnswerInfo(pollAnswerObj);

            Response.Redirect("Polls_Answer_Edit.aspx?answerId=" + Convert.ToString(pollAnswerObj.AnswerID) + "&saved=1");
        }
        else
        {
            // Error message - Validation
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
