using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Polls;

public partial class CMSDesk_Tools_Polls_Polls_Answer_List : CMSDeskPage
{
    protected int pollId = 0;

	protected void Page_Load(object sender, EventArgs e)
	{
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Read");
        }

        // Get poll id from querystring		
        pollId = ValidationHelper.GetInteger(Request.QueryString["pollId"], 0);

        // Set the page title
		PageTitle.TitleText = ResHelper.GetString("Polls_Answer_List.HeaderCaption");
		PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/answers.gif";
		
        // New item link
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/addanswer.gif";
        lnkNewItem.Text = ResHelper.GetString("Polls_Answer_List.NewItemCaption");
        lnkNewItem.NavigateUrl = "Polls_Answer_Edit.aspx?pollId=" + pollId;
        
        // Reset answer button
        btnReset.Text = ResHelper.GetString("Polls_Answer_List.ResetButton");
        btnReset.OnClientClick = "return confirm('" + ResHelper.GetString("Polls_Answer_List.ResetConfirmation") + "');";
        imgReset.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/resetanswers.gif";
        
        // Setup the grid
		UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
		UniGrid.GridView.GridLines = GridLines.Horizontal;
        UniGrid.GridView.AllowSorting = false;
        UniGrid.WhereCondition = "AnswerPollID=" + pollId;
	}


	/// <summary>
	/// Handles the UniGrid's OnAction event.
	/// </summary>
	/// <param name="actionName">Name of item (button) that throws event.</param>
	/// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
	protected void uniGrid_OnAction(string actionName, object actionArgument)
	{
		if (actionName == "delete")
		{
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
            }

			// Delete PollAnswerInfo object from database
			PollAnswerInfoProvider.DeletePollAnswerInfo(Convert.ToInt32(actionArgument));
		}
        else if (actionName == "moveup")
        {
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
            }

            // Move the answer up in order
            PollAnswerInfoProvider.MoveAnswerUp(pollId, Convert.ToInt32(actionArgument));
            UniGrid.ReloadData();
        }
        else if (actionName == "movedown")
        {
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
            }

            // Move the answer down in order
            PollAnswerInfoProvider.MoveAnswerDown(pollId, Convert.ToInt32(actionArgument));
            UniGrid.ReloadData();
        }
        else if (actionName == "vote")
        {
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
            }

            // Increment answercount of the specified answer
            PollAnswerInfoProvider.Vote(Convert.ToInt32(actionArgument));
        }
	}


    /// <summary>
    /// Reset all answers counts.
    /// </summary>
    /// <param name="sender">Sender.</param>
    /// <param name="e">EventArgs.</param>
    protected void btnReset_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        if (pollId > 0)
        {
            PollAnswerInfoProvider.ResetAnswers(pollId);
            UniGrid.ReloadData();
        }
    }
}
