using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Polls;
using CMS.LicenseProvider;

public partial class CMSDesk_Tools_Polls_Polls_List : CMSDeskPage
{
	protected void Page_Load(object sender, EventArgs e)
	{
        // Check license
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Polls);
        }

        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Read");
        }

        // Set the page title
        PageTitle.TitleText = ResHelper.GetString("Polls_List.HeaderCaption");
		PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/polls.gif";

        // New item link
		imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/addpoll.gif";
        lnkNewItem.Text = ResHelper.GetString("Polls_List.NewItemCaption");
        lnkNewItem.NavigateUrl = "Polls_New.aspx";

        // Setup the grid
		UniGrid.OnAction += new OnActionEventHandler(UniGrid_OnAction);
		UniGrid.GridView.GridLines = GridLines.Horizontal;
        UniGrid.HideControlForZeroRows = true;
	}


	/// <summary>
	/// Handles the UniGrid's OnAction event.
	/// </summary>
	/// <param name="actionName">Name of item (button) that throws event.</param>
	/// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
	protected void UniGrid_OnAction(string actionName, object actionArgument)
	{
        if (actionName == "delete")
		{
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
            }

			// Delete PollInfo object from database with it's dependences
			PollInfoProvider.DeletePollInfo(Convert.ToInt32(actionArgument));
		}
	}
}
