using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.Polls;

public partial class CMSDesk_Tools_Polls_Polls_New : CMSDeskPage
{
    int pollId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        // Init the labels
        rfvCodeName.ErrorMessage = ResHelper.GetString("Polls_New.CodeNameError");
        rfvDisplayName.ErrorMessage = ResHelper.GetString("Polls_New.DisplayNameError");
        rfvQuestion.ErrorMessage = ResHelper.GetString("Polls_New.QuestionError");

        lblCodeName.Text = ResHelper.GetString("Polls_New.CodeNameLabel");
        lblDisplayName.Text = ResHelper.GetString("Polls_New.DisplayNameLabel");
        lblTitle.Text = ResHelper.GetString("Polls_New.TitleLabel");
        lblQuestion.Text = ResHelper.GetString("Polls_New.QuestionLabel");

        btnOK.Text = ResHelper.GetString("General.OK");

        // Init breadcrumbs
        string[,] breadcrumbs = new string[2, 3];
        PageTitle.Breadcrumbs = breadcrumbs;

        // Get the poll
        pollId = ValidationHelper.GetInteger(Request.QueryString["pollid"], 0);
        PollInfo pi = PollInfoProvider.GetPollInfo(pollId);
        if (pi != null)
        {
            if (!IsPostBack)
            {
                LoadData(pi);
            }

            // Edit item breadcrumbs
            breadcrumbs[0, 0] = ResHelper.GetString("Polls_Edit.itemlistlink");
            breadcrumbs[0, 1] = "~/CMSDesk/Tools/Polls/Polls_List.aspx";
            breadcrumbs[0, 2] = "toolsmain";
            breadcrumbs[1, 0] = pi.PollDisplayName;
            breadcrumbs[1, 1] = "";
            breadcrumbs[1, 2] = "";

            // Show changes saved if specified from querystring
            if (Request.QueryString["saved"] == "1")
            {
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }

            PageTitle.TitleText = ResHelper.GetString("Polls_Edit.headercaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/poll.gif";
        }
        else
        {
            // New item breadcrumbs
            breadcrumbs[0, 0] = ResHelper.GetString("Polls_New.ItemListLink");
            breadcrumbs[0, 1] = "~/CMSDesk/Tools/Polls/Polls_List.aspx";
            breadcrumbs[0, 2] = "";
            breadcrumbs[1, 0] = ResHelper.GetString("Polls_New.NewItemCaption");
            breadcrumbs[1, 1] = "";
            breadcrumbs[1, 2] = "";

            // New item title
            PageTitle.TitleText = ResHelper.GetString("Polls_New.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Polls/newpoll.gif";
        }
    }


    /// <summary>
    /// Load data of editing poll.
    /// </summary>
    /// <param name="pollObj">Poll object.</param>
    protected void LoadData(PollInfo pollObj)
    {
        // Load the fields
        txtCodeName.Text = pollObj.PollCodeName;
        txtDisplayName.Text = pollObj.PollDisplayName;
        txtTitle.Text = pollObj.PollTitle;
        txtQuestion.Text = pollObj.PollQuestion;
    }


    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        // Perform validation
        string errorMessage = new Validator().NotEmpty(txtCodeName.Text, rfvCodeName.ErrorMessage)
            .NotEmpty(txtDisplayName.Text, rfvDisplayName.ErrorMessage).NotEmpty(txtQuestion.Text, rfvQuestion.ErrorMessage).Result;

        // Check CodeName for identificator format
        if (!ValidationHelper.IsCodeName(txtCodeName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }

        if (errorMessage == "")
        {
            bool isnew = false;

            // Get existing object
            PollInfo pollObj = PollInfoProvider.GetPollInfo(pollId);
            if (pollObj == null)
            {
                // Create new if not found
                pollObj = new PollInfo();
                pollObj.PollAllowMultipleAnswers = false;
                pollObj.PollAccess = PollInfoProvider.ACCESS_ALL;
                isnew = true;
            }

            // Check if codename already exists
            PollInfo pi = PollInfoProvider.GetPollInfo(txtCodeName.Text);

            if ((pi == null) || (pi.PollID == pollObj.PollID))
            {
                // Set the fields
                pollObj.PollCodeName = txtCodeName.Text.Trim();
                pollObj.PollDisplayName = txtDisplayName.Text.Trim();
                pollObj.PollTitle = txtTitle.Text.Trim();
                pollObj.PollQuestion = txtQuestion.Text.Trim();

                // Save the object
                PollInfoProvider.SetPollInfo(pollObj);

                // Add poll to current site
                if (CMSContext.CurrentSite != null)
                {
                    PollInfoProvider.AddPollToSite(pollObj.PollID, CMSContext.CurrentSite.SiteID);
                }

                // Redirect to edit mode
                if (isnew)
                {
                    Response.Redirect("Polls_Edit.aspx?pollId=" + Convert.ToString(pollObj.PollID) + "&saved=1");
                }
            }
            else
            {
                // Error message - code name already exists
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("polls.codenameexists");
            }
        }
        else
        {
            // Error message - validation
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
