using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.Forums;
using CMS.LicenseProvider;
using CMS.Polls;

public partial class CMSDesk_Tools_Polls_Polls_Security : CMSDeskPage
{
    protected int pollId = 0;
    protected PollInfo poll = null;

    protected int forumId = 0;
    protected ForumInfo forum = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        //if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        //{
        //    LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Forums);
        //}

        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Read");
        }

        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            btnAddRole.Enabled = false;
        }

        // Get poll ID from querystring
        pollId = ValidationHelper.GetInteger(Request.QueryString["pollId"], 0);
        if (pollId == 0)
        {
            return;
        }

        // Control initializations
        lblAllUsers.Text = ResHelper.GetString("Poll_Security.AllUsers");
        lblOnlyRoles.Text = ResHelper.GetString("Poll_Security.OnlyRoles");
        lblOnlyUsers.Text = ResHelper.GetString("Poll_Security.OnlyUsers");
        lblTitle.Text = ResHelper.GetString("Poll_Security.Title");
        btnRemoveRole.Text = ResHelper.GetString("Poll_Security.Remove");
        btnOk.Text = ResHelper.GetString("General.Ok");
        btnAddRole.Text = ResHelper.GetString("Poll_Security.Add");
        btnAddRole.Attributes.Add("onclick", "AddOperator(" + pollId + "); return false;");

        // Register dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        this.ltlScript.Text = ScriptHelper.GetScript("function UpdateForm(){ " + ClientScript.GetPostBackEventReference(btnUpdate, "") + "; } \n");

        poll = PollInfoProvider.GetPollInfo(pollId);
        if (poll == null)
        {
            throw new Exception("Poll with given ID not found!");
        }

        if (!IsPostBack)
        {
            // If access is enabled for all users
            if (poll.PollAccess == PollInfoProvider.ACCESS_ALL)
            {
                radAllUsers.Checked = true;
                btnAddRole.Enabled = false;
                btnRemoveRole.Enabled = false;
                lstRoles.Enabled = false;
            }

            // If access is enabled for authenticated users only
            else if (poll.PollAccess == PollInfoProvider.ACCESS_AUTHENTICATED)
            {
                radOnlyUsers.Checked = true;
                btnAddRole.Enabled = false;
                btnRemoveRole.Enabled = false;
                lstRoles.Enabled = false;
            }
            // Access is enabled for users in authorized roles only
            else
            {
                radOnlyRoles.Checked = true;
                radOnlyRoles_CheckedChanged(null, null);
                // Load poll's roles to the listbox
                LoadRoles();
            }
        }
    }


    /// <summary>
    /// Loades list of roles authorized for poll access into lstRoles control.
    /// </summary>
    protected void LoadRoles()
    {
        lstRoles.Items.Clear();
        // Get allowed roles of the poll
        DataSet ds = PollInfoProvider.GetPollRoles(pollId);

        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            int roleId = 0;
            string roleDisplayName = null;
            DataRowCollection rows = ds.Tables[0].Rows;
            foreach (DataRow row in rows)
            {
                roleId = ValidationHelper.GetInteger(DataHelper.GetDataRowValue(row,"RoleID"), 0);
                roleDisplayName = ValidationHelper.GetString(DataHelper.GetDataRowValue(row,"RoleDisplayName"),"");
                if ((roleId > 0) && (roleDisplayName.Length > 0))
                {
                    // Insert an item to the listbox
                    lstRoles.Items.Add(new ListItem(roleDisplayName, roleId.ToString()));
                }
            }
        }

        if (lstRoles.Items.Count == 0)
        {
            btnRemoveRole.Enabled = false;
        }
        else
        {
            btnRemoveRole.Enabled = true;
        }
    }


    /// <summary>
    /// Enables access for all users.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radAllUsers_CheckedChanged(object sender, EventArgs e)
    {
        if (radAllUsers.Checked)
        {
            btnAddRole.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    /// <summary>
    /// Enables access for authenticated users only.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radOnlyUsers_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyUsers.Checked)
        {
            btnAddRole.Enabled = false;
            btnRemoveRole.Enabled = false;
            lstRoles.Enabled = false;
        }
    }


    /// <summary>
    /// Enables access for users in authorized roles only.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radOnlyRoles_CheckedChanged(object sender, EventArgs e)
    {
        if (radOnlyRoles.Checked)
        {
            btnAddRole.Enabled = true;
            btnRemoveRole.Enabled = true;
            lstRoles.Enabled = true;

            LoadRoles();

            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
            {
                btnAddRole.Enabled = false;
            }
        }
    }


    /// <summary>
    /// Removes role from the list of authorized roles.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnRemoveRole_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        int roleId = 0;
        foreach (ListItem item in lstRoles.Items)
        {
            if (item.Selected)
            {
                roleId = Convert.ToInt32(item.Value);
                PollInfoProvider.RemoveRoleFromPoll(roleId, pollId);
            }
        }
        // Reload listbox with roles
        LoadRoles();
    }


    /// <summary>
    /// This function is executed by callback iniciated by 'Select roles' dialog after its closing
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnUpdate_Click(object sender, EventArgs e)
    {
        // Reload listbox with roles
        LoadRoles();
    }


    /// <summary>
    /// Button OK click handler.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOk_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.polls", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.polls", "Modify");
        }

        if (poll != null)
        {
            if (radAllUsers.Checked)
            {
                poll.PollAccess = PollInfoProvider.ACCESS_ALL;
            }
            else if (radOnlyUsers.Checked)
            {
                poll.PollAccess = PollInfoProvider.ACCESS_AUTHENTICATED;
            }
            else if (radOnlyRoles.Checked)
            {
                poll.PollAccess = PollInfoProvider.ACCESS_ROLES;
            }
            PollInfoProvider.SetPollInfo(poll);

            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("General.Changessaved");
        }
        else
        {
            throw new Exception("Poll with given ID not found!");
        }
    }
}
