using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.Reporting;

/// <summary>
/// Report items enumeration
/// </summary>
public enum ReportItemTypes
{
    ///<summary>Graph</summary>
    Graph,
    ///<summary>Table</summary>
    Table,
    ///<summary>Value</summary>
    Value
}

public partial class CMSDesk_Tools_Reporting_ItemsList : System.Web.UI.UserControl
{
    private string mEditUrl = "";
    private int mReportId = 0;
    private ReportItemTypes mItemType = ReportItemTypes.Graph;

    #region "Public properties"

    /// <summary>
    /// Url of the edit page
    /// </summary>
    public string EditUrl
    {
        get
        {
            return mEditUrl;
        }
        set
        {
            mEditUrl = value;
        }
    }

    /// <summary>
    /// ReportId
    /// </summary>
    public int ReportId
    {
        get
        {
            return mReportId;
        }
        set
        {
            mReportId = value;
        }
    }


    /// <summary>
    /// Item type
    /// </summary>
    public ReportItemTypes ItemType
    {
        get
        {
            return mItemType;
        }
        set
        {
            mItemType = value;
        }
    }

    #endregion

    /// <summary>
    /// Page load
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }

        btnAdd.Text = ResHelper.GetString("ItemList.Add");
        btnDelete.Text = ResHelper.GetString("ItemList.Delete");
        btnEdit.Text = ResHelper.GetString("ItemList.Edit");
        btnInsert.Text = ResHelper.GetString("ItemList.Insert");

        LoadData();
        Initialize();
    }

    /// <summary>
    /// Set buttons actions
    /// </summary>
    protected void Initialize()
    {

        // Return selected item in list
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "GetSelectedItem" + mItemType.ToString(), ScriptHelper.GetScript(
            "function getSelectedItem_" + mItemType.ToString() + "() { \n" +
            "   if (document.getElementById('" + this.lstItems.ClientID + "') != null) { \n" +
            "      return document.getElementById('" + this.lstItems.ClientID + "').value; " +
            "   } \n" +
            "   return 0; } \n\n" +
            "function DeleteItem_" + mItemType.ToString() + "() { \n" +
            "   if ((document.getElementById('" + this.lstItems.ClientID + "') != null) && (document.getElementById('" + this.lstItems.ClientID + "').value != '')) { \n" +
            "       if (confirm('" + ResHelper.GetString("ReportItemList.DeleteConfirm") + "')) { \n" +
            "           document.getElementById('" + this.hdnItemId.ClientID + "').value = getSelectedItem_" + mItemType.ToString() + "();  " + this.Page.ClientScript.GetPostBackEventReference(btnHdnDelete, null) + " } \n" +
            "   } else { alert('" + ResHelper.GetString("Reporting_General.SelectObjectFirst") + "'); } \n" +
            "} \n\n" +
            "function InserMacro_" + mItemType.ToString() + "() { \n" +
            "   if ((document.getElementById('" + this.lstItems.ClientID + "') != null) && (document.getElementById('" + this.lstItems.ClientID + "').value != '')) { \n" +
            "       InsertHTML('%%control:Report" + ItemType.ToString() + "?' + getSelectedItem_" + mItemType.ToString() + "() + '%%'); \n" +
            "   } else { alert('" + ResHelper.GetString("Reporting_General.SelectObjectFirst") + "'); } \n" +
            "} \n"
            ));

        string modalHeight = "570";
        if (mItemType == ReportItemTypes.Graph)
        {
            modalHeight = "730";
        }

        btnAdd.OnClientClick = "modalDialog('" + ResolveUrl(mEditUrl) + "?reportId=" + mReportId.ToString() + "','ReportItemEdit',800," + modalHeight + ");return false;";
        btnEdit.OnClientClick = "if (getSelectedItem_" + mItemType.ToString() + "() != '') { modalDialog('" + ResolveUrl(mEditUrl) + "?reportId=" + mReportId.ToString() + "&itemName='+ getSelectedItem_" + mItemType.ToString() + "(),'ReportItemEdit',800," + modalHeight + "); } else { alert('" + ResHelper.GetString("Reporting_General.SelectObjectFirst") + "');} return false;";
        btnDelete.OnClientClick = "DeleteItem_" + mItemType.ToString() + "(); return false;";
        btnInsert.OnClientClick = "InserMacro_" + mItemType.ToString() + "(); return false;";



    }

    /// <summary>
    /// Load data
    /// </summary>
    public void LoadData()
    {
        if (mReportId == 0)
        {
            return;
        }

        DataSet ds = null;
        string selected = lstItems.SelectedValue;
        lstItems.Items.Clear();

        if (mItemType == ReportItemTypes.Graph)
        {
            ds = ReportGraphInfoProvider.GetGraphs("GraphReportID = " + mReportId.ToString());
            lstItems.DataTextField = "GraphDisplayName";
            lstItems.DataValueField = "GraphName";
        }
        else if (mItemType == ReportItemTypes.Table)
        {
            ds = ReportTableInfoProvider.GetTables("TableReportID = " + mReportId.ToString());
            lstItems.DataTextField = "TableDisplayName";
            lstItems.DataValueField = "TableName";
        }
        else if (mItemType == ReportItemTypes.Value)
        {
            ds = ReportValueInfoProvider.GetValues("ValueReportID = " + mReportId.ToString());
            lstItems.DataTextField = "ValueDisplayName";
            lstItems.DataValueField = "ValueName";
        }

        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            lstItems.DataSource = ds;
            try
            {
                lstItems.DataBind();
            }
            catch
            {
            }

            if (!IsPostBack)
            {
                lstItems.SelectedIndex = 0;
            }
            else
            {
                try
                {
                    lstItems.SelectedValue = selected;
                }
                catch
                {
                    try
                    {
                        lstItems.SelectedIndex = 0;
                    }
                    catch
                    {
                    }
                }
            }
        }
    }

    /// <summary>
    /// 
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnHdnDelete_Click(object sender, EventArgs e)
    {

        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }

        string itemName = "";

        if (hdnItemId.Value != "")
        {
            itemName = ValidationHelper.GetString(hdnItemId.Value, "");

            if (mItemType == ReportItemTypes.Graph)
            {
                ReportGraphInfo rgi = ReportGraphInfoProvider.GetReportGraphInfo(itemName);

                if (rgi != null)
                {
                    ReportGraphInfoProvider.DeleteReportGraphInfo(rgi.GraphID);
                }
            }
            else if (mItemType == ReportItemTypes.Table)
            {
                ReportTableInfo rti = ReportTableInfoProvider.GetReportTableInfo(itemName);

                if (rti != null)
                {
                    ReportTableInfoProvider.DeleteReportTableInfo(rti.TableID);
                }
            }
            else if (mItemType == ReportItemTypes.Value)
            {
                ReportValueInfo rvi = ReportValueInfoProvider.GetReportValueInfo(itemName);

                if (rvi != null)
                {
                    ReportValueInfoProvider.DeleteReportValueInfo(rvi.ValueID);
                }
            }
            this.LoadData();
        }
    }
}
