using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.Reporting;
using CMS.DataEngine;
using CMS.CMSHelper;
using ZedGraph;

public partial class CMSDesk_Tools_Reporting_ReportGraph_edit : CMSDeskPage
{

    protected ReportGraphInfo graphInfo = null;
    protected int graphId;
    protected ReportInfo reportInfo = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }

        int reportId = ValidationHelper.GetInteger(Request.QueryString["reportid"], 0);
        if (reportId > 0)
            reportInfo = ReportInfoProvider.GetReportInfo(reportId);
        if (reportInfo != null) //must be valid reportid parameter
        {

            string graphName = ValidationHelper.GetString(Request.QueryString["itemname"], "");
            if (ValidationHelper.IsCodeName(graphName))
            {
                graphInfo = ReportGraphInfoProvider.GetReportGraphInfo(graphName);
                graphId = graphInfo.GraphID;
            }

            rfvCodeName.ErrorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorCodeName");
            rfvDisplayName.ErrorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorDisplayName");
            rfvQuery.ErrorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorQuery");

            // control initializations
            lblDisplayName.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.DisplayName");
            lblCodeName.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.CodeName");
            lblQuery.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.Query");
            lblStoredProcedure.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.StoredProcedure");
            lblGraphType.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphType");

            lblGraphHeight.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphHeight");
            lblGraphWidth.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphWidth");
            lblGraphTitle.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphTitle");
            lblGraphXAxisTitle.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphXAxisTitle");
            lblGraphYAxisTitle.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphYAxisTitle");
            lblGraphLegendPosition.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.GraphLegendPosition");

            if (graphInfo != null)
            {
                titleElem.TitleText = ResHelper.GetString("Reporting_ReportGraph_Edit.TitleText");
                titleElem.TitleImage = ResolveUrl("~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/graph.gif");
            }
            else //new item
            {
                titleElem.TitleText = ResHelper.GetString("Reporting_ReportGraph_Edit.NewItemTitleText");
                titleElem.TitleImage = ResolveUrl("~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/newgraph.gif");
            }

            if (!IsPostBack)
            {
                LoadData();
            }
        }
        else
        {
            pnlElements.Visible = false;
            btnOK.Visible = false;
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Reporting_ReportGraph_Edit.InvalidReportId");
        }
        btnOK.Text = ResHelper.GetString("General.OK");
        btnCancel.Text = ResHelper.GetString("General.Cancel");



    }

    protected void LoadData()
    {

        // load graph types
        drpGraphType.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.GraphType_Pie"), "pie"));
        drpGraphType.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.GraphType_Bar"), "bar"));

        // load legend positions
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_NoLegend"), ReportGraph.NO_LEGEND.ToString()));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_Top"), "0"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_Left"), "1"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_Right"), "2"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_Bottom"), "3"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_InsideTopLeft"), "4"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_InsideTopRight"), "5"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_InsideBotLeft"), "6"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_InsideBotRight"), "7"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_Float"), "8"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_TopCenter"), "9"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_BottomCenter"), "10"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_TopFlushLeft"), "11"));
        drpGraphLegendPosition.Items.Add(new ListItem(ResHelper.GetFileString("Reporting_ReportGraph.LegendPosition_BottomFlushLeft"), "12"));



        if (graphInfo != null)
        {
            txtDisplayName.Text = graphInfo.GraphDisplayName;
            txtCodeName.Text = graphInfo.GraphName;
            txtQuery.Text = graphInfo.GraphQuery;
            chkStoredProcedure.Checked = graphInfo.GraphQueryIsStoredProcedure;
            drpGraphType.SelectedValue = graphInfo.GraphType;
            drpGraphLegendPosition.SelectedValue = graphInfo.GraphLegendPosition.ToString();
            if (ValidationHelper.GetInteger(graphInfo.GraphHeight, 0) == 0)
            {
                txtGraphHeight.Text = "";
            }
            else
            {
                txtGraphHeight.Text = ValidationHelper.GetString(graphInfo.GraphHeight.ToString(), "");
            }
            if (ValidationHelper.GetInteger(graphInfo.GraphWidth, 0) == 0)
            {
                txtGraphWidth.Text = "";
            }
            else
            {
                txtGraphWidth.Text = ValidationHelper.GetString(graphInfo.GraphWidth.ToString(), "");
            }
            txtGraphTitle.Text = graphInfo.GraphTitle;
            txtGraphXAxisTitle.Text = graphInfo.GraphXAxisTitle;
            txtGraphYAxisTitle.Text = graphInfo.GraphYAxisTitle;
        }

    }


    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (Save())
        {
            ltlScript.Text += ScriptHelper.GetScript("wopener.ReloadPage();window.close();");
        }
    }

    /// <summary>
    /// Save data
    /// </summary>
    /// <returns>return true if save was successfull</returns>
    protected bool Save()
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtDisplayName.Text, rfvDisplayName.ErrorMessage).NotEmpty(txtCodeName.Text, rfvCodeName.ErrorMessage).NotEmpty(txtQuery.Text, rfvQuery.ErrorMessage).Result;

        if ((errorMessage == "") && (!ValidationHelper.IsCodeName(txtCodeName.Text.Trim())))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorCodeNameInvalid");
        }
        ReportGraphInfo codeNameCheck = ReportGraphInfoProvider.GetReportGraphInfo(txtCodeName.Text.Trim());
        if ((errorMessage == "") && (codeNameCheck != null) && (codeNameCheck.GraphID != graphId))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorCodeNameExist");
        }
        if ((errorMessage == "") && (txtGraphWidth.Text.Trim() != String.Empty) && ((!ValidationHelper.IsInteger(txtGraphWidth.Text.Trim())) || (Int32.Parse(txtGraphWidth.Text.Trim()) <= 0)))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorWidthInvalid");
        }
        if ((errorMessage == "") && (txtGraphHeight.Text.Trim() != String.Empty) && ((!ValidationHelper.IsInteger(txtGraphHeight.Text.Trim())) || (Int32.Parse(txtGraphHeight.Text.Trim()) <= 0)))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportGraph_Edit.ErrorHeightInvalid");
        }

        if ((errorMessage == ""))
        {
            if (graphInfo == null) //new graph
                graphInfo = new ReportGraphInfo();

            graphInfo.GraphDisplayName = txtDisplayName.Text;
            graphInfo.GraphName = txtCodeName.Text;
            graphInfo.GraphQuery = txtQuery.Text;
            graphInfo.GraphQueryIsStoredProcedure = chkStoredProcedure.Checked;
            graphInfo.GraphType = drpGraphType.SelectedValue;
            graphInfo.GraphReportID = reportInfo.ReportID;
            graphInfo.GraphHeight = ValidationHelper.GetInteger(txtGraphHeight.Text, 0);
            graphInfo.GraphWidth = ValidationHelper.GetInteger(txtGraphWidth.Text, 0);
            graphInfo.GraphTitle = txtGraphTitle.Text;
            graphInfo.GraphXAxisTitle = txtGraphXAxisTitle.Text;
            graphInfo.GraphYAxisTitle = txtGraphYAxisTitle.Text;
            graphInfo.GraphLegendPosition = ValidationHelper.GetInteger(drpGraphLegendPosition.SelectedValue, 0);

            ReportGraphInfoProvider.SetReportGraphInfo(graphInfo);
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
            return false;
        }
        return true;
    }

}
