using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.Reporting;
using CMS.DataEngine;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Reporting_ReportTable_edit : CMSModalPage
{

    protected ReportTableInfo tableInfo = null;
    protected int tableId;
    protected ReportInfo reportInfo = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }

        int reportId = ValidationHelper.GetInteger(Request.QueryString["reportid"], 0);

        if (reportId > 0)
        {
            reportInfo = ReportInfoProvider.GetReportInfo(reportId);
        }

        if (reportInfo != null) //must be valid reportid parameter
        {

            string tableName = ValidationHelper.GetString(Request.QueryString["itemname"], "");
            if (ValidationHelper.IsCodeName(tableName))
            {
                tableInfo = ReportTableInfoProvider.GetReportTableInfo(tableName);
                tableId = tableInfo.TableID;
            }
            


            rfvCodeName.ErrorMessage = ResHelper.GetString("Reporting_ReportTable_Edit.ErrorCodeName");
            rfvDisplayName.ErrorMessage = ResHelper.GetString("Reporting_ReportTable_Edit.ErrorDisplayName");
            rfvQuery.ErrorMessage = ResHelper.GetString("Reporting_ReportTable_Edit.ErrorQuery");

            // control initializations
            lblDisplayName.Text = ResHelper.GetString("Reporting_ReportTable_Edit.DisplayName");
            lblCodeName.Text = ResHelper.GetString("Reporting_ReportTable_Edit.CodeName");
            lblQuery.Text = ResHelper.GetString("Reporting_ReportTable_Edit.Query");
            lblStoredProcedure.Text = ResHelper.GetString("Reporting_ReportTable_Edit.StoredProcedure");

            if (tableInfo != null)
            {
                titleElem.TitleText = ResHelper.GetString("Reporting_ReportTable_Edit.TitleText");
                titleElem.TitleImage = ResolveUrl("~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/table.gif");
            }
            else //new item
            {
                titleElem.TitleText = ResHelper.GetString("Reporting_ReportTable_Edit.NewItemTitleText");
                titleElem.TitleImage = ResolveUrl("~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/newtable.gif");
            }

            if (!IsPostBack)
            {
                LoadData();
            }
        }
        else
        {
            pnlElements.Visible = false;
            btnOK.Visible = false;
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Reporting_ReportTable_Edit.InvalidReportId");
        }
        btnOK.Text = ResHelper.GetString("General.OK");
        btnCancel.Text = ResHelper.GetString("General.Cancel");



    }

    protected void LoadData()
    {

        if (tableInfo != null)
        {
            txtDisplayName.Text = tableInfo.TableDisplayName;
            txtCodeName.Text = tableInfo.TableName;
            txtQuery.Text = tableInfo.TableQuery;
            chkStoredProcedure.Checked = tableInfo.TableQueryIsStoredProcedure;
        }
    }



    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (Save())
        {
            ltlScript.Text += ScriptHelper.GetScript("wopener.ReloadPage();window.close();");
        }
    }

    /// <summary>
    /// Save data
    /// </summary>
    /// <returns>return true if save was successfull</returns>
    protected bool Save()
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtDisplayName.Text, rfvDisplayName.ErrorMessage).NotEmpty(txtCodeName.Text, rfvCodeName.ErrorMessage).NotEmpty(txtQuery.Text, rfvQuery.ErrorMessage).Result;

        if ((errorMessage == "") && (!ValidationHelper.IsCodeName(txtCodeName.Text.Trim())))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportTable_Edit.ErrorCodeNameInvalid");
        }
        ReportTableInfo codeNameCheck = ReportTableInfoProvider.GetReportTableInfo(txtCodeName.Text.Trim());
        if ((errorMessage == "") && (codeNameCheck != null) && (codeNameCheck.TableID != tableId))
            errorMessage = ResHelper.GetString("Reporting_ReportTable_Edit.ErrorCodeNameExist");

        if ((errorMessage == ""))
        {
            if (tableInfo == null) //new table
                tableInfo = new ReportTableInfo();

            tableInfo.TableDisplayName = txtDisplayName.Text.Trim();
            tableInfo.TableName = txtCodeName.Text.Trim();
            tableInfo.TableQuery = txtQuery.Text.Trim();
            tableInfo.TableQueryIsStoredProcedure = chkStoredProcedure.Checked;
            tableInfo.TableReportID = reportInfo.ReportID;

            ReportTableInfoProvider.SetReportTableInfo(tableInfo);
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
            return false;
        }
        return true;
    }

}
