using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.PortalEngine;
using CMS.Reporting;
using CMS.DataEngine;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Reporting_ReportValue_edit : CMSModalPage
{
    
    protected ReportValueInfo valueInfo = null;
    protected int valueId;
    protected ReportInfo reportInfo = null;    

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }        

        int reportId = ValidationHelper.GetInteger(Request.QueryString["reportid"], 0);
        if (reportId > 0)
            reportInfo = ReportInfoProvider.GetReportInfo(reportId);
        if (reportInfo != null) //must be valid reportid parameter
        {

            string valueName = ValidationHelper.GetString(Request.QueryString["itemname"], "");
            if (ValidationHelper.IsCodeName(valueName))
            {
                valueInfo = ReportValueInfoProvider.GetReportValueInfo(valueName);
                valueId = valueInfo.ValueID;
            }

            rfvCodeName.ErrorMessage = ResHelper.GetString("Reporting_ReportValue_Edit.ErrorCodeName");
            rfvDisplayName.ErrorMessage = ResHelper.GetString("Reporting_ReportValue_Edit.ErrorDisplayName");
            rfvQuery.ErrorMessage = ResHelper.GetString("Reporting_ReportValue_Edit.ErrorQuery");

            // control initializations
            lblDisplayName.Text = ResHelper.GetString("Reporting_ReportValue_Edit.DisplayName");
            lblCodeName.Text = ResHelper.GetString("Reporting_ReportValue_Edit.CodeName");
            lblQuery.Text = ResHelper.GetString("Reporting_ReportValue_Edit.Query");
            lblStoredProcedure.Text = ResHelper.GetString("Reporting_ReportValue_Edit.StoredProcedure");
            lblFormatString.Text = ResHelper.GetString("Reporting_ReportValue_Edit.FormatString");

            if (valueInfo != null)
            {
                titleElem.TitleText = ResHelper.GetString("Reporting_ReportValue_Edit.TitleText");
                titleElem.TitleImage = ResolveUrl("~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/value.gif");
            }
            else //new item
            {
                titleElem.TitleText = ResHelper.GetString("Reporting_ReportValue_Edit.NewItemTitleText");
                titleElem.TitleImage = ResolveUrl("~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/newvalue.gif");
            }

            if (!IsPostBack)
            {
                LoadData();
            }
        }
        else
        {            
            pnlElements.Visible = false;
            btnOK.Visible = false;
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Reporting_ReportValue_Edit.InvalidReportId");
        }
        btnOK.Text = ResHelper.GetString("General.OK");
        btnCancel.Text = ResHelper.GetString("General.Cancel");

        

    }

    protected void LoadData() {
        
        if (valueInfo != null)
        {
            txtDisplayName.Text = valueInfo.ValueDisplayName;
            txtCodeName.Text = valueInfo.ValueName;
            txtQuery.Text = valueInfo.ValueQuery;
            chkStoredProcedure.Checked = valueInfo.ValueQueryIsStoredProcedure;
            txtFormatString.Text = valueInfo.ValueFormatString;
        }
    }



    protected void btnOK_Click(object sender, EventArgs e)
    {
        if (Save())
        {
            ltlScript.Text += ScriptHelper.GetScript("wopener.ReloadPage();window.close();");
        }
    }

    /// <summary>
    /// Save data
    /// </summary>
    /// <returns>return true if save was successfull</returns>
    protected bool Save()
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtDisplayName.Text, rfvDisplayName.ErrorMessage).NotEmpty(txtCodeName.Text, rfvCodeName.ErrorMessage).NotEmpty(txtQuery.Text, rfvQuery.ErrorMessage).Result;

        if ((errorMessage == "") && (!ValidationHelper.IsCodeName(txtCodeName.Text.Trim())))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportValue_Edit.ErrorCodeNameInvalid");
        }

        ReportValueInfo codeNameCheck = ReportValueInfoProvider.GetReportValueInfo(txtCodeName.Text.Trim());

        if ((errorMessage == "") && (codeNameCheck != null) && (codeNameCheck.ValueID != valueId))
        {
            errorMessage = ResHelper.GetString("Reporting_ReportValue_Edit.ErrorCodeNameExist");
        }

        if ((errorMessage == ""))
        {                        
            if (valueInfo == null) //new Value
                valueInfo = new ReportValueInfo();

            valueInfo.ValueDisplayName = txtDisplayName.Text.Trim();
            valueInfo.ValueName = txtCodeName.Text.Trim();
            valueInfo.ValueQuery = txtQuery.Text.Trim();
            valueInfo.ValueQueryIsStoredProcedure = chkStoredProcedure.Checked;
            valueInfo.ValueFormatString = txtFormatString.Text.Trim();
            valueInfo.ValueReportID = reportInfo.ReportID;

            ReportValueInfoProvider.SetReportValueInfo(valueInfo);
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
            return false;
        }
        return true;
    }

}
