using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.Reporting;

public partial class CMSDesk_Tools_Reporting_Report_General : CMSDeskPage
{
    protected int reportId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ReloadPage", ScriptHelper.GetScript("function ReloadPage() { \n" + this.Page.ClientScript.GetPostBackEventReference(btnHdnReload, null) + "}"));

        reportId = ValidationHelper.GetInteger(Request.QueryString["reportId"], 0);

        // control initializations				
        rfvReportDisplayName.ErrorMessage = ResHelper.GetString("Report_New.EmptyDisplayName");
        rfvReportName.ErrorMessage = ResHelper.GetString("Report_New.EmptyCodeName");

        lblReportDisplayName.Text = ResHelper.GetString("Report_New.DisplayNameLabel");
        lblReportName.Text = ResHelper.GetString("Report_New.NameLabel");
        lblLayout.Text = ResHelper.GetString("Report_General.LayoutLabel");
        lblGraphs.Text = ResHelper.GetString("Report_General.GraphsLabel");
        lblTables.Text = ResHelper.GetString("Report_General.TablesLabel");
        lblValues.Text = ResHelper.GetString("Report_General.TablesValues");
        lblReportAccess.Text = ResHelper.GetString("Report_General.ReportAccessLabel");

        btnOK.Text = ResHelper.GetString("General.OK");

        if (!IsPostBack)
        {
            LoadData(reportId);
        }

        fckTemplateBody.BasePath = "~/CMSAdminControls/FCKeditor/";
        fckTemplateBody.AutoDetectLanguage = false;
        fckTemplateBody.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
        fckTemplateBody.EditorAreaCSS = "";

        // initialize item lis controls
        ilGraphs.ReportId = reportId;
        ilTables.ReportId = reportId;
        ilValues.ReportId = reportId;

        ilGraphs.EditUrl = "ReportGraph_Edit.aspx";
        ilTables.EditUrl = "ReportTable_Edit.aspx";
        ilValues.EditUrl = "ReportValue_Edit.aspx";

        ilGraphs.ItemType = ReportItemTypes.Graph;
        ilTables.ItemType = ReportItemTypes.Table;
        ilValues.ItemType = ReportItemTypes.Value;
    }


    /// <summary>
    /// Load data
    /// </summary>
    protected void LoadData(int jReportId)
    {

        ReportInfo ri = ReportInfoProvider.GetReportInfo(jReportId);

        if (ri == null)
        {
            return;
        }
        chkReportAccess.Checked = (ri.ReportAccess == ReportAccessEnum.All);
        txtReportDisplayName.Text = ri.ReportDisplayName;
        txtReportName.Text = ri.ReportName;
        fckTemplateBody.ResolvedValue = ri.ReportLayout;
    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }
        string errorMessage = new Validator().NotEmpty(txtReportDisplayName.Text.Trim(), rfvReportDisplayName.ErrorMessage).NotEmpty(txtReportName.Text.Trim(), rfvReportName.ErrorMessage).Result;

        if ((errorMessage == "") && (!ValidationHelper.IsCodeName(txtReportName.Text.Trim())))
        {
            errorMessage = ResHelper.GetString("Report_General.InvalidCodeName");
        }

        ReportAccessEnum reportAccess = ReportAccessEnum.All;

        if (!chkReportAccess.Checked)
        {
            reportAccess = ReportAccessEnum.Authenticated;
        }

        if (errorMessage == "")
        {
            ReportInfo ri = ReportInfoProvider.GetReportInfo(reportId);
            ReportInfo nri = ReportInfoProvider.GetReportInfo(txtReportName.Text.Trim());

            //if report with given name already exists show error message
            if ((nri != null) && (nri.ReportID != ri.ReportID))
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Report_New.ReportAlreadyExists");
                return;
            }

            if (ri != null)
            {
                ri.ReportDisplayName = txtReportDisplayName.Text.Trim();
                ri.ReportName = txtReportName.Text.Trim();
                ri.ReportLayout = fckTemplateBody.ResolvedValue;
                ri.ReportAccess = reportAccess;

                ReportInfoProvider.SetReportInfo(ri);

                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }


}
