using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Reporting;
using CMS.CMSHelper;
using CMS.LicenseProvider;

public partial class Reporting_Report_List : CMSDeskPage
{
    int categoryId = 0;

	protected void Page_Load(object sender, EventArgs e)
	{
        // Check license
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Reporting);
        }

        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }        

		PageTitle.TitleText = ResHelper.GetString("Report_List.HeaderCaption");
		PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/reports.gif";
        imgNewItem.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/addreport.gif";

        categoryId = ValidationHelper.GetInteger(Request.QueryString["categoryId"],0);
        lnkNewItem.NavigateUrl = "Report_New.aspx?categoryid=" + categoryId;

        UniGrid.WhereCondition = "[ReportCategoryId] = " + categoryId;
		UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
		UniGrid.GridView.GridLines = GridLines.Horizontal;

		lnkNewItem.Text = ResHelper.GetString("Report_List.NewItemCaption");
	}


	/// <summary>
	/// Handles the UniGrid's OnAction event.
	/// </summary>
	/// <param name="actionName">Name of item (button) that throws event.</param>
	/// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
	protected void uniGrid_OnAction(string actionName, object actionArgument)
	{
		if (actionName == "edit")
		{
			Response.Redirect("Report_Edit.aspx?reportId=" + Convert.ToString(actionArgument)+"&categoryId="+categoryId);
		}
		else if (actionName == "delete")
		{
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
            }

			// delete ReportInfo object from database
			ReportInfoProvider.DeleteReportInfo(Convert.ToInt32(actionArgument));
		}
	}
}
