using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.Reporting;
using CMS.DataEngine;

public partial class CMSDesk_Tools_Reporting_Report_new : CMSDeskPage
{

    int categoryId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }

        // control initializations				
        rfvReportDisplayName.ErrorMessage = ResHelper.GetString("Report_New.EmptyDisplayName");
        rfvReportName.ErrorMessage = ResHelper.GetString("Report_New.EmptyCodeName");

        lblReportDisplayName.Text = ResHelper.GetString("Report_New.DisplayNameLabel");
        lblReportName.Text = ResHelper.GetString("Report_New.NameLabel");
        lblReportAccess.Text = ResHelper.GetString("Report_New.ReportAccessLabel");

        btnOK.Text = ResHelper.GetString("General.OK");

        categoryId = ValidationHelper.GetInteger(Request.QueryString["categoryId"], 0);

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Report_New.ReportList");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Reporting/Report_List.aspx?categoryid="+categoryId;
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = ResHelper.GetString("Report_New.NewReport");
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = ResHelper.GetString("Report_New.NewReport");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/newreport.gif";

    }

   
    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check 'Modify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
        }
        

        string errorMessage = new Validator().NotEmpty(txtReportDisplayName.Text.Trim(), rfvReportDisplayName.ErrorMessage).NotEmpty(txtReportName.Text.Trim(), rfvReportName.ErrorMessage).Result;

        if ((errorMessage == "") && (!ValidationHelper.IsCodeName(txtReportName.Text.Trim())))
        {
            errorMessage = ResHelper.GetString("Report_General.InvalidCodeName");
        }

        if (ReportCategoryInfoProvider.GetReportCategoryInfo(categoryId) == null)
        {
            errorMessage = ResHelper.GetString("Report_General.InvalidReportCategory");
        }

        ReportAccessEnum reportAccess = ReportAccessEnum.All;
        if (!chkReportAccess.Checked)
        {
            reportAccess = ReportAccessEnum.Authenticated;
        }

        if (errorMessage == "")
        {
            //if report with given name already exists show error message
            if ( ReportInfoProvider.GetReportInfo(txtReportName.Text.Trim()) != null)
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Report_New.ReportAlreadyExists");
                return;
            }

            ReportInfo ri = new ReportInfo();

            ri.ReportDisplayName = txtReportDisplayName.Text.Trim();
            ri.ReportName = txtReportName.Text.Trim();
            ri.ReportCategoryID = categoryId;
            ri.ReportLayout = "";
            ri.ReportParameters = "";
            ri.ReportAccess = reportAccess;

            ReportInfoProvider.SetReportInfo(ri);

            Response.Redirect("Report_Edit.aspx?reportId=" + ri.ReportID.ToString() + "&saved=1&categoryId="+categoryId);
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
