using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.GlobalHelper;
using CMS.Reporting;
using CMS.SiteProvider;
using CMS.CMSHelper;

public partial class Reporting_SavedReports_List : CMSDeskPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Check 'Read' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Read"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Read");
        }
        PageTitle.TitleText = ResHelper.GetString("SavedReports_List.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Reporting/SavedReports/savedreports.gif";

        UniGrid.OnAction += new OnActionEventHandler(uniGrid_OnAction);
        UniGrid.GridView.GridLines = GridLines.Horizontal;
        UniGrid.OnExternalDataBound += new OnExternalDataBoundEventHandler(uniGrid_OnExternalDataBound);
        UniGrid.WhereCondition = createWhereCondition();

    }

    /// <summary>
    /// Create where condition for unigrid
    /// </summary>
    /// <returns></returns>
    private string createWhereCondition()
    {
        string condition = "";

        int reportId = ValidationHelper.GetInteger(Request.QueryString["reportId"], 0);

        if (reportId != 0)
        {
            condition += "SavedReportReportId = " + reportId;
        }

        return condition;
    }

    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void uniGrid_OnAction(string actionName, object actionArgument)
    {
        if (actionName == "edit")
        {
            Response.Redirect("SavedReport_View.aspx?reportId=" + Convert.ToString(actionArgument));
        }
        else if (actionName == "delete")
        {
            // Check 'Modify' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.reporting", "Modify"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.reporting", "Modify");
            }
            // delete ReportInfo object from database
            SavedReportInfoProvider.DeleteSavedReportInfo(Convert.ToInt32(actionArgument));
        }
    }

    /// <summary>
    /// Unigrid OnExternal DataBound
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="sourceName"></param>
    /// <param name="parameter"></param>
    /// <returns></returns>
    object uniGrid_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        if (sourceName.ToLower() == "savedreportcreatedbyuserid")
        {
            UserInfo ui = UserInfoProvider.GetUserInfo(ValidationHelper.GetInteger(parameter, 0));
            if (ui != null)
            {
                return ui.FullName;
            }

            return "";
        }

        return parameter;

    }

}
