using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using System.Collections;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Newsletter;
using CMS.CMSHelper;
using CMS.Staging;
using CMS.TreeEngine;
using CMS.SiteProvider;
using CMS.WorkflowEngine;

public partial class CMSDesk_Tools_Staging_Tasks_Tasks : CMSStagingPage
{
    private int serverId = 0;
    private int nodeId = 0;

    protected string viewImage = "";
    protected string deleteImage = "";
    protected string syncImage = "";

    protected string viewTooltip = "";
    protected string deleteTooltip = "";
    protected string syncTooltip = "";

    protected string syncCurrent = null;
    protected string syncSubtree = null;

    string aliasPath = "/";

    SiteInfo si = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'Manage servers' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.staging", "ManageTasks"))
        {
            CMSDeskPage.RedirectToAccessDenied("cms.staging", "ManageTasks");
        }

        // Register the dialog script
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

        this.ltlScript.Text += ScriptHelper.GetScript("function ConfirmDeleteTask(taskId) { return confirm('" + ResHelper.GetString("Tasks.ConfirmDelete") + "'); }");

        serverId = ValidationHelper.GetInteger(Request.QueryString["serverid"], 0);
        nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);

        aliasPath = "/";

        si = CMSContext.CurrentSite;

        // Get the document node
        if (nodeId > 0)
        {
            TreeProvider tree = new TreeProvider();
            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId, TreeProvider.ALL_CULTURES);
            if (node != null)
            {
                aliasPath = node.NodeAliasPath;
            }
        }

        string imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSAdminControls/UniGrid/";
        viewImage = imagesUrl + "view.gif";
        deleteImage = imagesUrl + "delete.gif";
        syncImage = imagesUrl + "synchronize.gif";

        syncTooltip = ResHelper.GetString("Tasks.SyncTooltip");
        deleteTooltip = ResHelper.GetString("Tasks.DeleteTooltip");
        viewTooltip = ResHelper.GetString("Tasks.ViewTooltip");

        syncCurrent = ResHelper.GetString("Tasks.SyncCurrent");
        syncSubtree = ResHelper.GetString("Tasks.SyncSubtree");

        imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Staging/Tasks/";
        imgCurrent.ImageUrl = imagesUrl + "synccurrent.gif";
        imgSubtree.ImageUrl = imagesUrl + "syncsubtree.gif";

        this.gridTask.Columns[0].HeaderText = ResHelper.GetString("Tasks.HeaderSelect");
        this.gridTask.Columns[1].HeaderText = ResHelper.GetString("Tasks.HeaderAction");
        this.gridTask.Columns[2].HeaderText = ResHelper.GetString("Tasks.HeaderTitle");
        this.gridTask.Columns[3].HeaderText = ResHelper.GetString("Tasks.HeaderType");
        this.gridTask.Columns[4].HeaderText = ResHelper.GetString("Tasks.HeaderTime");
        this.gridTask.Columns[5].HeaderText = ResHelper.GetString("Tasks.HeaderResult");

        this.btnDeleteAll.Text = ResHelper.GetString("Tasks.DeleteAll");
        this.btnDeleteSelected.Text = ResHelper.GetString("Tasks.DeleteSelected");
        this.btnSyncAll.Text = ResHelper.GetString("Tasks.SyncAll");
        this.btnSyncSelected.Text = ResHelper.GetString("Tasks.SyncSelected");

        this.btnDeleteAll.OnClientClick = "return confirm('" + ResHelper.GetString("Tasks.ConfirmDeleteAll") + "');";
        this.btnDeleteSelected.OnClientClick = "return confirm('" + ResHelper.GetString("Tasks.ConfirmDeleteSelected") + "');";

        this.chk.Attributes.Add("onclick", "SelectCheckboxes(this,'chckbox');");
        this.chk.Text = ResHelper.GetString("Tasks.SelectDeselectAll");
        this.chk.Checked = false;

        if (!this.IsPostBack)
        {
            ReloadTasks();
        }
    }


    protected void ReloadTasks()
    {
        DataSet ds = TaskInfoProvider.SelectTaskList(si.SiteID, serverId, aliasPath);
        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            this.gridTask.Visible = true;
            this.pnlFooter.Visible = true;
            this.gridTask.DataSource = ds;
            this.gridTask.DataBind();
        }
        else
        {
            if (this.lblInfo.Text == "")
            {
                this.lblInfo.Text = ResHelper.GetString("Tasks.NoTasks");
            }
            this.pnlFooter.Visible = false;
            this.gridTask.Visible = false;
            this.chk.Visible = false;
        }
    }


    protected void gridTask_RowCommand(object sender, GridViewCommandEventArgs e)
    {
        int taskId = ValidationHelper.GetInteger(e.CommandArgument, 0);
        if (taskId > 0)
        {
            switch (e.CommandName.ToLower())
            {
                case "delete":
                    // Delete task
                    SynchronizationInfoProvider.DeleteSynchronizationInfo(taskId, serverId);
                    ReloadTasks();
                    break;

                case "sync":
                    try
                    {
                        // Run task synchronization
                        string result = StagingHelper.RunSynchronization(taskId, serverId);

                        if ((result != null) && (result != ""))
                        {
                            this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed");
                        }
                        else
                        {
                            this.lblInfo.Text = ResHelper.GetString("Tasks.SynchronizationOK");
                        }
                    }
                    catch (Exception ex)
                    {
                        this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed") + " " + ex.Message;
                    }

                    ReloadTasks();
                    break;
            }
        }
    }


    /// <summary>
    /// Returns the result link for the synchronization log
    /// </summary>
    /// <param name="failedCount"></param>
    protected string GetResultLink(object failedCount, object taskId)
    {
        int count = ValidationHelper.GetInteger(failedCount, 0);
        if (count > 0)
        {
            string logUrl = "log.aspx?taskid=" + taskId.ToString() + "&serverId=" + serverId.ToString();
            return "<a target=\"_blank\" href=\"" + logUrl + "\" onclick=\"modalDialog('" + logUrl + "', 'tasklog', 700, 500); return false;\">" + ResHelper.GetString("Tasks.ResultFailed") + "</a>";
        }
        else
        {
            return ResHelper.GetString("Tasks.ResultOK");
        }
    }


    protected void gridTask_RowDeleting(object sender, GridViewDeleteEventArgs e)
    {
    }


    protected void btnSyncAll_Click(object sender, EventArgs e)
    {
        try
        {
            string result = "";
            // Process all records
            foreach (GridViewRow row in gridTask.Rows)
            {
                // Get ID
                Literal ltlID = (Literal)row.FindControl("ltlID");
                if (ltlID != null)
                {
                    int taskId = ValidationHelper.GetInteger(ltlID.Text, 0);
                    if (taskId > 0)
                    {
                        result += StagingHelper.RunSynchronization(taskId, serverId);
                    }
                }
            }

            if (result != "")
            {
                this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed");
            }
            else
            {
                this.lblInfo.Text = ResHelper.GetString("Tasks.SynchronizationOK");
            }
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed") + " " + ex.Message;
        }

        ReloadTasks();
    }


    protected void btnSyncSelected_Click(object sender, EventArgs e)
    {
        try
        {
            string result = "";
            foreach (GridViewRow row in gridTask.Rows)
            {
                // Get the checkbox status
                HtmlInputCheckBox chkSelect = (HtmlInputCheckBox)row.FindControl("chkSelect");
                if ((chkSelect != null) && (chkSelect.Checked))
                {
                    // Get ID
                    Literal ltlID = (Literal)row.FindControl("ltlID");
                    if (ltlID != null)
                    {
                        int taskId = ValidationHelper.GetInteger(ltlID.Text, 0);
                        if (taskId > 0)
                        {
                            result += StagingHelper.RunSynchronization(taskId, serverId);
                        }
                    }
                }
            }

            if (result != "")
            {
                this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed");
            }
            else
            {
                this.lblInfo.Text = ResHelper.GetString("Tasks.SynchronizationOK");
            }
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed") + " " + ex.Message;
        }

        ReloadTasks();
    }


    protected void btnDeleteAll_Click(object sender, EventArgs e)
    {
        // Process all records
        foreach (GridViewRow row in gridTask.Rows)
        {
            // Get ID
            Literal ltlID = (Literal)row.FindControl("ltlID");
            if (ltlID != null)
            {
                int taskId = ValidationHelper.GetInteger(ltlID.Text, 0);
                if (taskId > 0)
                {
                    SynchronizationInfoProvider.DeleteSynchronizationInfo(taskId, serverId);
                }
            }
        }

        this.lblInfo.Text = ResHelper.GetString("Tasks.DeleteOK");

        ReloadTasks();
    }


    protected void btnDeleteSelected_Click(object sender, EventArgs e)
    {
        foreach (GridViewRow row in gridTask.Rows)
        {
            // Get the checkbox status
            HtmlInputCheckBox chkSelect = (HtmlInputCheckBox)row.FindControl("chkSelect");
            if ((chkSelect != null) && (chkSelect.Checked))
            {
                // Get ID
                Literal ltlID = (Literal)row.FindControl("ltlID");
                if (ltlID != null)
                {
                    int taskId = ValidationHelper.GetInteger(ltlID.Text, 0);
                    if (taskId > 0)
                    {
                        SynchronizationInfoProvider.DeleteSynchronizationInfo(taskId, serverId);
                    }
                }
            }
        }

        this.lblInfo.Text = ResHelper.GetString("Tasks.DeleteOK");

        ReloadTasks();
    }


    protected void btnCurrent_Click(object sender, EventArgs e)
    {
        try
        {
            SynchronizeCurrent(true);
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed") + " " + ex.Message;
        }

    }


    /// <summary>
    /// Synchronizes the current document
    /// </summary>
    private string SynchronizeCurrent(bool finish)
    {
        int sid = serverId;
        if (sid <= 0)
        {
            sid = SynchronizationInfoProvider.ENABLED_SERVERS;
        }
        // Get the tasks
        ArrayList tasks = DocumentHelper.LogSynchronization(CMSContext.CurrentSite.SiteName, aliasPath, TaskTypeEnum.UpdateDocument, null, sid);

        string result = "";
        // Run the synchronization
        foreach (TaskInfo task in tasks)
        {
            result += StagingHelper.RunSynchronization(task.TaskID, serverId);
        }

        if (finish)
        {
            if (result != "")
            {
                this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed");
            }
            else
            {
                this.lblInfo.Text = ResHelper.GetString("Tasks.SynchronizationOK");
            }

            ReloadTasks();
        }

        return result;
    }


    protected void btnSubtree_Click(object sender, EventArgs e)
    {
        try
        {
            // Synchronize current node first
            string result = "";

            result += SynchronizeCurrent(false);

            if (result == "")
            {
                // Synchronize subnodes
                int sid = serverId;
                if (sid <= 0)
                {
                    sid = SynchronizationInfoProvider.ENABLED_SERVERS;
                }
                // Get the tasks
                ArrayList tasks = DocumentHelper.LogSynchronization(CMSContext.CurrentSite.SiteName, aliasPath.TrimEnd('/') + "/%", TaskTypeEnum.UpdateDocument, null, sid);

                // Run the synchronization
                foreach (TaskInfo task in tasks)
                {
                    result += StagingHelper.RunSynchronization(task.TaskID, serverId);
                }
            }

            if (result != "")
            {
                this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed");
            }
            else
            {
                this.lblInfo.Text = ResHelper.GetString("Tasks.SynchronizationOK");
            }
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("Tasks.SynchronizationFailed") + " " + ex.Message;
        }

        ReloadTasks();
    }


    protected override void OnPreRender(EventArgs e)
    {
        this.lblError.Visible = (this.lblError.Text != "");
        this.lblInfo.Visible = (this.lblInfo.Text != "");
        base.OnPreRender(e);
    }

}