using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.CMSHelper;
using CMS.GlobalHelper;

public partial class CMSEcommerce_MyAddresses : UserControl
{
    private int mCustomerId = 0;


    /// <summary>
    /// Customer ID.
    /// </summary>
    public int CustomerId
    {
        get { return mCustomerId; }
        set { mCustomerId = value; }
    }


    /// <summary>
    /// Address ID.
    /// </summary>
    private int AddressId
    {
        get { return ValidationHelper.GetInteger(ViewState["addressid"], 0); }
        set { ViewState["addressid"] = value; }
    }


    /// <summary>
    /// If true, control does not process the data
    /// </summary>
    public bool StopProcessing
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["StopProcessing"], false);
        }
        set
        {
            ViewState["StopProcessing"] = value;
            this.ucCountrySelector.StopProcessing = value;
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!StopProcessing)
        {
            InitControls();

            if (mCustomerId != 0)
            {
                BindData();
            }
        }
    }


    /// <summary>
    /// Control initialization.
    /// </summary>
    protected void InitControls()
    {
        // LIST
        gridAddresses.Columns[0].HeaderText = ResHelper.GetString("Unigrid.Actions");
        gridAddresses.Columns[1].HeaderText = ResHelper.GetString("Unigrid.Customer_Edit_Address.Columns.AddressName");

        btnNew.Text = ResHelper.GetString("Customer_Edit_Address_List.NewItemCaption");

        // EDIT
        rqvCity.ErrorMessage = ResHelper.GetString("Customer_Edit_Address_Edit.rqvCity");
        rqvLine.ErrorMessage = ResHelper.GetString("Customer_Edit_Address_Edit.rqvLine");
        rqvZipCode.ErrorMessage = ResHelper.GetString("Customer_Edit_Address_Edit.rqvZipCode");
        rqvPersonalName.ErrorMessage = ResHelper.GetString("Customer_Edit_Address_Edit.rqvPersonalName");

        // Label initialization
        lblAddressZip.Text = ResHelper.GetString("Customer_Edit_Address_Edit.AddressZipLabel");
        lblAddressDeliveryPhone.Text = ResHelper.GetString("Customer_Edit_Address_Edit.AddressDeliveryPhoneLabel");
        lblAddressCountry.Text = ResHelper.GetString("Customer_Edit_Address_Edit.AddressCountryIDLabel");
        lblAddressLine1.Text = ResHelper.GetString("Customer_Edit_Address_Edit.AddressLine1Label");
        lblAddressCity.Text = ResHelper.GetString("Customer_Edit_Address_Edit.AddressCityLabel");
        lblPersonalName.Text = ResHelper.GetString("Customer_Edit_Address_Edit.lblPersonalName");

        btnOK.Text = ResHelper.GetString("General.OK");
        btnList.Text = ResHelper.GetString("Customer_Edit_Address_Edit.ItemListLink");
    }


    /// <summary>
    /// On row data bound, set row action buttons text and "OnClientClick" actions.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void gridAddresses_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.RowType == DataControlRowType.DataRow)
        {
            // Find delete button and set it's text and onclientclick action
            LinkButton btnDelete = (LinkButton)e.Row.FindControl("btnDelete");
            if (btnDelete != null)
            {
                btnDelete.OnClientClick = "return confirm('" + ResHelper.GetString("Unigrid.Customer_Edit_Address.Actions.Delete.Confirmation") + "');";
                btnDelete.Text = ResHelper.GetString("Unigrid.Customer_Edit_Address.Actions.Delete");
            }
            // Find edit button and set it's text
            LinkButton btnEdit = (LinkButton)e.Row.FindControl("btnEdit");
            if (btnEdit != null)
            {
                btnEdit.Text = ResHelper.GetString("Unigrid.Customer_Edit_Address.Actions.Edit");
            }
        }
    }


    /// <summary>
    /// Bind data to gridview.
    /// </summary>
    protected void BindData()
    {
        // Get customer's addresses
        DataSet ds = AddressInfoProvider.GetAddressesForCustomer(mCustomerId, true, true, true);
        
        gridAddresses.DataSource = ds;
        gridAddresses.DataBind();
    }


    /// <summary>
    /// On btnNew click, go to empty form to create new address.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnNew_OnClick(object sender, EventArgs e)
    {
        plhList.Visible = false;
        plhEdit.Visible = true;

        AddressId = 0;

        InitData();
    }


    /// <summary>
    /// New address form initialization.
    /// </summary>
    protected void InitData()
    {
        lblAddress.Text = "> " + ResHelper.GetString("Customer_Edit_Address_Edit.NewItemCaption");
        // Fill default values
        CustomerInfo ci = CustomerInfoProvider.GetCustomerInfo(mCustomerId);
        if (ci != null)
        {
            txtAddressDeliveryPhone.Text = ci.CustomerPhone;
            txtPersonalName.Text = ci.CustomerFirstName + " " + ci.CustomerLastName;

            txtAddressZip.Text = "";
            txtAddressLine1.Text = "";
            txtAddressLine2.Text = "";
            txtAddressCity.Text = "";
            ucCountrySelector.CountryID = ci.CustomerCountryID;
            ucCountrySelector.StateID = ci.CustomerStateID;
        }
    }


    /// <summary>
    /// On gridAddresses row command, delete or edit selected address.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void gridAddresses_RowCommand(object sender, GridViewCommandEventArgs e)
    {
        // Get AddressId from the row
        AddressId = ValidationHelper.GetInteger(e.CommandArgument, 0);
        
        // Delete selected address
        if (e.CommandName == "Del")
        {
            // Check for the address dependences
            DataSet ds = OrderInfoProvider.GetOrders("OrderBillingAddressID=" + AddressId + " OR OrderShippingAddressID=" + AddressId, null);
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                BindData();

                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Ecommerce.DeleteDisabled");
                return;
            }

            // Delete AddressInfo object from database
            AddressInfoProvider.DeleteAddressInfo(AddressId);
            BindData();
        }
        // Edit selected address
        else if (e.CommandName == "Change")
        {
            plhList.Visible = false;
            plhEdit.Visible = true;

            AddressInfo ai = AddressInfoProvider.GetAddressInfo(AddressId);

            if (ai != null)
            {
                LoadData(ai);
            }
        }
    }


    /// <summary>
    /// Load address data into editing form.
    /// </summary>
    /// <param name="addressObj">AddressInfo object.</param>
    protected void LoadData(AddressInfo addressObj)
    {
        lblAddress.Text = "> " + addressObj.AddressName;

        txtAddressZip.Text = addressObj.AddressZip;
        txtAddressDeliveryPhone.Text = addressObj.AddressPhone;
        txtPersonalName.Text = addressObj.AddressPersonalName;
        txtAddressLine1.Text = addressObj.AddressLine1;
        txtAddressLine2.Text = addressObj.AddressLine2;
        txtAddressCity.Text = addressObj.AddressCity;

        ucCountrySelector.CountryID = addressObj.AddressCountryID;
        ucCountrySelector.StateID = addressObj.AddressStateID;
    }


    /// <summary>
    /// On btnList click, return to address list.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnList_OnClick(object sender, EventArgs e)
    {
        plhList.Visible = true;
        plhEdit.Visible = false;
        // Bind data to gridview
        BindData();
    }


    /// <summary>
    /// On btnOK click, save edited or new created address.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_OnClick(object sender, EventArgs e)
    {
        if (mCustomerId != 0)
        {
            // Check field emptiness
            string errorMessage = new Validator().NotEmpty(txtAddressLine1.Text, "Customer_Edit_Address_Edit.rqvLine").NotEmpty(txtAddressCity.Text, "Customer_Edit_Address_Edit.rqvCity").NotEmpty(txtAddressZip.Text, "Customer_Edit_Address_Edit.rqvZipCode").NotEmpty(txtPersonalName.Text, "Customer_Edit_Address_Edit.rqvPersonalName").Result;

            if (errorMessage == "")
            {
                AddressInfo ai = null;
                // Create new addressinfo or get the existing one
                if (AddressId == 0)
                {
                    ai = new AddressInfo();
                    ai.AddressEnabled = true;
                    ai.AddressIsBilling = true;
                    ai.AddressIsShipping = true;
                    ai.AddressCustomerID = mCustomerId;
                }
                else
                {
                    ai = AddressInfoProvider.GetAddressInfo(AddressId);
                }

                ai.AddressPersonalName = txtPersonalName.Text;
                ai.AddressLine1 = txtAddressLine1.Text;
                ai.AddressLine2 = txtAddressLine2.Text;
                ai.AddressCity = txtAddressCity.Text;
                ai.AddressZip = txtAddressZip.Text;
                ai.AddressCountryID = ucCountrySelector.CountryID;
                ai.AddressStateID = ucCountrySelector.StateID;
                ai.AddressPhone = txtAddressDeliveryPhone.Text;
                ai.AddressName = AddressInfoProvider.GetAddressName(ai);
                // Save addressinfo
                AddressInfoProvider.SetAddressInfo(ai);
                AddressId = ai.AddressID;

                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                lblAddress.Text = "> " + ai.AddressName;
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = errorMessage;
            }
        }
    }
}