using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSEcommerce_MyOrders : UserControl
{
    private int mCustomerId = 0;

    /// <summary>
    /// Customer ID.
    /// </summary>
    public int CustomerId
    {
        get { return mCustomerId; }
        set { mCustomerId = value; }
    }
    

    /// <summary>
    /// If true, control does not process the data
    /// </summary>
    public bool StopProcessing
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["StopProcessing"], false);
        }
        set
        {
            ViewState["StopProcessing"] = value;
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!StopProcessing)
        {
            gridOrders.Columns[0].HeaderText = ResHelper.GetString("MyOrders.OrderID");
            gridOrders.Columns[1].HeaderText = ResHelper.GetString("MyOrders.OrderDate");
            gridOrders.Columns[2].HeaderText = ResHelper.GetString("MyOrders.TotalPrice");
            gridOrders.Columns[3].HeaderText = ResHelper.GetString("MyOrders.Status");
            gridOrders.Columns[4].HeaderText = ResHelper.GetString("MyOrders.Invoice");

            if (mCustomerId != 0)
            {
                if (!IsPostBack)
                {
                    // Get customer's orders
                    DataSet ds = OrderInfoProvider.GetOrderList("CustomerID=" + mCustomerId, "OrderDate DESC");
                    if (!DataHelper.DataSourceIsEmpty(ds))
                    {
                        gridOrders.DataSource = ds;
                        gridOrders.DataBind();
                    }
                }
            }
        }
    }


    /// <summary>
    /// On row data bound.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void gridOrders_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.DataItem != null)
        {
            // Get the data from "OrderID" and "OrderInvoiceNumber" columns
            int orderId = ValidationHelper.GetInteger(((DataRowView)(e.Row.DataItem))["OrderID"], 0);
            string invoiceNumber = ValidationHelper.GetString(((DataRowView)(e.Row.DataItem))["OrderInvoiceNumber"], "");
            
            if ((invoiceNumber.Trim() != "") && (orderId != 0))
            {
                // Paste link
                HyperLink lnkInvoice = (HyperLink)e.Row.FindControl("lnkInvoice");
                if (lnkInvoice != null)
                {
                    lnkInvoice.Text = ResHelper.GetString("MyOrders.GetInvoice") + " " + invoiceNumber;
                    lnkInvoice.NavigateUrl = "~/CMSEcommerce/GetInvoice.aspx?orderid=" + orderId;
                }
            }

            // Get label control from the 3rd column
            Label lblTotalPrice = (Label)e.Row.FindControl("lblTotalPrice");
            if (lblTotalPrice != null)
            {
                DataRowView data = (DataRowView)e.Row.DataItem;
                // Format total price value
                lblTotalPrice.Text = String.Format(data.Row["CurrencyFormatString"].ToString(), data.Row["OrderTotalPrice"]);
            }
        }
    }
}