using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.EmailEngine;
using CMS.URLRewritingEngine;
using CMS.WebAnalytics;

public partial class CMSEcommerce_ShoppingCartControl : UserControl
{
    private string[] mStepFiles = null;
    private bool mReloadShoppingCart = false;
    private ShoppingCartStep mCurrentStepControl;
    private string mRedirectAfterPurchase = "";
    private bool mIsCreatedFromOrder = false;
    private ShoppingCartInfo mLocalShoppingCart = null;
    private ShoppingCartInfo mShoppingCartObj = null;
    private bool mPasswordRetrieval = false;
    private string mRegistrationTrackConversionName = "";
    private string mOrderTrackConversionName = "";

    #region "Public properties"

    /// <summary>
    /// Shopping cart current step index.
    /// </summary>
    public int CurrentStepIndex
    {
        get
        {
            object obj = ViewState["CurrentStepIndex"];
            return (obj == null) ? 0 : Convert.ToInt32(obj);
        }
        set
        {
            ViewState["CurrentStepIndex"] = value;
        }
    }


    /// <summary>
    /// Shopping cart current step control.
    /// </summary>
    public ShoppingCartStep CurrentStepControl
    {
        get
        {
            return mCurrentStepControl;
        }
        set
        {
            mCurrentStepControl = value;
        }
    }


    /// <summary>
    /// Indicates whether shopping cart should be reloaded from database.
    /// </summary>
    public bool ReloadShoppingCart
    {
        get
        {
            return mReloadShoppingCart;
        }
        set
        {
            mReloadShoppingCart = value;
        }
    }


    /// <summary>
    /// Shopping cart step files.
    /// </summary>
    public string[] StepFiles
    {
        get
        {
            return mStepFiles;
        }
        set
        {
            mStepFiles = value;
        }

    }


    /// <summary>
    /// Indicates whether shopping cart is created from order info or not.
    /// </summary>
    public bool IsShoppingCartCreatedFromOrder
    {
        get
        {
            return mIsCreatedFromOrder;
        }
        set
        {
            mIsCreatedFromOrder = value;
        }
    }


    /// <summary>
    /// Redirect after purchase
    /// </summary>
    public string RedirectAfterPurchase
    {
        get
        {
            return mRedirectAfterPurchase;
        }
        set
        {
            mRedirectAfterPurchase = value;
        }
    }


    /// <summary>
    /// Local shopping cart object
    /// </summary>
    public ShoppingCartInfo LocalShoppingCart
    {
        get
        {
            return mLocalShoppingCart;
        }
        set
        {
            mLocalShoppingCart = value;
        }
    }


    /// <summary>
    /// User info
    /// </summary>
    public UserInfo UserInfo
    {
        get
        {
            ShoppingCartInfo currentCart = this.ShoppingCartInfoObj;
            if ((currentCart == null) || (currentCart.UserInfoObj == null))
            {
                return CMSContext.CurrentUser;
            }
            else
            {
                return currentCart.UserInfoObj;
            }
        }
    }


    /// <summary>
    /// True if password retrieval is enabled.
    /// </summary>
    public bool PasswordRetrieval
    {
        get
        {
            return mPasswordRetrieval;
        }
        set
        {
            mPasswordRetrieval = value;
        }
    }


    /// <summary>
    /// Conversion track name used after successful registration.
    /// </summary>
    public string RegistrationTrackConversionName
    {
        get
        {
            return mRegistrationTrackConversionName;
        }
        set
        {
            mRegistrationTrackConversionName = value;
        }
    }


    /// <summary>
    /// Conversion track name used after successful order.
    /// </summary>
    public string OrderTrackConversionName
    {
        get
        {
            return mOrderTrackConversionName;
        }
        set
        {
            mOrderTrackConversionName = value;
        }
    }

    #endregion;


    /// <summary>
    /// Page url, we should return to after "Continue shopping" button is clicked.
    /// </summary>
    private string PreviousPageUrl
    {
        get
        {
            object obj = ViewState["PreviousPageUrl"];
            return (obj != null) ? (string)obj : "~/";
        }
        set
        {
            ViewState["PreviousPageUrl"] = value;
        }
    }


    /// <summary>
    /// Shopping cart info object
    /// </summary>
    private ShoppingCartInfo ShoppingCartInfoObj
    {
        get
        {
            if (mLocalShoppingCart == null)
            {
                if (mShoppingCartObj == null)
                {
                    mShoppingCartObj = CMSContext.CurrentShoppingCart;
                }

                if ((CMSContext.CurrentSite != null) && (mShoppingCartObj != null))
                {
                    mShoppingCartObj.SiteName = CMSContext.CurrentSite.SiteName;
                }
                return mShoppingCartObj;
            }
            else
            {
                if ((CMSContext.CurrentSite != null) && (mLocalShoppingCart != null))
                {
                    mLocalShoppingCart.SiteName = CMSContext.CurrentSite.SiteName;
                }
                return mLocalShoppingCart;
            }
        }
        set
        {
            if (mLocalShoppingCart == null)
            {
                mShoppingCartObj = value;
                CMSContext.CurrentShoppingCart = value;
            }
            else
            {
                mLocalShoppingCart = value;
            }
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {

        // if shopping cart doesnt exist create new one
        if (ShoppingCartInfoObj == null)
        {
            CreateEmptyShoppingCartInfo();
        }
        // if shopping cart object is already created and should be reloaded
        else if (ReloadShoppingCart)
        {
            ReloadShoppingCartInfo(ShoppingCartInfoObj.ShoppingCartGUID);
        }

        LoadCurrentStep((CurrentStepIndex == 0) && (!this.IsPostBack));

        if (!this.IsPostBack && (Request.UrlReferrer != null))
        {
            string path = UrlHelper.GetAppRelativePath(Request.UrlReferrer);
            if (!UrlHelper.IsExcludedSystem(path))
            {
                PreviousPageUrl = Request.UrlReferrer.AbsoluteUri;
            }
        }
    }


    /// <summary>
    /// On page pre-render event.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Prerender(object sender, EventArgs e)
    {
        plcCartStep.GroupingText = String.Format(ResHelper.GetString("Order_New.CurrentStep"), CurrentStepIndex + 1, mStepFiles.Length) + " - " + CurrentStepControl.TitleText;
    }


    /// <summary>
    /// Back button clicked.
    /// </summary>
    protected void btnBack_Click(object sender, EventArgs e)
    {
        if (CurrentStepIndex > 0)
        {
            if (CurrentStepControl.PreviousStepIndex >= 0)
            {
                CurrentStepIndex = CurrentStepControl.PreviousStepIndex;
                LoadCurrentStep(true);
            }
        }
        else if ((this.mLocalShoppingCart == null) && (CurrentStepIndex == 0))
        {
            Response.Redirect(this.PreviousPageUrl);
        }
    }

    /// <summary>
    /// Next button clicked.
    /// </summary>
    protected void btnNext_Click(object sender, EventArgs e)
    {
        // Validate current step
        if (CurrentStepControl.IsValid())
        {
            // Process information from the curent step
            if (CurrentStepControl.ProcessStep())
            {
                if (CurrentStepIndex < mStepFiles.Length - 1)
                {
                    if (CurrentStepControl.NextStepIndex <= mStepFiles.Length - 1)
                    {
                        CurrentStepIndex = CurrentStepControl.NextStepIndex;
                        LoadCurrentStep(true);
                    }
                }
                // redirect after order is finished
                else if (CurrentStepIndex == mStepFiles.Length - 1)
                {

                    // Actualize products' data from database
                    ShoppingCartInfoObj.CartItems = ShoppingCartInfoProvider.GetSKUInfoListFromShoppingCart(ShoppingCartInfoObj.ShoppingCartID);

                    // Actualize product available units after purchase                    
                    foreach (SKUInfo skuObj in ShoppingCartInfoObj.CartItems)
                    {
                        skuObj.SKUAvailableItems -= skuObj.SKUUnits;

                        if (skuObj.SKUAvailableItems < 0)
                        {
                            skuObj.SKUAvailableItems = 0;
                        }

                        SKUInfoProvider.SetSKUInfo(skuObj);
                    }

                    if (this.IsShoppingCartCreatedFromOrder)
                    {
                        ShoppingCartInfoObj.ReloadOrderSKUItems();
                    }
                    else 
                    {
                        //save order data to history
                        SaveOrderDataToHistory();
                    }

                    // Order made on the live site, set redirection URL
                    if (this.mLocalShoppingCart == null)
                    {
                        string redirectUrl = PaymentOptionInfoProvider.GetPaymentURL(this.ShoppingCartInfoObj);

                        if ((redirectUrl == null) || (redirectUrl == ""))
                        {
                            redirectUrl = CMSContext.GetUrl(this.RedirectAfterPurchase);
                        }

                        this.RedirectAfterPurchase = redirectUrl;
                    }

                    OrderInfoProvider.SendOrderNotificationToAdministrator(this.ShoppingCartInfoObj);
                    OrderInfoProvider.SendOrderNotificationToCustomer(this.ShoppingCartInfoObj);

                    // Delete shopping cart info (including all items) from database
                    ShoppingCartInfoProvider.DeleteShoppingCartInfo(ShoppingCartInfoObj.ShoppingCartID);

                    if (!IsShoppingCartCreatedFromOrder)
                    {
                        // Raise finish order event
                        if (OnFinishOrder != null)
                        {
                            OnFinishOrder(this, new EventArgs());
                        }
                        // Track successful order conversion
                        if (this.OrderTrackConversionName != string.Empty)
                        {
                            string siteName = CMSContext.CurrentSite.SiteName;

                            if (AnalyticsHelper.AnalyticsEnabled(siteName) && !AnalyticsHelper.IsIPExcluded(siteName, HttpContext.Current.Request.UserHostAddress))
                            {
                                string objectName = new ContextResolver().ResolveMacros(this.OrderTrackConversionName);
                                HitLogProvider.LogHit("conversion", siteName, CMSContext.CurrentUser.PreferredCultureCode, objectName, 0);
                            }
                        }
                    }

                    // Drop the shopping cart
                    this.ShoppingCartInfoObj = null;

                    if (this.RedirectAfterPurchase != "")
                    {
                        Response.Redirect(this.RedirectAfterPurchase);
                    }
                }
            }
        }
    }


    private void SaveOrderDataToHistory()
    {
        ShoppingCartInfo currentCart = this.ShoppingCartInfoObj;
        if (currentCart != null)
        {
            OrderStatusInfo orderStatus = OrderStatusInfoProvider.GetFirstEnabledStatus();
            if (orderStatus != null)
            {
                OrderStatusUserInfo orderStatusUser = new OrderStatusUserInfo();
                orderStatusUser.ChangedByUserID = 0;
                if (this.CurrentStepControl.IsInternalOrder)
                {
                    orderStatusUser.ChangedByUserID = CMSContext.CurrentUser.UserID;
                }
                else if (!this.UserInfo.IsPublic())
                {
                    orderStatusUser.ChangedByUserID = this.UserInfo.UserID;
                }                
                orderStatusUser.Date = DateTime.Now;
                orderStatusUser.FromStatusID = 0;
                orderStatusUser.Note = currentCart.ShoppingCartNote;
                orderStatusUser.OrderID = currentCart.OrderId;
                orderStatusUser.ToStatusID = orderStatus.StatusID;
                OrderStatusUserInfoProvider.SetOrderStatusUserInfo(orderStatusUser);
            }
        }
        else
        {
            return;
        }
    }


    /// <summary>
    /// Load control representing specified step.
    /// </summary>   
    /// <param name="loadStepInfo">Indicates whether step info should be loaded from the shopping cart info object.</param>
    protected void LoadCurrentStep(bool loadStepInfo)
    {
        if (mStepFiles != null)
        {
            if ((CurrentStepIndex >= 0) && (CurrentStepIndex <= mStepFiles.Length - 1))
            {
                // button settings
                btnBack.Visible = true;
                btnNext.Visible = true;
                btnBack.Text = ResHelper.GetString("Ecommerce.ShoppingCart.BackButtonText");
                btnNext.Text = ResHelper.GetString("Ecommerce.ShoppingCart.NextButtonText");
                btnBack.CssClass = "ContentButton";

                pnlCartStepInner.Controls.Clear();
                CurrentStepControl = (ShoppingCartStep)LoadControl(mStepFiles[CurrentStepIndex]);
                CurrentStepControl.IsInternalOrder = (this.mLocalShoppingCart != null);
                CurrentStepControl.IsShoppingCartCreatedFromOrder = this.IsShoppingCartCreatedFromOrder;
                CurrentStepControl.CurrentStepIndex = CurrentStepIndex;
                CurrentStepControl.ShoppingCartInfoObj = ShoppingCartInfoObj;
                CurrentStepControl.ID = "wzdStep" + CurrentStepIndex;
                CurrentStepControl.LoadStepInfo = loadStepInfo;
                CurrentStepControl.PasswordRetrieval = this.PasswordRetrieval;
                CurrentStepControl.RegistrationTrackConversionName = this.RegistrationTrackConversionName;

                // default button setting
                CurrentStepControl.ButtonBack = btnBack;
                CurrentStepControl.ButtonNext = btnNext;

                pnlCartStepInner.Controls.Add(CurrentStepControl);
            }
        }
    }


    /// <summary>
    /// Reloads shopping cart items and settings from database.
    /// </summary>
    /// <param name="cartGuid">GUID of the shopping cart to be reloaded.</param>
    protected void ReloadShoppingCartInfo(Guid cartGuid)
    {

        ShoppingCartInfoObj = ShoppingCartInfoProvider.GetShoppingCartInfo(cartGuid);

        // if shopping cart is not in database -> create empty one
        if (ShoppingCartInfoObj == null)
        {
            CreateEmptyShoppingCartInfo();
        }
    }


    /// <summary>
    /// Creates new empty shopping cart object and saves coresponding cookie.
    /// </summary>
    protected void CreateEmptyShoppingCartInfo()
    {
        if (CMSContext.CurrentSite != null)
        {
            this.ShoppingCartInfoObj = new ShoppingCartInfo(CMSContext.CurrentSite.SiteID);
        }
    }


    /// <summary>
    /// Finish order event
    /// </summary>
    public event EventHandler OnFinishOrder;

}