using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.Ecommerce;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.DataEngine;
using CMS.EmailEngine;
using CMS.EventLog;
using CMS.WebAnalytics;

public partial class CMSEcommerce_ShoppingCartCheckRegistration : ShoppingCartStep
{
    private bool mDataLoaded = false;

    /// <summary>
    /// '0' for Sign in using existing account.
    /// '1' for Create a new account.
    /// '2' for Continue as anonymous customer.
    /// </summary>
    public ShopingCartModeEnum RegistrationMode
    {
        get
        {
            if (radSignIn.Checked)
            {
                return ShopingCartModeEnum.ExistingAccount;
            }
            else if (radNewReg.Checked)
            {
                return ShopingCartModeEnum.NewAccount;
            }
            else
            {
                return ShopingCartModeEnum.AnonymousCustomer;
            }
        }
    }

    private bool mShowTaxRegistrationIDField = false;
    private bool mShowOrganizationIDField = false;

    /// <summary>
    /// On page load.
    /// </summary>
    protected void Page_Load(object sender, EventArgs e)
    {
        SiteInfo si = CMSContext.CurrentSite;
        if (si != null)
        {
            this.mShowOrganizationIDField = si.SiteShowOrganizationID;
            this.mShowTaxRegistrationIDField = si.SiteShowTaxRegistrationID;
        }

        this.PreRender += new EventHandler(CMSEcommerce_ShoppingCartCheckRegistration_PreRender);
        InitializeLabels();

        LoadStep(false);
    }


    void CMSEcommerce_ShoppingCartCheckRegistration_PreRender(object sender, EventArgs e)
    {
        if (!this.mDataLoaded)
        {
            LoadData();
        }
    }


    protected void LoadData()
    {
        this.mDataLoaded = true;
        // If user ID specified, load the given user ID
        if (!this.UserInfo.IsPublic())
        {
            // Get the customer data
            CustomerInfo ci = CustomerInfoProvider.GetCustomerInfoByUserId(this.UserInfo.UserID);

            // Set the fields
            if (ci != null)
            {
                this.txtEditCompany.Text = ci.CustomerCompany;
                this.txtEditEmail.Text = ci.CustomerEmail;
                this.txtEditFirst.Text = ci.CustomerFirstName;
                this.txtEditLast.Text = ci.CustomerLastName;
                this.txtEditOrgID.Text = ci.CustomerOrganizationID;
                this.txtEditTaxRegID.Text = ci.CustomerTaxRegistrationID;
            }
        }
    }


    protected void LoadStep(bool loadData)
    {
        // If user logged in, edit the customer data
        if (!this.UserInfo.IsPublic())
        {
            this.plcEditCustomer.Visible = true;
            this.plcEditOrgID.Visible = mShowOrganizationIDField;
            this.plcEditTaxRegID.Visible = mShowTaxRegistrationIDField;
            this.plcAccount.Visible = false;
            this.lblTitle.Text = ResHelper.GetString("ShoppingCart.CheckRegistrationEdit");

            if (loadData)
            {
                LoadData();
            }
        }
        else
        {
            // Display/Hide the form for anonymous customer
            if (CMSContext.CurrentSite != null)
            {
                plhAnonymous.Visible = CMSContext.CurrentSite.SiteStoreAllowAnonymousCustomers;
            }

            if (!IsPostBack)
            {
                // Enable 'Sign in' section
                AvailabilityOfSignInSection(true);
                // Disable 'New registration' section
                AvailabilityOfNewRegistrationSection(false);
                // Disable 'Continue as anonymous customer' section
                AvailabilityOfAnonymousSection(false);
            }

            this.plcEditCustomer.Visible = false;
            this.plcAccount.Visible = true;

            this.plcTaxRegistrationID.Visible = this.mShowTaxRegistrationIDField;
            this.plcOrganizationID.Visible = this.mShowOrganizationIDField;

            this.plcTaxRegistrationID2.Visible = this.mShowTaxRegistrationIDField;
            this.plcOrganizationID2.Visible = this.mShowOrganizationIDField;

            this.lblTitle.Text = ResHelper.GetString("ShoppingCart.CheckRegistration");


            // Set strings
            lnkPasswdRetrieval.Text = ResHelper.GetString("LogonForm.lnkPasswordRetrieval");
            lblPasswdRetrieval.Text = ResHelper.GetString("LogonForm.lblPasswordRetrieval");
            btnPasswdRetrieval.Text = ResHelper.GetString("LogonForm.btnPasswordRetrieval");
            rqValue.ErrorMessage = ResHelper.GetString("LogonForm.rqValue");

            this.ltlScript.Text = ScriptHelper.GetScript("function ShowPasswdRetrieve(id){style=document.getElementById(id).style;style.display=(style.display == 'block')?'none':'block';return false;}");
            this.lnkPasswdRetrieval.Attributes.Add("onclick", "return ShowPasswdRetrieve('" + pnlPasswdRetrieval.ClientID + "');");

            this.lnkPasswdRetrieval.Visible = this.PasswordRetrieval;
            btnPasswdRetrieval.Click += new EventHandler(btnPasswdRetrieval_Click);

            this.pnlPasswdRetrieval.Attributes.Add("style", "display:none;");
        }

        this.TitleText = ResHelper.GetString("Order_new.ShoppingCartCheckRegistration.Title");
    }

    // Retrieve the user password
    void btnPasswdRetrieval_Click(object sender, EventArgs e)
    {
        string value = txtPasswordRetrieval.Text.Trim();
        if (value != "")
        {
            object[,] parameters = new object[1, 3];
            parameters[0, 0] = "User";
            parameters[0, 1] = txtPasswordRetrieval.Text.Trim();

            GeneralConnection conn = ConnectionHelper.GetConnection();
            DataSet ds = conn.ExecuteQuery("cms.user.selectuserbynameoremail", parameters);

            // User exists, send email with password
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                SiteInfo currentSite = CMSContext.CurrentSite;
                if (currentSite != null)
                {
                    // Get user info
                    UserInfo user = new UserInfo(ds.Tables[0].Rows[0], null, null);

                    // Quit if user do not have an email
                    if (user.Email == null || user.Email == "")
                    {
                        lblResult.Text = ResHelper.GetString("LogonForm.NoEmail");
                        this.pnlPasswdRetrieval.Attributes.Add("style", "display:block;");
                        lblResult.Visible = true;
                        return;
                    }

                    // Send password
                    EmailTemplateInfo emailTemplate = EmailTemplateProvider.GetEmailTemplate("forgottenPassword", currentSite.SiteName);

                    if (emailTemplate != null)
                    {
                        EmailMessage message = new EmailMessage();
                        message.From = currentSite.SiteSendStoreEmailsFrom;
                        message.Subject = ResHelper.GetString("LogonForm.ForgottenPasswordSubject");
                        message.Recipients = user.Email;
                        message.EmailFormat = EmailFormatEnum.Html;

                        string newPassword = UserInfoProvider.GenerateNewPassword();

                        // Macros
                        string[,] macros = new string[3, 2];
                        macros[0, 0] = "LogonUrl";
                        macros[0, 1] = HttpContext.Current.Request.UrlReferrer.AbsoluteUri;
                        macros[1, 0] = "UserName";
                        macros[1, 1] = user.UserName;
                        macros[2, 0] = "Password";
                        macros[2, 1] = newPassword;

                        // Set new password
                        UserInfoProvider.SetPassword(user.UserName, newPassword);
                        try
                        {
                            // Send email
                            EmailSender.SendEmailWithTemplateText(currentSite.SiteName, message, emailTemplate.TemplateText, macros);
                        }
                        catch (Exception ex)
                        {
                            try
                            {
                                EventLogProvider eventLog = new EventLogProvider();
                                eventLog.LogEvent("Password retrieval", "ECOMMERCE", ex);
                            }
                            catch
                            {
                                // Unable to log the event
                            }
                        }
                    }

                    lblResult.Text = ResHelper.GetString("LogonForm.PasswordSent");
                }
                //this.pnlPasswdRetrieval.Attributes.Add("style", "display:none;");
            }
            // Wrong username or email, inform user
            else
            {
                lblResult.Text = ResHelper.GetString("LogonForm.NoUser");
            }
            lblResult.Visible = true;
            this.pnlPasswdRetrieval.Attributes.Add("style", "display:block;");
        }
    }

    /// <summary>
    /// Initialization of labels.
    /// </summary>
    protected void InitializeLabels()
    {
        radSignIn.Text = ResHelper.GetString("ShoppingCartCheckRegistration.SignIn");
        lblUsername.Text = ResHelper.GetString("ShoppingCartCheckRegistration.Username");
        lblPsswd1.Text = ResHelper.GetString("ShoppingCartCheckRegistration.Psswd");
        radNewReg.Text = ResHelper.GetString("ShoppingCartCheckRegistration.NewReg");
        lblFirstName1.Text = ResHelper.GetString("ShoppingCartCheckRegistration.FirstName");
        lblLastName1.Text = ResHelper.GetString("ShoppingCartCheckRegistration.LastName");
        lblEmail2.Text = ResHelper.GetString("ShoppingCartCheckRegistration.EmailUsername");
        lblPsswd2.Text = lblPsswd1.Text;
        lblConfirmPsswd.Text = ResHelper.GetString("ShoppingCartCheckRegistration.ConfirmPsswd");
        lblCompany1.Text = ResHelper.GetString("ShoppingCartCheckRegistration.Company");
        radAnonymous.Text = ResHelper.GetString("ShoppingCartCheckRegistration.Anonymous");
        lblFirstName2.Text = lblFirstName1.Text;
        lblLastName2.Text = lblLastName1.Text;
        lblEmail3.Text = ResHelper.GetString("ShoppingCartCheckRegistration.Email");
        lblCompany2.Text = lblCompany1.Text;

        lblEditFirst.Text = lblFirstName1.Text;
        lblEditLast.Text = lblLastName1.Text;
        lblEditEmail.Text = lblEmail2.Text;
        lblEditCompany.Text = lblCompany1.Text;

        lblTaxRegistrationID.Text = ResHelper.GetString("ShoppingCartCheckRegistration.lblTaxRegistrationID");
        lblEditTaxRegID.Text = lblTaxRegistrationID.Text;
        lblTaxRegistrationID2.Text = lblTaxRegistrationID.Text;

        lblOrganizationID.Text = ResHelper.GetString("ShoppingCartCheckRegistration.lblOrganizationID");
        lblEditOrgID.Text = lblOrganizationID.Text;
        lblOrganizationID2.Text = lblOrganizationID.Text;

    }


    /// <summary>
    /// On radSingIn radiobutton checked changed.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void radSignIn_CheckedChanged(object sender, EventArgs e)
    {
        // Enable 'Sign in' section
        AvailabilityOfSignInSection(true);
        // Disable 'New registration' section
        AvailabilityOfNewRegistrationSection(false);
        // Disable 'Continue as anonymous customer' section
        AvailabilityOfAnonymousSection(false);
    }


    /// <summary>
    /// On radNewReg radiobutton checked changed.
    /// </summary>
    protected void radNewReg_CheckedChanged(object sender, EventArgs e)
    {
        // Disable 'Sign in' section
        AvailabilityOfSignInSection(false);
        // Enable 'New registration' section
        AvailabilityOfNewRegistrationSection(true);
        // Disable 'Continue as anonymous custome' section
        AvailabilityOfAnonymousSection(false);
    }


    /// <summary>
    /// On radAnonymous radiobutton checked changed.
    /// </summary>
    protected void radAnonymous_CheckedChanged(object sender, EventArgs e)
    {
        // Disable 'Sign in' section
        AvailabilityOfSignInSection(false);
        // Disable 'New registration' section
        AvailabilityOfNewRegistrationSection(false);
        // Enable 'Continue as anonymous custome' section
        AvailabilityOfAnonymousSection(true);
    }


    /// <summary>
    /// Clean and change availability of 'Sign in' section textboxes.
    /// </summary>
    /// <param name="availability"></param>
    protected void AvailabilityOfSignInSection(bool availability)
    {
        txtUsername.Text = "";
        txtUsername.Enabled = availability;
        txtPsswd1.Text = "";
        txtPsswd1.Enabled = availability;
    }


    /// <summary>
    /// Clean and change availability of 'New registration' section textboxes. 
    /// </summary>
    /// <param name="availability"></param>
    protected void AvailabilityOfNewRegistrationSection(bool availability)
    {
        txtFirstName1.Text = "";
        txtFirstName1.Enabled = availability;
        txtLastName1.Text = "";
        txtLastName1.Enabled = availability;
        txtEmail2.Text = "";
        txtEmail2.Enabled = availability;
        txtPsswd2.Text = "";
        txtPsswd2.Enabled = availability;
        txtConfirmPsswd.Text = "";
        txtConfirmPsswd.Enabled = availability;
        txtCompany1.Text = "";
        txtCompany1.Enabled = availability;
        txtOrganizationID.Text = "";
        txtOrganizationID.Enabled = availability;
        txtTaxRegistrationID.Text = "";
        txtTaxRegistrationID.Enabled = availability;
    }


    /// <summary>
    /// Clean and change availability of 'Continue as anonymous customer' section textboxes.
    /// </summary>
    /// <param name="availability"></param>
    protected void AvailabilityOfAnonymousSection(bool availability)
    {
        txtFirstName2.Text = "";
        txtFirstName2.Enabled = availability;
        txtLastName2.Text = "";
        txtLastName2.Enabled = availability;
        txtEmail3.Text = "";
        txtEmail3.Enabled = availability;
        txtCompany2.Text = "";
        txtCompany2.Enabled = availability;
        txtOrganizationID2.Text = "";
        txtOrganizationID2.Enabled = availability;
        txtTaxRegistrationID2.Text = "";
        txtTaxRegistrationID2.Enabled = availability;
    }


    /// <summary>
    /// Validate values in textboxes.
    /// </summary>
    /// <returns></returns>
    public override bool IsValid()
    {
        Validator val = new Validator();
        string result = null;

        if (this.plcAccount.Visible)
        {
            // Validate registration data
            if (radSignIn.Checked)
            {
                result = val.NotEmpty(txtUsername.Text, ResHelper.GetString("ShoppingCartCheckRegistration.ErrorMissingUsername")).Result;
                if ((result != null) && (result != ""))
                {
                    lblError.Text = result;
                    lblError.Visible = true;
                    return false;
                }
            }
            // Check 'New registration' section
            else if (radNewReg.Checked)
            {
                result = val.NotEmpty(txtFirstName1.Text, ResHelper.GetString("ShoppingCartCheckRegistration.FirstNameErr"))
                    .NotEmpty(txtLastName1.Text, ResHelper.GetString("ShoppingCartCheckRegistration.LastNameErr"))
                    .NotEmpty(txtEmail2.Text, ResHelper.GetString("ShoppingCartCheckRegistration.EmailErr"))
                    .NotEmpty(txtPsswd2.Text, ResHelper.GetString("ShoppingCartCheckRegistration.PsswdErr")).Result;
                if (result == "")
                {
                    if (!ValidationHelper.IsEmail(txtEmail2.Text))
                    {
                        lblEmail2Err.Text = ResHelper.GetString("ShoppingCartCheckRegistration.EmailErr");
                        lblEmail2Err.Visible = true;
                    }
                    // Password and confirmed password must be same
                    if (txtPsswd2.Text != txtConfirmPsswd.Text)
                    {
                        lblPsswdErr.Text = ResHelper.GetString("ShoppingCartCheckRegistration.DifferentPsswds");
                        lblPsswdErr.Visible = true;
                    }
                    if ((!DataHelper.IsEmpty(lblEmail2Err.Text)) || (!DataHelper.IsEmpty(lblPsswdErr.Text)))
                    {
                        return false;
                    }
                }
                else
                {
                    lblError.Text = result;
                    lblError.Visible = true;
                    return false;
                }
            }
            // Check 'Continue as anonymous customer' section
            else if (radAnonymous.Checked)
            {
                result = val.NotEmpty(txtFirstName2.Text, ResHelper.GetString("ShoppingCartCheckRegistration.FirstNameErr"))
                    .NotEmpty(txtLastName2.Text, ResHelper.GetString("ShoppingCartCheckRegistration.LastNameErr"))
                    .NotEmpty(txtEmail3.Text, ResHelper.GetString("ShoppingCartCheckRegistration.EmailErr")).Result;
                if (result == "")
                {
                    if (!ValidationHelper.IsEmail(txtEmail3.Text))
                    {
                        lblEmail3Err.Text = ResHelper.GetString("ShoppingCartCheckRegistration.EmailErr");
                        lblEmail3Err.Visible = true;
                        return false;
                    }
                }
                else
                {
                    lblError.Text = result;
                    lblError.Visible = true;
                    return false;
                }
            }
        }
        else
        {
            // Validate customer data
            result = val.NotEmpty(txtEditFirst.Text, ResHelper.GetString("ShoppingCartCheckRegistration.FirstNameErr"))
                    .NotEmpty(txtEditLast.Text, ResHelper.GetString("ShoppingCartCheckRegistration.LastNameErr"))
                    .IsEmail(txtEditEmail.Text, ResHelper.GetString("ShoppingCartCheckRegistration.EmailErr")).Result;
            if (result == "")
            {
                return true;
            }
            else
            {
                lblError.Text = result;
                lblError.Visible = true;
                return false;
            }
        }

        return true;
    }


    /// <summary>
    /// Process valid values of this step.
    /// </summary>
    /// <returns></returns>
    public override bool ProcessStep()
    {
        if (this.plcAccount.Visible)
        {
            // Existing account
            if (radSignIn.Checked)
            {
                // Sign in customer with existing account

                // Authenticate user
                UserInfo ui = UserInfoProvider.AuthenticateUser(txtUsername.Text.Trim(), txtPsswd1.Text, CMSContext.CurrentSite.SiteName);
                if (ui == null)
                {
                    lblError.Text = ResHelper.GetString("ShoppingCartCheckRegistration.LoginFailed");
                    lblError.Visible = true;
                    return false;
                }

                // Sign in
                FormsAuthentication.SetAuthCookie(ui.UserName, false);

                this.ShoppingCartInfoObj.UserInfoObj = ui;
                LoadStep(true);

                // Return false to get to Edit customer page
                return false;
            }
            // New registration
            else if (radNewReg.Checked)
            {
                // Check if user exists
                UserInfo ui = UserInfoProvider.GetUserInfo(txtEmail2.Text.Trim());
                if (ui != null)
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("ShoppingCartUserRegistration.ErrorUserExists");
                    return false;
                }

                // Create new customer and user account and sign in
                // User
                ui = new UserInfo();
                ui.UserName = txtEmail2.Text.Trim();
                ui.Email = txtEmail2.Text.Trim();
                ui.FirstName = txtFirstName1.Text.Trim();
                ui.LastName = txtLastName1.Text.Trim();
                ui.FullName = ui.FirstName + " " + ui.LastName;
                ui.Enabled = true;

                try
                {
                    UserInfoProvider.SetUserInfo(ui);
                    UserInfoProvider.SetPassword(ui.UserName, txtPsswd2.Text);
                    UserInfoProvider.AddUserToSite(ui.UserName, CMSContext.CurrentSite.SiteName);
                }
                catch (Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = ex.Message;
                    return false;
                }

                // Customer
                CustomerInfo ci = new CustomerInfo();
                ci.CustomerFirstName = this.txtFirstName1.Text.Trim();
                ci.CustomerLastName = this.txtLastName1.Text.Trim();
                ci.CustomerEmail = this.txtEmail2.Text.Trim();
                ci.CustomerCompany = this.txtCompany1.Text.Trim();
                ci.CustomerTaxRegistrationID = this.txtTaxRegistrationID.Text.Trim();
                ci.CustomerOrganizationID = this.txtOrganizationID.Text.Trim();
                ci.CustomerUserID = ui.UserID;
                ci.CustomerEnabled = true;
                CustomerInfoProvider.SetCustomerInfo(ci);

                // Track successful registration conversion
                if (this.RegistrationTrackConversionName != string.Empty)
                {
                    string siteName = CMSContext.CurrentSite.SiteName;

                    if (AnalyticsHelper.AnalyticsEnabled(siteName) && !AnalyticsHelper.IsIPExcluded(siteName, HttpContext.Current.Request.UserHostAddress))
                    {
                        string objectName = new ContextResolver().ResolveMacros(this.RegistrationTrackConversionName);
                        HitLogProvider.LogHit("conversion", siteName, CMSContext.CurrentUser.PreferredCultureCode, objectName, 0);
                    }
                }

                // Sign in
                FormsAuthentication.SetAuthCookie(ui.UserName, false);

                this.ShoppingCartInfoObj.ShoppingCartCustomerID = ci.CustomerID;
            }
            // Anonymous customer
            else if (radAnonymous.Checked)
            {
                // Create new customer account
                CustomerInfo ci = new CustomerInfo();
                ci.CustomerFirstName = this.txtFirstName2.Text.Trim();
                ci.CustomerLastName = this.txtLastName2.Text.Trim();
                ci.CustomerEmail = this.txtEmail3.Text.Trim();
                ci.CustomerCompany = this.txtCompany2.Text.Trim();
                ci.CustomerOrganizationID = this.txtOrganizationID2.Text.Trim();
                ci.CustomerTaxRegistrationID = this.txtTaxRegistrationID2.Text.Trim();
                ci.CustomerEnabled = true;
                CustomerInfoProvider.SetCustomerInfo(ci);

                this.ShoppingCartInfoObj.ShoppingCartCustomerID = ci.CustomerID;
            }
            else
            {
                return false;
            }
        }
        else
        {
            // Save the customer data
            CustomerInfo ci = CustomerInfoProvider.GetCustomerInfoByUserId(this.UserInfo.UserID);
            if (ci == null)
            {
                ci = new CustomerInfo();
                ci.CustomerUserID = this.UserInfo.UserID;
                ci.CustomerEnabled = true;
            }
            ci.CustomerFirstName = this.txtEditFirst.Text.Trim();
            ci.CustomerLastName = this.txtEditLast.Text.Trim();
            ci.CustomerEmail = this.txtEditEmail.Text.Trim();
            ci.CustomerCompany = this.txtEditCompany.Text.Trim();
            ci.CustomerTaxRegistrationID = this.txtEditTaxRegID.Text.Trim();
            ci.CustomerOrganizationID = this.txtEditOrgID.Text.Trim();


            CustomerInfoProvider.SetCustomerInfo(ci);

            // Set the shopping cart customer ID
            this.ShoppingCartInfoObj.ShoppingCartCustomerID = ci.CustomerID;
        }

        try
        {
            ShoppingCartInfoProvider.SetShoppingCartInfo(this.ShoppingCartInfoObj);
            return true;
        }
        catch
        {
            return false;
        }
    }
}
