using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSEcommerce_ShoppingCartContent : ShoppingCartStep
{
    #region Private properties

    private bool mHideCurrency = false;
    private bool mHideCoupon = false;

    private string mTotalPrice = "";
    private string mTotalTax = "";
    private string mTaxClassesSubtotal = "";
    private string mRoundedDifference = "";    

    protected Button btnAddProduct = null;
    protected HiddenField hidProductID = null;
    protected HiddenField hidQuantity = null;

    #endregion

    #region Public properties

    public bool HideCurrency
    {
        get
        {
            return mHideCurrency;
        }
        set
        {
            mHideCurrency = value;
        }
    }

    public bool HideCoupon
    {
        get
        {
            return mHideCoupon;
        }
        set
        {
            mHideCoupon = value;
        }
    }

    public string TotalPrice
    {
        get
        {
            return mTotalPrice;
        }
        set
        {
            mTotalPrice = value;
        }
    }

    public string TotalTax
    {
        get
        {
            return mTotalTax;
        }
        set
        {
            mTotalTax = value;
        }
    }

    public string TaxClassesSubtotal
    {
        get
        {
            return mTaxClassesSubtotal;
        }
        set
        {
            mTaxClassesSubtotal = value;
        }
    }

    public string RoundedDifference
    {
        get
        {
            return mRoundedDifference;
        }
        set
        {
            mRoundedDifference = value;
        }
    }

    #endregion


    /// <summary>
    /// Child control creation.
    /// </summary>
    protected override void CreateChildControls()
    {
        // Add product button
        this.btnAddProduct = new Button();
        this.btnAddProduct.CssClass = "HiddenButton";
        this.Controls.Add(this.btnAddProduct);
        this.btnAddProduct.Click += new EventHandler(btnAddProduct_Click);

        // Add the hidden fields for productId and units quantity
        this.hidProductID = new HiddenField();
        this.hidProductID.ID = "hidProductID";
        this.Controls.Add(this.hidProductID);

        this.hidQuantity = new HiddenField();
        this.hidQuantity.ID = "hidQuantity";
        this.Controls.Add(this.hidQuantity);
    }


    /// <summary>
    /// Page pre-render.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_PreRender(object sender, EventArgs e)
    {
        // Register the dialog scripts
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "AddProductScript",
            ScriptHelper.GetScript(
                "function setProduct(val) { document.getElementById('" + this.hidProductID.ClientID + "').value = val; } \n" +
                "function setQuantity(val) { document.getElementById('" + this.hidQuantity.ClientID + "').value = val; } \n" +
                "function AddProduct(productIDs, quantities) { \n" +
                    "setProduct(productIDs); \n" +
                    "setQuantity(quantities); \n" +
                    this.Page.ClientScript.GetPostBackEventReference(this.btnAddProduct, null) +
                ";} \n"
            ));
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), ScriptHelper.DIALOG_SCRIPT_KEY, ScriptHelper.DialogScript);

    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        this.lblTitle.Text = ResHelper.GetString("ShoppingCart.CartContent");
        //bool currencySelected = false;

        if ((ShoppingCartInfoObj != null) && (ShoppingCartInfoObj.CountryID == 0) && (CMSContext.CurrentSite != null))
        {
            ShoppingCartInfoObj.CountryID = CMSContext.CurrentSite.SiteDefaultCountryID;
        }

        // Initialization
        imgNewItem.ImageUrl = "~/App_Themes/" + Page.Theme + "/Images/CMSDesk/Tools/ECommerce/Orders/additem.gif";
        lblCurrency.Text = ResHelper.GetString("Ecommerce.ShoppingCartContent.Currency");
        lblCoupon.Text = ResHelper.GetString("Ecommerce.ShoppingCartContent.Coupon");
        lnkNewItem.Text = ResHelper.GetString("Ecommerce.ShoppingCartContent.AddItem");
        btnUpdate.Text = ResHelper.GetString("Ecommerce.ShoppingCartContent.BtnUpdate");
        this.TitleText = ResHelper.GetString("order_new.cartcontent.title");
        lnkNewItem.OnClientClick = "OpenAddProductDialog();return false;";
        gridData.Columns[1].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.Remove");
        gridData.Columns[2].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.SKUName");
        gridData.Columns[3].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.SKUUnits");
        gridData.Columns[4].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.UnitPrice");
        gridData.Columns[5].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.UnitDiscount");
        gridData.Columns[6].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.Tax");
        gridData.Columns[7].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.Subtotal");

        // hide "add product" link if it is live site order
        if (!this.IsInternalOrder)
        {
            pnlNewItem.Visible = false;
            //this.ButtonBack.Visible = false;
            this.ButtonBack.Text = ResHelper.GetString("Ecommerce.CartContent.ButtonBackText");
            this.ButtonBack.CssClass = "LongButton";
            this.ButtonNext.Text = ResHelper.GetString("Ecommerce.CartContent.ButtonNextText");


            if (this.LoadStepInfo)
            {
                // Add product to the shopping cart, if enabled
                int productId = ValidationHelper.GetInteger(HttpContext.Current.Request.QueryString["productId"], 0);

                SKUInfo skuInfo = SKUInfoProvider.GetSKUInfo(productId);
                if ((skuInfo != null) && (!skuInfo.SKUEnabled))
                {
                    ltlAlert.Text = ScriptHelper.GetAlertScript(string.Format(ResHelper.GetString("Ecommerce.CartContent.ProductDisabled"), skuInfo.SKUName));
                }
                else
                {
                    int quantity = ValidationHelper.GetInteger(HttpContext.Current.Request.QueryString["quantity"], 0);
                    AddProducts(productId, quantity);
                }
            }
        }
        if (IsShoppingCartCreatedFromOrder)
        {
            this.ButtonBack.Visible = false;
            this.ButtonNext.Text = ResHelper.GetString("General.OK");
            this.ShoppingCartInfoObj.CheckAvailableItems = false;
        }

        // fill dropdownlist
        if (this.LoadStepInfo)
        {
            this.LoadStepInfo = false;
            drpCurrency.Items.Clear();
            DataSet ds = CurrencyInfoProvider.GetCurrenciesWithExchangeRate();
            if (!DataHelper.IsEmpty(ds))
            {
                drpCurrency.DataTextField = "CurrencyDisplayName";
                drpCurrency.DataValueField = "CurrencyID";
                drpCurrency.DataSource = ds.Tables[0];
                drpCurrency.DataBind();
            }

            // Add site default currency if it is not already included in currency dropdown list
            if (CMSContext.CurrentSite != null)
            {
                CurrencyInfo defaultCurrency = CurrencyInfoProvider.GetCurrencyInfo(CMSContext.CurrentSite.SiteDefaultCurrencyID);
                if (defaultCurrency != null)
                {
                    bool isIncluded = false;
                    for (int i = 0; i < drpCurrency.Items.Count; i++)
                    {
                        if (drpCurrency.Items[i].Value == defaultCurrency.CurrencyID.ToString())
                        {
                            isIncluded = true;
                            break;
                        }
                    }
                    if (isIncluded == false)
                    {
                        ListItem siteDefaultCurrencyItem = new ListItem(defaultCurrency.CurrencyDisplayName, defaultCurrency.CurrencyID.ToString());
                        drpCurrency.Items.Add(siteDefaultCurrencyItem);
                    }
                }
            }

            if (this.ShoppingCartInfoObj != null)
            {
                if (ShoppingCartInfoObj.ShoppingCartCurrencyID == 0)
                {
                    // select customer preffered currency                    
                    if (ShoppingCartInfoObj.CustomerInfoObj != null)
                    {
                        ShoppingCartInfoObj.ShoppingCartCurrencyID = ShoppingCartInfoObj.CustomerInfoObj.CustomerPreferredCurrencyID;
                        // select shopping cart currency in dropdown list
                        ListItem li = drpCurrency.Items.FindByValue(ShoppingCartInfoObj.ShoppingCartCurrencyID.ToString());
                        if (li != null)
                        {
                            li.Selected = true;
                            //currencySelected = true;
                        }
                        else
                        {
                            ShoppingCartInfoObj.ShoppingCartCurrencyID = 0;
                        }
                    }
                }

                if (ShoppingCartInfoObj.ShoppingCartCurrencyID == 0)
                {
                    if (CMSContext.CurrentSite != null)
                    {
                        ShoppingCartInfoObj.ShoppingCartCurrencyID = CMSContext.CurrentSite.SiteDefaultCurrencyID;
                    }
                }
                if (ShoppingCartInfoObj.ShoppingCartCurrencyID > 0)
                {
                    // select shopping cart currency in dropdown list
                    ListItem li = drpCurrency.Items.FindByValue(ShoppingCartInfoObj.ShoppingCartCurrencyID.ToString());
                    if (li != null)
                    {
                        li.Selected = true;
                        //currencySelected = true;
                    }

                    /*if (CMSContext.CurrentSite != null)
                    {
                        if (CMSContext.CurrentSite.SiteDefaultCurrencyID != ShoppingCartInfoObj.ShoppingCartCurrencyID)
                        {
                            //this.ShoppingCartInfoObj.ExchangeRate = CurrencyInfoProvider.GetLastValidExchangeRate(ShoppingCartInfoObj.ShoppingCartCurrencyID);
                            //ShoppingCartInfoProvider.EvaluateShoppingCartContent(ShoppingCartInfoObj);
                        }
                        else
                        {
                            this.ShoppingCartInfoObj.ExchangeRate = 1;
                        }
                    }*/
                }

                if (ShoppingCartInfoObj.ShoppingCartDiscountCouponID > 0)
                {
                    // fill textbox with discount coupon code
                    DiscountCouponInfo dci = DiscountCouponInfoProvider.GetDiscountCouponInfo(ShoppingCartInfoObj.ShoppingCartDiscountCouponID);
                    if (dci != null)
                    {
                        if (dci.IsValid)
                        {
                            txtCoupon.Text = dci.DiscountCouponCode;
                        }

                    }
                }
            }

            ReloadData();
        }

        // Turn on available items checking after content is loaded
        ShoppingCartInfoObj.CheckAvailableItems = true;
    }  


    /// <summary>
    /// On btnUpdate click event.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnUpdate_Click1(object sender, EventArgs e)
    {
        if (this.ShoppingCartInfoObj != null)
        {    

            this.ShoppingCartInfoObj.ShoppingCartCurrencyID = ValidationHelper.GetInteger(drpCurrency.SelectedValue, 0);

            if (this.ShoppingCartInfoObj.CartItems != null)
            {
                // Skip if method was called by btnAddProduct
                if (sender != this.btnAddProduct)
                {
                    foreach (GridViewRow row in gridData.Rows)
                    {
                        foreach (SKUInfo sku in this.ShoppingCartInfoObj.CartItems)
                        {
                            // Find item on SKUID
                            if (sku.SKUID == Convert.ToInt32(((Label)row.Cells[0].Controls[1]).Text))
                            {
                                if (((CheckBox)row.Cells[1].Controls[1]).Checked && (sender != null))
                                {
                                    // Remove product from shopping cart object
                                    //this.ShoppingCartInfoObj.CartItems.Remove(sku);

                                    this.ShoppingCartInfoObj.DeleteShoppingCartSKU(sku);


                                    if (CMSContext.CurrentShoppingCart != null)
                                    {
                                        CMSContext.CurrentShoppingCart.CartItems = this.ShoppingCartInfoObj.CartItems;
                                    }

                                    // Delete product from database
                                    ShoppingCartInfoProvider.DeleteShoppingCartSKU(sku.SKUID, ShoppingCartInfoObj.ShoppingCartID);
                                }
                                else
                                {
                                    // Get number of units
                                    int itemUnits = ValidationHelper.GetInteger(((TextBox)(row.Cells[3].Controls[1])).Text.Trim(), 0);
                                    if (itemUnits > 0)
                                    {
                                        // Update product units in shopping cart object
                                        sku.SKUUnits = itemUnits;

                                        if(ShoppingCartInfoObj.ShoppingCartID > 0)
                                        {
                                            ShoppingCartInfoProvider.SetShoppingCartSKUUnits(ShoppingCartInfoObj.ShoppingCartID, sku.SKUID, sku.SKUUnits);
                                        }
                                    }
                                }
                                break;
                            }
                        }
                    }
                }
            }

            ShoppingCartInfoObj.ShoppingCartDiscountCouponID = 0;

            if (txtCoupon.Text.Trim() != "")
            {
                // Get discount info
                DiscountCouponInfo dci = DiscountCouponInfoProvider.GetDiscountCouponInfo(txtCoupon.Text.Trim());
                if ((dci != null) && (dci.IsValid))
                {
                    ShoppingCartInfoObj.ShoppingCartDiscountCouponID = dci.DiscountCouponID;
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("ecommerce.error.couponcodeisnotvalid");
                }

            }

            ReloadData();
        }
    }


    /// <summary>
    /// Validates this step.
    /// </summary>
    /// <returns></returns>
    public override bool IsValid()
    {

        // allow to go to the next step only if shopping cart contains some products
        bool IsValid = (ShoppingCartInfoObj.CartItems.Count > 0);

        if (this.IsShoppingCartCreatedFromOrder)
        {
            IsValid = true;
        }

        if (!IsValid)
        {
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Ecommerce.Error.InsertSomeProducts");
        }

        return IsValid;
    }


    /// <summary>
    /// Process this step.
    /// </summary>
    /// <returns></returns>
    public override bool ProcessStep()
    {
        // Shopping cart units are already saved in database (on "Update" or on "btnAddProduct_Click" actions) 

        bool isOK = false;

        if (ShoppingCartInfoObj != null)
        {            
            //if (IsShoppingCartCreatedFromOrder)
            //{
            //    int skuId = 0;
            //    int skuUnits = 0;
            //    SKUInfo skuObj = null;                

            //    // Reset sku counts to the default values
            //    foreach (DictionaryEntry item in ShoppingCartInfoObj.OrderSKUItems)
            //    {
            //        skuId = ValidationHelper.GetInteger(item.Key, 0);
            //        skuUnits = ValidationHelper.GetInteger(item.Value, 0);

            //        skuObj = SKUInfoProvider.GetSKUInfo(skuId);
            //        if (skuObj != null)
            //        {
            //            skuObj.SKUAvailableItems += skuUnits;
            //            SKUInfoProvider.SetSKUInfo(skuObj);
            //        }
            //    }
            //}


            // Check available items before "Check out"
            ShoppingCartInfoProvider.EvaluateShoppingCartContent(ShoppingCartInfoObj);

            if (ShoppingCartInfoObj.ItemsNotAvailable)
            {
                // Show error message with new data
                ReloadData();
            }
            else if (this.IsShoppingCartCreatedFromOrder)
            {
                // indicates wheter order saving process is successful
                isOK = true;

                // Set order values            
                OrderInfo oi = OrderInfoProvider.GetOrderInfo(ShoppingCartInfoObj.OrderId);
                if (oi != null)
                {

                    oi.OrderTotalPrice = ShoppingCartInfoObj.TotalPrice;
                    oi.OrderTotalTax = ShoppingCartInfoObj.TotalTax;
                    oi.OrderDiscountCouponID = ShoppingCartInfoObj.ShoppingCartDiscountCouponID;
                    oi.OrderCurrencyID = ShoppingCartInfoObj.ShoppingCartCurrencyID;
                    oi.OrderTotalShipping = ShoppingCartInfoObj.TotalShipping;
                    OrderInfoProvider.SetOrderInfo(oi);
                }

                // Clear order
                OrderItemInfoProvider.DeleteAllOrderItems(ShoppingCartInfoObj.OrderId);

                SKUInfo SKUObj = null;

                //SKUInfo SKUObj = null;
                foreach (object item in ShoppingCartInfoObj.CartItems)
                {
                    if (item is SKUInfo)
                    {
                        OrderItemInfo oii = new OrderItemInfo();

                        SKUObj = (SKUInfo)item;
                        oii.OrderItemSKUID = SKUObj.SKUID;
                        oii.OrderItemOrderID = ShoppingCartInfoObj.OrderId;
                        oii.OrderItemSKUName = SKUObj.SKUName;
                        oii.OrderItemUnitCount = SKUObj.SKUUnits;
                        oii.OrderItemUnitPrice = SKUObj.SKUPrice;

                        try
                        {
                            OrderItemInfoProvider.SetOrderItemInfo(oii);
                        }
                        catch
                        {
                            OrderInfoProvider.DeleteOrderInfo(ShoppingCartInfoObj.OrderId);
                            isOK = false;
                            break;
                        }
                    }
                }

                if (isOK)
                {
                    //if (this.IsShoppingCartCreatedFromOrder)
                    //{
                    //    ShoppingCartInfoObj.ReloadOrderSKUItems();
                    //}

                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Ecommerce.OrderPreview.ErrorOrderSave");
                }
            }
            // go to the next step
            else
            {
                // Save other options
                ShoppingCartInfoProvider.SetShoppingCartInfo(ShoppingCartInfoObj);
                isOK = true;
            }            
        }

        return isOK;
    }


    /// <summary>
    /// Add product event handler
    /// </summary>
    void btnAddProduct_Click(object sender, EventArgs e)
    {
        // Get strings with productIDs and quantities separated by ';'
        string productIDs = ValidationHelper.GetString(this.hidProductID.Value, "");
        string quantities = ValidationHelper.GetString(this.hidQuantity.Value, "");

        // Add new products to shopping cart
        if ((productIDs != "") && (quantities != ""))
        {
            string[] arrID = productIDs.TrimEnd(';').Split(';');
            string[] arrQuant = quantities.TrimEnd(';').Split(';');

            lblError.Text = "";

            for (int i = 0; i < arrID.Length; i++)
            {
                int ID = ValidationHelper.GetInteger(arrID[i], 0);

                SKUInfo skuInfo = SKUInfoProvider.GetSKUInfo(ID);
                if (skuInfo != null)
                {
                    if (!skuInfo.SKUEnabled)
                    {
                        ltlAlert.Text = ScriptHelper.GetAlertScript(string.Format(ResHelper.GetString("Ecommerce.CartContent.ProductDisabled"), skuInfo.SKUName));
                    }
                    else
                    {                        
                        int quant = ValidationHelper.GetInteger(arrQuant[i], 0);

                        int orderItems = 0;
                        // Get product items from existing order before update
                        if (this.IsShoppingCartCreatedFromOrder && ShoppingCartInfoObj.OrderSKUItems.Contains(skuInfo.SKUID))
                        {
                            orderItems = ValidationHelper.GetInteger(ShoppingCartInfoObj.OrderSKUItems[skuInfo.SKUID], 0);
                        }

                        // Check available items
                        if (skuInfo.SKUSellOnlyAvailable && (skuInfo.SKUAvailableItems + orderItems < quant))
                        {                            
                            lblError.Visible = true;
                            lblError.Text += string.Format(ResHelper.GetString("Ecommerce.AddProduct.ItemsNotAvailable"), skuInfo.SKUName, skuInfo.SKUAvailableItems);
                        }
                        else
                        {
                            this.ShoppingCartInfoObj.AddSKUUnitsToShoppingCart(ID, quant);

                            // Get updated SKU from shopping cart
                            skuInfo = ShoppingCartInfoObj.GetSKUInfoFromCartItems(ID);

                            if (ShoppingCartInfoObj.ShoppingCartID > 0)
                            {
                                // Update product units in database
                                ShoppingCartInfoProvider.SetShoppingCartSKUUnits(ShoppingCartInfoObj.ShoppingCartID, ID, skuInfo.SKUUnits);
                            }
                        }
                    }
                }
            }
            // Update values in table
            btnUpdate_Click1(this.btnAddProduct, e);
        }
    }


    // Displays total price
    protected void DisplayTotalPrice()
    {
        pnlPrice.Visible = true;
        lblTotalPriceValue.Text = CurrencyInfoProvider.GetFormatedPrice(ShoppingCartInfoObj.RoundedTotalPrice, ShoppingCartInfoObj.CurrencyInfoObj);
        lblTotalPrice.Text = ResHelper.GetString("ecommerce.cartcontent.totalpricelabel");

        lblShippingPrice.Text = ResHelper.GetString("ecommerce.cartcontent.shippingpricelabel");
        lblShippingPriceValue.Text = CurrencyInfoProvider.GetFormatedPrice(ShoppingCartInfoObj.TotalShipping, ShoppingCartInfoObj.CurrencyInfoObj);
    }


    /// <summary>
    /// Displays or hides "Unit discount" column according to whether discount coupon code is set or not
    /// </summary>
    protected void DisplayHideDiscountColumn()
    {
        gridData.Columns[5].Visible = (ShoppingCartInfoObj.ShoppingCartDiscountCouponID > 0);
    }


    /// <summary>
    /// Adds product to shopping cart.
    /// </summary>
    /// <param name="productId">Product id.</param>
    /// <param name="quatity">Product quantity.</param>
    protected void AddProducts(int productId, int quatity)
    {
        // Add new products to shopping cart
        if ((productId > 0) && (quatity > 0))
        {            
            // Get actual SKU info object from database
            SKUInfo skuObj = SKUInfoProvider.GetSKUInfo(productId); 
            if (skuObj != null)
            {
                int orderItems = 0;
                // Get product items from existing order before update
                if (this.IsShoppingCartCreatedFromOrder && ShoppingCartInfoObj.OrderSKUItems.Contains(skuObj.SKUID))
                {
                    orderItems = ValidationHelper.GetInteger(ShoppingCartInfoObj.OrderSKUItems[skuObj.SKUID], 0);
                }

                // Check available items
                if (skuObj.SKUSellOnlyAvailable && ((skuObj.SKUAvailableItems + orderItems) < quatity))
                {
                    lblError.Visible = true;
                    lblError.Text = string.Format(ResHelper.GetString("Ecommerce.AddProduct.ItemsNotAvailable"), skuObj.SKUName, skuObj.SKUAvailableItems);
                }
                else
                {
                    this.ShoppingCartInfoObj.AddSKUUnitsToShoppingCart(productId, quatity);


                    // Get coresponding sku info from shopping cart
                    skuObj =  ShoppingCartInfoObj.GetSKUInfoFromCartItems(productId);

                    // Shopping cart is not saved yet
                    if (ShoppingCartInfoObj.ShoppingCartID == 0)
                    {
                        ShoppingCartInfoProvider.SetShoppingCartInfo(ShoppingCartInfoObj);
                    }

                    if (skuObj != null)
                    {
                        // Update product units in database
                        ShoppingCartInfoProvider.SetShoppingCartSKUUnits(ShoppingCartInfoObj.ShoppingCartID, productId, skuObj.SKUUnits);
                    }
                }
            }

            // avoid adding the same product after page refresh

            if (lblError.Text == "")
            {
                // Remove add parameter from URL
                string newUrl = UrlHelper.RemoveParameterFromUrl(Page.Request.RawUrl, "quantity");
                Response.Redirect(newUrl);
            }
        }
    }

    /// <summary>
    /// Hides cart content controls when no items are in shopping cart.
    /// </summary>
    protected void HideCartContentWhenEmpty()
    {
        pnlNewItem.Visible = IsInternalOrder;
        pnlPrice.Visible = false;

        if (!this.IsInternalOrder)
        {
            pnlCurrency.Visible = false;
            plcCoupon.Visible = false;
            gridData.Visible = false;
            ButtonNext.Visible = false;
            lblError.Visible = (lblError.Text != "");
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("Ecommerce.ShoppingCartEmpty");            
        }
    }


    /// <summary>
    /// Reloads the form data
    /// </summary>
    protected void ReloadData()
    {
        gridData.DataSource = ShoppingCartInfoObj.ShoppingCartContentTable;
        gridData.DataBind();

        if (!DataHelper.DataSourceIsEmpty(ShoppingCartInfoObj.ShoppingCartContentTable))
        {
            // Display total price
            DisplayTotalPrice();
            // Display/hide discount column
            DisplayHideDiscountColumn();
        }
        else
        {
            // Hide some items
            HideCartContentWhenEmpty();
        }
    }


    protected void drpCurrency_SelectedIndexChanged(object sender, EventArgs e)
    {
        btnUpdate_Click1(null, null);
    }
}
