using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.Ecommerce;
using CMS.GlobalHelper;

public partial class CMSEcommerce_ShoppingCartPaymentShipping : ShoppingCartStep
{

    /// <summary>
    /// On page load.
    /// </summary>
    /// <param name="sender">Sender.</param>
    /// <param name="e">Event arguments.</param>
    protected void Page_Load(object sender, EventArgs e)
    {
        this.lblTitle.Text = ResHelper.GetString("ShoppingCart.ShippingPaymentOptions");

        if ((ShoppingCartInfoObj != null) && (ShoppingCartInfoObj.CountryID == 0) && (CMSContext.CurrentSite != null))
        {
            ShoppingCartInfoObj.CountryID = CMSContext.CurrentSite.SiteDefaultCountryID;
        }
        // Initialize labels
        //lblInfo.Text = ResHelper.GetString("ShoppingCartPaymentShipping.Info");
        lblPayment.Text = ResHelper.GetString("ShoppingCartPaymentShipping.Payment");
        lblShipping.Text = ResHelper.GetString("ShoppingCartPaymentShipping.Shipping");
        this.TitleText = ResHelper.GetString("Order_new.PaymentShipping.Title");

        if (LoadStepInfo)
        {
            if (CMSContext.CurrentSite != null)
            {
                int siteId = CMSContext.CurrentSite.SiteID;

                // Initialize shipping                
                InitializeShippingList(siteId);
                SelectShippingOption();

                // Initialize payment 
                InitializePaymentList();
                SelectPaymentOption();

            }
        }

        drpShipping.SelectedIndexChanged += new EventHandler(drpShipping_SelectedIndexChanged);
    }


    void drpShipping_SelectedIndexChanged(object sender, EventArgs e)
    {
        InitializePaymentList();
    }


    /// <summary>
    /// Initialize payment option dropdown list.
    /// </summary>
    protected void InitializePaymentList()
    {       
        int shippingId = ValidationHelper.GetInteger(drpShipping.SelectedValue, 0);

        if (shippingId > 0)
        {
            drpPayment.DataSource = PaymentOptionInfoProvider.GetShippingPayments(shippingId, true, false);
        }
        drpPayment.DataTextField = "PaymentOptionDisplayName";
        drpPayment.DataValueField = "PaymentOptionID";
        drpPayment.DataBind();
    }


    /// <summary>
    /// Initialize shipping option dropdown list.
    /// </summary>
    /// <param name="siteId">SiteID.</param>
    protected void InitializeShippingList(int siteId)
    {        
        drpShipping.DataSource = ShippingOptionInfoProvider.GetAllShippingsForSite(siteId, StatusEnum.Enabled);
        drpShipping.DataTextField = "ShippingOptionDisplayName";
        drpShipping.DataValueField = "ShippingOptionID";
        drpShipping.DataBind();
    }


    public override bool ProcessStep()
    {
        try
        {
            ShoppingCartInfoObj.ShoppingCartShippingOptionID = ValidationHelper.GetInteger(drpShipping.SelectedValue, 0);
            ShoppingCartInfoObj.ShoppingCartPaymentOptionID = ValidationHelper.GetInteger(drpPayment.SelectedValue, 0);
            
            ShoppingCartInfoProvider.SetShoppingCartInfo(ShoppingCartInfoObj);
            return true;
        }
        catch (Exception ex)
        {
            lblError.Visible = true;
            lblError.Text = ex.Message;
            return false;
        }
    }

    /// <summary>
    /// Select saved payment option.
    /// </summary>
    protected void SelectPaymentOption()
    {

        try
        {
            // try to select payment option accroding to saved option in shopping cart object
            if (ShoppingCartInfoObj.ShoppingCartPaymentOptionID > 0)
            {
                drpPayment.SelectedValue = Convert.ToString(ShoppingCartInfoObj.ShoppingCartPaymentOptionID);
            }
            // try to select payment option according to user preffered option
            else
            {
                if (ShoppingCartInfoObj.CustomerInfoObj != null)
                {
                    drpPayment.SelectedValue = Convert.ToString(ShoppingCartInfoObj.CustomerInfoObj.CustomerPrefferedPaymentOptionID);
                }
            }
        }
        catch
        {
        }
    }




    /// <summary>
    /// Select saved shipping option.
    /// </summary>
    protected void SelectShippingOption()
    {
        try
        {
            // try to select shipping option accroding to saved option in shopping cart object
            if (ShoppingCartInfoObj.ShoppingCartShippingOptionID > 0)
            {
                drpShipping.SelectedValue = Convert.ToString(ShoppingCartInfoObj.ShoppingCartShippingOptionID);
            }
            // try to select shipping option according to user preffered option
            else
            {
                if (ShoppingCartInfoObj.CustomerInfoObj != null)
                {
                    drpShipping.SelectedValue = Convert.ToString(ShoppingCartInfoObj.CustomerInfoObj.CustomerPreferredShippingOptionID);
                }
            }
        }
        catch
        {
        }
    }

    public override bool IsValid()
    {
        string errorMessage = "";

        if (ValidationHelper.GetInteger(drpShipping.SelectedValue, 0) <= 0)            
        {            
            errorMessage = ResHelper.GetString("Order_New.NoShippingOption");            
        }

        if ((errorMessage == "") && (ValidationHelper.GetInteger(drpPayment.SelectedValue, 0) <= 0))
        {
            errorMessage = ResHelper.GetString("Order_New.NoPaymentMethod");            
        }


        if (errorMessage == "")
        {
            // Form is valid
            return true;
        }
        else
        {
            // Form is not valid
            lblError.Visible = true;
            lblError.Text = errorMessage;
            return false;
        }
    }
}
