using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSEcommerce_ShoppingCartPreview : ShoppingCartStep
{
    protected void Page_Load(object sender, EventArgs e)
    {
        this.lblTitle.Text = ResHelper.GetString("ShoppingCartPreview.Title");

        if ((ShoppingCartInfoObj != null) && (ShoppingCartInfoObj.CountryID == 0) && (CMSContext.CurrentSite != null))
        {
            ShoppingCartInfoObj.CountryID = CMSContext.CurrentSite.SiteDefaultCountryID;
        }

        this.TitleText = ResHelper.GetString("Order_New.CartPreview.Title");
        this.ButtonNext.Text = ResHelper.GetString("Ecommerce.OrderPreview.NextButtonText");

        // addresses initialization
        pnlBillingAddress.GroupingText = ResHelper.GetString("Ecommerce.CartPreview.BillingAddressPanel");
        pnlShippingAddress.GroupingText = ResHelper.GetString("Ecommerce.CartPreview.ShippingAddressPanel");

        FillBillingAddressForm(ShoppingCartInfoObj.ShoppingCartBillingAddressID);
        FillShippingAddressForm(ShoppingCartInfoObj.ShoppingCartShippingAddressID);
      
        // shopping cart content table initialization
        gridData.Columns[1].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.SKUName");
        gridData.Columns[2].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.SKUUnits");
        gridData.Columns[3].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.UnitPrice");
        gridData.Columns[4].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.UnitDiscount");
        gridData.Columns[5].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.Tax");
        gridData.Columns[6].HeaderText = ResHelper.GetString("Ecommerce.ShoppingCartContent.Subtotal");

        // tax summary table initialiazation
        gridTaxSummary.Columns[0].HeaderText = ResHelper.GetString("Ecommerce.CartContent.TaxDisplayName");
        gridTaxSummary.Columns[1].HeaderText = ResHelper.GetString("Ecommerce.CartContent.TaxSummary");

        ReloadData();

        // order note initialization
        lblNote.Text = ResHelper.GetString("ecommerce.cartcontent.notelabel");
        if (this.LoadStepInfo)
        {
            txtNote.Text = ShoppingCartInfoObj.ShoppingCartNote;
        }

        DisplayHideDiscountColumn();
    }


    protected void ReloadData()
    {

        gridData.DataSource = ShoppingCartInfoObj.ShoppingCartContentTable;
        gridData.DataBind();

        gridTaxSummary.DataSource = ShoppingCartInfoObj.ShoppingCartTaxTable;
        gridTaxSummary.DataBind();

        // shipping option, payment method initialization
        InitPaymentShipping();
    }


    /// <summary>
    /// Fills billing address form.
    /// </summary>
    /// <param name="addressId">Billing address id.</param>
    protected void FillBillingAddressForm(int addressId)
    {
        this.lblBill.Text = OrderInfoProvider.GetAddress(addressId);
    }


    /// <summary>
    /// Fills shipping address form.
    /// </summary>
    /// <param name="addressId">Shipping address id.</param>
    protected void FillShippingAddressForm(int addressId)
    {
        this.lblShip.Text = OrderInfoProvider.GetAddress(addressId);
    }


    /// <summary>
    /// Saves order information from ShoppingCartInfo object to database as new order.
    /// </summary>
    /// <returns></returns>
    public override bool ProcessStep()
    {
        // Check available items before order is finished
        ShoppingCartInfoProvider.EvaluateShoppingCartContent(ShoppingCartInfoObj);

        if (ShoppingCartInfoObj.ItemsNotAvailable)
        {
            ReloadData();
            return false;
        }
        else
        {
            OrderInfo oi = new OrderInfo();
            oi.OrderCustomerID = ShoppingCartInfoObj.ShoppingCartCustomerID;

            oi.OrderCompletedByUserID = ShoppingCartInfoObj.ShoppingCartUserID;
            oi.OrderCurrencyID = ShoppingCartInfoObj.ShoppingCartCurrencyID;
            oi.OrderDate = DateTime.Now;
            oi.OrderBillingAddressID = ShoppingCartInfoObj.ShoppingCartBillingAddressID;
            oi.OrderPaymentOptionID = ShoppingCartInfoObj.ShoppingCartPaymentOptionID;
            oi.OrderShippingAddressID = ShoppingCartInfoObj.ShoppingCartShippingAddressID;
            oi.OrderShippingOptionID = ShoppingCartInfoObj.ShoppingCartShippingOptionID;
            oi.OrderSiteID = ShoppingCartInfoObj.ShoppingCartSiteID;
            oi.OrderNote = txtNote.Text.Trim();
            oi.OrderDiscountCouponID = ShoppingCartInfoObj.ShoppingCartDiscountCouponID;

            OrderStatusInfo osi = OrderStatusInfoProvider.GetFirstEnabledStatus();

            oi.OrderStatusID = (osi != null) ? osi.StatusID : 0;
            oi.OrderTotalPrice = ShoppingCartInfoObj.RoundedTotalPrice;
            oi.OrderTotalShipping = ShoppingCartInfoObj.TotalShipping;
            oi.OrderTotalTax = ShoppingCartInfoObj.TotalTax;

            try
            {
                OrderInfoProvider.SetOrderInfo(oi);
                oi.OrderInvoiceNumber = oi.OrderID.ToString(); //.PadLeft(8, '0');
                OrderInfoProvider.SetOrderInfo(oi);

                SKUInfo SKUObj = null;
                foreach (object item in ShoppingCartInfoObj.CartItems)
                {
                    if (item is SKUInfo)
                    {
                        OrderItemInfo oii = new OrderItemInfo();

                        SKUObj = (SKUInfo)item;
                        oii.OrderItemSKUID = SKUObj.SKUID;
                        oii.OrderItemOrderID = oi.OrderID;
                        oii.OrderItemSKUName = SKUObj.SKUName;
                        oii.OrderItemUnitCount = SKUObj.SKUUnits;
                        oii.OrderItemUnitPrice = SKUObj.SKUPrice;

                        try
                        {
                            OrderItemInfoProvider.SetOrderItemInfo(oii);
                        }
                        catch (Exception ex)
                        {
                            OrderInfoProvider.DeleteOrderInfo(oi.OrderID);
                            throw ex;
                        }
                    }
                }

                // Save customers' prefferd options
                CustomerInfo ci = ShoppingCartInfoObj.CustomerInfoObj;
                if (ci != null)
                {
                    ci.CustomerPreferredCurrencyID = ShoppingCartInfoObj.ShoppingCartCurrencyID;
                    ci.CustomerPreferredShippingOptionID = ShoppingCartInfoObj.ShoppingCartShippingOptionID;
                    ci.CustomerPrefferedPaymentOptionID = ShoppingCartInfoObj.ShoppingCartPaymentOptionID;

                    CustomerInfoProvider.SetCustomerInfo(ci);
                }

                // Generate the invoice
                oi.OrderInvoice = OrderInfoProvider.GetInvoice(oi.OrderID, oi.OrderSiteID, CMSContext.CurrentSite.SiteDefaultCountryID);

                OrderInfoProvider.SetOrderInfo(oi);

                ShoppingCartInfoObj.ShoppingCartNote = oi.OrderNote;
                ShoppingCartInfoObj.OrderId = oi.OrderID;

                return true;
            }
            catch (Exception ex)
            {
                lblError.Text = ResHelper.GetString("Ecommerce.OrderPreview.ErrorOrderSave") + " (" + ex.Message + ")";
                lblError.Visible = true;
                return false;
            }
        }
    }


    protected void InitPaymentShipping()
    {
        // shipping option and payment method
        lblShippingOption.Text = ResHelper.GetString("Ecommerce.CartContent.ShippingOption");
        lblPaymentMethod.Text = ResHelper.GetString("Ecommerce.CartContent.PaymentMethod");
        lblShipping.Text = ResHelper.GetString("Ecommerce.CartContent.Shipping");
        
        if (CMSContext.CurrentSite != null)
        {
            // get shipping option name
            ShippingOptionInfo shippingObj = ShippingOptionInfoProvider.GetShippingOptionInfo(ShoppingCartInfoObj.ShoppingCartShippingOptionID);
            if (shippingObj != null)
            {
                lblShippingOptionValue.Text = shippingObj.ShippingOptionDisplayName;
                lblShippingValue.Text = CurrencyInfoProvider.GetFormatedPrice(ShoppingCartInfoObj.TotalShipping, ShoppingCartInfoObj.CurrencyInfoObj);
            }
        }

        // get payment method name
        PaymentOptionInfo paymentObj = PaymentOptionInfoProvider.GetPaymentOptionInfo(ShoppingCartInfoObj.ShoppingCartPaymentOptionID);
        if (paymentObj != null)
        {
            lblPaymentMethodValue.Text = paymentObj.PaymentOptionDisplayName;
        }


        // total price initialization
        lblTotalPrice.Text = ResHelper.GetString("ecommerce.cartcontent.totalprice");
        lblTotalPriceValue.Text = CurrencyInfoProvider.GetFormatedPrice(ShoppingCartInfoObj.RoundedTotalPrice, ShoppingCartInfoObj.CurrencyInfoObj);

    }

    /// <summary>
    /// Displays or hides "Unit discount" column according to whether discount coupon code is set or not
    /// </summary>
    protected void DisplayHideDiscountColumn()
    {
        gridData.Columns[4].Visible = (ShoppingCartInfoObj.ShoppingCartDiscountCouponID > 0);
    }
}
