using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;

public partial class CMSEcommerce_Wishlist : System.Web.UI.UserControl
{
    protected int mSKUId = 0;
    protected UserInfo currentUser = null;
    protected bool mRemove = false;

    protected Button btnRemoveProduct = null;
    protected HiddenField hidProductID = null;
    protected HiddenField hidQuantity = null;
    protected string mTransformationName = "cms.root.wishlist";


    #region "Private properties"

    /// <summary>
    /// Page url, we should return to after "Continue shopping" button is clicked.
    /// </summary>
    private string PreviousPageUrl
    {
        get
        {
            object obj = ViewState["PreviousPageUrl"];
            return (obj != null) ? (string)obj : "~/";
        }
        set
        {
            ViewState["PreviousPageUrl"] = value;
        }
    }

    #endregion


    #region " Public properties "

    /// <summary>
    /// Name of the transformation which is used to display wishlist content.
    /// </summary>
    public string TransformationName
    {
        get
        {
            return mTransformationName;
        }
        set
        {
            mTransformationName = value;
        }
    }

    #endregion


    /// <summary>
    /// Child control creation.
    /// </summary>
    protected override void CreateChildControls()
    {
        // Add product button
        this.btnRemoveProduct = new Button();
        this.btnRemoveProduct.CssClass = "HiddenButton";
        this.Controls.Add(this.btnRemoveProduct);
        this.btnRemoveProduct.Click += new EventHandler(btnRemoveProduct_Click);

        // Add the hidden fields for productId 
        this.hidProductID = new HiddenField();
        this.hidProductID.ID = "hidProductID";
        this.Controls.Add(this.hidProductID);
    }


    /// <summary>
    /// Page pre-render.
    /// </summary>
    protected void Page_PreRender(object sender, EventArgs e)
    {
        // Register the dialog scripts
        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "RemoveProductFromWishlist",
            ScriptHelper.GetScript(
                "function setProduct(val) { document.getElementById('" + this.hidProductID.ClientID + "').value = val; } \n" +
                "function RemoveFromWishlist(productId) { \n" +
                    "setProduct(productId); \n" +
                    this.Page.ClientScript.GetPostBackEventReference(this.btnRemoveProduct, null) +
                ";} \n"
            ));        
    }


    /// <summary>
    /// Removes product from wishlist
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void btnRemoveProduct_Click(object sender, EventArgs e)
    {
        // Remove specified product from the user's wishlist
        SKUInfoProvider.RemoveSKUFromWishlist(currentUser.UserID, ValidationHelper.GetInteger(this.hidProductID.Value, 0));

        ReloadData();
    }


    /// <summary>
    /// Reloads data for wishlist.
    /// </summary>
    private void ReloadData()
    {
        repeater.DataSource = SKUInfoProvider.GetWishlist(currentUser.UserID);
        repeater.DataBind();

        // Show "Empty wishlist" message
        if (DataHelper.DataSourceIsEmpty(repeater.DataSource))
        {
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("Ecommerce.Wishlist.EmptyMessage");
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        // Control initialiazation
        plcCartStep.GroupingText = ResHelper.GetString("Ecommerce.Wishlist.Title");
        btnContinue.Text = ResHelper.GetString("Ecommerce.Wishlist.btnContinue");        

        mSKUId = ValidationHelper.GetInteger(Request.QueryString["productID"], 0);        
        currentUser = CMSContext.CurrentUser;
        
        if (!this.IsPostBack && (mSKUId > 0))
        {
            // Add specified product to the user's wishlist
            SKUInfoProvider.AddSKUToWishlist(currentUser.UserID, mSKUId);
        }

        // Set repeater transformation
        repeater.TransformationName = this.TransformationName;

        ReloadData();


        // Set previous page url
        if ((!this.IsPostBack) && (Request.UrlReferrer != null))
        {
            string path = UrlHelper.GetAppRelativePath(Request.UrlReferrer);
            if (!UrlHelper.IsExcludedSystem(path))
            {
                this.PreviousPageUrl = Request.UrlReferrer.AbsoluteUri;
            }            
        }
    }


    // Continue shopping
    protected void btnContinue_Click(object sender, EventArgs e)
    {
        Response.Redirect(this.PreviousPageUrl);
    }

}
