using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.FormEngine;

public partial class CMSFormControls_CountrySelector : FormEngineUserControl
{
    private int stateId = 0;
    private int countryId = 0;
    private string stateName = "";
    private string countryName = "";
    private bool mAddNoneRecord = false;
    private bool mUseCodeNameForSelection = true;


    /// <summary>
    /// Add none record to the dropdownlist
    /// </summary>
    public bool AddNoneRecord
    {
        get
        {
            return mAddNoneRecord;
        }
        set
        {
            mAddNoneRecord = value;
        }
    }


    /// <summary>
    /// Set/get Value property in the form 'CountryName;StateName' or 'CountryID;StateID'
    /// </summary>
    public bool UseCodeNameForSelection
    {
        get
        {
            return mUseCodeNameForSelection;
        }
        set
        {
            mUseCodeNameForSelection = value;
        }
    }


    /// <summary>
    /// Selected country ID
    /// </summary>
    public int CountryID
    {
        get
        {
            if (mUseCodeNameForSelection)
            {
                CountryInfo ci = CountryInfoProvider.GetCountryInfo(drpCountry.SelectedValue);
                if (ci != null)
                {
                    return ci.CountryID;
                }
                return 0;
            }
            return ValidationHelper.GetInteger(drpCountry.SelectedValue, 0);
        }
        set
        {
            countryId = ValidationHelper.GetInteger(value, 0);
            if (countryId != 0)
            {
                try
                {
                    drpCountry.SelectedValue = countryId.ToString();
                    drpCountry_SelectedIndexChanged(this, new EventArgs());
                }
                catch
                {
                }
            }
        }
    }


    /// <summary>
    /// Selected State ID. Zero if not available
    /// </summary>
    public int StateID
    {
        get
        {
            if (drpState.Visible)
            {
                if (mUseCodeNameForSelection)
                {
                    StateInfo si = StateInfoProvider.GetStateInfo(drpState.SelectedValue);
                    if (si != null)
                    {
                        return si.StateID;
                    }
                }
                else
                {
                    return ValidationHelper.GetInteger(drpState.SelectedValue, 0);
                }
            }
            return 0;
        }
        set
        {
            stateId = ValidationHelper.GetInteger(value, 0);
            try
            {
                drpState.SelectedValue = stateId.ToString();
            }
            catch
            {
            }
        }
    }


    /// <summary>
    /// Selected Country name.
    /// </summary>
    public string CountryName
    {
        get
        {
            if (mUseCodeNameForSelection)
            {
                return drpCountry.SelectedValue;
            }
            else
            {
                CountryInfo ci = CountryInfoProvider.GetCountryInfo(ValidationHelper.GetInteger(drpCountry.SelectedValue, 0));
                if (ci != null)
                {
                    return ci.CountryName;
                }
                return "";
            }
        }
        set
        {
            countryName = value;
            if (!DataHelper.IsEmpty(countryName))
            {
                try
                {
                    drpCountry.SelectedValue = countryName;
                    drpCountry_SelectedIndexChanged(this, new EventArgs());
                }
                catch
                {
                }
            }
        }
    }


    /// <summary>
    /// Selected State name.
    /// </summary>
    public string StateName
    {
        get
        {
            if (drpState.Visible)
            {
                if (mUseCodeNameForSelection)
                {
                    return drpState.SelectedValue;
                }
                else
                {
                    StateInfo si = StateInfoProvider.GetStateInfo(ValidationHelper.GetInteger(drpState.SelectedValue, 0));
                    if (si != null)
                    {
                        return si.StateName;
                    }
                }
            }
            return "";
        }
        set
        {
            stateName = value;
            try
            {
                drpState.SelectedValue = stateName;
            }
            catch
            {
            }
        }
    }


    /// <summary>
    /// Gets or sets field value.
    /// </summary>
    public override object Value
    {
        get
        {
            if (mUseCodeNameForSelection)
            {
                return CountryName + ";" + StateName;
            }
            else
            {
                return CountryID + ";" + StateID;
            }
        }
        set
        {
            string[] ids = ValidationHelper.GetString(value, "").Split(';');

            if (ids.Length == 2)
            {
                if (mUseCodeNameForSelection)
                {
                    CountryName = ValidationHelper.GetString(ids[0], "");
                    StateName = ValidationHelper.GetString(ids[1], "");
                }
                else
                {
                    CountryID = ValidationHelper.GetInteger(ids[0], 0);
                    StateID = ValidationHelper.GetInteger(ids[1], 0);
                }
            }
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!StopProcessing)
        {
            drpCountry.SelectedIndexChanged += new EventHandler(drpCountry_SelectedIndexChanged);

            if (this.drpCountry.Items.Count == 0)
            {
                LoadData();
            }
        }
    }


    private void drpCountry_SelectedIndexChanged(object sender, EventArgs e)
    {
        if (mUseCodeNameForSelection)
        {
            CountryInfo ci = CountryInfoProvider.GetCountryInfo(drpCountry.SelectedValue);
            if (ci != null)
            {
                DataSet ds = CountryInfoProvider.GetCountryStates(ci.CountryID);
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    drpState.ClearSelection();
                    drpState.SelectedIndex = -1;
                    drpState.SelectedValue = null;

                    drpState.Visible = true;
                    drpState.DataSource = ds;
                    drpState.DataTextField = "StateDisplayName";
                    drpState.DataValueField = "StateName";
                    drpState.DataBind();

                    if (this.stateName != "")
                    {
                        drpState.SelectedValue = this.stateName;
                    }
                }
                else
                {
                    drpState.Visible = false;
                }
            }
            else
            {
                drpState.Visible = false;
            }
        }
        else
        {
            int countryId = ValidationHelper.GetInteger(drpCountry.SelectedValue, 0);
            if (countryId != 0)
            {
                DataSet ds = CountryInfoProvider.GetCountryStates(countryId);
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    drpState.ClearSelection();
                    drpState.SelectedIndex = -1;
                    drpState.SelectedValue = null;

                    drpState.Visible = true;
                    drpState.DataSource = ds;
                    drpState.DataTextField = "StateDisplayName";
                    drpState.DataValueField = "StateID";
                    drpState.DataBind();

                    if (this.stateId > 0)
                    {
                        drpState.SelectedValue = this.stateId.ToString();
                    }
                }
                else
                {
                    drpState.Visible = false;
                }
            }
            else
            {
                drpState.Visible = false;
            }
        }
    }


    /// <summary>
    /// Loads country selector.
    /// </summary>
    public void LoadData()
    {
        // Fill the county list
        DataSet ds = CountryInfoProvider.GetAllCountries();
        if (!DataHelper.DataSourceIsEmpty(ds) && this.AddNoneRecord)
        {
            DataRow noneRow = ds.Tables[0].NewRow();
            noneRow["CountryDisplayName"] = ResHelper.GetString("Country.None");
            if (mUseCodeNameForSelection)
            {
                noneRow["CountryName"] = "";
            }
            else
            {
                noneRow["CountryID"] = 0;
            }
            ds.Tables[0].Rows.InsertAt(noneRow, 0);
        }
        drpCountry.DataSource = ds;
        drpCountry.DataTextField = "CountryDisplayName";
        if (mUseCodeNameForSelection)
        {
            drpCountry.DataValueField = "CountryName";
        }
        else
        {
            drpCountry.DataValueField = "CountryID";
        }

        try
        {
            drpCountry.DataBind();
        }
        catch
        {
            if (mUseCodeNameForSelection)
            {
                drpCountry.DataValueField = "CountryID";
            }
            else
            {
                drpCountry.DataValueField = "CountryName";
            }

            try
            {
                drpCountry.DataBind();
            }
            catch
            {
            }
        }

        drpCountry_SelectedIndexChanged(this, null);
    }
}
