using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.FormEngine;

public partial class CMSFormControls_CurrencySelector : FormEngineUserControl
{
    private int mCurrencyId = 0;
    private bool mAddNoneRecord = false;
    private bool mCheckUser = false;
    private string mDropDownItemEnabledCss = "";
    private string mDropDownItemDisabledCss = "";


    #region " Public properties "

    /// <summary>
    /// If is true, currency is checke if is enabled and have current exchange table
    /// </summary>
    public bool CheckUser
    {
        get
        {
            return mCheckUser;
        }
        set
        {
            mCheckUser = value;
        }
    }

    /// <summary>
    /// Add none record to the dropdownlist
    /// </summary>
    public bool AddNoneRecord
    {
        get
        {
            return mAddNoneRecord;
        }
        set
        {
            mAddNoneRecord = value;
        }
    }


    /// <summary>
    /// Currency ID
    /// </summary>
    public int CurrencyID
    {
        get { return ValidationHelper.GetInteger(drpCurrency.SelectedValue, 0); }
        set { mCurrencyId = value; }
    }


    /// <summary>
    /// Gets or sets field value.
    /// </summary>
    public override object Value
    {
        get
        {
            return ValidationHelper.GetInteger(drpCurrency.SelectedValue, 0); ;
        }
        set
        {
            mCurrencyId = ValidationHelper.GetInteger(value, 0);
        }
    }

    /// <summary>
    /// Enabled dropdownlist item css style.
    /// </summary>
    public string DropDownItemEnabledCss
    {
        get
        {
            return mDropDownItemEnabledCss;
        }
        set
        {
            mDropDownItemEnabledCss = value;
        }
    }


    /// <summary>
    /// Disabled dropdownlist item css style.
    /// </summary>
    public string DropDownItemDisabledCss
    {
        get
        {
            return mDropDownItemDisabledCss;
        }
        set
        {
            mDropDownItemDisabledCss = value;
        }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {        
        if ((!StopProcessing && !Page.IsPostBack) || ((this.DropDownItemEnabledCss != "") || (this.DropDownItemDisabledCss != "")))
        {
            LoadData();
        }
    }


    protected void LoadData()
    {
        DataSet ds = null;

        if (!mCheckUser)
        {
            ds = CurrencyInfoProvider.GetAllCurrencies();
        }
        else
        {
            if (CMSContext.CurrentUser != null)
            {
                if (CMSContext.CurrentUser.IsGlobalAdministrator)
                {
                    ds = CurrencyInfoProvider.GetAllCurrencies();
                }
                else
                {
                    ds = CurrencyInfoProvider.GetCurrenciesWithExchangeRate();
                }
            }
            else
            {
                ds = CurrencyInfoProvider.GetAllCurrencies();
            }
        }

        // Remember previously selected item
        ListItem li = drpCurrency.SelectedItem;

        if (!DataHelper.DataSourceIsEmpty(ds) && this.AddNoneRecord)
        {
            DataRow noneRow = ds.Tables[0].NewRow();
            noneRow["CurrencyDisplayName"] = ResHelper.GetString("Currency.None");
            noneRow["CurrencyID"] = 0;
            ds.Tables[0].Rows.InsertAt(noneRow, 0);
        }
        drpCurrency.DataSource = ds;        
        drpCurrency.DataTextField = "CurrencyDisplayName";
        drpCurrency.DataValueField = "CurrencyID";
        drpCurrency.DataBind();

        if ((this.DropDownItemEnabledCss != "") || (this.DropDownItemDisabledCss != ""))
        {
            EcommerceFunctions.MarkEnabledAndDisabledItems(drpCurrency, "CurrencyID", "CurrencyEnabled");
        }

        if ((li != null) && (drpCurrency.Items.FindByValue(mCurrencyId.ToString()) != null))
        {
            drpCurrency.SelectedValue = li.Value;
        }
        else if ((mCurrencyId != 0) && (drpCurrency.Items.FindByValue(mCurrencyId.ToString()) != null))
        {
            drpCurrency.SelectedValue = mCurrencyId.ToString();
        }    
    }

}
