using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSFormControls_PaymentSelector : CMS.FormEngine.FormEngineUserControl
{
    private int mPaymentId = 0;
    private bool mAddNoneRecord = false;
    private int mShippingOptionId = 0;
    private StatusEnum mDisplayItems = StatusEnum.Both;
    private string mDropDownItemEnabledCss = "";
    private string mDropDownItemDisabledCss = "";


    #region " Public properties "
     
    /// <summary>
    /// Indicates which payment methods should be displayed (Enabled/Disabled/Both). Default values is 'Both'.
    /// </summary>
    public StatusEnum DisplayItems
    {
        get
        {
            return mDisplayItems;
        }
        set
        {
            mDisplayItems = value;
        }
    }


    /// <summary>
    /// Add none record to the dropdownlist
    /// </summary>
    public bool AddNoneRecord
    {
        get
        {
            return mAddNoneRecord;
        }
        set
        {
            mAddNoneRecord = value;
        }
    }


    /// <summary>
    /// Payment ID
    /// </summary>
    public int PaymentID
    {
        get { return ValidationHelper.GetInteger(drpPayment.SelectedValue, 0); }
        set { mPaymentId = value; }
    }



    /// <summary>
    /// Shipping option ID.
    /// </summary>
    public int ShippingOptionID
    {
        get { return mShippingOptionId; }
        set { mShippingOptionId = value; }
    }


    /// <summary>
    /// Gets or sets field value.
    /// </summary>
    public override object Value
    {
        get
        {
            return ValidationHelper.GetInteger(drpPayment.SelectedValue, 0); ;
        }
        set
        {
            mPaymentId = ValidationHelper.GetInteger(value, 0);
        }
    }


    /// <summary>
    /// Enabled dropdownlist item css style.
    /// </summary>
    public string DropDownItemEnabledCss
    {
        get
        {
            return mDropDownItemEnabledCss;
        }
        set
        {
            mDropDownItemEnabledCss = value;
        }
    }


    /// <summary>
    /// Disabled dropdownlist item css style.
    /// </summary>
    public string DropDownItemDisabledCss
    {
        get
        {
            return mDropDownItemDisabledCss;
        }
        set
        {
            mDropDownItemDisabledCss = value;
        }
    }

#endregion


    protected void Page_Load(object sender, EventArgs e)
    {
        if ((!StopProcessing && !Page.IsPostBack) || ((this.DropDownItemEnabledCss != "") || (this.DropDownItemDisabledCss != "")))
        {
            LoadData();        
        }
    }


    /// <summary>
    /// Loads payment methods according to the control settings.
    /// </summary>
    public void LoadData()
    {
        DataSet ds = null;

        // Display only payment methods for specified shippiong option
        if (this.ShippingOptionID > 0)
        {

            bool enabled = false;
            bool disabled = false;

            switch (this.DisplayItems)
            {
                case StatusEnum.Enabled:
                    enabled = true;
                    break;

                case StatusEnum.Disabled:
                    disabled = true;
                    break;

                case StatusEnum.Both:
                    enabled = true;
                    disabled = true;
                    break;
            }

            ds = PaymentOptionInfoProvider.GetShippingPayments(this.ShippingOptionID, enabled, disabled);
        }
        // Display all payment methods for specified site
        else
        {
            ds = PaymentOptionInfoProvider.GetAllPaymentsForSite(CMSContext.CurrentSite.SiteID, this.DisplayItems);
        }

        if (!DataHelper.DataSourceIsEmpty(ds) && this.AddNoneRecord)
        {
            DataRow noneRow = ds.Tables[0].NewRow();
            noneRow["PaymentOptionDisplayName"] = ResHelper.GetString("Payment.None");
            noneRow["PaymentOptionID"] = 0;
            ds.Tables[0].Rows.InsertAt(noneRow, 0);
        }

        // Remember previously selected item
        ListItem li = drpPayment.SelectedItem;

        drpPayment.DataSource = ds;
        drpPayment.DataTextField = "PaymentOptionDisplayName";
        drpPayment.DataValueField = "PaymentOptionID";
        drpPayment.DataBind();

        if ((this.DropDownItemEnabledCss != "") || (this.DropDownItemDisabledCss != ""))
        {
            EcommerceFunctions.MarkEnabledAndDisabledItems(drpPayment, "PaymentOptionID", "PaymentOptionEnabled", this.DropDownItemEnabledCss, this.DropDownItemDisabledCss);
        }

        if ((li != null) && (drpPayment.Items.FindByValue(mPaymentId.ToString()) != null))
        {
            drpPayment.SelectedValue = li.Value;
        }
        else if ((mPaymentId != 0) && (drpPayment.Items.FindByValue(mPaymentId.ToString()) != null))
        {
            drpPayment.SelectedValue = mPaymentId.ToString();
        }
    }

}
