using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;

public partial class CMSFormControls_securitycode : CMS.FormEngine.FormEngineUserControl
{

    private bool mGenerateNumberEveryTime = true;
    private bool mShowInfoLabel = false;
    private bool mShowAfterText = false;
    private bool mForumExtension = false;

    /// <summary>
    /// Indicates wheather the after text should be displayed.
    /// </summary>
    public bool ShowAfterText
    {
        get
        {
            return mShowAfterText;
        }
        set
        {
            mShowAfterText = value;
        }
    }

    /// <summary>
    /// Forum extension
    /// </summary>
    public bool ForumExtension
    {
        get
        {
            return mForumExtension;
        }
        set
        {
            mForumExtension = value;
        }
    }


    /// <summary>
    /// Indicates wheather new random number is generated after the wrong number was entered.
    /// </summary>
    public bool GenerateNumberEveryTime
    {
        get
        {
            return mGenerateNumberEveryTime;
        }
        set
        {
            mGenerateNumberEveryTime = value;
        }
    }


    /// <summary>
    /// Indicates wheather the info label should be displayed.
    /// </summary>
    public bool ShowInfoLabel
    {
        get
        {
            return mShowInfoLabel;
        }
        set
        {
            mShowInfoLabel = value;
        }
    }


    /// <summary>
    /// Gets or sets field value.
    /// </summary>
    public override object Value
    {
        get
        {
            return this.txtSecurityCode.Text;
        }
        set
        {
            this.txtSecurityCode.Text = (string)value;
        }
    }


    // For generating random numbers.
    private Random random = new Random();
    
    protected void Page_Load(object sender, EventArgs e)
    {
        if (this.ShowInfoLabel)
        {
            this.lblSecurityCode.Text = ResHelper.GetString("SecurityCode.lblSecurityCode");
        }
        else
        {
            this.lblSecurityCode.Visible = false;
        }

        if (this.ShowAfterText)
        {
            this.plcAfterText.Visible = true;
            this.lblAfterText.Text = ResHelper.GetString("SecurityCode.Aftertext");
        }
        else
        {
            this.plcAfterText.Visible = false;
        }

        if (!this.IsPostBack)
        {
            // Create a random code and store it in the Session object.
            if (!this.ForumExtension)
            {
                this.Session["CaptchaImageText"] = GenerateRandomCode();
            }
        }
        else
        {
            if (!IsValid() && GenerateNumberEveryTime)
            {
                this.txtSecurityCode.Text = "";
                this.Session["CaptchaImageText"] = GenerateRandomCode();
            }
        }
    }


    /// <summary>
    /// Generate new code
    /// </summary>
    public void GenerateNewCode()
    {
        this.txtSecurityCode.Text = "";
        this.Session["CaptchaImageText"] = GenerateRandomCode();
    }


    /// <summary>
    /// Return true if user control is valid.
    /// </summary>
    /// <returns></returns>
    public override bool IsValid()
    {
        bool isValid = false;
        if (this.Session["CaptchaImageText"] != null)
        {
            isValid = (txtSecurityCode.Text == Convert.ToString(this.Session["CaptchaImageText"]));
        }

        if (!isValid)
        {
            this.ValidationError = ResHelper.GetString("SecurityCode.ValidationError");
        }
        return isValid;
    }


    //
    // Return a string of six random digits.
    //
    private string GenerateRandomCode()
    {
        string s = "";
        for (int i = 0; i < 6; i++)
        {
            s = String.Concat(s, this.random.Next(10).ToString());
        }
        return s;
    }

}
