using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Ecommerce;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSFormControls_ShippingSelector : CMS.FormEngine.FormEngineUserControl
{
    private int mShippingId = 0;
    private bool mAddNoneRecord = false;
    private StatusEnum mDisplayItems = StatusEnum.Both;
    private string mDropDownItemEnabledCss = "";
    private string mDropDownItemDisabledCss = "";


    #region " Public properties "

    /// <summary>
    /// Indicates which shipping options should be displayed (Enabled/Disabled/Both). Default values is 'Both'.
    /// </summary>
    public StatusEnum DisplayItems
    {
        get
        {
            return mDisplayItems;
        }
        set
        {
            mDisplayItems = value;
        }
    }


    /// <summary>
    /// Add none record to the dropdownlist
    /// </summary>
    public bool AddNoneRecord
    {
        get
        {
            return mAddNoneRecord;
        }
        set
        {
            mAddNoneRecord = value;
        }
    }


    /// <summary>
    /// Shipping ID
    /// </summary>
    public int ShippingID
    {
        get { return ValidationHelper.GetInteger(drpShipping.SelectedValue, 0); }
        set { mShippingId = value; }
    }


    /// <summary>
    /// Gets or sets field value.
    /// </summary>
    public override object Value
    {
        get
        {
            return ValidationHelper.GetInteger(drpShipping.SelectedValue, 0); ;
        }
        set
        {
            mShippingId = ValidationHelper.GetInteger(value, 0);
        }
    }

    /// <summary>
    /// Enabled dropdownlist item css style.
    /// </summary>
    public string DropDownItemEnabledCss
    {
        get
        {
            return mDropDownItemEnabledCss;
        }
        set
        {
            mDropDownItemEnabledCss = value;
        }
    }


    /// <summary>
    /// Disabled dropdownlist item css style.
    /// </summary>
    public string DropDownItemDisabledCss
    {
        get
        {
            return mDropDownItemDisabledCss;
        }
        set
        {
            mDropDownItemDisabledCss = value;
        }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {

        if ((!StopProcessing && !Page.IsPostBack) || ((this.DropDownItemEnabledCss != "") || (this.DropDownItemDisabledCss != "")))
        {
            LoadData();   
        }

    }

    protected void LoadData()
    {
        DataSet ds = ShippingOptionInfoProvider.GetAllShippingsForSite(CMSContext.CurrentSite.SiteID, this.DisplayItems);

        if (!DataHelper.DataSourceIsEmpty(ds) && this.AddNoneRecord)
        {
            DataRow noneRow = ds.Tables[0].NewRow();
            noneRow["ShippingOptionDisplayName"] = ResHelper.GetString("Shipping.None");
            noneRow["ShippingOptionID"] = 0;
            ds.Tables[0].Rows.InsertAt(noneRow, 0);
        }

        // Remember previously selected item
        ListItem li = drpShipping.SelectedItem;

        drpShipping.DataSource = ds;
        drpShipping.DataTextField = "ShippingOptionDisplayName";
        drpShipping.DataValueField = "ShippingOptionID";
        drpShipping.DataBind();


        if ((this.DropDownItemEnabledCss != "") || (this.DropDownItemDisabledCss != ""))
        {
            EcommerceFunctions.MarkEnabledAndDisabledItems(drpShipping, "ShippingOptionID", "ShippingOptionEnabled");
        }

        if ((li != null) && (drpShipping.Items.FindByValue(mShippingId.ToString()) != null))
        {
            drpShipping.SelectedValue = li.Value;
        }
        else if ((mShippingId != 0) && (drpShipping.Items.FindByValue(mShippingId.ToString()) != null))
        {
            drpShipping.SelectedValue = mShippingId.ToString();
        }
    }
}
