using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using System.IO;
using CMS.FileManager;
using CMS.DirectoryUtilities;

public partial class CMSFormControls_UserPictureEdit : CMS.FormEngine.FormEngineUserControl
{
    UserInfo mUserInfo;


    /// <summary>
    /// User information
    /// </summary>
    public UserInfo UserInfo
    {
        get { return mUserInfo; }
        set
        {
            mUserInfo = value;
            picUser.UserID = mUserInfo.UserID;
            if (mUserInfo.UserPicture != "")
            {
                plcImageActions.Visible = true;
            }
            else
            {
                plcImageActions.Visible = false;
            }
        }
    }


    /// <summary>
    /// Max picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get 
        { 
            return picUser.Width; 
        }
        set
        {
            picUser.Width = ValidationHelper.GetInteger(value, 0);
        }
    }

    
    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get 
        { 
            return picUser.Height; 
        }
        set
        {
            picUser.Height = ValidationHelper.GetInteger(value, 0);
        }
    }


    /// <summary>
    /// Max upload file/picture field width
    /// </summary>
    public int FileUploadFieldWidth
    {
        get { return (int)uplFilePicture.Width.Value; }
        set { uplFilePicture.Width = Unit.Pixel(value); }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {        
        btnDeleteImage.ImageUrl = ResolveUrl("~/App_Themes/Default/Images/Controls/Uploader/delete.gif");
        btnDeleteImage.OnClientClick = "return DeleteConfirmation();";        
    }


    public void UpdateUserPicture(UserInfo ui)
    {
        this.UserInfo = ui;
        if (uplFilePicture.HasFile)
        {
            try
            {                
                string mgui = Guid.NewGuid().ToString();
                string extension = "";
                if (uplFilePicture.FileName.Contains("."))
                {
                    extension = uplFilePicture.FileName.Remove(0, uplFilePicture.FileName.LastIndexOf('.') + 1);
                }

                if (ImageHelper.IsImage(extension))
                {

                    string mGuid = Guid.NewGuid().ToString();

                    // Remove old picture
                    if (ui.UserPicture != "")
                    {
                        try
                        {
                            // Remove from HDD
                            string jDirectory = HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/UserPictures/");
                            string filename = ui.UserPicture.Remove(ui.UserPicture.IndexOf('/'));
                            if (File.Exists(jDirectory + filename))
                            {
                                File.Delete(jDirectory + filename);
                            }
                        }
                        catch
                        {
                        }

                        ui.UserPicture = "";
                        UserInfoProvider.SetUserInfo(ui);
                        CMSContext.CurrentUser.UserPicture = "";
                    }

                    string name = mGuid + "." + extension + "/" + uplFilePicture.FileName;

                    string mDirectory = HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/UserPictures/");

                    if (!Directory.Exists(mDirectory))
                    {
                        DirectoryHelper.CreateDirectory(mDirectory);
                    }

                    uplFilePicture.SaveAs(mDirectory + mGuid + "." + extension);

                    ui.UserPicture = name;
                    CMSContext.CurrentUser.UserPicture = name;
                }
                else
                {
                    lblPictureError.Visible = true;
                    lblPictureError.Text = ResHelper.GetString("User.UserPictureExtensionError");
                }
            }
            catch
            {
            }
        }
    }


    protected void DeleteImage_Click(object sender, EventArgs e)
    {
        UserInfo ui = this.UserInfo;
        if (ui != null)
        {

            try
            {
                // Remove from HDD
                string mDirectory = HttpContext.Current.Server.MapPath("~/CMSGlobalFiles/UserPictures/");
                string filename = ui.UserPicture.Remove(ui.UserPicture.IndexOf('/'));
                if (File.Exists(mDirectory + filename))
                {
                    File.Delete(mDirectory + filename);
                }
            }
            catch
            {
            }


            ui.UserPicture = "";
            UserInfoProvider.SetUserInfo(ui);
            CMSContext.CurrentUser.UserPicture = "";

            plcImageActions.Visible = false;
        }
    }
}
