using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.Forums;
using CMS.CMSHelper;

public partial class CMSForum_Forum : System.Web.UI.UserControl
{
    /// <summary>
    /// Forum properties
    /// </summary>
    public ForumProperties mForumProperties = new ForumProperties();


    #region "Public properties"

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return mForumProperties.EnablePicture; ; }
        set { mForumProperties.EnablePicture = value; }
    }


    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return mForumProperties.MaxPictureWidth; }
        set { mForumProperties.MaxPictureWidth = value; }
    }


    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return mForumProperties.MaxPictureHeight; }
        set { mForumProperties.MaxPictureHeight = value; }
    }


    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return mForumProperties.EnableSignature; }
        set { mForumProperties.EnableSignature = value; }
    }


    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get { return mForumProperties.EnableSubscription; }
        set { mForumProperties.EnableSubscription = value; }
    }


    /// <summary>
    /// If set public user can read, no insert new post
    /// </summary>
    public bool NoAuthenticatedRead
    {
        get { return mForumProperties.NoAuthenticatedRead; }
        set { mForumProperties.NoAuthenticatedRead = value; }
    }


    /// <summary>
    /// Alternating style
    /// </summary>
    public bool UseAlternatingStyle
    {
        get { return mForumProperties.UseAlternatingStyle; }
        set { mForumProperties.UseAlternatingStyle = value; }
    }


    /// <summary>
    /// Query strin represent Forum
    /// </summary>
    public string QueryStringForumID
    {
        get { return mForumProperties.QueryStringForumID; }
        set { mForumProperties.QueryStringForumID = value; }
    }


    /// <summary>
    /// CheckPermissions
    /// </summary>
    public bool CheckPermissions
    {
        get { return mForumProperties.CheckPermissions; }
        set { mForumProperties.CheckPermissions = value; }
    }


    /// <summary>
    /// GroupId
    /// </summary>
    public int GroupID
    {
        get { return mForumProperties.GroupID; }
        set { mForumProperties.GroupID = value; }
    }


    /// <summary>
    /// DisplayOnlyOpen
    /// </summary>
    public bool DisplayOnlyOpen
    {
        get { return mForumProperties.DisplayOnlyOpen; }
        set { mForumProperties.DisplayOnlyOpen = value; }
    }


    /// <summary>Enable paging</summary>
    public bool EnablePaging
    {
        get { return mForumProperties.EnablePaging; }
        set { mForumProperties.EnablePaging = value; }
    }


    /// <summary>Page size</summary>
    public int PageSize
    {
        get { return mForumProperties.PageSize; }
        set { mForumProperties.PageSize = value; }
    }


    /// <summary> Stop processing </summary>
    public bool StopProcessing
    {
        get { return mForumProperties.StopProcessing; }
        set { mForumProperties.StopProcessing = value; }
    }


    /// <summary> ShowMode </summary>
    public ShowModeEnum ShowMode
    {
        get { return mForumProperties.ShowMode; }
        set { mForumProperties.ShowMode = value; }
    }


    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get { return mForumProperties.WhereCondition; }
        set { mForumProperties.WhereCondition = value; }
    }


    /// <summary>
    /// Path
    /// </summary>
    public string PostPath
    {
        get { return mForumProperties.PostPath; }
        set { mForumProperties.PostPath = value; }
    }


    /// <summary>
    /// Max relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get { return mForumProperties.MaxRelativeLevel; }
        set { mForumProperties.MaxRelativeLevel = value; }
    }


    /// <summary>
    /// Select only approved
    /// </summary>
    public bool SelectOnlyApproved
    {
        get { return mForumProperties.SelectOnlyApproved; }
        set { mForumProperties.SelectOnlyApproved = value; }
    }


    /// <summary>
    /// Expand tree
    /// </summary>
    public bool ExpandTree
    {
        get { return mForumProperties.ExpandTree; }
        set { mForumProperties.ExpandTree = value; }
    }


    /// <summary>
    /// Use flat view
    /// </summary>
    public bool UseFlatView
    {
        get { return mForumProperties.UseFlatView; }
        set { mForumProperties.UseFlatView = value; }
    }


    /// <summary>
    /// name of group
    /// </summary>
    public string GroupName
    {
        get { return mForumProperties.GroupName; }
        set { mForumProperties.GroupName = value; }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {
        ForumFlatView1.mForumProperties = this.mForumProperties;
        ForumTreeView1.mForumProperties = this.mForumProperties;
        ForumGroup1.mForumProperties = this.mForumProperties;

        if (this.StopProcessing)
        {
            return;
        }

        string siteName = CMSContext.CurrentSiteName;

        ForumInfo fi = null;
        ForumGroupInfo fgi = null;

        //Check if isn't unsubscribe request
        mForumProperties.CheckUnsubscribe();

        // Check searching
        string search = ValidationHelper.GetString(Request.QueryString["SearchForum"], "");
        if (search != "")
        {
            this.StopProcessing = true;
            return;
        }

        // Get forum
        int forumId = ValidationHelper.GetInteger(HttpContext.Current.Request.QueryString[ForumGroup1.QueryStringForumID], 0);
        if (forumId > 0)
        {
            //Check permissions
            if (!mForumProperties.CheckPermission(forumId) && (!NoAuthenticatedRead))
            {
                StopProcessing = true;
                return;
            }

            fi = ForumInfoProvider.GetForumInfo(forumId);
        }

        if ((fi == null) || ((!fi.ForumOpen) && (this.mForumProperties.DisplayOnlyOpen)))
        {
            // Get forum group
            fgi = ForumGroupInfoProvider.GetForumGroupInfo(this.GroupName, siteName);

            // Show forum group
            ForumFlatView1.Visible = false;
            ForumTreeView1.Visible = false;

            if (fgi != null)
            {
                ForumGroup1.Visible = true;
                ForumGroup1.GroupID = fgi.GroupID;
            }
            else
            {
                ForumGroup1.Visible = false;
            }
        }
        else
        {
            ForumGroup1.Visible = false;

            if (this.UseFlatView)
            {
                // FlatView
                ForumTreeView1.Visible = false;

                ForumFlatView1.Visible = true;
                ForumFlatView1.ForumID = forumId;
            }
            else
            {
                // Tree view
                ForumTreeView1.Visible = true;
                ForumTreeView1.ForumID = forumId;

                ForumFlatView1.Visible = false;
            }
        }
    }


    /// <summary> 
    /// Render 
    /// </summary>
    /// <param name="writer"></param>
    protected override void Render(HtmlTextWriter writer)
    {
        if (!this.StopProcessing)
        {
            base.Render(writer);
        }
    }

}
