using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Forums;
using CMS.GlobalHelper;
using CMS.ExtendedControls;
using CMS.CMSHelper;
using CMS.URLRewritingEngine;

/// <summary>
/// Forum group control
/// </summary>
public partial class CMSForum_ForumGroup : System.Web.UI.UserControl
{
    // Forum properties
    public ForumProperties mForumProperties = new ForumProperties();

    #region "Public properties"

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return mForumProperties.EnablePicture; ; }
        set { mForumProperties.EnablePicture = value; }
    }


    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return mForumProperties.MaxPictureWidth; }
        set { mForumProperties.MaxPictureWidth = value; }
    }


    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return mForumProperties.MaxPictureHeight; }
        set { mForumProperties.MaxPictureHeight = value; }
    }


    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return mForumProperties.EnableSignature; }
        set { mForumProperties.EnableSignature = value; }
    }


    /// <summary>
    /// If set public user can read, no insert new post
    /// </summary>
    public bool NoAuthenticatedRead
    {
        get { return mForumProperties.NoAuthenticatedRead; }
        set { mForumProperties.NoAuthenticatedRead = value; }
    }


    /// <summary>
    /// Alternating style
    /// </summary>
    public bool UseAlternatingStyle
    {
        get { return mForumProperties.UseAlternatingStyle; }
        set { mForumProperties.UseAlternatingStyle = value; }
    }


    /// <summary>
    /// Query strin represent Forum
    /// </summary>
    public string QueryStringForumID
    {
        get { return mForumProperties.QueryStringForumID; }
        set { mForumProperties.QueryStringForumID = value; }
    }


    /// <summary>
    /// GroupId
    /// </summary>
    public int GroupID
    {
        get { return mForumProperties.GroupID; }
        set { mForumProperties.GroupID = value; }
    }


    /// <summary>
    /// DisplayOnlyOpen
    /// </summary>
    public bool DisplayOnlyOpen
    {
        get { return mForumProperties.DisplayOnlyOpen; }
        set { mForumProperties.DisplayOnlyOpen = value; }
    }


    /// <summary>
    /// CheckPermissions
    /// </summary>
    public bool CheckPermissions
    {
        get { return mForumProperties.CheckPermissions; }
        set { mForumProperties.CheckPermissions = value; }
    }


    /// <summary> Stop processing </summary>
    public bool StopProcessing
    {
        get { return mForumProperties.StopProcessing; }
        set { mForumProperties.StopProcessing = value; }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {
        // Do not proccess if stop processing is set
        if (StopProcessing)
        {
            return;
        }

        // Set string values
        lblForum.Text = ResHelper.GetString("ForumGroup.lblForum");
        lblPosts.Text = ResHelper.GetString("ForumGroup.lblPosts");
        lblThreads.Text = ResHelper.GetString("ForumGroup.lblThreads");
        lblLastPost.Text = ResHelper.GetString("ForumGroup.lblLastPost");

        // Get current forum group info
        ForumGroupInfo fgi = ForumGroupInfoProvider.GetForumGroupInfo(this.GroupID);

        if (fgi != null)
        {
            lblForumHeader.Text = HTMLHelper.HTMLEncode(ResHelper.LocalizeString(fgi.GroupDisplayName));
            lblForumHeaderDescription.Text = HTMLHelper.HTMLEncode(ResHelper.LocalizeString(fgi.GroupDescription));

            // Get all forums for group
            DataSet ds = ForumInfoProvider.GetForumsByGroupID(this.GroupID);

            string mForums = "";

            // Assign alternate row
            bool even = false;

            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                foreach (DataRow dr in ds.Tables[0].Rows)
                {
                    // Change alterante value for every row
                    even = !even;

                    // Display only open forums
                    if ((!this.DisplayOnlyOpen) || (ValidationHelper.GetBoolean(dr["ForumOpen"], false)))
                    {
                        // Get forum access value
                        int mForumAcess = ValidationHelper.GetInteger(dr["ForumAccess"], 0);

                        // Check permissions and display only allowed forum
                        if ((!this.CheckPermissions) || mForumProperties.CheckPermission(ValidationHelper.GetInteger(dr["ForumID"], 0)) || NoAuthenticatedRead)
                        {
                            // Get last post in forum
                            DataSet mDs = null;
                            mDs = ForumPostInfoProvider.SelectForumPosts(ValidationHelper.GetInteger(dr["ForumID"], 0), "/%", "PostUserName = '" + Server.HtmlDecode(ValidationHelper.GetString(dr["ForumLastPostUserName"], "")).Replace("'", "''") + "'", "'PostTime'");

                            // Counts of threads and posts
                            int numThreads = ValidationHelper.GetInteger(dr["ForumThreads"], 0);
                            int numPosts = ValidationHelper.GetInteger(dr["forumPosts"], 0);

                            // Get count of posts and threads
                            if (!this.mForumProperties.SelectOnlyApproved)
                            {
                                // Get thrad count
                                DataSet jds = ForumPostInfoProvider.SelectForumPosts(ValidationHelper.GetInteger(dr["ForumId"], 0), "/%", "PostLevel=0", null, -1, false);
                                if (!DataHelper.DataSourceIsEmpty(jds))
                                {
                                    numThreads = jds.Tables[0].Rows.Count;
                                }

                                // Get posts count
                                jds = ForumPostInfoProvider.SelectForumPosts(ValidationHelper.GetInteger(dr["ForumId"], 0), "/%", null, null, -1, false);
                                if (!DataHelper.DataSourceIsEmpty(jds))
                                {
                                    numPosts = jds.Tables[0].Rows.Count;
                                }
                            }
                            else // Set post count only for posts where root post is approved
                            {
                                ForumInfo fi = ForumInfoProvider.GetForumInfo(ValidationHelper.GetInteger(dr["ForumId"], 0));

                                // Do special count only for moderated forums
                                if ((fi != null) && (fi.ForumModerated))
                                {
                                    DataSet jds = ForumPostInfoProvider.SelectForumPosts(ValidationHelper.GetInteger(dr["ForumId"], 0), "/%", null, "PostIDPath", -1, false);
                                    if (!DataHelper.DataSourceIsEmpty(jds))
                                    {
                                        // Get all threads and check if some post under this thread are
                                        // approwed but thread isn't
                                        numPosts = 0;
                                        Hashtable threads = new Hashtable();
                                        foreach (DataRow mdr in jds.Tables[0].Rows)
                                        {
                                            ForumPostInfo jfpi = new ForumPostInfo(mdr);
                                            if (jfpi != null)
                                            {
                                                if (jfpi.PostIDPath.LastIndexOf('/') == jfpi.PostIDPath.IndexOf('/'))
                                                {
                                                    if (jfpi.PostApprovedByUserID != 0)
                                                    {
                                                        numPosts++;
                                                    }
                                                    else
                                                    {
                                                        threads[jfpi.PostIDPath] = 0;
                                                    }
                                                }
                                                else
                                                {
                                                    string mPath = jfpi.PostIDPath;
                                                    mPath = mPath.Remove(mPath.IndexOf('/', 2));
                                                    if ((threads[mPath] == null) && (jfpi.PostApprovedByUserID != 0))
                                                    {
                                                        numPosts++;
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }

                            // Create group row
                            mForums += CreateForumRow(Server.HtmlEncode(ValidationHelper.GetString(dr["ForumDisplayName"], "")), Server.HtmlEncode(ValidationHelper.GetString(dr["ForumDescription"], "")),
                                                      numThreads, numPosts,
                                                      Server.HtmlEncode(ValidationHelper.GetString(dr["ForumLastPostUserName"], "")), ValidationHelper.GetDateTime(dr["ForumLastPostTime"],
                                                      DateTimePicker.NOT_SELECTED), ValidationHelper.GetInteger(dr["ForumID"], 0), even, mDs, ValidationHelper.GetBoolean(dr["ForumDisplayEmails"], false));
                        }
                    }
                }

                // Set group HTML code
                ltlForums.Text = mForums;
            }
        }
    }

    /// <summary>
    /// Generate forum row
    /// </summary>
    /// <param name="forumName"></param>
    /// <param name="forumDescription"></param>
    /// <param name="threads"></param>
    /// <param name="posts"></param>
    public string CreateForumRow(string forumName, string forumDescription, int threads, int posts, string lastUser, DateTime lastTime, int forumId, bool even, DataSet lastPost, bool displayEmail)
    {
        string row = "";

        string url = URLRewriter.CurrentURL;
        url = UrlHelper.AddParameterToUrl(url, this.QueryStringForumID, forumId.ToString());

        // Row
        if (this.UseAlternatingStyle)
        {
            if (even)
            {
                row += "<tr class=\"Forum ForumEven\">";
            }
            else
            {
                row += "<tr class=\"Forum ForumOdd\">";
            }
        }
        else
        {
            row += "<tr class=\"Forum\">";
        }

        row += "<td class=\"ForumInfo\">\n";
        row += "<div>\n";
        row += "<a href=\"" + url + "\" class=\"ForumName\">" + ResHelper.LocalizeString(forumName) + "</a>\n";
        row += "</div>\n";
        row += "<div class=\"ForumDescription\">\n";
        row += ResHelper.LocalizeString(forumDescription);
        row += "</div>\n";
        row += "</td>\n";

        row += "<td class=\"Threads\">\n";
        row += "<span>\n";
        row += threads.ToString();
        row += "</span>\n";
        row += "</td>\n";

        row += "<td class=\"Posts\">\n";
        row += "<span>\n";
        row += posts.ToString();
        row += "</span>\n";
        row += "</td>\n";

        // If webpart enable display non approved post must selct it
        if ((!mForumProperties.SelectOnlyApproved))
        {
            ForumInfo fi = ForumInfoProvider.GetForumInfo(forumName, CMSContext.CurrentSite.SiteID);

            if (fi != null)
            {
                DataSet ds = ForumPostInfoProvider.SelectForumPosts(fi.ForumID, "/%", null, "PostTime Desc", -1, false, 1);
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    lastPost = ds;
                    ForumPostInfo fpi = new ForumPostInfo(ds.Tables[0].Rows[0]);
                    if (fpi != null)
                    {
                        lastTime = fpi.PostTime;
                        lastUser = fpi.PostUserName;
                    }
                }
            }
        }

        row += "<td class=\"LastPost\">\n";
        row += "<div class=\"PostUser\">\n";
        if ((displayEmail) && (!DataHelper.DataSourceIsEmpty(lastPost)) && (ValidationHelper.GetString(lastPost.Tables[0].Rows[0]["PostUserMail"], "") != ""))
        {
            row += "<a href=\"mailto:" + Server.HtmlEncode(ValidationHelper.GetString(lastPost.Tables[0].Rows[0]["PostUserMail"], "")) + " \" >" + lastUser + "</a>\n";
        }
        else
        {
            row += lastUser;
        }

        row += "</div>\n";
        row += "<div class=\"PostTime\">\n";
        row += "(" + lastTime.ToString() + ")\n";
        row += "</div>\n";
        row += "</td>\n";
        row += "</tr>\n";

        return row;
    }
}
