using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Forums;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSForum_ForumNewPost : System.Web.UI.UserControl
{


    private int mForumID = 0;
    private bool mAllowRedirect = true;
    private int mPostID = 0;
    private bool mAdHoc = false;
    private bool isPreview = false;
    private bool mEnableSubscription = true;
    private bool mEnableCancel = true;
    private bool enableInsert = true;
    private bool loadNewValues = true;

    public ForumProperties mForumProperties = new ForumProperties();

    #region "Public properties"

    /// <summary>
    /// Enable display user picture.
    /// </summary>
    public bool EnablePicture
    {
        get { return mForumProperties.EnablePicture; ; }
        set { mForumProperties.EnablePicture = value; }
    }

    /// <summary>
    /// Max. picture width
    /// </summary>
    public int MaxPictureWidth
    {
        get { return mForumProperties.MaxPictureWidth; }
        set { mForumProperties.MaxPictureWidth = value; }
    }

    /// <summary>
    /// Max picture height
    /// </summary>
    public int MaxPictureHeight
    {
        get { return mForumProperties.MaxPictureHeight; }
        set { mForumProperties.MaxPictureHeight = value; }
    }

    /// <summary>
    /// Enable signature
    /// </summary>
    public bool EnableSignature
    {
        get { return mForumProperties.EnableSignature; }
        set { mForumProperties.EnableSignature = value; }
    }

    /// <summary>
    /// Enable Cancel button
    /// </summary>
    public bool EnableCancel
    {
        get { return ValidationHelper.GetBoolean(mEnableCancel, true); }
        set { mEnableCancel = value; }
    }

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get { return ValidationHelper.GetBoolean(mEnableSubscription, true); }
        set { mEnableSubscription = value; }
    }

    /// <summary>
    /// AdHoc forum
    /// </summary>
    public bool AdHocForum
    {
        get { return mAdHoc; }
        set { mAdHoc = value; }
    }


    /// <summary>
    /// ForumId
    /// </summary>
    public int ForumID
    {
        get { return mForumID; }
        set { mForumID = value; }
    }


    /// <summary>
    /// Allows redirect when new post is inserted, it's write only
    /// </summary>
    public bool AllowRedirect
    {
        set { mAllowRedirect = value; }
    }


    /// <summary>
    /// PostID of inserted forum post, it's readonly
    /// </summary>
    public int PostID
    {
        get { return mPostID; }
    }

    /// <summary>
    /// Reply To
    /// </summary>
    public int ReplyToPostID
    {
        get { return ValidationHelper.GetInteger(ViewState["ReplyToPostID"], 0); }
        set { ViewState["ReplyToPostID"] = value; }
    }
    
#endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        // Do not generate security every time
        this.SecurityCode1.GenerateNumberEveryTime = false;
        this.SecurityCode1.ForumExtension = true;

        // Set fck editor properties
        fckTemplateBody.BasePath = "~/CMSAdminControls/FCKeditor/";
        fckTemplateBody.AutoDetectLanguage = false;
        fckTemplateBody.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
        fckTemplateBody.EditorAreaCSS = "";
        fckTemplateBody.ToolbarSet = "Forum";
    }

    /// <summary>
    /// OnPreRender
    /// </summary>
    /// <param name="e"></param>
    protected override void OnPreRender(EventArgs e)
    {
        bool mNeedEmail = false;

        // Get forum info
        ForumInfo fi = ForumInfoProvider.GetForumInfo(mForumID);
        if (fi != null)
        {
            // Show/hide fck editor
            if (fi.ForumHTMLEditor)
            {
                fckTemplateBody.Visible = true;
                txtText.Visible = false;
                rfvText.Enabled = false;
            }
            
            // Check if email is required
            if (fi.ForumRequireEmail)
            {
                mNeedEmail = true;
            }

            // Check if CPATCHA is required and hide captcha area if isn't
            if (fi.ForumUseCAPTCHA)
            {
                plcCaptcha.Visible = true;
            }
        }

        // Check if it was reply
        if (ReplyToPostID > 0)
        {
            postReply.AllowReply = false;
            postReply.EnableSubscription = false;
        }
        else
        {
            pnlReplyPost.Visible = false;
        }

        // Disable subscription if is not allowed
        if (!EnableSubscription)
        {
            SubscribeHolder.Visible = false;
        }
        
        // Hide cancel button if isn't allowed
        if (!mEnableCancel)
        {
            btnCancel.Enabled = false;
        }

        // Display user name or nick, editable or non editable
        ForumInfo jfi = ForumInfoProvider.GetForumInfo(this.ForumID);
        if (jfi != null)
        {
            if ((!jfi.ForumAllowChangeName)&&(jfi.ForumAccess != 0))
            {
                plcUserName.Visible = false;
                plcNickName.Visible = true;
                lblNickName.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.NickName");

                if (CMSContext.CurrentUser.UserNickName.Trim() != "")
                {
                    lblNickNameValue.Text = CMSContext.CurrentUser.UserNickName;
                }
                else
                {
                    lblNickNameValue.Text = CMSContext.CurrentUser.UserName;
                }
            }

            if (this.EnableSignature)
            {
                plcSignature.Visible = true;
                if (enableInsert)
                {
                    txtSignature.Text = CMSContext.CurrentUser.UserSignature;
                }
            }

        }

        // Strings + validation
        lblEmail.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.email");
        rfvEmail.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.emailErrorMsg");

        lblCaptcha.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.captcha");

        // Regular expression to validate email (e-mail is not required)
        rfvEmail.ValidationExpression = @"^([\w0-9_-]+(\.[\w0-9_-]+)*@[\w0-9_-]+(\.[\w0-9_-]+)+)*$";

        if (mNeedEmail)
        {
            rfvEmailRequired.Enabled = true;
            rfvEmailRequired.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.emailRequireErrorMsg");
        }

        lblSubject.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.subject");
        rfvSubject.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.subjectErrorMsg");
        lblText.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.text");
        rfvText.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.textErrorMsg");
        lblUserName.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.username");
        rfvUserName.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.usernameErrorMsg");
        btnOK.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.OK");
        btnCancel.Text = ResHelper.GetString("general.cancel");
        btnPreview.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.Preview");
        lblSubscribe.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.Subscription");
        lblSignature.Text = ResHelper.GetString("Forums_WebInterface_ForumNewPost.Signature");

        if (isPreview)
        {
            postReply.AllowReply = false;
            postReply.Visible = true;
            pnlReplyPost.Visible = true;
        }
        else
        {
            // Fill user name if user is authenticated
            if ((CMSContext.CurrentUser != null && (!CMSContext.CurrentUser.IsPublic()))&&(loadNewValues))
            {
                txtUserName.Text = CMSContext.CurrentUser.UserName;

                if (CMSContext.CurrentUser.UserNickName.Trim() != "")
                {
                    txtUserName.Text = CMSContext.CurrentUser.UserNickName;
                }
            }

            lblHeader.Text = ResHelper.GetString("Forums_ForumNewPost_Header.NewThread");

            if (ReplyToPostID <= 0)
            {
                pnlReplyPost.Visible = false;
                if (mNeedEmail && (txtEmail.Text == String.Empty)) txtEmail.Text = CMSContext.CurrentUser.Email;
            }
            else
            {

                lblHeader.Text = ResHelper.GetString("Forums_ForumNewPost_Header.Reply");
                if (fi != null)
                {
                    postReply.DisplayEmail = fi.ForumDisplayEmails;
                }

                postReply.Visible = true;
                pnlReplyPost.Visible = true;
                postReply.PostID = ReplyToPostID;

                // Add Re: in reply
                ForumPostInfo fpi = ForumPostInfoProvider.GetForumPostInfo(ReplyToPostID);
                if ((fpi != null)&&(loadNewValues))
                {
                    if (!fpi.PostSubject.StartsWith(ResHelper.GetString("Forums.ReplyPrefix")))
                    {
                        txtSubject.Text = ResHelper.GetString("Forums.ReplyPrefix") + fpi.PostSubject;
                    }
                    else
                    {
                        txtSubject.Text = fpi.PostSubject;
                    }

                    if (mNeedEmail && (txtEmail.Text == String.Empty)) txtEmail.Text = CMSContext.CurrentUser.Email;
                }
            }
        }

        base.OnPreRender(e);
    }


    /// <summary>
    /// When post is added
    /// </summary>
    public event EventHandler OnInsertPost;

    /// <summary>
    /// Btn OK handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        enableInsert = false;
        bool isHtml = false;

        string userName = (txtUserName.Text == "") ? lblNickNameValue.Text : txtUserName.Text;

        string result = new Validator().NotEmpty(txtSubject.Text, rfvSubject.ErrorMessage).NotEmpty(userName, rfvUserName.ErrorMessage).Result;


        // Check if email was inserted if forum require it
        bool mNeedEmail = false;
        ForumInfo fi = ForumInfoProvider.GetForumInfo(mForumID);
        if (fi != null)
        {
            if (fi.ForumRequireEmail)
            {
                mNeedEmail = true;
            }
        }

        // Check CAPTCHA code if forum require security code
        if ((fi != null) && (fi.ForumUseCAPTCHA) && (result == ""))
        {
            if (!SecurityCode1.IsValid())
            {
                result = ResHelper.GetString("ForumNepPost.InvalidCaptcha");
                SecurityCode1.GenerateNewCode();
            }
        }

        // Check if is some text in TextArea or in FCKEditor
        if ((result == "") && (fi != null))
        {
            if (fi.ForumHTMLEditor)
            {
                isHtml = true;
                if (fckTemplateBody.ResolvedValue.Trim() == "")
                {
                    result = rfvText.ErrorMessage;
                }
            }
            else
            {
                if (txtText.Text.Trim() == "")
                {
                    result = rfvText.ErrorMessage;
                }
            }

        }

        if (mNeedEmail && result == "")
        {
            result = new Validator().NotEmpty(txtEmail.Text, rfvEmail.ErrorMessage).Result;
        }

        if (result == "")
        {
            if ((chkSubscribe.Checked) && ((txtEmail.Text == null) || (txtEmail.Text.Trim() == "")))
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Forums.Emailsubscribe");
                this.Visible = true;
                return;
            }

            // Create AdHocForum if doesn't exists
            if (this.AdHocForum && this.ForumID == 0 && CMSContext.CurrentDocument != null)
            {

                fi = new ForumInfo();

                int siteId = 0;
                if (CMSContext.CurrentSite != null)
                {
                    siteId = CMSContext.CurrentSite.SiteID;
                }

                fi.ForumID = 0;
                fi.ForumGroupID = ForumGroupInfoProvider.GetAdHocGroupInfo(siteId).GroupID;
                fi.ForumDisplayName = CMSContext.CurrentDocument.DocumentName;
                fi.ForumName = "AdHoc-" + Guid.NewGuid().ToString();
                fi.ForumOpen = true;
                fi.ForumModerated = false;
                fi.ForumAccess = 0;
                fi.ForumPosts = 0;
                fi.ForumThreads = 0;
                fi.ForumRequireEmail = false;
                fi.ForumDisplayEmails = true;
                fi.ForumDocumentID = CMSContext.CurrentDocument.DocumentID;


                ForumInfoProvider.SetForumInfo(fi);

                this.ForumID = fi.ForumID;
            }

            ForumPostInfo fp = new ForumPostInfo();
            fp.PostParentID = this.ReplyToPostID;
            fp.PostForumID = this.ForumID;

            if ((CMSContext.CurrentUser != null) && (!CMSContext.CurrentUser.IsPublic()))
            {
                fp.PostUserID = CMSContext.CurrentUser.UserID;
            }

            fp.PostUserName = userName;
            if (isHtml)
            {
                fp.PostText = fckTemplateBody.ResolvedValue;
            }
            else
            {
                fp.PostText = txtText.Text;
            }
            fp.PostSubject = txtSubject.Text;
            fp.PostTime = DateTime.Now;
            fp.PostUserMail = txtEmail.Text;
            fp.PostUserSignature = txtSignature.Text;

            ForumPostInfoProvider.SetForumPostInfo(fp);




            //Add to subscribe
            if ((chkSubscribe.Checked) && (fp.PostUserMail != null) && (fp.PostUserMail.Trim() != ""))
            {
                ForumSubscriptionInfo fsi = new ForumSubscriptionInfo();
                fsi.SubscriptionForumID = this.ForumID;
                fsi.SubscriptionEmail = fp.PostUserMail;
                fsi.SubscriptionPostID = fp.PostId;
                fsi.SubscriptionUserID = fp.PostUserID;
                fsi.SubscriptionGUID = Guid.NewGuid();

                ForumSubscriptionInfoProvider.SetForumSubscriptionInfo(fsi);
            }


            mPostID = fp.PostId;

            if (OnInsertPost != null)
            {
                OnInsertPost(this, null);
            }

            if (mAllowRedirect)
            {
                HttpContext.Current.Response.Redirect(HttpContext.Current.Request.RawUrl);
            }
            else
            {
                mAllowRedirect = true;
            }

            this.ClearForm();
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
            this.Visible = true;

            this.loadNewValues = false;
        }
    }

    /// <summary>
    /// Clear from fields
    /// </summary>
    public void ClearForm()
    {
        txtText.Text = "";
        txtSubject.Text = "";
        txtEmail.Text = "";
        txtUserName.Text = "";
        txtSignature.Text = CMSContext.CurrentUser.UserSignature;
        fckTemplateBody.ResolvedValue = "";
        SecurityCode1.GenerateNewCode();
    }

    public event EventHandler OnCancelClick;

    /// <summary>
    /// Cancel click handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnCancel_Click(object sender, EventArgs e)
    {

        ClearForm();

        if (OnCancelClick != null)
        {
            OnCancelClick(this, null);
        }

        HttpContext.Current.Response.Redirect(HttpContext.Current.Request.RawUrl);
    }

    /// <summary>
    /// Encode text
    /// </summary>
    /// <param name="input"></param>
    /// <returns></returns>
    public string EncodedText(string input)
    {
        input = Server.HtmlDecode(input);
        return Server.HtmlEncode(input);
    }

    /// <summary>
    /// Preview click handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnPreview_Click(object sender, EventArgs e)
    {
        enableInsert = false;

        ForumPostInfo fp = new ForumPostInfo();

        string userName = (txtUserName.Text == "") ? lblNickNameValue.Text : txtUserName.Text;

        fp.PostUserMail = txtEmail.Text;
        fp.PostUserName = userName;
        fp.PostText = txtText.Text;
        
        ForumInfo fi = ForumInfoProvider.GetForumInfo(this.ForumID);
        if ((fi != null)&&(fi.ForumHTMLEditor))
        {
            fp.PostText = fckTemplateBody.ResolvedValue;
        }
        
        fp.PostTime = DateTime.Now;
        fp.PostSubject = txtSubject.Text;
        fp.PostUserSignature = txtSignature.Text;
        fp.PostForumID = this.ForumID;

        this.postReply.PostSrcDataRow = fp.DataClass.DataRow;
        this.postReply.EnableSubscription = false;
        if (this.EnableSignature)
        {
            this.postReply.EnableSignature = true;  
        }
        this.Visible = true;
        isPreview = true;
        lblHeader.Text = ResHelper.GetString("Forums_ForumNewPost_Header.Preview");
    }
}
