using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.Forums;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSForum_NewSubscription : System.Web.UI.UserControl
{
    
    private int mForumID = 0;
    private int mPostID = 0;
    private bool mEnableSubscription = true;

    #region "Public properties"

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get { return ValidationHelper.GetBoolean(mEnableSubscription, true); }
        set { mEnableSubscription = value; }
    }


    /// <summary>
    /// ForumId
    /// </summary>
    public int ForumID
    {
        get { return mForumID; }
        set { mForumID = value; }
    }


    /// <summary>
    /// PostID of inserted forum post
    /// </summary>
    public int PostID
    {
        get { return mPostID; }
        set { mPostID = value; }
    }

    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        // Set string values
        lblEmail.Text = ResHelper.GetString("ForumSubscription.Email");
        rfvEmail.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.emailErrorMsg");

        // Regular expression to validate email (e-mail is not required)
        rfvEmail.ValidationExpression = @"^([\w0-9_-]+(\.[\w0-9_-]+)*@[\w0-9_-]+(\.[\w0-9_-]+)+)*$";
        rfvEmailRequired.ErrorMessage = ResHelper.GetString("Forums_WebInterface_ForumNewPost.emailRequireErrorMsg");

        btnOK.Text = ResHelper.GetString("General.Ok");
        btnCancel.Text = ResHelper.GetString("General.Cancel");

        lblHeader.Text = ResHelper.GetString("ForumSubscription.SubscribeForum");

        // Disable reply and subscribtion
        postReply.AllowReply = false;
        postReply.EnableSubscription = false;

        if (this.PostID > 0)
        {
            lblHeader.Text = ResHelper.GetString("ForumSubscription.SubscribePost");

            pnlReplyPost.Visible = true;
            postReply.PostID = this.PostID;
        }
        else
        {
            pnlReplyPost.Visible = false;
        }
    }


    /// <summary>
    /// Clear from fields
    /// </summary>
    public void ClearForm()
    {
        txtEmail.Text = "";
    }

    /// <summary>
    /// OK click handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check input fields
        string result = new Validator().NotEmpty(txtEmail.Text, rfvEmailRequired.ErrorMessage).IsRegularExp(txtEmail.Text, @"^([\w0-9_-]+(\.[\w0-9_-]+)*@[\w0-9_-]+(\.[\w0-9_-]+)+)*$", rfvEmail.ErrorMessage).Result;

        if (result == "")
        {
            // For selected forum and only if subscribtion is enabled
            if ((this.ForumID > 0)&&(this.EnableSubscription))
            {
                if ((txtEmail.Text != null) && (txtEmail.Text.Trim()!=""))
                {
                    // Create new subscribtion
                    ForumSubscriptionInfo fsi = new ForumSubscriptionInfo();
                    fsi.SubscriptionForumID = this.ForumID;
                    fsi.SubscriptionEmail = Server.HtmlEncode(txtEmail.Text);
                    fsi.SubscriptionGUID = Guid.NewGuid();

                    if (this.PostID > 0)
                    {
                        fsi.SubscriptionPostID = this.PostID;
                    }
                    
                    if (CMSContext.CurrentUser != null)
                    {
                        fsi.SubscriptionUserID = CMSContext.CurrentUser.UserID;
                    }
                    
                    ForumSubscriptionInfoProvider.SetForumSubscriptionInfo(fsi);
                }

                
            }


            ClearForm();

            HttpContext.Current.Response.Redirect(HttpContext.Current.Request.RawUrl);
        }

    }


    public event EventHandler OnCancelClick;

    /// <summary>
    /// Cancel click nahdler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnCancel_Click(object sender, EventArgs e)
    {
        // Clear input form
        ClearForm();

        if (OnCancelClick != null)
        {
            OnCancelClick(this, null);
        }
        
        // Redirect
        HttpContext.Current.Response.Redirect(HttpContext.Current.Request.RawUrl);
    }
}
