using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Text;

using CMS.Forums;
using CMS.GlobalHelper;


public partial class CMSForum_PostTree : System.Web.UI.UserControl
{
    /// <summary>
    /// Forum Post tree provider.
    /// </summary>
    protected ForumPostTreeProvider mForumPostTreeProvider = null;

    /// <summary>Forum properties</summary>
    public ForumProperties mForumProperties = new ForumProperties();

    private bool mAllowReply = true;

    /// <summary>
    /// Item CSS class
    /// </summary>
    protected string mItemCssClass = "ThreadPost";

    /// <summary>
    /// Selcted item CSS class
    /// </summary>
    protected string mSelectedItemCssClass = "ThreadPostSelected";


    #region "Public properties"

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool AllowReply
    {
        get
        {
            return mAllowReply;
        }
        set
        {
            mAllowReply = value;
        }
    }

    /// <summary>
    /// Enable subscription
    /// </summary>
    public bool EnableSubscription
    {
        get
        {
            return mForumProperties.EnableSubscription;
        }
        set
        {
            mForumProperties.EnableSubscription = value;
        }
    }


    /// <summary>
    /// Forum Id
    /// </summary>
    public int ForumID
    {
        get
        {
            return mForumProperties.ForumID;
        }
        set
        {
            mForumProperties.ForumID = value;
        }
    }


    /// <summary> Stop processing </summary>
    public bool StopProcessing
    {
        get
        {
            return mForumProperties.StopProcessing;
        }
        set
        {
            mForumProperties.StopProcessing = value;
        }
    }


    /// <summary>
    /// Where condition
    /// </summary>
    public string WhereCondition
    {
        get
        {
            return mForumProperties.WhereCondition;
        }
        set
        {
            mForumProperties.WhereCondition = value;
        }
    }


    /// <summary>
    /// Path
    /// </summary>
    public string PostPath
    {
        get
        {
            return mForumProperties.PostPath;
        }
        set
        {
            mForumProperties.PostPath = value;
        }
    }


    /// <summary>
    /// Max relative level
    /// </summary>
    public int MaxRelativeLevel
    {
        get
        {
            return mForumProperties.MaxRelativeLevel;
        }
        set
        {
            mForumProperties.MaxRelativeLevel = value;
        }
    }


    /// <summary>
    /// Select only approved
    /// </summary>
    public bool SelectOnlyApproved
    {
        get
        {
            return mForumProperties.SelectOnlyApproved;
        }
        set
        {
            mForumProperties.SelectOnlyApproved = value;
        }
    }


    /// <summary>
    /// Expand tree
    /// </summary>
    public bool ExpandTree
    {
        get
        {
            return mForumProperties.ExpandTree;
        }
        set
        {
            mForumProperties.ExpandTree = value;
        }
    }

    /// <summary> ShowMode </summary>
    public ShowModeEnum ShowMode
    {
        get
        {
            return mForumProperties.ShowMode;
        }
        set
        {
            mForumProperties.ShowMode = value;
        }
    }


    /// <summary>
    /// Selected path.
    /// </summary>
    public int Selected
    {
        get { return mForumProperties.Selected; }
        set { mForumProperties.Selected = value; }
    }


    /// <summary> AdministrationMode </summary>
    public bool AdministrationMode
    {
        get
        {
            return mForumProperties.AdministrationMode;
        }
        set
        {
            mForumProperties.AdministrationMode = value;
        }
    }


    /// <summary>
    /// Show approved pictures in tree.
    /// </summary>
    public bool ShowApprovePics
    {
        get
        {
            return mForumProperties.ShowApprovePics;
        }
        set
        {
            mForumProperties.ShowApprovePics = value;
        }
    }


    /// <summary>
    /// Post tree provider that the tree uses
    /// </summary>
    public ForumPostTreeProvider MapProvider
    {
        get
        {
            if (mForumPostTreeProvider == null) { mForumPostTreeProvider = new ForumPostTreeProvider(); }
            return mForumPostTreeProvider;
        }
    }


    /// <summary>
    /// Provides acces to treeElem property
    /// </summary>
    public TreeView TreeView
    {
        get
        {
            return treeElem;
        }
    }


    /// <summary>
    /// Item CSS class
    /// </summary>
    public string ItemCssClass
    {
        get
        {
            return mItemCssClass;
        }
        set
        {
            mItemCssClass = value;
        }
    }


    /// <summary>
    /// Selected item CSS class
    /// </summary>
    public string SelectedItemCssClass
    {
        get
        {
            return mSelectedItemCssClass;
        }
        set
        {
            mSelectedItemCssClass = value;
        }
    }

    #endregion


    #region "Functions"

    /// <summary>
    /// OnPreRender
    /// </summary>
    /// <param name="e"></param>
    protected override void OnPreRender(EventArgs e)
    {
        ReloadData();

        base.OnPreRender(e);
    }

    /// <summary>
    /// Reload data
    /// </summary>
    public void ReloadData()
    {
        if (StopProcessing) return;

        // Set Map provider values
        MapProvider.BindNodeData = true;
        MapProvider.Path = this.PostPath;
        MapProvider.MaxRelativeLevel = this.MaxRelativeLevel;
        MapProvider.SelectOnlyApproved = this.SelectOnlyApproved;
        MapProvider.ForumID = this.ForumID;
        MapProvider.WhereCondition = this.WhereCondition;

        // Create root node
        if (((ForumPostTreeNode)MapProvider.RootNode).TreeNode != null)
        {
            this.treeElem.ExpandImageToolTip = ResHelper.GetString("ContentTree.Expand");
            this.treeElem.CollapseImageToolTip = ResHelper.GetString("ContentTree.Collapse");

            this.treeElem.EnableViewState = false;
            this.treeElem.Nodes.Clear();

            // Add root node
            this.treeElem.Nodes.Add(CreateNode((ForumPostTreeNode)MapProvider.RootNode));
            this.treeElem.DataBind();
        }

    }


    /// <summary>
    /// Create node
    /// </summary>
    /// <param name="sourceNode"></param>
    /// <returns></returns>
    protected System.Web.UI.WebControls.TreeNode CreateNode(ForumPostTreeNode sourceNode)
    {
        // Create root node
        System.Web.UI.WebControls.TreeNode newNode = new System.Web.UI.WebControls.TreeNode();

        newNode = sourceNode.TreeNode;
        newNode.NavigateUrl = Request.RawUrl + "#";

        // Set node dispalyed tex depend on view mode
        if (AdministrationMode)
        {
            newNode.Text = "<span class=\"" + this.ItemCssClass + "\" onclick=\"ShowPost('-1'); SelectNode('-1',''); \"><span class=\"Name\">" + newNode.Text + "</span></span>";
        }
        else
        {
            if (this.ShowMode == ShowModeEnum.DynamicDetailMode)
            {
                newNode.Text = "<span class=\"" + this.ItemCssClass + "\" onclick=\"ReplyToPost('-1'); ShowPost('-1'); SelectNode('-1',''); \"><span class=\"Name\">" + newNode.Text + "</span></span>";
            }
            else
            {
                newNode.Text = "<span class=\"" + this.ItemCssClass + "\" onclick=\"ReplyToPost('-1'); ShowPost('-1'); SelectNode('-1'); \"><span class=\"Name\">" + newNode.Text + "</span></span>";
            }
        }

        newNode.Select();
        newNode.PopulateOnDemand = true;

        newNode.Expand();

        return newNode;
    }


    /// <summary>
    /// Image delegate
    /// </summary>
    /// <param name="node"></param>
    /// <returns></returns>
    public delegate string GetIconEventHandler(ForumPostTreeNode node);

    /// <summary>
    /// Get image Url
    /// </summary>
    public event GetIconEventHandler OnGetPostIconUrl;


    /// <summary>
    /// On populate create child nodes
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void treeElem_TreeNodePopulate1(object sender, TreeNodeEventArgs e)
    {
        string mPath = "";

        //Get path of current node
        ForumPostTreeNode fptn = MapProvider.GetNodeById(Selected);
        if (fptn != null && fptn.ItemData != null)
        {
            mPath = ((DataRow)fptn.ItemData)["PostIDPath"].ToString();
        }

        e.Node.ChildNodes.Clear();

        // Get node by nodeId
        int nodeID = ValidationHelper.GetInteger(e.Node.Value, 0);
        ForumPostTreeNode node = MapProvider.GetNodeById(nodeID);



        if (node != null)
        {
            bool expand = false;

            // Add all child in tree
            foreach (ForumPostTreeNode childNode in node.ChildNodes)
            {
                System.Web.UI.WebControls.TreeNode newNode = CreateNode(childNode);
                newNode.NavigateUrl = Request.RawUrl + "#";

                string imageUrl = "";
                string imageTag = "";

                if (OnGetPostIconUrl != null)
                {
                    imageUrl = OnGetPostIconUrl(childNode);
                }

                if (imageUrl != null && imageUrl.Trim() != "")
                {
                    imageTag = "<img src=\"" + imageUrl + "\" alt=\"\" style=\"border:0px;vertical-align:middle;\" onclick=\"return false;\"/>&nbsp;";
                }

                // Create detail of post to string
                StringBuilder sb = new StringBuilder();
                string mId = "";

                if (this.ShowMode != ShowModeEnum.TreeMode)
                {
                    Html32TextWriter writer = new Html32TextWriter(new StringWriter(sb));
                    CMSForum_ForumPost post = (CMSForum_ForumPost)this.Page.LoadControl("~/CMSForum/ForumPost.ascx");
                    post.PostID = ValidationHelper.GetInteger(newNode.Value, 0);
                    post.EnableSubscription = this.EnableSubscription;
                    post.AllowReply = this.AllowReply;
                    post.mForumProperties = this.mForumProperties;

                    if (this.MaxRelativeLevel != -1)
                    {
                        ForumPostInfo fpi = ForumPostInfoProvider.GetForumPostInfo(post.PostID);
                        if (fpi != null)
                        {
                            if (fpi.PostLevel >= this.MaxRelativeLevel)
                            {
                                post.EnableSubscription = false;
                                post.AllowReply = false;
                            }
                        }
                    }
                    
                    ForumInfo fi = ForumInfoProvider.GetForumInfo(this.ForumID);
                    if (fi != null)
                    {
                        post.DisplayEmail = fi.ForumDisplayEmails;
                    }
                    post.ReloadData();
                    post.RenderControl(writer);
                    newNode.Text = sb.ToString();
                    mId = this.ClientID + post.PostID.ToString();
                }

                // Post subject
                string mText = newNode.Text;

                // Set display mode
                switch (this.ShowMode)
                {
                    // Dynamic detail mode
                    case ShowModeEnum.DynamicDetailMode:
                        {

                            newNode.Text = "<span style=\"display:block;\" ID=\"" + mId + "\" class=\"" + this.ItemCssClass + "\" onclick=\" SelectNode('" + "Selected" + mId + "','" + mId + "'); return false;\">" + imageTag + Server.HtmlEncode(((DataRow)childNode.ItemData)["PostSubject"].ToString()) + "</span>" + "<div ID=\"" + "Selected" + mId + "\" style=\"display: none;\" class=\"TreeSelectedPost\">" + sb.ToString() + "</div>";
                        }
                        break;

                    // Detail mode
                    case ShowModeEnum.DetailMode:
                        newNode.Text = "<div ID=\"" + "Selected" + mId + "\" style=\"display: block;\" class=\"TreeSelectedPost\">" + sb.ToString() + "</div>";
                        break;

                    // Tree mode
                    default: newNode.Text = "<span class=\"" + this.ItemCssClass + "\" onclick=\"ShowPost(" + newNode.Value + " ); SelectNode(this);\"><span class=\"Name\">" + imageTag + Server.HtmlEncode(((DataRow)childNode.ItemData)["PostSubject"].ToString()) + "</span></span>";
                        break;

                }

                // Set selected item class
                string mClass = this.SelectedItemCssClass;

                string spanId = "";

                // Higlight selected item in administration mode
                if (AdministrationMode && ValidationHelper.GetInteger(((DataRow)childNode.ItemData)["PostID"], -1) == this.Selected)
                {
                    mClass = this.SelectedItemCssClass;
                    spanId = "id=\"treeSelectedNode\"";
                    //ltlScript.Text = ScriptHelper.GetScript("SelectReloadNode(getElementById("+this.ClientID+"));");
                }

                // highlight selected item
                if ((this.ShowMode == ShowModeEnum.TreeMode) && (ValidationHelper.GetInteger(childNode.TreeNode.Value, -1) == this.Selected))
                {
                    newNode.Text = "<span " + spanId + " class=\"" + mClass + "\" onclick=\"ShowPost(" + newNode.Value + " ); SelectNode(this);\"><span class=\"Name\">" + imageTag + Server.HtmlEncode(((DataRow)childNode.ItemData)["PostSubject"].ToString()) + "</span></span>";
                }

                // Colapse this node
                newNode.Collapse();

                // When expand tree is checke expand it
                if (this.ExpandTree)
                {
                    newNode.Expand();
                }

                // Get ForumPostTreeNode of current Childnode 
                ForumPostTreeNode mNode = MapProvider.GetNodeById(Convert.ToInt32(childNode.TreeNode.Value));

                //Expand actual Path
                if (mNode != null && mNode.ItemData != null)
                {
                    string actPath = ((DataRow)mNode.ItemData)["PostIDPath"].ToString();

                    if (mPath.StartsWith(actPath))
                    {
                        expand = true;
                    }
                }

                //newNode.Collapse();
                e.Node.ChildNodes.Add(newNode);

                if (expand)
                {
                    e.Node.Expand();
                }
            }
        }
    }


    /// <summary> Render </summary>
    /// <param name="writer"></param>
    protected override void Render(HtmlTextWriter writer)
    {
        if (!this.StopProcessing)
        {
            base.Render(writer);
        }
    }

    #endregion

}
