using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Drawing;
using System.Collections.Generic;

using ZedGraph;
using ZedGraph.Web;

using CMS.CMSHelper;
using CMS.Reporting;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SettingsProvider;
using CMS.EventLog;


public partial class CMSPages_GetReportGraph : System.Web.UI.Page
{
    protected Guid sGraphGuid;
    protected ReportGraphInfo reportGraph;
    protected DataSet dsGraphData;
    protected string mCulture = "en-us";

     /// <summary>
    /// Constructor
    /// </summary>
    public CMSPages_GetReportGraph()
    {
        mCulture = Page.UICulture;

        if ((HttpContext.Current != null) && (HttpContext.Current.Request != null) && (ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "") != ""))
        {
            this.UICulture = ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "");
            mCulture = ValidationHelper.GetString(HttpContext.Current.Request.QueryString["UILang"], "");
        }
        else
        {

            if (CMSContext.CurrentDocument != null)
            {
                mCulture = CMSContext.CurrentDocument.DocumentCulture;
            }
            else
            {
                mCulture = System.Globalization.CultureInfo.CurrentUICulture.IetfLanguageTag;
            }
        }


        System.Threading.Thread.CurrentThread.CurrentCulture = new System.Globalization.CultureInfo(mCulture);
        System.Threading.Thread.CurrentThread.CurrentUICulture = new System.Globalization.CultureInfo(mCulture);
    }


    protected void Page_Load(object sender, EventArgs e)
    {   
        //check if it is request for saved graph - by graph guid
        sGraphGuid = ValidationHelper.GetGuid(Request.QueryString["graphguid"], Guid.Empty);
        if (sGraphGuid != Guid.Empty)
        {
            SavedGraphInfo sGraphInfo = SavedGraphInfoProvider.GetSavedGraphInfo(sGraphGuid);
            if (sGraphInfo != null)
            {
                SavedReportInfo savedReport = SavedReportInfoProvider.GetSavedReportInfo(sGraphInfo.SavedGraphSavedReportID);
                ReportInfo report = ReportInfoProvider.GetReportInfo(savedReport.SavedReportReportID);
                
                //check graph security settings
                if (report.ReportAccess != ReportAccessEnum.All)
                {
                    if (!CMSContext.CurrentUser.IsAuthenticated())
                    {
                        Response.StatusCode = (int)System.Net.HttpStatusCode.Unauthorized;
                        return;
                    }
                }

                //send response with image data
                SendGraph(sGraphInfo);
                return;
            }
        }
        else //generate graph on the fly from report data
        {
            int graphId = ValidationHelper.GetInteger(Request.QueryString["graphid"], 0);
            string[] httpParameters = ValidationHelper.GetString(Request.QueryString["parameters"], "").Split(";".ToCharArray());
            reportGraph = ReportGraphInfoProvider.GetReportGraphInfo(graphId);

            if (reportGraph != null)
            {
                ReportInfo report = ReportInfoProvider.GetReportInfo(reportGraph.GraphReportID);
                //check graph security settings
                if (report.ReportAccess != ReportAccessEnum.All)
                {
                    if (!CMSContext.CurrentUser.IsAuthenticated())
                    {
                        Response.StatusCode = (int)System.Net.HttpStatusCode.Unauthorized;
                        return;
                    }
                }

                string aliasPath = "";

                object[,] parameters = null;
                if ((httpParameters.Length > 0) && ((httpParameters.Length % 2) == 0))
                {
                    parameters = new object[httpParameters.Length / 2, 3];
                    for (int i = 0; i < (httpParameters.Length / 2); i++)
                    {
                        parameters[i, 0] = httpParameters[i * 2];
                        parameters[i, 1] = httpParameters[i * 2 + 1];
                        if (httpParameters[i * 2].ToLower() == "aliaspathgraph")
                        {
                            aliasPath = httpParameters[i * 2 + 1];
                        }
                    }
                }

                CMS.TreeEngine.TreeNode node = null;

                if (aliasPath != "")
                {
                    node = TreeHelper.SelectSingleNode(aliasPath);
                }

                GeneralConnection gc = new GeneralConnection();
                object[,] mParams = SpecialFunctions.ConvertDataRowToParams(CMSContext.GetContextParametersDataRow(), gc.DataConnection);

                object[,] allParams = new object[mParams.GetUpperBound(0) + parameters.GetUpperBound(0) + 2, 3];
                // Context parameters
                for (int j = 0; j <= mParams.GetUpperBound(0); j++)
                {
                    allParams[j, 0] = mParams[j, 0];
                    allParams[j, 1] = mParams[j, 1];
                    allParams[j, 2] = mParams[j, 2];

                    if (node != null && mParams[j, 0].ToString().ToLower() == "@cmscontextcurrentaliaspath")
                    {
                        allParams[j, 1] = aliasPath;
                    }

                    if (node != null && mParams[j, 0].ToString().ToLower() == "@cmscontextcurrentdocumentname")
                    {
                        allParams[j, 1] = node.DocumentName;
                    }

                    if (node != null && mParams[j, 0].ToString().ToLower() == "@cmscontextcurrentnodeid")
                    {
                        allParams[j, 1] = node.NodeID;
                    }

                    if (node != null && mParams[j, 0].ToString().ToLower() == "@cmscontextcurrentdocumentid")
                    {
                        allParams[j, 1] = node.DocumentID;
                    }

                    if (node != null && mParams[j, 0].ToString().ToLower() == "@cmscontextcurrentdocumentnamepath")
                    {
                        allParams[j, 1] = node.DocumentID;
                    }
                }

                // User parameters
                for (int j = 0; j <= parameters.GetUpperBound(0); j++)
                {
                    allParams[j + mParams.GetUpperBound(0)+1, 0] = parameters[j, 0];
                    allParams[j + mParams.GetUpperBound(0)+1, 1] = parameters[j, 1];
                    allParams[j + mParams.GetUpperBound(0)+1, 2] = parameters[j, 2];
                }

                ContextResolver resolver = CMSContext.CurrentResolver.CreateChild();
                
                try
                {
                    
                    resolver.SourceParameters = allParams;

                    reportGraph.GraphQuery = resolver.ResolveMacros(reportGraph.GraphQuery);
                    dsGraphData = ReportGraphInfoProvider.GetGraphData(reportGraph, allParams);
                }
                catch (Exception ex) //try to catch exception raised most probably by reporgGraph sql query
                {
                    EventLogProvider ev = new EventLogProvider();
                    ev.LogEvent("Get report graph", "E", ex);

                    ReportGraph gr = new ReportGraph();
                    byte[] invalidGraph = gr.CreateInvalidGraph(reportGraph);

                    if (invalidGraph != null)
                    {
                        SendGraph("image/png", invalidGraph);
                    }

                    return;
                }

                ReportGraph graph = new ReportGraph();
                reportGraph.GraphTitle = resolver.ResolveMacros(reportGraph.GraphTitle);
                reportGraph.GraphXAxisTitle = resolver.ResolveMacros(reportGraph.GraphXAxisTitle);
                reportGraph.GraphYAxisTitle = resolver.ResolveMacros(reportGraph.GraphYAxisTitle);

                //create graph image
                byte[] createdGraph = graph.CreateGraph(reportGraph, dsGraphData);

                //if ok, send response with image data
                if (createdGraph != null)
                {
                    SendGraph("image/png", createdGraph);
                }

                return;
            }
        }

        //bad parameters, guid ... -> not found
        Response.StatusCode = (int)System.Net.HttpStatusCode.NotFound;
        Response.End();
    }


    /// <summary>
    /// Sends the graph
    /// </summary>
    /// <param name="graphObj">Graph obj containing graph</param>
    protected void SendGraph(SavedGraphInfo graphObj)
    {
        if (graphObj != null)
        {
            SendGraph(graphObj.SavedGraphMimeType, graphObj.SavedGraphBinary);
        }
    }

    /// <summary>
    /// Sends the graph
    /// </summary>
    /// <param name="mimeType">response mime type</param>
    /// <param name="graph">raw data to be sent</param>
    protected void SendGraph(string mimeType, byte[] graph)
    {
        // Clear response.
        Response.Cookies.Clear();
        Response.Clear();

        // Prepare response
        Response.ContentType = mimeType;

        Response.OutputStream.Write(graph, 0, graph.Length);

        Response.End();
    }




}
