using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.FileManager;
using CMS.SiteProvider;

public partial class SiteManager_Administration_RecycleBin_default : AdministrationPage
{
    private int selectedSite = 0;

    protected void Page_Load(object sender, EventArgs e)
    {

        if (CMSContext.CurrentSite != null)
        {
            selectedSite = CMSContext.CurrentSite.SiteID;
        }

        if (ValidationHelper.GetInteger(Request.QueryString["siteId"], 0) != 0)
        {
            drpSite.Visible = false;
            lblSite.Visible = false;
        }

        string id = ValidationHelper.GetString(Request.QueryString["toSite"], String.Empty);
        if (id != String.Empty)
        {
            selectedSite = ValidationHelper.GetInteger(id, 0);
        }

        this.titleElem.TitleText = ResHelper.GetString("Administration-RecycleBin.Header");
        this.titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/RecycleBin/recyclebin.gif";
        ugRecycleBin.GridView.GridLines = GridLines.Horizontal;
        ugRecycleBin.ImageDirectoryPath = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/MyDesk/RecycleBin/";

        object[,] parameters = new object[1, 3];
        parameters[0, 0] = "@SiteID";

        if (this.drpSite.SelectedValue != String.Empty)
        {
            selectedSite = Convert.ToInt32(this.drpSite.SelectedValue);
            parameters[0, 1] = selectedSite;
        }
        else
        {
            parameters[0, 1] = selectedSite;
        }

        ugRecycleBin.QueryParameters = parameters;
        ugRecycleBin.OnAction += new OnActionEventHandler(ugRecycleBin_OnAction);
        ugRecycleBin.HideControlForZeroRows = true;

        btnEmptyRecBin.Text = ResHelper.GetString("RecycleBin.EmptyRecycleBin");
        btnEmptyRecBin.Attributes.Add("onclick", "if(confirm('" + ResHelper.GetString("recyclebin.confirmemptyrecbin") + "')==false){return false;}" + ClientScript.GetPostBackEventReference(this.btnEmptyRecBin, null));


        string error = ValidationHelper.GetString(Request.QueryString["displayerror"], "");
        if (error != "")
        {
            this.lblError.Text = ResHelper.GetString("recyclebin.errorsomenotdestroyed");
        }

        this.lblSite.Text = ResHelper.GetString("Administration-RecycleBin.Site");

        // loads all sites
        if (!IsPostBack)
        {
            DataSet ds = CMS.SiteProvider.SiteInfoProvider.GetAllSites();
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                this.drpSite.DataSource = ds.Tables[0].DefaultView;
                this.drpSite.DataTextField = "SiteDisplayName";
                this.drpSite.DataValueField = "SiteID";
                this.drpSite.DataBind();

                // initially the current site is set as selected 
                ListItem item = this.drpSite.Items.FindByValue(selectedSite.ToString());
                if (item != null)
                {
                    this.drpSite.SelectedIndex = this.drpSite.Items.IndexOf(item);
                }
            }
            else
            {
                PanelTop.Visible = false;
            }
        }
    }

    /// <summary>
    /// Empty recycle bin handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnEmptyRecBin_Click(System.Object sender, System.EventArgs e)
    {
        // Check the permissions
        SiteInfo info = SiteInfoProvider.GetSiteInfo(this.selectedSite);
        if ((info != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Delete")))
        {
            RedirectToCMSDeskAccessDenied("CMS.Administration", "Delete");
        }

        bool allDeleted = true;
        TreeProvider tree = new TreeProvider();
        VersionManager verMan = new VersionManager(tree);
        CMS.TreeEngine.TreeNode deletedNode = null;
        bool userHasGlobalDestroyPerm = CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "Destroy");

        object[,] parameters = new object[2, 3];
        parameters[0, 0] = "@UserID";
        parameters[0, 1] = CMSContext.CurrentUser.UserID;
        parameters[1, 0] = "@SiteID";
        parameters[1, 1] = this.selectedSite;

        DataSet ds = tree.Connection.ExecuteQuery("cms.versionhistory.selectmyrecyclebin", parameters, null);
        // check permissions and destroy                            
        foreach (DataRow dr in ds.Tables[0].Rows)
        {
            deletedNode = verMan.GetVersion(Convert.ToInt32(dr["VersionHistoryId"]), null);
            string aliasPath = Convert.ToString(deletedNode.GetValue("NodeAliasPath"));
            int aclId = Convert.ToInt32(deletedNode.GetValue("NodeACLID"));
            string className = deletedNode.NodeClassName;

            // check permissions
            if (!((userHasGlobalDestroyPerm || CMSContext.CurrentUser.IsAuthorizedPerClassName(className, "Destroy") ||
                (TreeSecurityProvider.IsAuthorizedPerACL(aclId, NodePermissionsEnum.Destroy, CMSContext.CurrentUser) == AuthorizationResultEnum.Allowed))))
            {
                allDeleted = false;
            }
            else
            {
                // destroy
                verMan.DestroyDocumentHistory(Convert.ToInt32(dr["DocumentID"]));
            }
        }

        string url = UrlHelper.RemoveParameterFromUrl(Page.Request.Url.ToString(), "toSite");

        if (allDeleted == false)
        {
            Response.Redirect(url + "&displayerror=true&toSite=" + drpSite.SelectedValue.ToString());
        }
        else
        {
            Response.Redirect(url + "&toSite=" + drpSite.SelectedValue.ToString());
        }
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void ugRecycleBin_OnAction(string actionName, object actionArgument)
    {
        SiteInfo info = SiteInfoProvider.GetSiteInfo(this.selectedSite);
        VersionManager verMan = new VersionManager();
        if (actionName == "restore")
        {
            // Check the permissions
            if ((info != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Modify")))
            {
                RedirectToCMSDeskAccessDenied("CMS.Administration", "Modify");
            }

            int versionHistoryId = Convert.ToInt32(actionArgument);
            try
            {
                verMan.RestoreDocument(versionHistoryId);
            }
            catch (Exception ex)
            {
                lblError.Visible = true;
                lblError.Text = ex.Message;
            }
        }
        else if (actionName == "destroy")
        {
            // Check the permissions
            if ((info != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Delete")))
            {
                RedirectToCMSDeskAccessDenied("CMS.Administration", "Delete");
            }

            int documentId = Convert.ToInt32(actionArgument);
            verMan.DestroyDocumentHistory(documentId);
        }
    }

}
