using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Scheduler;
using CMS.CMSHelper;
using CMS.WebFarmSync;

public partial class MS2_Project_CMSSolution_Scheduler_Task_Edit : AdministrationPage
{
    protected int taskId = 0;
    protected int siteId = 0;

    protected TaskInfo taskObj = null;
    protected SiteInfo si = null;

    bool cmsdesk = false;

    protected void Page_Load(object sender, EventArgs e)
    {
        rfvAssembly.ErrorMessage = ResHelper.GetString("Task_Edit.EmptyAssembly");
        rfvDisplayName.ErrorMessage = ResHelper.GetString("Task_Edit.EmptyDisplayName");
        //rfvInterval.ErrorMessage = ResHelper.GetString("Task_Edit.EmptyInterval");
        rfvName.ErrorMessage = ResHelper.GetString("Task_Edit.EmptyName");
        rfvClass.ErrorMessage = ResHelper.GetString("Task_Edit.EmptyClass");

        // control initializations				
        lblTaskAssemblyName.Text = ResHelper.GetString("Task_Edit.TaskAssemblyNameLabel");

        lblTaskClass.Text = ResHelper.GetString("Task_Edit.TaskClassLabel");
        lblTaskData.Text = ResHelper.GetString("Task_Edit.TaskDataLabel");
        lblTaskName.Text = ResHelper.GetString("Task_Edit.TaskNameLabel");
        lblTaskEnabled.Text = ResHelper.GetString("Task_Edit.TaskEnabledLabel");
        lblTaskInterval.Text = ResHelper.GetString("Task_Edit.TaskIntervalLabel");
        lblTaskDisplayName.Text = ResHelper.GetString("Task_Edit.TaskDisplayNameLabel");
        lblTaskDeleteAfterLastRun.Text = ResHelper.GetString("Task_Edit.TaskDeleteAfterLastRunLabel");
        lblServerName.Text = ResHelper.GetString("Task_Edit.TaskServerNameLabel");
        chkAllServers.Text = ResHelper.GetString("Task_Edit.TaskAllServers");
        
        btnOK.Text = ResHelper.GetString("General.OK");

        string currentTask = ResHelper.GetString("Task_Edit.NewItemCaption");
        string title = ResHelper.GetString("Task_Edit.HeaderCaption");

        taskId = ValidationHelper.GetInteger(Request.QueryString["taskname"], 0);
        if (taskId > 0)
        {
            taskObj = TaskInfoProvider.GetTaskInfo(taskId);

            currentTask = taskObj.TaskDisplayName;
            title = ResHelper.GetString("Task_Edit.HeaderCaptionEdit");

            if (!IsPostBack)
            {
                ReloadData();

                // Show that the task was created or updated successfully
                if (Request.QueryString["saved"] == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
        }
        else
        {
            // Check create permission
            if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Create")))
            {
                RedirectToCMSDeskAccessDenied("CMS.Administration", "Create");
            }

            if (WebFarmServerInfoProvider.UseWebFarmSynchronization())
            {
                if (!IsPostBack)
                {
                    this.chkAllServers.Visible = true;
                    //this.chkAllServers.Checked = true;
                    //this.txtServerName.Enabled = false;
                }
                this.chkAllServers.Attributes.Add("onclick", "document.getElementById('" + this.txtServerName.ClientID + "').disabled = document.getElementById('" + this.chkAllServers.ClientID + "').checked;");
            }
        }

        siteId = ValidationHelper.GetInteger(Request.QueryString["siteid"], 0);
        if (siteId > 0)
        {
            cmsdesk = true;
            siteId = Convert.ToInt32(Request.QueryString["siteid"]);
        }

        if ((Request.QueryString["selectedsiteid"] != null) && (Request.QueryString["selectedsiteid"] != ""))
        {
            cmsdesk = false;
            if (Request.QueryString["selectedsiteid"] != "Global")
            {
                siteId = Convert.ToInt32(Request.QueryString["selectedsiteid"]);
            }
        }

        // Get the site record
        if (siteId > 0)
        {
            si = SiteInfoProvider.GetSiteInfo(siteId);
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("Task_Edit.ItemListLink");
        if (cmsdesk)
        {
            pageTitleTabs[0, 1] = "~/CMSSiteManager/Administration/ScheduledTasks/Task_List.aspx?siteid=" + siteId;
        }
        else
        {
            pageTitleTabs[0, 1] = "~/CMSSiteManager/Administration/ScheduledTasks/Task_List.aspx?selectedsiteid=" + siteId;
        }
        pageTitleTabs[0, 2] = "adminmain";
        pageTitleTabs[1, 0] = currentTask;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
        PageTitle.TitleText = title;
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/ScheduledTasks/newtask.gif";
    }


    /// <summary>
    /// Load data of editing task.
    /// </summary>
    /// <param name="taskObj">Task object.</param>
    protected void ReloadData()
    {
        txtTaskAssemblyName.Text = taskObj.TaskAssemblyName;
        txtTaskClass.Text = taskObj.TaskClass;
        txtTaskData.Text = taskObj.TaskData;
        txtTaskName.Text = taskObj.TaskName;
        chkTaskEnabled.Checked = taskObj.TaskEnabled;
        chkTaskDeleteAfterLastRun.Checked = taskObj.TaskDeleteAfterLastRun;
        ScheduleInterval1.ScheduleInterval = taskObj.TaskInterval;
        txtTaskDisplayName.Text = taskObj.TaskDisplayName;
        txtServerName.Text = taskObj.TaskServerName;
        siteId = taskObj.TaskSiteID;
    }


    //private bool CheckInterval()
    //{
    //    string sched = ScheduleInterval1.ScheduleInterval;
    //    if (sched.Contains("Minute") || sched.Contains("Hour"))
    //    {
    //    }
    //}

    //private bool CheckDays()
    //{
    //}

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Check modify permission
        if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Modify")))
        {
            RedirectToCMSDeskAccessDenied("CMS.Administration", "Modify");
        }

        string errorMessage = new Validator().NotEmpty(txtTaskDisplayName.Text, rfvDisplayName.ErrorMessage).NotEmpty(txtTaskName.Text, rfvName.ErrorMessage).NotEmpty(txtTaskAssemblyName.Text, rfvAssembly.ErrorMessage).NotEmpty(txtTaskClass.Text, rfvClass.ErrorMessage).Result;

        if (errorMessage == String.Empty && !ScheduleInterval1.CheckIntervalPreceedings())
        {
            errorMessage = ResHelper.GetString("Task_Edit.BetweenIntervalPreceedingsError");
        }

        if (errorMessage == String.Empty && !ScheduleInterval1.CheckOneDayMinimum())
        {
            errorMessage = ResHelper.GetString("Task_Edit.AtLeastOneDayError");
        }

        if (errorMessage != "")
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
        else
        {
            // Check existing task name
            TaskInfo existingTask = null;
            if (si != null)
            {
                existingTask = TaskInfoProvider.GetTaskInfo(txtTaskName.Text.Trim(), si.SiteName);
            }
            else
            {
                existingTask = TaskInfoProvider.GetTaskInfo(txtTaskName.Text.Trim(), null);
            }

            if ((existingTask != null) && ((taskObj == null) || (existingTask.TaskID != taskObj.TaskID)))
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Task_Edit.TaskNameExists").Replace("%%name%%", existingTask.TaskName);
                return;
            }

            if (taskObj == null)
            {
                // create new item -> insert
                taskObj = new TaskInfo();
                taskObj.TaskSiteID = siteId;
            }

            taskObj.TaskAssemblyName = txtTaskAssemblyName.Text.Trim();
            taskObj.TaskClass = txtTaskClass.Text.Trim();
            taskObj.TaskData = txtTaskData.Text.Trim();
            taskObj.TaskName = txtTaskName.Text.Trim();
            taskObj.TaskEnabled = chkTaskEnabled.Checked;
            taskObj.TaskDeleteAfterLastRun = chkTaskDeleteAfterLastRun.Checked;
            taskObj.TaskInterval = ScheduleInterval1.ScheduleInterval;
            taskObj.TaskDisplayName = txtTaskDisplayName.Text.Trim();
            taskObj.TaskServerName = txtServerName.Text.Trim();
            taskObj.TaskNextRunTime = SchedulingHelper.GetNextTime(taskObj.TaskInterval, DateTime.Now);

            // If web farm support, create the tasks for all servers
            if (chkAllServers.Checked)
            {
                TaskInfoProvider.CreateWebFarmTasks(taskObj);
            }
            else
            {
                TaskInfoProvider.SetTaskInfo(taskObj);
            }

            if (cmsdesk)
            {
                Response.Redirect("Task_Edit.aspx?taskname=" + taskObj.TaskID + "&saved=1&siteid=" + siteId);
            }
            else
            {
                Response.Redirect("Task_Edit.aspx?taskname=" + taskObj.TaskID + "&saved=1&selectedsiteid=" + siteId);
            }
        }
    }
}
