using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Threading;
using System.Diagnostics;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;

public partial class CMSSiteManager_Administration_System_System : AdministrationPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        lblAspAccount.Text = ResHelper.GetString("Administration-System.Account");
        lblValueAspAccount.Text = System.Security.Principal.WindowsIdentity.GetCurrent().Name;

        lblAlocatedMemory.Text = ResHelper.GetString("Administration-System.Memory");
        lblPeakMemory.Text = ResHelper.GetString("Administration-System.PeakMemory");
        lblVirtualMemory.Text = ResHelper.GetString("Administration-System.VirtualMemory");
        lblPhysicalMemory.Text = ResHelper.GetString("Administration-System.PhysicalMemory");

        btnClear.Text = ResHelper.GetString("Administration-System.btnClear");
        btnClearCache.Text = ResHelper.GetString("Administration-System.btnClearCache");
        btnRestart.Text = ResHelper.GetString("Administration-System.btnRestart");

        LoadData();

        ltlScript.Text = ScriptHelper.GetScript(" function Load() {}");

        if ((!Page.IsPostBack) && Request.QueryString["IsRestarted"] != null && Request.QueryString["IsRestarted"] != "" && Request.QueryString["IsRestarted"] == "1")
        {
            lblInfo.Text = ResHelper.GetString("Administration-System.RestartSuccess");
        }

        lblRunTime.Text = ResHelper.GetString("Administration.System.RunTime");

        // Remove miliseconds from the end of the time string
        string timeSpan = (DateTime.Now - Global.ApplicationStart).ToString();
        int index = timeSpan.LastIndexOf('.');
        if (index >= 0)
        {
            timeSpan = timeSpan.Remove(index);
        }

        // Display application run time
        lblRunTimeValue.Text = timeSpan;


    }


    /// <summary>
    /// Loads the data
    /// </summary>
    protected void LoadData()
    {
        lblValueAlocatedMemory.Text = DataHelper.GetSizeString(GC.GetTotalMemory(false));

        lblValueVirtualMemory.Text = "N/A";
        lblValuePhysicalMemory.Text = "N/A";
        lblValuePeakMemory.Text = "N/A";

        try
        {
            ProcessInfo pr = ProcessModelInfo.GetCurrentProcessInfo();
            lblValuePeakMemory.Text = DataHelper.GetSizeString(pr.PeakMemoryUsed * 1024);

            lblValueVirtualMemory.Text = DataHelper.GetSizeString(SystemHelper.GetVirtualMemorySize());
            lblValuePhysicalMemory.Text = DataHelper.GetSizeString(SystemHelper.GetWorkingSetSize());
            lblValuePeakMemory.Text = DataHelper.GetSizeString(SystemHelper.GetPeakWorkingSetSize());
        }
        catch
        {
        }
    }


    /// <summary>
    /// Clear unused memory
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnClear_Click(object sender, EventArgs e)
    {
        // Check modify permission
        if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Modify")))
        {
            RedirectToCMSDeskAccessDenied("CMS.Administration", "Modify");
        }

        GC.Collect();
        GC.WaitForPendingFinalizers();

        lblInfo.Text = ResHelper.GetString("Administration-System.ClearSuccess");

        LoadData();
    }


    /// <summary>
    /// Restart application
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnRestart_Click(object sender, EventArgs e)
    {
        // Check modify permission
        if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Modify")))
        {
            RedirectToCMSDeskAccessDenied("CMS.Administration", "Modify");
        }

        HttpRuntime.UnloadAppDomain();

        string url = UrlHelper.AddParameterToUrl(Request.RawUrl, "IsRestarted", "1");
        Response.Redirect(url);
    }


    protected void btnClearCache_Click(object sender, EventArgs e)
    {
        // Check modify permission
        if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Modify")))
        {
            RedirectToCMSDeskAccessDenied("CMS.Administration", "Modify");
        }

        CacheHelper.ClearCache("", true);

        lblInfo.Text = ResHelper.GetString("Administration-System.ClearCacheSuccess");

        LoadData();
    }
}
