using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Net;
using System.Net.Mail;

using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.EmailEngine;

public partial class CMSSiteManager_Administration_System_System_Email : AdministrationPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Initialize controls
        lblServer.Text = ResHelper.GetString("System_Email.SMTPServer");
        lblUserName.Text = ResHelper.GetString("System_Email.SMTPUserName");
        lblPassword.Text = ResHelper.GetString("System_Email.SMTPPassword");
        lblFrom.Text = ResHelper.GetString("System_Email.From");
        lblTo.Text = ResHelper.GetString("System_Email.To");
        lblSubject.Text = ResHelper.GetString("System_Email.Subject");
        lblText.Text = ResHelper.GetString("System_Email.Text");
        btnSend.Text = ResHelper.GetString("System_Email.Send");
        lblEncoding.Text = ResHelper.GetString("System_Email.Encoding");
        lblSSL.Text = ResHelper.GetString("System_Email.SSL");
        
        // Initialize required field validators
        rfvServer.ErrorMessage = ResHelper.GetString("System_Email.ErrorServer");
        revFrom.ErrorMessage = ResHelper.GetString("System_Email.ErrorEmail");
        rfvFrom.ErrorMessage = ResHelper.GetString("System_Email.EmptyEmail"); ;
        revFrom.ValidationExpression = @"^[A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)*@[A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)+$";
        revTo.ErrorMessage = revFrom.ErrorMessage;
        rfvTo.ErrorMessage = rfvFrom.ErrorMessage;
        revTo.ValidationExpression = @"^([A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)*@[A-Za-z0-9_-]+(\.[A-Za-z0-9_-]+)+(;)?)+$";

        if (!IsPostBack)
        {
            // Fill SMTP fields
            if (CMSContext.CurrentSite != null)
            {
                string siteName = CMSContext.CurrentSite.SiteName;
                txtServer.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSSMTPServer");
                txtUserName.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSSMTPServerUser");
                txtPassword.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSSMTPServerPassword");
            }
        }
    }


    /// <summary>
    /// On btnSend click.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnSend_Click(object sender, EventArgs e)
    {
        string result = new Validator().NotEmpty(txtServer.Text, ResHelper.GetString("System_Email.ErrorServer")).NotEmpty(txtFrom.Text, ResHelper.GetString("System_Email.EmptyEmail")).NotEmpty(txtTo.Text, ResHelper.GetString("System_Email.EmptyEmail")).Result;

        if (result == "")
        {
            // Validate e-mail addresses
            if (ValidationHelper.IsEmail(txtFrom.Text) && ValidationHelper.AreEmails(txtTo.Text))
            {
                // Send the testing e-mail
                try
                {
                    SendEmail();

                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("System_Email.EmailSent");
                }
                catch(Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = ex.Message;
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("System_Email.ErrorEmail");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    /// <summary>
    /// Send testing e-mail.
    /// </summary>
    protected void SendEmail()
    {
        EmailMessage msg = new EmailMessage();

        // Set from, to, subject and body.
        msg.From = txtFrom.Text;
        msg.Recipients = txtTo.Text;
        msg.Subject = txtSubject.Text;
        msg.Body = txtText.Text;
        msg.EmailFormat = EmailFormatEnum.Html;

        EmailSender.SendEmail(null, msg, txtServer.Text, txtUserName.Text, txtPassword.Text, txtEncoding.Text, chkSSL.Checked); 
    }
}
