using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.Ecommerce;

public partial class CMSSiteManager_Administration_Users_User_edit_Departments : AdministrationPage
{
    const int COL_MEMBER = 0;
    const int COL_DEPART_NAME = 1;
    const int COL_DEPART_ID = 2;

    protected int userId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        InitGUI();

        // is e-commerce on site? => show department tab
        bool ecommerceOnSite = false;
        if (CMSContext.CurrentSite != null)
        {
            ResourceInfo ri = ResourceInfoProvider.GetResourceInfo("CMS.Ecommerce");
            if (ri != null)
            {
                ecommerceOnSite = ResourceInfoProvider.IsResourceOnSite(ri.ResourceId, CMSContext.CurrentSite.SiteID);
            }
        }

        // check 'EcommerceRead' permission
        if (!ecommerceOnSite || !CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        userId = ValidationHelper.GetInteger(Request.QueryString["userid"], 0);

        if (!ValidateUserID(userId))
        {
            return;
        }

        if (userId > 0)
        {
            DataSet ds =  DepartmentInfoProvider.GetDepartments();
            GridViewDepartments.Columns[COL_DEPART_ID].Visible = true;
            GridViewDepartments.DataSource = ds.Tables[0];
            GridViewDepartments.DataBind();

            //after id is copied, the 3rd column it's not needed anymore
            GridViewDepartments.Columns[COL_DEPART_ID].Visible = false;
            GridViewDepartments.GridLines = GridLines.Horizontal;
        }

    }


    protected void InitGUI()
    {
        ButtonOK.Text = ResHelper.GetString("General.OK");
        GridViewDepartments.Columns[COL_MEMBER].HeaderText = ResHelper.GetString("Administration-User_Edit_Departments.IsMember");
        GridViewDepartments.Columns[COL_DEPART_NAME].HeaderText = ResHelper.GetString("Administration-User_Edit_Departments.Department");
    }


    protected bool ValidateUserID(int userid)
    {
        if (UserInfoProvider.GetUserInfo(userId) == null)
        {
            lblInfo.Visible = true;
            lblInfo.Text = ResHelper.GetString("Administration-User_Edit_Departments.InvalidUserID");
            ButtonOK.Visible = false;
            return false;
        }
        return true;
    }


    protected void GridViewDepartments_DataBound(object sender, EventArgs e)
    {
        for (int i = 0; i < GridViewDepartments.Rows.Count; i++)
        {
            CheckBox isMember = new CheckBox();
            int departmentId = ValidationHelper.GetInteger(GridViewDepartments.Rows[i].Cells[COL_DEPART_ID].Text, -1);

            DepartmentInfo di = DepartmentInfoProvider.GetDepartmentInfo(departmentId);
            if (di != null)
            {
                isMember.Checked = DepartmentInfoProvider.IsUserInDepartment(departmentId, userId);
                GridViewDepartments.Rows[i].Cells[COL_MEMBER].Controls.Add(isMember);
            }
        }
    }


    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        if (!ValidateUserID(userId))
        {
            return;
        }


        string userName = UserInfoProvider.GetUserNameById(userId);

        for (int i = 0; i < GridViewDepartments.Rows.Count; i++)
        {
            CheckBox isMember = (CheckBox)GridViewDepartments.Rows[i].Cells[COL_MEMBER].Controls[0];
            int departmentId = ValidationHelper.GetInteger(GridViewDepartments.Rows[i].Cells[COL_DEPART_ID].Text, -1);

            if (isMember.Checked)
            {
                // if user is not in department, add it to the department
                DepartmentInfoProvider.AddUserToDepartment(departmentId, userId);
            }

            else
            {
                // if user is in department, remove it from the department
                DepartmentInfoProvider.RemoveUserFromDepartment(departmentId, userId);
            }
        }

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
    }
}
