using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.FileManager;
using CMS.DirectoryUtilities;

public partial class SiteManager_Administration_Users_User_Edit_General : AdministrationPage
{
    protected int userId = 0;
    protected string password;
    protected string myCulture = "";
    protected string myUICulture = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        LabelUserName.Text = ResHelper.GetString("Administration-User_Edit_General.UserName");
        LabelFullName.Text = ResHelper.GetString("Administration-User_Edit_General.FullName");
        LabelFirstName.Text = ResHelper.GetString("Administration-User_Edit_General.FirstName");
        LabelMiddleName.Text = ResHelper.GetString("Administration-User_Edit_General.MiddleName");
        LabelLastName.Text = ResHelper.GetString("Administration-User_Edit_General.LastName");
        LabelEmail.Text = ResHelper.GetString("Administration-User_Edit_General.Email");
        LabelEnabled.Text = ResHelper.GetString("Administration-User_Edit_General.Enabled");
        LabelIsEditor.Text = ResHelper.GetString("Administration-User_Edit_General.IsEditor");
        LabelIsGlobalAdministrator.Text = ResHelper.GetString("Administration-User_Edit_General.IsGlobalAdministrator");
        lblCulture.Text = ResHelper.GetString("Administration-User_Edit_General.Culture");
        lblUICulture.Text = ResHelper.GetString("Administration-User_Edit_General.UICulture");
        ButtonOK.Text = ResHelper.GetString("Administration-User_Edit_General.OK");
        RequiredFieldValidatorFullName.ErrorMessage = ResHelper.GetString("Administration-User_New.RequiresFullName");
        RequiredFieldValidatorUserName.ErrorMessage = ResHelper.GetString("Administration-User_New.RequiresUserName");
        lblIsExternal.Text = ResHelper.GetString("Administration-User_Edit_General.IsExternal");
        lblCreated.Text = ResHelper.GetString("Administration-User_Edit_General.UserCreated");
        lblLastLogon.Text = ResHelper.GetString("Administration-User_Edit_General.LastLogon");
        lblReferrer.Text = ResHelper.GetString("Administration-User_Edit_General.URLReferrer");
        lblCampaign.Text = ResHelper.GetString("Administration-User_Edit_General.Campaign");

        this.Page.ClientScript.RegisterClientScriptBlock(typeof(string), "PictDelConfirm", ScriptHelper.GetScript("" +
            "function DeleteConfirmation(){ return confirm('" + ResHelper.GetString("MyProfile.PictDeleteConfirm") + "');}"));


        lblUserPicture.Text = ResHelper.GetString("Administration-User_Edit_General.UserPicture");
        lblUserSignature.Text = ResHelper.GetString("Administration-User_Edit_General.UserSignature");
        lblNickName.Text = ResHelper.GetString("Administration-User_Edit_General.UserNickName");

        if (CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            LabelIsGlobalAdministrator.Visible = true;
            CheckBoxLabelIsGlobalAdministrator.Visible = true;
        }
        if ((Request.QueryString["userid"] != null) && (Request.QueryString["userid"] != ""))
        {
            userId = Convert.ToInt32(Request.QueryString["userid"]);
            if (!IsPostBack)
            {
                LoadData();
            }
        }

        UserInfo mui = UserInfoProvider.GetUserInfo(userId);

        if (mui != null)
        {
            SetUserPictureArea(mui);
        }
    }

    /// <summary>
    /// Loads data of edited user from DB into TextBoxes.
    /// </summary>
    protected void LoadData()
    {
        // Fill lstCulture
        lstCulture.DataSource = CultureInfoProvider.GetAllCultures();
        lstCulture.DataTextField = "CultureName";
        lstCulture.DataValueField = "CultureID";
        lstCulture.DataBind();

        lstCulture.Items.Insert(0, ResHelper.GetString("Administration-User_Edit.Default"));
        lstCulture.Items[0].Value = "0";

        // Fill lstUICulture

        lstUICulture.DataSource = UICultureInfoProvider.GetAllUICultures();
        lstUICulture.DataTextField = "UICultureName";
        lstUICulture.DataValueField = "UICultureID";
        lstUICulture.DataBind();

        lstUICulture.Items.Insert(0, ResHelper.GetString("Administration-User_Edit.Default"));
        lstUICulture.Items[0].Value = "0";

        string userName = UserInfoProvider.GetUserNameById(userId);
        UserInfo ui = UserInfoProvider.GetUserInfo(userId);

        if (ui != null)
        {
            TextBoxEmail.Text = ui.Email;
            TextBoxFirstName.Text = ui.FirstName;
            TextBoxFullName.Text = ui.FullName;
            TextBoxLastName.Text = ui.LastName;
            TextBoxMiddleName.Text = ui.MiddleName;
            TextBoxUserName.Text = ui.UserName;

            txtNickName.Text = ui.UserNickName;
            txtUserSignature.Text = ui.UserSignature;

            CheckBoxEnabled.Checked = ui.Enabled;
            CheckBoxIsEditor.Checked = ui.IsEditor;
            if (CheckBoxLabelIsGlobalAdministrator.Visible)
            {
                CheckBoxLabelIsGlobalAdministrator.Checked = ui.IsGlobalAdministrator;
            }
            chkIsExternal.Checked = ui.IsExternal;
            password = ui.GetValue("UserPassword").ToString();

            if (ui.IsPublic())
            {
                this.TextBoxUserName.Enabled = false;
            }

            myCulture = ui.PreferredCultureCode;
            myUICulture = ui.PreferredUICultureCode;

            txtReferrer.Text = ui.UserURLReferrer;
            txtCampaign.Text = ui.UserCampaign;
        }

        // select cultures for actual user or set default
        if ((myCulture != null) && (myCulture != ""))
        {
            try
            {
                CultureInfo ci = CultureInfoProvider.GetCultureInfo(myCulture);
                lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue(ci.CultureID.ToString()));
            }
            catch
            {
                lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue("0"));
            }
        }
        else
            lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue("0"));

        if ((myUICulture != null) && (myUICulture != ""))
        {
            try
            {
                UICultureInfo ciUI = UICultureInfoProvider.GetUICultureInfo(myUICulture);
                lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue(ciUI.UICultureID.ToString()));
            }
            catch
            {
                lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue("0"));
            }
        }
        else
            lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue("0"));

        lblCreatedInfo.Text = ui.UserCreated.ToString();
        lblLastLogonInfo.Text = ui.LastLogon.ToString();

        if (ui.UserCreated == DataHelper.DATETIME_NOT_SELECTED)
        {
            lblCreatedInfo.Text = ResHelper.GetString("Administration-User_Edit_General.Never");
        }

        if (ui.LastLogon == DataHelper.DATETIME_NOT_SELECTED)
        {
            lblLastLogonInfo.Text = ResHelper.GetString("Administration-User_Edit_General.Never");
        }

    }

    /// <summary>
    /// Saves data of edited user from TextBoxes into DB.
    /// </summary>
    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        // Check modify permission
        if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.administration", "Modify")))
        {
            RedirectToCMSDeskAccessDenied("cms.administration", "Modify");
        }


        // finds whether required fields are not empty
        string result = new Validator().NotEmpty(TextBoxUserName.Text, ResHelper.GetString("Administration-User_New.RequiresUserName")).NotEmpty(TextBoxFullName.Text, ResHelper.GetString("Administration-User_New.RequiresFullName")).Result;

        if (result == "")
        {
            UserInfo ui = UserInfoProvider.GetUserInfo(userId);
            password = ui.GetValue("UserPassword").ToString();
            userId = ui.UserID;

            UserInfo uiTest = UserInfoProvider.GetUserInfo(TextBoxUserName.Text);
            if ((uiTest == null) || (uiTest.UserID == userId))
            {
                if (ui == null)
                {
                    ui = new UserInfo();
                }

                UserPictureFormControl.UpdateUserPicture(ui);

                // email format validation
                if ((TextBoxEmail.Text.Trim() != "") && (!ValidationHelper.IsEmail(TextBoxEmail.Text)))
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Administration-User_New.WrongEmailFormat");
                    return;
                }

                ui.Email = TextBoxEmail.Text;
                ui.FirstName = TextBoxFirstName.Text;
                ui.FullName = TextBoxFullName.Text;
                ui.LastName = TextBoxLastName.Text;
                ui.MiddleName = TextBoxMiddleName.Text;
                ui.UserName = TextBoxUserName.Text;
                ui.Enabled = CheckBoxEnabled.Checked;
                ui.IsEditor = CheckBoxIsEditor.Checked;
                if (CheckBoxLabelIsGlobalAdministrator.Visible)
                {
                    ui.IsGlobalAdministrator = CheckBoxLabelIsGlobalAdministrator.Checked;
                }
                else
                {
                    ui.IsGlobalAdministrator = false;
                }
                ui.IsExternal = chkIsExternal.Checked;
                ui.SetValue("UserPassword", password);
                ui.UserID = userId;
                ui.UserCampaign = txtCampaign.Text;
                ui.UserURLReferrer = txtReferrer.Text;

                // Set values of cultures.
                if (lstCulture.SelectedValue == "0")
                    ui.PreferredCultureCode = "";
                else
                {
                    CultureInfo ci = CultureInfoProvider.GetCultureInfo(Convert.ToInt32(lstCulture.SelectedValue));
                    ui.PreferredCultureCode = ci.CultureCode;
                }
                if (lstUICulture.SelectedValue == "0")
                    ui.PreferredUICultureCode = "";
                else
                {
                    UICultureInfo ciUI = UICultureInfoProvider.GetUICultureInfo(Convert.ToInt32(lstUICulture.SelectedValue));
                    ui.PreferredUICultureCode = ciUI.UICultureCode;
                }

                ui.UserNickName = txtNickName.Text.Trim();
                ui.UserSignature = txtUserSignature.Text;
                CMSContext.CurrentUser.UserNickName = ui.UserNickName;
                CMSContext.CurrentUser.UserSignature = ui.UserSignature;

                UserInfoProvider.SetUserInfo(ui);

                SetUserPictureArea(ui);

                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Administration-User_New.UserExists");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    protected void SetUserPictureArea(UserInfo ui)
    {
        UserPictureFormControl.UserInfo = ui;
        UserPictureFormControl.MaxPictureWidth = 100;
        UserPictureFormControl.MaxPictureHeight = 100;
        UserPictureFormControl.FileUploadFieldWidth = 370;
    }

}
