using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.FormEngine;

public partial class SiteManager_Administration_Users_User_New : AdministrationPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Check modify permission
        if ((CMSContext.CurrentSite != null) && (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Administration", "Create")))
        {
            RedirectToCMSDeskAccessDenied("CMS.Administration", "Create");
        }

        LabelConfirmPassword.Text = ResHelper.GetString("Administration-User_New.ConfirmPassword");
        LabelEmail.Text = ResHelper.GetString("Administration-User_New.Email");
        LabelEnabled.Text = ResHelper.GetString("Administration-User_New.Enabled");
        LabelIsEditor.Text = ResHelper.GetString("Administration-User_New.IsEditor");
        LabelFullName.Text = ResHelper.GetString("Administration-User_New.FullName");
        LabelPassword.Text = ResHelper.GetString("Administration-User_New.Password");
        LabelUserName.Text = ResHelper.GetString("Administration-User_New.UserName");
        ButtonOK.Text = ResHelper.GetString("Administration-User_New.OK");
        RequiredFieldValidatorFullName.ErrorMessage = ResHelper.GetString("Administration-User_New.RequiresFullName");
        RequiredFieldValidatorUserName.ErrorMessage = ResHelper.GetString("Administration-User_New.RequiresUserName");
        
        if (!IsPostBack)
        {
            CheckBoxEnabled.Checked = true;
            CheckBoxIsEditor.Checked = true;
        }

        string users = ResHelper.GetString("Administration-User_New.Users");
        string currentUser = ResHelper.GetString("Administration-User_New.CurrentUser");
        string title = ResHelper.GetString("Administration-User_New.Title");
        
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = users;
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Administration/Users/User_List.aspx?siteid=" + ValidationHelper.GetInteger(Request.QueryString["siteid"], 0).ToString();
        pageTitleTabs[0, 2] = "adminmain";
        pageTitleTabs[1, 0] = currentUser;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle1.Breadcrumbs = pageTitleTabs;
        PageTitle1.TitleText = title;
        PageTitle1.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/Users/user.gif";
    }
    
    protected void ButtonOK_Click(object sender, EventArgs e)
    {

        // email format validation
        if ((TextBoxEmail.Text.Trim() != "") && (!ValidationHelper.IsEmail(TextBoxEmail.Text)))
        {
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Administration-User_New.WrongEmailFormat");
            return;
        }

        // finds whether required fields are not empty
        string result = new Validator().NotEmpty(TextBoxUserName.Text, ResHelper.GetString("Administration-User_New.RequiresUserName")).NotEmpty(TextBoxFullName.Text, ResHelper.GetString("Administration-User_New.RequiresFullName")).Result;

        if (result == "")
        {
            if (TextBoxConfirmPassword.Text == TextPassword.Text)
            {
                if (UserInfoProvider.GetUserInfo(TextBoxUserName.Text) == null)
                {
                    int userId = SaveNewUser();
                    Response.Redirect("User_Edit_Frameset.aspx?userId=" + userId + "&siteid=" + ValidationHelper.GetInteger(Request.QueryString["siteid"], 0).ToString());
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Administration-User_New.UserExists");
                }
            }
            else
            {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Administration-User_Edit_Password.PasswordsDoNotMatch");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    /// <summary>
    /// Saves new user's data into DB.
    /// </summary>
    /// <returns>Returns ID of created user</returns>
    protected int SaveNewUser()
    {
        UserInfo ui = new UserInfo();

        // Load default values
        FormHelper.LoadDefaultValues("cms.user", ui.DataClass.DataRow);

        ui.PreferredCultureCode = "";
        ui.Email = TextBoxEmail.Text;
        ui.FirstName = "";
        ui.FullName = TextBoxFullName.Text;
        ui.LastName = "";
        ui.MiddleName = "";
        ui.UserName = TextBoxUserName.Text;
        ui.Enabled = CheckBoxEnabled.Checked;
        ui.IsEditor = CheckBoxIsEditor.Checked;
        ui.IsExternal = false;
        ui.IsGlobalAdministrator = false;

        UserInfoProvider.SetUserInfo(ui);
        UserInfoProvider.SetPassword(ui.UserName, TextPassword.Text);

        int siteId = ValidationHelper.GetInteger(Request.QueryString["siteid"], 0);
        if (siteId > 0)
        {
            UserInfoProvider.AddUserToSite(ui.UserName, SiteInfoProvider.GetSiteInfo(siteId).SiteName);
        }
        return ui.UserID;
    }
}
