using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SettingsProvider;

public partial class SiteManager_Development_DocumentTypes_DocumentType_Edit_ChildTypes : SiteManagerPage
{
    private static int classId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // gets classID from querystring
        if (Request.QueryString["documenttypeid"] != null)
        {
            // initializes labels
            lblTitle.Text = ResHelper.GetString("DocumentType_Edit_ChildTypes.Info");
            btnOK.Text = ResHelper.GetString("DocumentType_Edit_ChildTypes.ButtonOK");

            classId = Convert.ToInt32(Request.QueryString["documenttypeid"]);

            GridViewChildTypes.GridLines = GridLines.Horizontal;

            if (!Page.IsPostBack)
            {
                // initializes gridview
                GridViewChildTypes.Columns[0].HeaderText = ResHelper.GetString("DocumentType_Edit_ChildTypes.Select");
                GridViewChildTypes.Columns[1].HeaderText = ResHelper.GetString("DocumentType_Edit_ChildTypes.DisplayName");
                GridViewChildTypes.Columns[2].HeaderText = ResHelper.GetString("DocumentType_Edit_ChildTypes.CodeName");

                // reads document types to gridview
                DataSet ds = DataClassInfoProvider.GetDocumentTypeClasses();
                GridViewChildTypes.DataSource = ds.Tables[0];

                GridViewChildTypes.Columns[3].Visible = true;
                GridViewChildTypes.DataBind();
                GridViewChildTypes.Columns[3].Visible = false;
            }
        }
    }

    /// <summary>
    /// Initializes CheckBoxField in GridView
    /// </summary>
    protected void GridViewChildTypes_DataBound(object sender, EventArgs e)
    {
        // gets child types per class
        DataSet ds = GetChildTypesPerClass();

        for (int i = 0; i < GridViewChildTypes.Rows.Count; i++)
        {
            CheckBox chBox = (CheckBox)GridViewChildTypes.Rows[i].FindControl("chkSelect");
            DataRow[] foundRows;
            string expression = "ChildClassID=" + GridViewChildTypes.Rows[i].Cells[3].Text;

            foundRows = ds.Tables[0].Select(expression);

            // if child class exists, checkbox is checked
            if (foundRows.Length != 0) chBox.Checked = true;
            // otherwise checkbox is not checked
            else chBox.Checked = false;
        }
    }

    /// <summary>
    /// Adds or removes child class to or from DB.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // goes through the gridview rows
        for (int i = 0; i < GridViewChildTypes.Rows.Count; i++)
        {
            int childClassID = Convert.ToInt32(GridViewChildTypes.Rows[i].Cells[3].Text);

            bool isChecked = ((CheckBox) GridViewChildTypes.Rows[i].FindControl("chkSelect")).Checked;
            
            // if checkbox is checked, child class can be placed under parent class
            if (isChecked)
            {
                DataClassInfoProvider.AllowChildClass(classId, childClassID);
            }
            else
            {
                DataClassInfoProvider.RemoveChildClass(classId, childClassID);
            }
        }

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
    }

    /// <summary>
    /// Gets all child types which can be placed under the class (document)
    /// </summary>
    /// <returns>DataSet of child types</returns>
    protected static DataSet GetChildTypesPerClass()
    {
        GeneralConnection genConn = ConnectionHelper.GetConnection();

        object[,] parameters = new object[1, 3];
        parameters[0, 0] = "@ParentClassID";
        parameters[0, 1] = classId;

        DataSet ds = genConn.ExecuteQuery("cms.class.childclasses", parameters);
        return ds;
    }
}
