using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.FormEngine;
using CMS.SettingsProvider;
using CMS.Ecommerce;

public partial class CMSSiteManager_Development_DocumentTypes_DocumentType_Edit_Ecommerce : CMSEcommercePage
{
    int docTypeId = 0;
    DataClassInfo dci = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        
        lblName.Text = ResHelper.GetString("DocType.Ecommerce.lblName");
        lblWeight.Text = ResHelper.GetString("DocType.Ecommerce.lblWeight");
        lblHeight.Text = ResHelper.GetString("DocType.Ecommerce.lblHeight");
        lblWidth.Text = ResHelper.GetString("DocType.Ecommerce.lblWidth");
        lblDepth.Text = ResHelper.GetString("DocType.Ecommerce.lblDepth");
        lblImage.Text = ResHelper.GetString("DocType.Ecommerce.lblImage");
        lblPrice.Text = ResHelper.GetString("DocType.Ecommerce.lblPrice");
        lblDescription.Text = ResHelper.GetString("DocType.Ecommerce.lblDescription");
        btnOK.Text = ResHelper.GetString("General.OK");
        lblTitle.Text = ResHelper.GetString("DocType.Ecommerce.lblTitle");
        lblGenerateSKU.Text = ResHelper.GetString("DocType.Ecommerce.lblGenerateSKU");
        lblDepartments.Text = ResHelper.GetString("DocType.Ecommerce.lblDepartments");

        docTypeId = ValidationHelper.GetInteger(Request.QueryString["documenttypeid"], 0);
        dci = DataClassInfoProvider.GetDataClass(docTypeId);

        chkGenerateSKU.Attributes.Add("onClick", "EnableDisableForm()");

        if (!this.IsPostBack)
        {
            FillDropDownLists();
            SelectMappings();            

            // Load departments
            drpDepartments.DataSource = DepartmentInfoProvider.GetDepartments(null, "DepartmentDisplayName");
            drpDepartments.DataBind();
            drpDepartments.Items.Insert(0, "");

            // Try to select specified department
            ListItem li = drpDepartments.Items.FindByValue((dci.ClassSKUDefaultDepartmentID).ToString());
            if (li != null)
            {
                chkGenerateSKU.Checked = true;                      
                li.Selected = true;                
            }
        }

        // Enable / disable form
        ltlScrpt.Text = ScriptHelper.GetScript("EnableDisableForm();");     
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {
        // Validate form
        string errorMessage = ValidateForm();

        if (errorMessage == "")
        {

            dci = DataClassInfoProvider.GetDataClass(docTypeId);
            if (dci != null)
            {
                //string mappings = null;
                string key = "";

                #region " Set mappings "

                key = "SKUImagePath";
                if (drpImage.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpImage.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUName";
                if (drpName.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpName.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUWeight";
                if (drpWeight.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpWeight.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUHeight";
                if (drpHeight.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpHeight.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUWidth";
                if (drpWidth.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpWidth.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUDepth";
                if (drpDepth.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpDepth.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUPrice";
                if (drpPrice.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpPrice.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                key = "SKUDescription";
                if (drpDescription.SelectedIndex > 0)
                {
                    dci.SKUMappings[key] = drpDescription.SelectedValue;
                }
                else if (dci.SKUMappings.Contains(key))
                {
                    dci.SKUMappings.Remove(key);
                }

                #endregion

                dci.ClassSKUDefaultDepartmentID = ValidationHelper.GetInteger(drpDepartments.SelectedValue, 0);

                try
                {
                    // Save changed to database
                    DataClassInfoProvider.SetDataClass(dci);
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
                catch (Exception ex)
                {
                    errorMessage = ex.Message;
                }
            }
        }

        // Show error message
        if (errorMessage != "")
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }


    /// <summary>
    /// Validates form and returns error message when occures.
    /// </summary>
    /// <returns></returns>
    protected string ValidateForm()
    {
        string errorMessage = "";

        if (chkGenerateSKU.Checked)
        {
            // Product name and Product price fields must be mapped
            if ((drpName.SelectedValue == "") || (drpPrice.SelectedValue == ""))
            {
                errorMessage = ResHelper.GetString("DocType.Ecommerce.MappingMissing");
            }

            if (errorMessage == "")
            {
                // Check department
                if (ValidationHelper.GetInteger(drpDepartments.SelectedValue, 0) == 0)
                {
                    errorMessage = ResHelper.GetString("DocType.Ecommerce.DepartmentEmpty");
                }
            }
        }

        return errorMessage;
    }


    /// <summary>
    /// Selects specified mappings in dropdownlists
    /// </summary>
    protected void SelectMappings()
    {
        if (dci != null)
        {
            drpName.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUName"], "0");
            drpImage.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUImagePath"], "0");
            drpWeight.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUWeight"], "0");
            drpHeight.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUHeight"], "0");
            drpWidth.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUWidth"], "0");
            drpDepth.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUDepth"], "0");
            drpPrice.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUPrice"], "0");
            drpDescription.SelectedValue = ValidationHelper.GetString(dci.SKUMappings["SKUDescription"], "0");
        }
    }

    /// <summary>
    /// Fills dropdownlists with data.
    /// </summary>
    protected void FillDropDownLists()
    {
        FormFieldInfo[] fields = null;

        if (dci != null)
        {
            FormInfo fi = new FormInfo();
            fi.LoadXmlDefinition(dci.ClassFormDefinition);
            fields = fi.GetFields(true, true);
        }

        // Insert '( none )' item into all dropdownlists
        string noneString = ResHelper.GetString("doctype.ecommerce.noneitem");
        drpImage.Items.Add(new ListItem(noneString, ""));
        drpHeight.Items.Add(new ListItem(noneString, ""));
        drpDepth.Items.Add(new ListItem(noneString, ""));
        drpWeight.Items.Add(new ListItem(noneString, ""));
        drpWidth.Items.Add(new ListItem(noneString, ""));
        drpName.Items.Add(new ListItem(noneString, ""));
        drpPrice.Items.Add(new ListItem(noneString, ""));
        drpDescription.Items.Add(new ListItem(noneString, ""));

        // Insert 'Document name' item into all dropdownlists                        
        string docNameValue = "DocumentName";
        drpImage.Items.Add(new ListItem(docNameValue, docNameValue));
        drpHeight.Items.Add(new ListItem(docNameValue, docNameValue));
        drpDepth.Items.Add(new ListItem(docNameValue, docNameValue));
        drpWeight.Items.Add(new ListItem(docNameValue, docNameValue));
        drpWidth.Items.Add(new ListItem(docNameValue, docNameValue));
        drpName.Items.Add(new ListItem(docNameValue, docNameValue));
        drpPrice.Items.Add(new ListItem(docNameValue, docNameValue));
        drpDescription.Items.Add(new ListItem(docNameValue, docNameValue));

        // Fill dropdownlists with data
        if (fields != null)
        {
            foreach (FormFieldInfo ffi in fields)
            {
                drpImage.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpHeight.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpDepth.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpWeight.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpWidth.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpName.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpPrice.Items.Add(new ListItem(ffi.Name, ffi.Name));
                drpDescription.Items.Add(new ListItem(ffi.Name, ffi.Name));
            }
        }
    }
}
