using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.FormEngine;
using CMS.CMSHelper;


public partial class CMSSiteManager_Development_DocumentTypes_DocumentType_Edit_Form : CMSDeskPage
{
    private int classId = 0;
    private bool isDocType = false;

    /// <summary>
    /// Indicates whether custom form layout is set or not
    /// </summary>
    private bool IsLayoutSet
    {
        get
        {
            object obj = ViewState["IsLayoutSet"];
            return (obj == null) ? false : (bool)obj;
        }

        set
        {
            ViewState["IsLayoutSet"] = value;
        }

    }


    protected void Page_Load(object sender, EventArgs e)
    {   
        int formClassId = 0;
        int documentTypeId = 0;


        chkCustomLayout.Text = ResHelper.GetString("DocumentType_Edit_Form.chkCustomLayout");
        lblAvailableFields.Text = ResHelper.GetString("DocumentType_Edit_Form.AvailableFields");
        btnGenerateLayout.Text = ResHelper.GetString("DocumentType_Edit_Form.btnGenerateLayout");
        btnInsertLabel.Text = ResHelper.GetString("DocumentType_Edit_Form.btnInsertLabel");
        btnInsertInput.Text = ResHelper.GetString("DocumentType_Edit_Form.btnInsertInput");
        btnInsertValLabel.Text = ResHelper.GetString("DocumentType_Edit_Form.InsertValidationLabel");
        btnOK.Text = ResHelper.GetString("DocumentType_Edit_Form.btnOK");
        ltlAlertExist.Text = "<input type=\"hidden\" id=\"alertexist\" value=\"" + ResHelper.GetString("DocumentType_Edit_Form.AlertExist") + "\">";
        ltlAlertExistFinal.Text = "<input type=\"hidden\" id=\"alertexistfinal\" value=\"" + ResHelper.GetString("DocumentType_Edit_Form.AlertExistFinal") + "\">";
        ltlConfirmDelete.Text = "<input type=\"hidden\" id=\"confirmdelete\" value=\"" + ResHelper.GetString("DocumentType_Edit_Form.ConfirmDelete") + "\">";            
        

        if (!IsPostBack)
        {
            // initialize FCK editor
            InitFCKeditor();
        }

        // get document type id from querystring;
        documentTypeId = ValidationHelper.GetInteger(Request.QueryString["documenttypeid"], 0);

        // get form class id from querystring;
        formClassId = ValidationHelper.GetInteger(Request.QueryString["formclassid"], 0);

        // determines whether it is a document type or bizform
        if (documentTypeId > 0)
        {
            classId = documentTypeId;
            isDocType = true;
        }
        else if(formClassId > 0)
        {
            classId = formClassId;
            isDocType = false;
        }

        if ((classId > 0) )
        {     
            // check permissions if it is bizform
            if (!isDocType)
            {
                // check 'ReadForm' permission
                if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "ReadForm"))
                {
                    CMSDeskPage.RedirectToAccessDenied("cms.form", "ReadForm");
                }
            }        

            if (!IsPostBack)
            {
                DataClassInfo dci = DataClassInfoProvider.GetDataClass(classId);

                if (dci != null)
                {
                    // enable or disable form
                    EnableDisableForm(dci.ClassFormLayout);
                }
                else
                {
                    // disable form by default
                    EnableDisableForm(null);
                }

                // enable or disable OK button
                EnableDisableOKButton();

                // fill list of available fields                    
                FillFieldsList();
            }

        }
         
    }


    /// <summary>
    /// Custom layout checkbox checked changed
    /// </summary>
    protected void chkCustomLayout_CheckedChanged(object sender, EventArgs e)
    {

        pnlCustomLayout.Visible = !pnlCustomLayout.Visible;

        // remove content checking and add delete confirmation
        if (!chkCustomLayout.Checked && IsLayoutSet)
        {
            btnOK.OnClientClick = "return ConfirmDelete();";
        }
        // remove delete confirmation and add content checking
        else if (chkCustomLayout.Checked)
        {
            btnOK.OnClientClick = "return CheckContent();";                            
        }
        
        // enable or disable OK button
        EnableDisableOKButton();
    }


    /// <summary>
    /// OK button is clicked
    /// </summary>
    protected void btnOK_Clicked(object sender, EventArgs e)
    {
        // check permissions if it is bizform
        if (!isDocType)
        {
            // check 'ReadForm' permission
            if (!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.form", "EditForm"))
            {
                CMSDeskPage.RedirectToAccessDenied("cms.form", "EditForm");
            }
        }  

        DataClassInfo dci = DataClassInfoProvider.GetDataClass(classId);

        if (dci != null)
        {
            // save custom form layout
            if (chkCustomLayout.Checked)
            {
                dci.ClassFormLayout = fckEditor.Value;
                try
                {
                    DataClassInfoProvider.SetDataClass(dci);                    
                    DisplayInfoMessage(ResHelper.GetString("General.ChangesSaved"));
                    EnableDisableForm(dci.ClassFormLayout);
                
                }
                catch (Exception ex)
                {
                    DisplayErrorMessage(ex.Message);
                }
            }
            // delete custom form layout if exists
            else if (IsLayoutSet)
            {
                dci.ClassFormLayout = null;                
                try
                {
                    DataClassInfoProvider.SetDataClass(dci);
                    DisplayInfoMessage(ResHelper.GetString("DocumentType_Edit_Form.LayoutDeleted"));
                    EnableDisableForm(dci.ClassFormLayout);
                }
                catch (Exception ex)
                {
                    DisplayErrorMessage(ex.Message);
                }
            }
        }
        // enable or disable OK button
        EnableDisableOKButton();
    }


    /// <summary>
    /// Fills list of available fields
    /// </summary>
    protected void FillFieldsList()
    {
        FormInfo fi = new FormInfo();
        FormFieldInfo[] visibleFields = null;
        DataClassInfo dci = DataClassInfoProvider.GetDataClass(classId);

        if (dci != null)
        {
            // load form definition and get visible fields
            fi.LoadXmlDefinition(dci.ClassFormDefinition);
            visibleFields = fi.GetFields(true, false);

            lstAvailableFields.Items.Clear();

            if (isDocType)
            {
                if (dci.ClassNodeNameSource == "") //if node name source is not set
                {
                    lstAvailableFields.Items.Add(new ListItem(ResHelper.GetString("DocumentType_Edit_Form.DocumentName"), "DocumentName"));
                }
            }

            if (visibleFields != null)
            {
                // add visible fields to the list
                foreach (FormFieldInfo ffi in visibleFields)
                {
                    lstAvailableFields.Items.Add(new ListItem(ffi.Name, ffi.Name));
                }
            }

            if (isDocType)
            {
                if (dci.ClassUsePublishFromTo)
                {
                    lstAvailableFields.Items.Add(new ListItem(ResHelper.GetString("DocumentType_Edit_Form.DocumentPublishFrom"), "DocumentPublishFrom"));
                    lstAvailableFields.Items.Add(new ListItem(ResHelper.GetString("DocumentType_Edit_Form.DocumentPublishTo"), "DocumentPublishTo"));
                }
            }
                
            lstAvailableFields.SelectedIndex = 0;
        }
    }


    /// <summary>
    /// Enables or disables form according to form layout is defined or not
    /// </summary>
    protected void EnableDisableForm(string formLayout)
    {        

        // if form layout is set                 
        if (formLayout != null)
        {
            //enable form editing                    
            chkCustomLayout.Checked = true;
            pnlCustomLayout.Visible = true;

            // set text (form layout) to the editable window of the FCK editor
            fckEditor.Value = formLayout;

            // save info to viewstate 
            IsLayoutSet = true;
        }
        else
        {
            // form is not enabled by default        
            chkCustomLayout.Checked = false;
            pnlCustomLayout.Visible = false;

            fckEditor.Value = "";

            // save info to viewstate
            IsLayoutSet = false;
        }
    }


    /// <summary>
    /// Enables or disables 'OK button' according to form layout is defined or not
    /// </summary>
    protected void EnableDisableOKButton()
    {
        if ((!IsLayoutSet) && (!chkCustomLayout.Checked))
        {
            btnOK.Enabled = false;
        }
        else
        {
            btnOK.Enabled = true;
        }
    }


    /// <summary>
    /// Displays specified info message and hide error message.
    /// </summary>
    /// <param name="infoMessage">Info message to display.</param>
    protected void DisplayInfoMessage(string infoMessage)
    {
        lblError.Visible = false;
        lblInfo.Visible = true;
        lblInfo.Text = infoMessage;        
    }


    /// <summary>
    /// Displays specified error message and hide info message.
    /// </summary>
    /// <param name="errorMessage">Error message to display.</param>
    protected void DisplayErrorMessage(string errorMessage)
    {
        lblInfo.Visible = false;
        lblError.Visible = true;
        lblError.Text = errorMessage;
    }


    /// <summary>
    /// Initializes FCK editor's settings
    /// </summary>
    protected void InitFCKeditor()
    {
        fckEditor.BasePath = "~/CMSAdminControls/FCKeditor/";
        fckEditor.AutoDetectLanguage = false;
        fckEditor.DefaultLanguage = System.Threading.Thread.CurrentThread.CurrentCulture.TwoLetterISOLanguageName;
    }

} 

  
