using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.PortalEngine;
using CMS.DataEngine;
using CMS.IDataConnectionLibrary;

public partial class SiteManager_Development_DocumentTypes_DocumentType_General : SiteManagerPage
{
    private int documentTypeId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // gets classID from querystring
        if (Request.QueryString["documenttypeid"] != null)
        {
            documentTypeId = Convert.ToInt32(Request.QueryString["documenttypeid"]);
        }

        // initializes labels
        lblFullCodeName.Text = ResHelper.GetString("DocumentType_Edit_General.FullCodeName");
        lblCodeName.Text = ResHelper.GetString("DocumentType_Edit_General.CodeName");
        lblNamespaceName.Text = ResHelper.GetString("DocumentType_Edit_General.Namespace");
        lblDisplayName.Text = ResHelper.GetString("DocumentType_Edit_General.DisplayName");
        lblEditingPage.Text = ResHelper.GetString("DocumentType_Edit_General.EditingPage");
        lblNewPage.Text = ResHelper.GetString("DocumentType_Edit_General.NewPage");
        lblListPage.Text = ResHelper.GetString("DocumentType_Edit_General.ListPage");
        lblTemplateSelection.Text = ResHelper.GetString("DocumentType_Edit_General.TemplateSelection");
        lblViewPage.Text = ResHelper.GetString("DocumentType_Edit_General.ViewPage");
        lblPreviewPage.Text = ResHelper.GetString("DocumentType_Edit_General.PreviewPage");
        lblClassUsePublishFromTo.Text = ResHelper.GetString("DocumentType_Edit_General.UsePublishFromTo");
        lblIsMenuItem.Text = ResHelper.GetString("DocumentType_Edit_General.IsMenuItem");
        lblDefaultTemplate.Text = ResHelper.GetString("DocumentType_Edit_General.DefaultTemplate");

        btnOK.Text = ResHelper.GetString("DocumentType_Edit_General.ButtonOK");
        // initializes validators
        RequiredFieldValidatorDisplayName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_General.DisplayNameRequired");
        RequiredFieldValidatorNamespaceName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_General.NamespaceNameRequired");
        RequiredFieldValidatorCodeName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_General.CodeNameRequired");
        RegularExpressionValidatorNameSpaceName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_General.NamespaceNameIdentificator");
        RegularExpressionValidatorCodeName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_General.CodeNameIdentificator");
        // sets regular expression for identificator validation
        RegularExpressionValidatorNameSpaceName.ValidationExpression = "^([A-Za-z]|_[A-Za-z])\\w*$";
        RegularExpressionValidatorCodeName.ValidationExpression = "^([A-Za-z]|_[A-Za-z])\\w*$";

        if (!Page.IsPostBack)
        {
            // loads data to the form
            LoadData();
        }
    }


    /// <summary>
    /// Loads data of edited document type from DB.
    /// </summary>
    protected void LoadData()
    {
        if (documentTypeId > 0)
        {
            // gets class name of specified classID
            string className = DataClassInfoProvider.GetClassName(documentTypeId);
            // gets DataClassInfo of specified class name
            DataClassInfo classInfo = DataClassInfoProvider.GetDataClass(className);

            string[] fullName = ClassNameParser(className);

            tbDisplayName.Text = classInfo.ClassDisplayName;
            tbNamespaceName.Text = fullName[0];
            tbCodeName.Text = fullName[1];
            tbEditingPage.Text = classInfo.ClassEditingPageURL;
            tbListPage.Text = classInfo.ClassListPageURL;
            txtViewPage.Text = classInfo.ClassViewPageUrl;
            txtPreviewPage.Text = classInfo.ClassPreviewPageUrl;
            txtNewPage.Text = classInfo.ClassNewPageURL;
            chkClassUsePublishFromTo.Checked = classInfo.ClassUsePublishFromTo;
            chkTemplateSelection.Checked = classInfo.ClassShowTemplateSelection;
            chkIsMenuItem.Checked = classInfo.ClassIsMenuItemType;
            this.templateDefault.PageTemplateID = classInfo.ClassDefaultPageTemplateID;
            chkTemplateSelection_CheckedChanged(null, null);
        }
    }


    /// <summary>
    /// Parses the class name into the string array
    /// </summary>
    /// <param name="className">Class name to parse</param>
    private static string[] ClassNameParser(string className)
    {
        string[] fullName = new string[2];
        // finds last dot in full class name
        int lastDot = className.LastIndexOf('.');

        if (lastDot > 0)
        {
            // full class name = namespace + '.' + class name
            fullName[0] = className.Substring(0, lastDot);
            fullName[1] = className.Substring(lastDot + 1, className.Length - lastDot - 1);
        }
        else
        {
            // full transformation name = query name
            fullName[0] = "";
            fullName[1] = className;
        }

        return fullName;
    }


    /// <summary>
    /// Handles the ButtonOK's onClick event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty or well filled
        string result = new Validator().NotEmpty(tbDisplayName.Text, ResHelper.GetString("DocumentType_Edit_General.DisplayNameRequired")).
            NotEmpty(tbNamespaceName.Text, ResHelper.GetString("DocumentType_Edit_General.NamespaceNameRequired")).
            NotEmpty(tbCodeName.Text, ResHelper.GetString("DocumentType_Edit_General.CodeNameRequired")).
            IsIdentificator(tbNamespaceName.Text, ResHelper.GetString("DocumentType_Edit_General.NamespaceNameIdentificator")).
            IsIdentificator(tbCodeName.Text, ResHelper.GetString("DocumentType_Edit_General.CodeNameIdentificator")).Result;

        if (result == "")
        {
            if (documentTypeId > 0)
            {
                string className = DataClassInfoProvider.GetClassName(documentTypeId);
                DataClassInfo classInfo = DataClassInfoProvider.GetDataClass(className);

                // sets properties of the classInfo
                classInfo.ClassDisplayName = tbDisplayName.Text;
                classInfo.ClassName = tbNamespaceName.Text.Trim() + "." + tbCodeName.Text.Trim();
                classInfo.ClassNewPageURL = txtNewPage.Text;
                classInfo.ClassEditingPageURL = tbEditingPage.Text;
                classInfo.ClassListPageURL = tbListPage.Text;
                classInfo.ClassViewPageUrl = txtViewPage.Text;
                classInfo.ClassPreviewPageUrl = txtPreviewPage.Text;
                classInfo.ClassUsePublishFromTo = chkClassUsePublishFromTo.Checked;
                classInfo.ClassShowTemplateSelection = chkTemplateSelection.Checked;
                classInfo.ClassIsMenuItemType = chkIsMenuItem.Checked;
                classInfo.ClassDefaultPageTemplateID = templateDefault.PageTemplateID;

                // updates dataclass in DB
                DataClassInfoProvider.SetDataClass(classInfo);

                if ((className.ToLower() != classInfo.ClassName.ToLower()) && (classInfo.ClassIsDocumentType))
                {
                    // Class name was changed -> update queries
                    SqlGenerator.GenerateQuery(classInfo.ClassName, "searchtree", SqlOperationTypeEnum.SearchTree, false);
                    SqlGenerator.GenerateQuery(classInfo.ClassName, "selectdocuments", SqlOperationTypeEnum.SelectDocuments, false);
                    SqlGenerator.GenerateQuery(classInfo.ClassName, "selectversions", SqlOperationTypeEnum.SelectVersions, false);
                }

                // Actualize doctype icon
                string sourceFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/" + className.Replace(".", "_") + ".gif"; ;
                string destFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/" + classInfo.ClassName.Replace(".", "_") + ".gif";

                // Rename icon file
                if (File.Exists(Server.MapPath(sourceFile)))
                {    
                    if (className.ToLower() != classInfo.ClassName.ToLower())
                    {
                        try
                        {
                            File.Move(Server.MapPath(sourceFile), Server.MapPath(destFile));
                        }
                        catch
                        {
                        }
                    }
                }
                // Create new icon file
                else
                {
                    if (!classInfo.ClassIsCoupledClass) 
                    {
                        sourceFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/defaultcontainer.gif";
                    }
                    else
                    {
                        sourceFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/default.gif";
                    }

                    try
                    {                            
                        File.Copy(Server.MapPath(sourceFile), Server.MapPath(destFile));
                    }
                    catch
                    {
                    }
                }              

                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
        }
        else
        {
            // hides asp validators in case the javascript is disabled
            RequiredFieldValidatorDisplayName.Visible = false;
            RequiredFieldValidatorNamespaceName.Visible = false;
            RequiredFieldValidatorCodeName.Visible = false;
            RegularExpressionValidatorNameSpaceName.Visible = false;
            RegularExpressionValidatorCodeName.Visible = false;

            lblError.Visible = true;
            lblError.Text = result;
        }
    }

    protected void chkTemplateSelection_CheckedChanged(object sender, EventArgs e)
    {
        this.templateDefault.Enabled = !this.chkTemplateSelection.Checked;
        if (!this.templateDefault.Enabled)
        {
            templateDefault.PageTemplateID = 0;
        }
    }
}
