using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.IDataConnectionLibrary;
using CMS.DataEngine;

public partial class SiteManager_Development_DocumentTypes_DocumentType_Edit_Query_Edit : SiteManagerPage
{
    private int queryId = 0;
    private string className = "";
    private Query myQuery = new Query();
    private string actualQueryName = ResHelper.GetString("DocumentType_Edit_Query_Edit.NewQueryName"); 

    protected void Page_Load(object sender, EventArgs e)
    {
        // gets queryID from querystring
        if (Request.QueryString["queryid"] != null)
        {
            queryId = Convert.ToInt32(Request.QueryString["queryid"]);
            string queryFullName = QueryProvider.GetQueryFullName(queryId);
            myQuery = QueryProvider.GetQuery(queryFullName);

            className = DataClassInfoProvider.GetClassName(myQuery.QueryClassId);
            actualQueryName = myQuery.QueryName;

            if (!Page.IsPostBack)
            {
                // fills form with query information
                tbQueryName.Text = actualQueryName;
                rblQueryType.SelectedValue = myQuery.QueryType.ToString();
                chbTransaction.Checked = myQuery.RequiresTransaction;
                chbAutoUpdates.Checked = myQuery.QueryIsLocked;
                tbQueryText.Text = myQuery.QueryText;

                tbQueryText.Focus();
                // shows that the query was created or updated successfully
                if (Request.QueryString["saved"] == "1")
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
        }
        // gets classID from querystring, used when creating new query
        if (Request.QueryString["documenttypeid"] != null)
        {
            className = DataClassInfoProvider.GetClassName(Convert.ToInt32(Request.QueryString["documenttypeid"]));
            tbQueryName.Focus();
        }

        // Ensure generate button for default queries
        if (SqlGenerator.IsSystemQuery(actualQueryName))
        {
            btnGenerate.Visible = true;
        }

        //initializes PageTitle
        string queries = ResHelper.GetString("DocumentType_Edit_Query_Edit.Queries");
        int classId = DataClassInfoProvider.GetDataClass(className).ClassID;

        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = queries;
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Development/DocumentTypes/DocumentType_Edit_Query_List.aspx?documenttypeid=" + classId.ToString();
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = actualQueryName;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;

        // initializes labels
        lblQueryName.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.QueryName");
        lblQueryType.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.QueryType");
        lblTransaction.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.TransactionRequired");
        lblAutoUpdates.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.AutoUpdates");
        lblQueryText.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.QueryText");
        btnOK.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.ButtonOK");
        btnGenerate.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.btnGenerate");
        // initializes validator
        RequiredFieldValidatorQueryName.ErrorMessage = ResHelper.GetString("DocumentType_Edit_Query_Edit.QueryNameRequired");
    }


    /// <summary>
    /// Generate default query
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnGenerate_Click(object sender, EventArgs e)
    {
        chbAutoUpdates.Checked = false;
        rblQueryType.SelectedIndex = 0;
        tbQueryText.Text = SqlGenerator.GetSqlQuery(className, SqlGenerator.GetQueryType(actualQueryName));
    }

        
    /// <summary>
    /// Saves data of edited or new query into DB.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty or well filled
        string result = new Validator().NotEmpty(tbQueryName.Text, ResHelper.GetString("DocumentType_Edit_Query_Edit.QueryNameRequired")).Result;

        if (result == "")
        {
            bool isSaved = false;
            Query newQuery = null;
            // gets full query name in the form - "ClassName.QueryName"
            string fullQueryName;
            if (className != "")
            {
                fullQueryName = className + "." + tbQueryName.Text;
            }
            else
            {
                fullQueryName = tbQueryName.Text;
            }
            // finds whether new or edited query is unique in the document type
            try
            {
                // throws exception if query of the given name doesn't exist
                newQuery = QueryProvider.GetQuery(fullQueryName);
                
                if (newQuery.QueryId == queryId)
                {
                    SaveQuery();
                    isSaved = true;
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("DocumentType_Edit_Query_Edit.UniqueQueryName");
                }
            }
            catch
            {
                SaveQuery();
                isSaved = true;
            }
            if (isSaved)
            {
                Response.Redirect("DocumentType_Edit_Query_Edit.aspx?queryid=" + myQuery.QueryId.ToString() + "&saved=1");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }

    /// <summary>
    /// Saves new or edited query of the given name and returns to the query list.
    /// </summary>
    private void SaveQuery()
    {
        // sets query object's properties
        myQuery.QueryName = tbQueryName.Text;
        myQuery.QueryClassId = DataClassInfoProvider.GetDataClass(className).ClassID;
        if (rblQueryType.SelectedValue == "SQLQuery")
        {
            myQuery.QueryType = QueryTypeEnum.SQLQuery;
        }
        else
        {
            myQuery.QueryType = QueryTypeEnum.StoredProcedure;
        }
        myQuery.RequiresTransaction = chbTransaction.Checked;
        myQuery.QueryIsLocked = chbAutoUpdates.Checked;
        myQuery.QueryText = tbQueryText.Text;

        QueryProvider.SetQuery(myQuery);
    }
}
