using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;

public partial class SiteManager_Development_Workflows_Workflow_Step_New : SiteManagerPage
{
    protected int workflowid = 0;
    
    protected void Page_Load(object sender, EventArgs e)
    {
        // initializes labels
        lblWorkflowCodeName.Text = ResHelper.GetString("Development-Workflow_General.CodeName");
        lblWorkflowDisplayName.Text = ResHelper.GetString("Development-Workflow_General.DisplayName");
        ButtonOK.Text = ResHelper.GetString("General.OK");

        string workflowSteps = ResHelper.GetString("Development-Workflow_Step_New.Steps");
        string currentWorkflow = ResHelper.GetString("Development-Workflow_Steps.NewStep");
        //string title = ResHelper.GetString("Development-Workflow_Step_New.Title");
        // initializes validators
        RequiredFieldValidatorCodeName.ErrorMessage = ResHelper.GetString("Development-Workflow_New.RequiresCodeName");
        RequiredFieldValidatorDisplayName.ErrorMessage = ResHelper.GetString("Development-Workflow_New.RequiresDisplayName");

        if ((Request.QueryString["workflowid"] != null) && (Request.QueryString["workflowid"].ToString() != ""))
        {
            workflowid = Convert.ToInt32(Request.QueryString["workflowid"]);
        }
        string workflowStepsUrl = "~/CMSSiteManager/Development/Workflows/Workflow_Steps.aspx?workflowid=" + workflowid.ToString();

        // initializes page title
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = workflowSteps;
        pageTitleTabs[0, 1] = workflowStepsUrl;
        pageTitleTabs[0, 2] = "workflowsContent";
        pageTitleTabs[1, 0] = currentWorkflow;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle1.Breadcrumbs = pageTitleTabs;
        //PageTitle1.TitleText = title;
        //PageTitle1.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/Workflows/workflow.gif";
    }


    /// <summary>
    /// Saves new workflow step's data and redirects to Workflow_Edit.aspx.
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Event arguments</param>
    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        // finds whether required fields are not empty
        string result = new Validator().NotEmpty(txtWorkflowDisplayName.Text, ResHelper.GetString("Development-Workflow_Step_New.RequiresDisplayName")).NotEmpty(txtWorkflowCodeName.Text, ResHelper.GetString("Development-Workflow_Step_New.RequiresCodeName")).Result;

        if (result == "")
        {
            WorkflowStepInfo wsi = WorkflowInfoProvider.GetWorkflowStepInfo(txtWorkflowCodeName.Text, workflowid);
            if (wsi == null)
            {
                int workflowStepId = SaveNewWorkflowStep();

                if (workflowStepId > 0)
                {
                    Response.Redirect("Workflow_Step_Edit.aspx?workflowStepid=" + workflowStepId);
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Development-Workflow_Step_New.WorkflowStepExists");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }


    /// <summary>
    /// Saves new wokflow step's data into DB
    /// </summary>
    /// <returns>Returns ID of created wokflow step</returns>
    protected int SaveNewWorkflowStep()
    {
        
        WorkflowStepInfo wsi = new WorkflowStepInfo();
        wsi.StepDisplayName = txtWorkflowDisplayName.Text;
        wsi.StepName = txtWorkflowCodeName.Text;

        // Get published step info for the proper position
        WorkflowStepInfo psi = WorkflowInfoProvider.GetPublishedStep(workflowid);
        if (psi != null)
        {
            wsi.StepOrder = psi.StepOrder;
            // Move the published step down
            psi.StepOrder += 1;
            WorkflowInfoProvider.SetWorkflowStepInfo(psi);

            // Move the archived step down
            WorkflowStepInfo asi = WorkflowInfoProvider.GetArchivedStep(workflowid);
            if (asi != null)
            {
                asi.StepOrder += 1;
                WorkflowInfoProvider.SetWorkflowStepInfo(asi);
            }
        }

        wsi.StepWorkflowID = workflowid;
        WorkflowInfoProvider.SetWorkflowStepInfo(wsi);
        return wsi.StepID;
    }

}

