using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.SettingsProvider;
using CMS.TreeEngine;

public partial class CMSSiteManager_Sites_CultureChange : CMSModalPage
{
    private int siteId = 0;
    private string currentCulture = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        // Get data from parameters
        siteId = ValidationHelper.GetInteger(Request.QueryString["siteid"], 0);
        currentCulture = ValidationHelper.GetString(Request.QueryString["culture"], "");
        
        // Strings and images
        btnOk.Text = ResHelper.GetString("General.Ok");
        btnCancel.Text = ResHelper.GetString("General.Cancel");

        lblNewCulture.Text = ResHelper.GetString("SiteDefaultCultureChange.NewCulture");
        chkDocuments.Text = ResHelper.GetString("SiteDefaultCultureChange.Documents");

        PageTitle.TitleText = ResHelper.GetString("SiteDefaultCultureChange.Title");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/changeculture.gif";

        SiteInfo si = SiteInfoProvider.GetSiteInfo(siteId);
        if (si != null)
        {
            currentCulture = CultureHelper.GetDefaultCulture(si.SiteName);

            // Fill dropdown list with cultures
            if (!IsPostBack)
            {
                drpCultures.DataTextField = "CultureName";
                drpCultures.DataValueField = "CultureCode";
                DataSet ds = CultureInfoProvider.GetSiteCultures(si.SiteName);
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    ds.Tables[0].DefaultView.Sort = "CultureName ASC";
                    drpCultures.DataSource = ds.Tables[0].DefaultView;
                    drpCultures.DataBind();

                    // sets English as default culture
                    int index = 0;
                    if (currentCulture != null && currentCulture != "")
                    {
                        CultureInfo ci = CultureInfoProvider.GetCultureInfo(currentCulture);
                        if (ci != null)
                        {
                            ListItem li = drpCultures.Items.FindByValue(ci.CultureCode);
                            if (li != null)
                            {
                                index = drpCultures.Items.IndexOf(li);
                            }
                        }
                    }

                    if (index < 0)
                    {
                        index = drpCultures.Items.IndexOf(new ListItem("English - United States", "en-US"));
                    }

                    if (index >= 0)
                    {
                        drpCultures.SelectedIndex = index;
                    }
                    else
                    {
                        drpCultures.SelectedIndex = 0;
                    }
                }
            }
        }
    }


    /// <summary>
    /// OkClick Handler
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOk_Click(object sender, EventArgs e)
    {
        string culture = ValidationHelper.GetString(drpCultures.SelectedValue, ""); ;
        bool valid = true;

        if ((culture != "") && ((currentCulture.ToLower() != culture.ToLower()) || (chkDocuments.Checked)))
        {
            // Set new culture
            SiteInfo si = SiteInfoProvider.GetSiteInfo(siteId);
            if (si != null)
            {
                try
                {
                    // Set default culture and change current culture label
                    SettingsKeyProvider.SetValue(si.SiteName + ".CMSDefaultCultureCode", culture.Trim());
                }
                catch
                {
                    valid = false;
                }

                //Change culutre of documents
                if ((valid) && (chkDocuments.Checked))
                {
                    TreeProvider tree = new TreeProvider();
                    tree.ChangeCulture(si.SiteName, currentCulture, culture);


                    DataSet ds = CultureInfoProvider.GetSiteCultures(si.SiteName);

                    // Add current culture to site culture and remove old culture if doesn't exists
                    // any document on this culture and is the only one culture
                    CultureInfoProvider.AddCultureToSite(culture, si.SiteName);

                    if ((!DataHelper.DataSourceIsEmpty(ds)) && (ds.Tables[0].Rows.Count == 1) && (!CultureInfoProvider.IsAnyDocument(si.SiteName, currentCulture)))
                    {
                        CultureInfoProvider.RemoveCultureFromSite(currentCulture, si.SiteName);
                    }
                }

                if (valid)
                {
                    ltlScript.Text = ScriptHelper.GetScript("wopener.ChangeCulture(); window.close();");
                }
            }
        }
        else
        {
            ltlScript.Text = ScriptHelper.GetScript("window.close();");
        }
    }
}
