using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Threading;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.ImportExport;
using CMS.CMSHelper;
using CMS.FileManager;
using CMS.SettingsProvider;
using CMS.DirectoryUtilities;


public partial class SiteManager_Sites_Export_ExportSite : SiteManagerPage, ICallbackEventHandler
{
    public int siteId = 0;
    public string siteName = "";

    public ExportManager Manager
    {
        set
        {
            Session["ExportManager"] = value;
        }

        get
        {
            if (Session["ExportManager"] == null)
            {
                Session["ExportManager"] = new ExportManager();
            }
            return (ExportManager)Session["ExportManager"];
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        // If there is no write permission, inform the user
        string rootPath = HttpContext.Current.Server.MapPath("~");
        string exportPath = HttpContext.Current.Server.MapPath(ExportProvider.EXPORT_RELATIVE_PATH);
        if ((Directory.Exists(exportPath)) && (!DirectoryHelper.CheckPermissions(exportPath, false, true, true, true)))
        //|| ((Directory.Exists(rootPath)) && (!DirectoryHelper.CheckPermissions(rootPath, false, true, true, true))))
        {
            pnlForm.Visible = false;
            lblError.Text = string.Format(ResHelper.GetString("ExportSite.ErrorPermissions"), ExportProvider.EXPORT_RELATIVE_PATH);
            this.lnkPermissions.Visible = true;
            this.lnkPermissions.Target = "_blank";
            this.lnkPermissions.Text = ResHelper.GetFileString("Install.ErrorPermissions");
            this.lnkPermissions.NavigateUrl = ResolveUrl("~/CMSMessages/ConfigurePermissions.aspx");
        }

        if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"] != ""))
        {
            siteId = Convert.ToInt32(Request.QueryString["siteid"]);
        }
        else
        {
            siteId = CMSContext.CurrentSite.SiteID;
        }

        SiteInfo siteInfo = SiteInfoProvider.GetSiteInfo(siteId);
        siteName = siteInfo.SiteName;
        lblFileCaption.Text = ResHelper.GetString("ExportSite.FileCaption");
        btnOK.Text = ResHelper.GetString("ExportSite.btnOK");
        btnCancel.Text = ResHelper.GetString("General.Cancel");
        btnTemporaryFiles.Text = ResHelper.GetString("ExportSite.btnTemporaryFiles");
        btnFinall.Text = ResHelper.GetString("ExportSite.btnOK");
        lblSiteCaption.Text = ResHelper.GetString("ExportSite.SiteCaption");
        lblSiteName.Text = siteInfo.DisplayName;
        rfvRequiredFile.ErrorMessage = ResHelper.GetString("ExportSite.ErrorFileRequired");

        string sites = ResHelper.GetString("ExportSite.Sites");
        string title = ResHelper.GetString("ExportSite.Title");

        //initializes PageTitle
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = sites;
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Sites/site_list.aspx";
        pageTitleTabs[1, 0] = ResHelper.GetString("ExportSite.ExportSite");
        pageTitleTabs[1, 1] = "";
        ptExport.Breadcrumbs = pageTitleTabs;
        ptExport.TitleText = title;
        ptExport.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/export.gif";

        // Register the script to perform get flags for showing buttons retrieval callback
        Page.ClientScript.RegisterClientScriptBlock(GetType(), "GetExportState", ScriptHelper.GetScript("function GetExportState(cancel){ return " + this.Page.ClientScript.GetCallbackEventReference(this, "cancel", "SetExportStateMssg", null) + " } \n"));

        this.btnCancel.Attributes.Add("onclick", "document.getElementById('hdnFinish').value='" + ResHelper.GetString("ExportSite.ExportCanceled") + "';document.getElementById('btnCancel').disabled = true;document.getElementById('btnFinall').disabled = false;return CancelExport();");

        if (!IsPostBack && !IsCallback)
        {
            try
            {
                ExportProvider.DeleteTemporaryFiles();
            }
            catch (Exception ex)
            {
                pnlForm.Visible = false;
                lblError.Visible = true;
                btnTemporaryFiles.Visible = true;
                lblError.Text = ex.Message;

            }
        }
    }


    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        if (txtFile.Text != "")
        {
            // if there is no zip extension in filename, adds it
            string filename = txtFile.Text.ToLower();
            int index = filename.IndexOf('.');
            if ((index == -1) || (filename.Substring(index + 1) != "zip"))
            {
                filename += ".zip";
                txtFile.Text = filename;
            }
            SiteExportSettings settings = new SiteExportSettings(siteId, filename);

            // File already exists, inform the user
            if (File.Exists(settings.TargetPath + filename))
            {
                lblError.Text = ResHelper.GetString("ExportSite.FileExists");
            }
            else
            {
                ltlScript.Text = ScriptHelper.GetScript("StartExportStateTimer();");

                settings.AddToExportTable(@"Data\siteinfo.xml", ExportSchema.SITEINFO_XML);
                settings.AddToExportTable(@"Data\settings.xml", ExportSchema.SETTINGS_XML);
                settings.AddToExportTable(@"Data\documenttypes.xml", ExportSchema.DOCUMENTTYPES_XML);
                settings.AddToExportTable(@"Data\systemtables.xml", ExportSchema.SYSTEMTABLES_XML);
                settings.AddToExportTable(@"Data\users.xml", ExportSchema.USERS_XML);
                settings.AddToExportTable(@"Data\modules.xml", ExportSchema.MODULES_XML);
                settings.AddToExportTable(@"Data\roles.xml", ExportSchema.ROLES_XML);
                settings.AddToExportTable(@"Data\globalpermissions.xml", ExportSchema.PERMISSIONS_XML);
                settings.AddToExportTable(@"Data\cultures.xml", ExportSchema.CULTURES_XML);
                settings.AddToExportTable(@"Data\pagetemplates.xml", ExportSchema.PAGETEMPLATES_XML);
                settings.AddToExportTable(@"Data\documents.xml", ExportSchema.DOCUMENTS_XML);
                settings.AddToExportTable(@"Data\emailtemplates.xml", ExportSchema.EMAILTEMPLATES_XML);
                settings.AddToExportTable(@"Data\workflows.xml", ExportSchema.WORKFLOWS_XML);
                if (settings.ExportDocumentHistory)
                {
                    settings.AddToExportTable(@"Data\workflowhistories.xml", ExportSchema.WORKFLOWHISTORIES_XML);
                    settings.AddToExportTable(@"Data\versionhistories.xml", ExportSchema.VERSIONHISTORIES_XML);
                    settings.AddToExportTable(@"Data\attachmenthistories.xml", ExportSchema.ATTACHMENTHISTORIES_XML);
                }
                settings.AddToExportTable(@"Data\webparts.xml", ExportSchema.WEBPARTS_XML);
                settings.AddToExportTable(@"Data\formusercontrols.xml", ExportSchema.FORMUSERCONTROLS_XML);
                settings.AddToExportTable(@"Data\cssstylesheets.xml", ExportSchema.CSSSTYLESHEETS_XML);
                settings.AddToExportTable(@"Data\translationresources.xml", ExportSchema.RESOURCES_XML);
                settings.AddToExportTable(@"Data\attachments.xml", ExportSchema.ATTACHMENTS_XML);
                settings.AddToExportTable(@"Data\inlinecontrols.xml", ExportSchema.INLINECONTROLS_XML);
                settings.AddToExportTable(@"Data\relationships.xml", ExportSchema.RELATIONSHIPS_XML);
                settings.AddToExportTable(@"Data\bizforms.xml", ExportSchema.BIZFORMS_XML);
                settings.AddToExportTable(@"Data\newsletters.xml", ExportSchema.NEWSLETTERS_XML);
                settings.AddToExportTable(@"Data\newslettersubscribers.xml", ExportSchema.NEWSLETTERSUBSCRIBERS_XML);
                settings.AddToExportTable(@"Data\licensekeys.xml", ExportSchema.LICENSEKEYS_XML);
                settings.AddToExportTable(@"Data\scheduledtasks.xml", ExportSchema.SCHEDULEDTASKS_XML);
                settings.AddToExportTable(@"Data\stagingservers.xml", ExportSchema.STAGING_SERVERS_XML);
                settings.AddToExportTable(@"Data\webfarmservers.xml", ExportSchema.WEBFARM_SERVERS_XML);

                // Forums export
                settings.AddToExportTable(@"Data\forums.xml", ExportSchema.FORUMS_XML);
                settings.AddToExportTable(@"Data\forumsubscriptions.xml", ExportSchema.FORUMSUBSCRIPTIONS_XML);

                settings.AddToExportTable(@"Data\polls.xml", ExportSchema.POLLS_XML);
                settings.AddToExportTable(@"Data\blogcomments.xml", ExportSchema.BLOG_COMMENTS_XML);
                settings.AddToExportTable(@"Data\reporting.xml", ExportSchema.REPORTING_XML);
                settings.AddToExportTable(@"Data\reportingsaveditems.xml", ExportSchema.REPORTING_SAVED_XML);
                settings.AddToExportTable(@"Data\countries.xml", ExportSchema.COUNTRIES_XML);
                
                // Ecommerce export
                settings.AddToExportTable(@"Data\COM\options.xml", ExportSchema.COM_OPTIONS_XML);
                settings.AddToExportTable(@"Data\COM\status.xml", ExportSchema.COM_STATUS_XML);
                settings.AddToExportTable(@"Data\COM\orderstatus.xml", ExportSchema.COM_ORDERSTATUS_XML);
                settings.AddToExportTable(@"Data\COM\exchangetables.xml", ExportSchema.COM_EXCHANGETABLE_XML);
                settings.AddToExportTable(@"Data\COM\currencies.xml", ExportSchema.COM_CURRENCIES_XML);
                settings.AddToExportTable(@"Data\COM\departments.xml", ExportSchema.COM_DEPARTMENTS_XML);
                settings.AddToExportTable(@"Data\COM\manufacturers.xml", ExportSchema.COM_MANUFACTURERS_XML);
                settings.AddToExportTable(@"Data\COM\customers.xml", ExportSchema.COM_CUSTOMERS_XML);
                settings.AddToExportTable(@"Data\COM\addresses.xml", ExportSchema.COM_ADDRESSES_XML);
                settings.AddToExportTable(@"Data\COM\suppliers.xml", ExportSchema.COM_SUPPLIERS_XML);
                settings.AddToExportTable(@"Data\COM\skus.xml", ExportSchema.COM_SKUS_XML);
                settings.AddToExportTable(@"Data\COM\orders.xml", ExportSchema.COM_ORDERS_XML);
                settings.AddToExportTable(@"Data\COM\taxclasses.xml", ExportSchema.COM_TAXCLASSES_XML);
                settings.AddToExportTable(@"Data\COM\discountcoupons.xml", ExportSchema.COM_DISCOUNTCOUPONS_XML);
                settings.AddToExportTable(@"Data\COM\volumediscounts.xml", ExportSchema.COM_VOLUMEDISCOUNTS_XML);
                settings.AddToExportTable(@"Data\COM\orderitems.xml", ExportSchema.COM_ORDERITEMS_XML);
                settings.AddToExportTable(@"Data\COM\discountlevels.xml", ExportSchema.COM_DISCOUNTLEVELS_XML);
                //settings.AddToExportTable(@"Data\COM\shoppingcarts.xml", ExportSchema.COM_SHOPPINGCARTS_XML);
                settings.AddToExportTable(@"Data\COM\userrelations.xml", ExportSchema.COM_USERRELATIONS_XML);

                settings.WebsitePath = HttpContext.Current.Server.MapPath("~/");

                Manager.Settings = settings;

                // Try delete old temporary files
                try
                {
                    hdnFinish.Value = string.Format(ResHelper.GetString("ExportSite.MessageOK"), MapPath(ExportProvider.EXPORT_RELATIVE_PATH) + filename);
                    // Start export in new thread
                    Thread thread = new Thread(new ThreadStart(Manager.RunAsync));
                    thread.Start();

                    pnlForm.Visible = false;
                    btnOK.Visible = false;
                    btnFinall.Visible = true;
                    btnCancel.Visible = true;
                    lblInfo.Text = ResHelper.GetString("SiteExport.PreparingExport");
                    //lblInfo.Text = ResHelper.GetString("ExportSite.MessageOK") + " " + MapPath(ExportProvider.EXPORT_RELATIVE_PATH) + filename + ".";
                }
                catch (Exception ex)
                {
                    pnlForm.Visible = true;
                    btnFinall.Visible = false;
                    lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
                }
                //finally
                //{
                //    try
                //    {
                //        //ExportProvider.DeleteTemporaryFiles(settings);
                //    }
                //    catch (TemporaryFilesDeletionException ex)
                //    {
                //        if (lblError.Text != "")
                //        {
                //            lblError.Text += "<br/>" + ex.Message;
                //        }
                //        else
                //        {
                //            lblError.Text = ex.Message;
                //        }
                //    }
                //}
            }
        }
    }

    protected void btnFinall_Click(object sender, EventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/site_list.aspx");
    }

    protected void btnTemporaryFiles_Click(object sender, EventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/Export/ExportSite.aspx?" + Request.QueryString);
    }

    /// <summary>
    /// Callback event handler
    /// </summary>
    /// <param name="argument">Callback argument</param>
    public void RaiseCallbackEvent(string argument)
    {
        if (Manager.Settings != null)
        {
            // Cancel export
            if(ValidationHelper.GetBoolean(argument,false))
            {
                Manager.Settings.Cancel();
            }

            string value = Manager.Settings.ExportState;

            if (value.StartsWith("F<#>"))
            {
                try
                {
                    ExportProvider.DeleteTemporaryFiles();
                }
                catch
                {
                    // Temporary files have not been deleted.
                }
            }
            hdnState.Value = value;
        }
    }


    /// <summary>
    /// Callback result retrieving handler
    /// </summary>
    public string GetCallbackResult()
    {
        return hdnState.Value;
    }

}
