using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Threading;

using CMS.GlobalHelper;
using CMS.ImportExport;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.SettingsProvider;


public partial class Import_ObjectsWizard : System.Web.UI.UserControl
{
    #region Properties
    /// <summary>
    /// Import settings stored in viewstate
    /// </summary>
    public SiteImportSettings ImportSettings
    {
        get
        {
            if (ViewState["settings"] == null)
            {
                throw new Exception("[Import_ObjectsWizard]: ImportSettings not initialized!");
            }
            return (SiteImportSettings)ViewState["settings"];
        }
        set
        {
            ViewState["settings"] = value;
        }
    }


    /// <summary>
    /// Real index
    /// </summary>
    private int WizardIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["globalIndex"], 1);
        }
        set
        {
            ViewState["globalIndex"] = value;
        }
    }


    /// <summary>
    /// Flag if this is only settings import
    /// </summary>
    public bool ImportOnlySettings
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["importOnlySettings"], false);
        }
        set
        {
            ViewState["importOnlySettings"] = value;
        }
    }


    /// <summary>
    /// Start index
    /// </summary>
    public int StartIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["startIndex"], -1);
        }
        set
        {
            ViewState["startIndex"] = value;
        }
    }


    /// <summary>
    /// Caption index
    /// </summary>
    public int CaptionIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["captionIndex"], -1);
        }
        set
        {
            ViewState["captionIndex"] = value;
            // First step caption
            lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.StepImportType.lblStepImportType"), CaptionIndex + "." + WizardIndex);
        }
    }


    /// <summary>
    /// True if asynchronous import
    /// </summary>
    public bool AsyncImport
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["AsyncImport"], true);
        }
        set
        {
            ViewState["AsyncImport"] = value;
        }
    }


    /// <summary>
    /// Result
    /// </summary>
    public ResultEnum Result
    {
        get
        {
            if (ViewState["result"] == null)
            {
                ViewState["result"] = ResultEnum.Success;
            }
            return (ResultEnum)ViewState["result"];
        }
        set
        {
            ViewState["result"] = value;
        }
    }


    /// <summary>
    /// Result warning messages
    /// </summary>
    public ArrayList WarningMessages
    {
        get
        {
            if (ViewState["resultWarningMessage"] == null)
            {
                ViewState["resultWarningMessage"] = new ArrayList();
            }
            return (ArrayList)ViewState["resultWarningMessage"];
        }
        set
        {
            ViewState["resultWarningMessage"] = value;
        }
    }


    /// <summary>
    /// Permission messages
    /// </summary>
    public ArrayList PermissionMessages
    {
        get
        {
            if (ViewState["permissionMessage"] == null)
            {
                ViewState["permissionMessage"] = new ArrayList();
            }
            return (ArrayList)ViewState["permissionMessage"];
        }
        set
        {
            ViewState["permissionMessage"] = value;
            if (value.Count != 0)
            {
                Result = ResultEnum.Warning;
            }
        }
    }


    /// <summary>
    /// Imported css styles
    /// </summary>
    private ArrayList ImportedStyles
    {
        get
        {
            if (ViewState["cssStyles"] == null)
            {
                ViewState["cssStyles"] = new ArrayList();
            }
            return (ArrayList)ViewState["cssStyles"];
        }
    }


    /// <summary>
    /// Flag if documents are imported
    /// </summary>
    private bool DocumentsImported
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["docImported"], false);
        }
        set
        {
            ViewState["docImported"] = value;
        }
    }


    /// <summary>
    /// Wizard in which is this user control included
    /// </summary>

    private Wizard mWizard = null;

    public Wizard Wizard
    {
        get
        {
            if (mWizard == null)
            {
                throw new Exception("[Import_ObjectsWizard]: Wizard propety not initialised!");
            }
            return mWizard;
        }
        set
        {
            mWizard = (Wizard)value;
        }
    }


    /// <summary>
    /// True if last step finishes the wizard
    /// </summary>
    public bool LastStepFinish
    {
        get
        {
            return ValidationHelper.GetBoolean(ViewState["lastStepFinish"], false);
        }
        set
        {
            ViewState["lastStepFinish"] = value;
        }
    }


    /// <summary>
    /// Import manager
    /// </summary>
    public ImportManager Manager
    {
        get
        {
            if (Session["ImportManager"] == null)
            {
                Session["ImportManager"] = new ImportManager();
            }
            return (ImportManager)Session["ImportManager"];
        }
        set
        {
            Session["ImportManager"] = value;
        }
    }


    /// <summary>
    /// Import type
    /// </summary>
    public ImportTypeEnum ImportType
    {
        get
        {
            if (ucImportType != null)
            {
                return ucImportType.ImportType;
            }
            return ImportTypeEnum.OverwriteAll;
        }
    }

    #endregion

    #region Events

    ///<summary>Occurs after the wizard is finished.</summary>
    public delegate void OnFinishHandler();


    ///<summary>OnFinish event.</summary>
    public event OnFinishHandler OnFinish;


    ///<summary>Occurs after the wizard is asynchronously started.</summary>
    public delegate void OnAfterAsyncStartHandler();


    ///<summary>OnAfterAsyncStart event.</summary>
    public event OnAfterAsyncStartHandler OnAfterAsyncStart;


    ///<summary>Occurs before the wizard is asynchronously started.</summary>
    public delegate void OnBeforeAsyncStartHandler();


    ///<summary>OnBeforeAsyncStart event.</summary>
    public event OnBeforeAsyncStartHandler OnBeforeAsyncStart;
    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsCallback)
        {
            if (!IsPostBack)
            {
                wzdImport.StartNextButtonText = ResHelper.GetString("ImportSite.NextStep");
                wzdImport.StepNextButtonText = ResHelper.GetString("ImportSite.NextStep");

                lblStepDesc.Text = ResHelper.GetString("ImportSite.Step.wizardIntro");


                wzdImport.ActiveStepIndex = 0;

                // First step caption
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.StepImportType.lblStepImportType"), CaptionIndex + "." + WizardIndex);
            }
            this.ltlScript.Text = ScriptHelper.GetScript("function NextObjectWizardStep(btnNext,elementDiv){btnNext.disabled=true;elementDiv.disabled=true;" + Page.ClientScript.GetPostBackEventReference(btnHidden, null) + "}");

            wzdImport.ActiveStep.EnableViewState = true;
        }
    }


    protected void btnHidden_onClick(object sender, EventArgs e)
    {
        ++WizardIndex;
        lblError.Visible = false;

        // handles wizards steps
        switch (wzdImport.ActiveStepIndex)
        {
            case 0:
                ImportSettings.ImportOnlySettings = ImportOnlySettings;
                
                // Proceed actions depending on import type
                switch (ucImportType.ImportType)
                {
                    case ImportTypeEnum.OverwriteAll:
                    case ImportTypeEnum.DoNotOverwrite:

                        if (AsyncImport)
                        {
                            // tries import site
                            try
                            {
                                // Do not resolve conflicts manually, act like web template
                                ImportSettings.OverwriteAll = true;

                                // If only new objects should be imported, do not allow overwriting existing objects
                                if (ucImportType.ImportType == ImportTypeEnum.DoNotOverwrite)
                                {
                                    ImportSettings.OverwriteAllowed = false;
                                }
                                
                                if (OnBeforeAsyncStart != null)
                                {
                                    OnBeforeAsyncStart();
                                }

                                // Import site asynchronous
                                Manager.Settings = ImportSettings;

                                // Create thread
                                Thread thread = new Thread(new ThreadStart(Manager.RunAsync));
                                thread.Start();

                                // Hide current wizard and show the old
                                HideWizard();


                                if (OnAfterAsyncStart != null)
                                {
                                    OnAfterAsyncStart();
                                }
                            }
                            catch (Exception ex)
                            {
                                HandleError(ex);
                            }
                        }
                        else
                        {
                            // tries import site
                            try
                            {
                                // Do not resolve conflicts manually, act like web template
                                ImportSettings.OverwriteAll = true;

                                // If only new objects should be imported, do not allow overwriting existing objects
                                if (ucImportType.ImportType == ImportTypeEnum.DoNotOverwrite)
                                {
                                    ImportSettings.OverwriteAllowed = false;
                                }

                                ImportProvider.ImportSite(ImportSettings);

                                // Clear hashtables
                                Functions.ClearHashtables();

                                // Hide current wizard and show the old
                                HideWizard();

                                if (!ImportOnlySettings && (ImportSettings.PermissionWarningMessages.Count == 0))
                                {
                                    // Run site
                                    SiteInfoProvider.RunSite(ImportSettings.NewSiteName);
                                }

                                if (OnFinish != null)
                                {
                                    OnFinish();
                                }

                                DeleteTempFiles();
                            }
                            catch (RunningSiteException ex)
                            {
                                HandleWarning(ex);

                                DeleteTempFiles();
                                if (OnFinish != null)
                                {
                                    PermissionMessages = ImportSettings.PermissionWarningMessages;
                                    OnFinish();
                                }
                            }
                            catch (Exception ex)
                            {
                                HandleError(ex);
                            }
                        }
                        break;
                    case ImportTypeEnum.OnlySelected:
                        if (ImportSettings.ImportOnlySettings)
                        {
                            wzdImport.ActiveStepIndex += 3;
                        }
                        else
                        {
                            wzdImport.ActiveStepIndex++;
                        }
                        LoadData(wzdImport.ActiveStepIndex);
                        break;
                }
                break;
            // Set system tables
            case 1:
                // Fill selected objects for the import provider
                ImportSettings.SelectedSysTables = ucSysTables.GetSelectedObjects();

                // Try import system tables
                try
                {
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.SetSystemTables(ImportSettings);
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex += 3;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set countries
            case 2:
                // Fill selected objects for the import provider
                ImportSettings.SelectedCountries = ucCountries.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCountries(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set css styles and create site skeleton
            case 3:
                // Fill selected objects for the import provider
                ImportSettings.SelectedCssStyles = ucCssStyles.GetSelectedObjects();

                // Try import css styles, create site skeleton
                try
                {
                    ImportProvider.SetCssStyleSheets(ImportSettings, ImportedStyles);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.CreateSiteSkeleton(ImportSettings);
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex += 2;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set roles
            case 4:
                // Fill selected objects for the import provider
                ImportSettings.SelectedRoles = ucRoles.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetRoles(ImportSettings);
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set users
            case 5:
                // Fill selected objects for the import provider
                ImportSettings.SelectedUsers = ucUsers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetUsersAndRoleRelations(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.SetCultures(ImportSettings);
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set page templates
            case 6:
                // Fill selected objects for the import provider
                ImportSettings.SelectedPageTemplates = ucPageTemplates.GetSelectedObjects();
                ImportSettings.SelectedLayouts = ucLayouts.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetPageTemplates(ImportSettings);
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set document types
            case 7:
                // Fill selected objects for the import provider
                ImportSettings.SelectedDocumentTypes = ucDocTypes.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetDocumentTypes(ImportSettings, null);
                    if (ImportOnlySettings)
                    {
                        wzdImport.ActiveStepIndex += 5;
                    }
                    else
                    {
                        wzdImport.ActiveStepIndex++;
                    }
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set workflow
            case 8:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWorkflows = ucWorkflows.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWorkflows(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        ImportProvider.CreateSiteRoot(ImportSettings);
                        ImportProvider.AddCssStyleSheetsToSite(ImportSettings, ImportedStyles);
                        ImportProvider.SetDomainAliases(ImportSettings);
                    }
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set email templates
            case 9:
                // Fill selected objects for the import provider
                ImportSettings.SelectedLocalEmailTemplates = ucLocalEmailTemplates.GetSelectedObjects();
                ImportSettings.SelectedGlobalEmailTemplates = ucGlobalEmailTemplates.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetEmailTemplates(ImportSettings);
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set site settings, resources, permissions
            case 10:
                // Fill selected objects for the import provider
                ImportSettings.SelectedSiteSettings = ucSettings.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetSettingsAndCategories(ImportSettings);
                    ImportProvider.SetResources(ImportSettings);
                    ImportProvider.SetPermissions(ImportSettings);

                    wzdImport.ActiveStepIndex++;

                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // If the documents should be imported, import it
            case 11:
                if (ucDocuments.ImportDocuments)
                {
                    try
                    {
                        ImportProvider.SetDocuments(ImportSettings);
                        // Set blog comments
                        ImportProvider.SetBlogComments(ImportSettings);
                        DocumentsImported = true;
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                    catch (Exception ex)
                    {
                        HandleError(ex);
                    }
                }
                else
                {
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                break;
            // Set webparts
            case 12:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWebParts = ucWebParts.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWebParts(ImportSettings);
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set webpart containers
            case 13:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWebPartContainers = ucWebPartContainers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWebPartContainers(ImportSettings);
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set form user controls
            case 14:
                // Fill selected objects for the import provider
                ImportSettings.SelectedFormUserControls = ucFormUserCtrls.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetFormUserControls(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        if (DocumentsImported)
                        {
                            ImportProvider.SetAttachments(ImportSettings);
                            ImportProvider.SetScheduledTasks(ImportSettings);
                        }

                        ImportProvider.SetTranslationResourcesAndUICultures(ImportSettings);
                        ImportProvider.SetForums(ImportSettings);
                        ImportProvider.SetStagingServers(ImportSettings);
                    }
                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set inline controls
            case 15:
                // Fill selected objects for the import provider
                ImportSettings.SelectedInlineControls = ucInlineCtrls.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetInlineControls(ImportSettings);
                    if (!ImportOnlySettings)
                    {
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                    else
                    {
                        // Copy files for objects import
                        ImportProvider.CopyGlobalFolder(ImportSettings);
                        ImportProvider.CopyGlobalAppCodeFolder(ImportSettings);


                        // Hide current wizard and show the old
                        HideWizard();

                        if (OnFinish != null)
                        {
                            if (ImportSettings.PermissionWarningMessages.Count != 0)
                            {
                                Result = ResultEnum.Warning;
                                PermissionMessages = ImportSettings.PermissionWarningMessages;
                            }
                            OnFinish();
                        }

                        DeleteTempFiles();
                    }
                }
                // Delete site and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set relationship names
            case 16:
                // Fill selected objects for the import provider
                ImportSettings.SelectedRelationshipNames = ucRelationships.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetRelationshipNames(ImportSettings);
                    ImportProvider.SetBizForms(ImportSettings);
                    ImportProvider.SetNewsletters(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set web farm servers
            case 17:
                // Fill selected objects for the import provider
                ImportSettings.SelectedWebFarmServers = ucWebFarmServers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetWebFarmServers(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set polls
            case 18:
                // Fill selected objects for the import provider
                ImportSettings.SelectedPolls = ucPolls.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetPolls(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set reporting
            case 19:
                // Fill selected objects for the import provider
                ImportSettings.SelectedReports = ucReports.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetReporting(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce maunfacturers
            case 20:
                // Fill selected objects for the import provider
                ImportSettings.SelectedManufacturers = ucCOMManufacturers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMManufacturers(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce suppliers
            case 21:
                // Fill selected objects for the import provider
                ImportSettings.SelectedSuppliers = ucCOMSuppliers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMSuppliers(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce tax classes
            case 22:
                // Fill selected objects for the import provider
                ImportSettings.SelectedTaxClasses = ucCOMTaxClasses.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMTaxClasses(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce discount coupons
            case 23:
                // Fill selected objects for the import provider
                ImportSettings.SelectedDiscountCoupons = ucCOMDiscountCoupons.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMDiscountCoupons(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce statuses
            case 24:
                // Fill selected objects for the import provider
                ImportSettings.SelectedInternalStatuses = ucCOMInternalStatuses.GetSelectedObjects();
                ImportSettings.SelectedPublicStatuses = ucCOMPublicStatuses.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMStatuses(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce departments
            case 25:
                // Fill selected objects for the import provider
                ImportSettings.SelectedDepartments = ucCOMDepartments.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMDepartments(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce exchange tables
            case 26:
                // Fill selected objects for the import provider
                ImportSettings.SelectedExTables = ucCOMExTables.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMExchnageTables(ImportSettings);
                    ImportProvider.SetCOMOptions(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce currencies
            case 27:
                // Fill selected objects for the import provider
                ImportSettings.SelectedCurrencies = ucCOMCurrencies.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMCurrencies(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce discount levels
            case 28:
                // Fill selected objects for the import provider
                ImportSettings.SelectedDiscountLevels = ucCOMDiscountLevels.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMDiscountLevels(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce customers
            case 29:
                // Fill selected objects for the import provider
                ImportSettings.SelectedCustomers = ucCOMCustomers.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMCustomers(ImportSettings);
                    ImportProvider.SetCOMAddresses(ImportSettings);

                    wzdImport.ActiveStepIndex++;
                    LoadData(wzdImport.ActiveStepIndex);
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce order statuses
            case 30:
                // Fill selected objects for the import provider
                ImportSettings.SelectedOrderStatuses = ucCOMOrderStatuses.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMOrderStatuses(ImportSettings);
                    ImportProvider.SetCOMOrders(ImportSettings);

                    // 
                    if (DocumentsImported)
                    {
                        wzdImport.ActiveStepIndex++;
                        LoadData(wzdImport.ActiveStepIndex);
                    }
                    else
                    {
                        // Hide current wizard and show the old
                        HideWizard();

                        if (ImportSettings.PermissionWarningMessages.Count == 0)
                        {
                            // Run site
                            SiteInfoProvider.RunSite(ImportSettings.NewSiteName);
                        }
                        DeleteTempFiles();

                        if (OnFinish != null)
                        {
                            PermissionMessages = ImportSettings.PermissionWarningMessages;
                            OnFinish();
                        }
                    }
                }
                catch (RunningSiteException ex)
                {
                    HandleWarning(ex);

                    DeleteTempFiles();

                    if (OnFinish != null)
                    {
                        PermissionMessages = ImportSettings.PermissionWarningMessages;
                        OnFinish();
                    }
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            // Set ecommerce SKUs
            case 31:
                // Fill selected objects for the import provider
                ImportSettings.SelectedSKUs = ucCOMSKUs.GetSelectedObjects();

                // Try import objects
                try
                {
                    ImportProvider.SetCOMSKUs(ImportSettings);
                    ImportProvider.SetCOMOrderItems(ImportSettings);
                    ImportProvider.SetCOMVolumeDiscounts(ImportSettings);

                    // Copy files for site import
                    ImportProvider.CopySiteFolder(ImportSettings);
                    ImportProvider.CopyGlobalFolder(ImportSettings);
                    ImportProvider.CopyTemplatesFolder(ImportSettings);
                    ImportProvider.CopySiteAppDataFolder(ImportSettings);
                    ImportProvider.CopySiteAppCodeFolder(ImportSettings);
                    ImportProvider.CopyGlobalAppCodeFolder(ImportSettings);

                    //ImportProvider.SetCOMShoppingCarts(ImportSettings);

                    // Hide current wizard and show the old
                    HideWizard();

                    if (ImportSettings.PermissionWarningMessages.Count == 0)
                    {
                        // Run site
                        SiteInfoProvider.RunSite(ImportSettings.NewSiteName);
                    }
                    DeleteTempFiles();

                    if (OnFinish != null)
                    {
                        PermissionMessages = ImportSettings.PermissionWarningMessages;
                        OnFinish();
                    }
                }
                catch (RunningSiteException ex)
                {
                    HandleWarning(ex);

                    DeleteTempFiles();

                    if (OnFinish != null)
                    {
                        PermissionMessages = ImportSettings.PermissionWarningMessages;
                        OnFinish();
                    }
                }
                // Delete site, temporary files and return to the begining
                catch (Exception ex)
                {
                    HandleError(ex);
                }
                break;
            default:
                break;
        }
    }


    private void LoadData(int stepIndex)
    {
        lblStepDesc.Visible = false;
        lblStepDesc.Text = ResHelper.GetString("ImportSite.Step.lblAsteriskExplanation");

        switch (stepIndex)
        {
            // Load data for system tables selection step
            case 1:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepCssStyles.lblStepSysTables"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = false;

                ucSysTables.LabelCaption = ResHelper.GetString("SiteImport.wzdStepSysTables.lblSysTables");
                ucSysTables.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepSysTables.noSysTables");
                ucSysTables.FirstBoundField = "ClassDisplayName";
                ucSysTables.SecondBoundField = "ClassName";
                ucSysTables.CheckBoxClass = "systab";
                ucSysTables.ResolveConflicts = false;
                ucSysTables.DataSet = ImportProvider.GetSysTablesDataSet(ImportSettings);
                ucSysTables.Bind();
                break;
            // Load data for countries
            case 2:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCountries.lblStepCountries"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind countries
                ucCountries.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCountries.lblCountries");
                ucCountries.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCountries.noCountries");
                ucCountries.FirstBoundField = "CountryDisplayName";
                ucCountries.SecondBoundField = "CountryName";
                ucCountries.CheckBoxClass = "country";
                ucCountries.DataSet = ImportProvider.GetCountriesDataSet(ImportSettings);
                ucCountries.Bind();
                break;
            // Load data for stylesheets selection step
            case 3:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepCssStyles.lblStepCssStyles"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                ucCssStyles.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCssStyles.lblCssStyles");
                ucCssStyles.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCssStyles.noCssStyles");
                ucCssStyles.FirstBoundField = "StylesheetDisplayName";
                ucCssStyles.SecondBoundField = "StylesheetName";
                ucCssStyles.CheckBoxClass = "css";
                ucCssStyles.DataSet = ImportProvider.GetCssStyleSheetsDataSet(ImportSettings);
                ucCssStyles.Bind();
                break;
            // Load data for roles
            case 4:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepRoles.lblStepRoles"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind roles
                ucRoles.LabelCaption = ResHelper.GetString("SiteImport.wzdStepRoles.lblRoles");
                ucRoles.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepRoles.noRoles");
                ucRoles.FirstBoundField = "RoleDisplayName";
                ucRoles.SecondBoundField = "RoleName";
                ucRoles.CheckBoxClass = "rol";
                ucRoles.DataSet = ImportProvider.GetRolesDataSet(ImportSettings);
                ucRoles.Bind();
                break;
            // Load data for users
            case 5:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepUsers.lblStepUsers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind users
                ucUsers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepUsers.lblUsers");
                ucUsers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepUsers.noUsers");
                ucUsers.SecondColumnHeader = ResHelper.GetString("SiteImport.wzdStepUsers.SecondColumnHeader");
                ucUsers.ThirdColumnHeader = ResHelper.GetString("SiteImport.wzdStepUsers.ThirdColumnHeader");
                ucUsers.FirstBoundField = "FullName";
                ucUsers.SecondBoundField = "UserName";
                ucUsers.CheckBoxClass = "usr";
                ucUsers.DataSet = ImportProvider.GetUsersDataSet(ImportSettings);
                ucUsers.Bind();
                break;
            // Load data for page templates
            case 6:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblStepPageTemplates"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                lblNote.Visible = true;
                lblNote.Text = ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblNote");

                // Data bind page templates
                ucPageTemplates.LabelCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblPageTemplates");
                ucPageTemplates.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.noPageTemplates");
                ucPageTemplates.FirstBoundField = "PageTemplateDisplayName";
                ucPageTemplates.SecondBoundField = "PageTemplateCodeName";
                ucPageTemplates.CheckBoxClass = "pt";
                ucPageTemplates.DataSet = ImportProvider.GetPageTemplatesDataSet(ImportSettings);
                ucPageTemplates.Bind();

                // Data bind layouts
                ucLayouts.LabelCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.lblLayouts");
                ucLayouts.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepPageTemplates.noLayouts");
                ucLayouts.FirstBoundField = "LayoutDisplayName";
                ucLayouts.SecondBoundField = "LayoutCodeName";
                ucLayouts.CheckBoxClass = "lay";
                ucLayouts.DataSet = ImportProvider.GetLayoutsDataSet(ImportSettings);
                ucLayouts.Bind();
                break;
            // Load data for document types
            case 7:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepDocumentTypes.lblStepDocumentTypes"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind document types
                ucDocTypes.LabelCaption = ResHelper.GetString("SiteImport.wzdStepDocumentTypes.lblDocumentTypes");
                ucDocTypes.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepDocumentTypes.noDocumentTypes");
                ucDocTypes.FirstBoundField = "ClassDisplayName";
                ucDocTypes.SecondBoundField = "ClassName";
                ucDocTypes.CheckBoxClass = "doct";
                ucDocTypes.DataSet = ImportProvider.GetDocumentTypesDataSet(ImportSettings);
                ucDocTypes.Bind();
                break;
            // Load data for workflows
            case 8:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWorkflows.lblStepWorkflows"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind workflows
                ucWorkflows.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWorkflows.lblWorkflows");
                ucWorkflows.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWorkflows.noWorkflows");
                ucWorkflows.FirstBoundField = "WorkflowDisplayName";
                ucWorkflows.SecondBoundField = "WorkflowName";
                ucWorkflows.CheckBoxClass = "workf";
                ucWorkflows.DataSet = ImportProvider.GetWorkflowsDataSet(ImportSettings);
                ucWorkflows.Bind();
                break;
            // Load data for email templates
            case 9:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepEmailTemplates.lblStepEmailTemplates"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind local email templates
                ucLocalEmailTemplates.LabelCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.lblLocalEmailTemplates");
                ucLocalEmailTemplates.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.noLocalEmailTemplates");
                ucLocalEmailTemplates.FirstBoundField = "EmailTemplateDisplayName";
                ucLocalEmailTemplates.SecondBoundField = "EmailTemplateName";
                ucLocalEmailTemplates.CheckBoxClass = "leml";
                ucLocalEmailTemplates.DataSet = ImportProvider.GetLocalEmailTemplatesDataSet(ImportSettings);
                ucLocalEmailTemplates.Bind();

                // Data bind global email templates
                ucGlobalEmailTemplates.LabelCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.lblGlobalEmailTemplates");
                ucGlobalEmailTemplates.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepEmailTemplates.noGlobalEmailTemplates");
                ucGlobalEmailTemplates.FirstBoundField = "EmailTemplateDisplayName";
                ucGlobalEmailTemplates.SecondBoundField = "EmailTemplateName";
                ucGlobalEmailTemplates.CheckBoxClass = "geml";
                ucGlobalEmailTemplates.DataSet = ImportProvider.GetGlobalEmailTemplatesDataSet(ImportSettings);
                ucGlobalEmailTemplates.Bind();
                break;
            // Load data for settings
            case 10:
                lblStepTitle.Text = string.Format(ResHelper.GetString("SiteImport.wzdStepSettings.lblStepSettings"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind settings
                ucSettings.LabelCaption = ResHelper.GetString("SiteImport.wzdStepSettings.lblSettings");
                ucSettings.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepSettings.noSettings");
                ucSettings.FirstBoundField = "KeyDisplayName";
                ucSettings.SecondBoundField = "KeyName";
                ucSettings.CheckBoxClass = "sett";
                ucSettings.DataSet = ImportProvider.GetSiteSettingsDataSet(ImportSettings);
                ucSettings.Bind();
                break;
            // Load data for documents
            case 11:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepDocuments.lblStepDocuments"), CaptionIndex + "." + WizardIndex);
                break;
            // Load data for webparts
            case 12:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWebparts.lblStepWebparts"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucWebParts.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.lblWebparts");
                ucWebParts.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.noWebparts");
                ucWebParts.FirstBoundField = "WebPartDisplayName";
                ucWebParts.SecondBoundField = "WebPartName";
                ucWebParts.CheckBoxClass = "webp";
                ucWebParts.DataSet = ImportProvider.GetWebpartsDataSet(ImportSettings);
                ucWebParts.Bind();
                break;
            // Load data for webpart containers
            case 13:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWebparts.lblStepWebpartContainers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web part containers
                ucWebPartContainers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.lblWebpartContainers");
                ucWebPartContainers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWebparts.noWebpartContainers");
                ucWebPartContainers.FirstBoundField = "ContainerDisplayName";
                ucWebPartContainers.SecondBoundField = "ContainerName";
                ucWebPartContainers.CheckBoxClass = "webc";
                ucWebPartContainers.DataSet = ImportProvider.GetWebpartContainersDataSet(ImportSettings);
                ucWebPartContainers.Bind();
                break;
            // Load data for form user controls
            case 14:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepFormUserControls.lblStepFormUserControls"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind user controls
                ucFormUserCtrls.LabelCaption = ResHelper.GetString("SiteImport.wzdStepFormUserControls.lblFormUserControls");
                ucFormUserCtrls.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepFormUserControls.noFormUserControls");
                ucFormUserCtrls.FirstBoundField = "UserControlDisplayName";
                ucFormUserCtrls.SecondBoundField = "UserControlCodeName";
                ucFormUserCtrls.CheckBoxClass = "fuc";
                ucFormUserCtrls.DataSet = ImportProvider.GetFormUserControlsDataSet(ImportSettings);
                ucFormUserCtrls.Bind();
                break;
            // Load data for inline controls
            case 15:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepInlineControls.lblStepInlineControls"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind inline controls
                ucInlineCtrls.LabelCaption = ResHelper.GetString("SiteImport.wzdStepInlineControls.lblInlineControls");
                ucInlineCtrls.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepInlineControls.noInlineControls");
                ucInlineCtrls.FirstBoundField = "ControlDisplayName";
                ucInlineCtrls.SecondBoundField = "ControlName";
                ucInlineCtrls.CheckBoxClass = "inc";
                ucInlineCtrls.DataSet = ImportProvider.GetInlineControlsDataSet(ImportSettings);
                ucInlineCtrls.Bind();
                break;
            // Load data for reltionship names
            case 16:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepRelationshipNames.lblStepRelationshipNames"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind reltionship names
                ucRelationships.LabelCaption = ResHelper.GetString("SiteImport.wzdStepRelationshipNames.lblRelationshipNames");
                ucRelationships.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepRelationshipNames.noRelationshipNames");
                ucRelationships.FirstBoundField = "RelationshipDisplayName";
                ucRelationships.SecondBoundField = "RelationshipName";
                ucRelationships.CheckBoxClass = "relation";
                ucRelationships.DataSet = ImportProvider.GetRelationshipNamesDataSet(ImportSettings);
                ucRelationships.Bind();
                break;
            // Load data for web farm servers
            case 17:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepWebFarmServers.lblStepWebFarmServers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web farm servers
                ucWebFarmServers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepWebFarmServers.lblWebFarmServers");
                ucWebFarmServers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepWebFarmServers.noWebFarmServers");
                ucWebFarmServers.FirstBoundField = "ServerDisplayName";
                ucWebFarmServers.SecondBoundField = "ServerName";
                ucWebFarmServers.CheckBoxClass = "webfarmsrv";
                ucWebFarmServers.DataSet = ImportProvider.GetWebFarmServersDataSet(ImportSettings);
                ucWebFarmServers.Bind();
                break;
            // Load data for polls
            case 18:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepPolls.lblStepPolls"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind polls
                ucPolls.LabelCaption = ResHelper.GetString("SiteImport.wzdStepPolls.lblPolls");
                ucPolls.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepPolls.noPolls");
                ucPolls.FirstBoundField = "PollDisplayName";
                ucPolls.SecondBoundField = "PollCodeName";
                ucPolls.CheckBoxClass = "polls";
                ucPolls.DataSet = ImportProvider.GetPollsDataSet(ImportSettings);
                ucPolls.Bind();
                break;
            // Load data for reporting
            case 19:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepreports.lblStepReports"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind reports
                ucReports.LabelCaption = ResHelper.GetString("SiteImport.wzdStepreports.lblReports");
                ucReports.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepReports.noReports");
                ucReports.FirstBoundField = "ReportDisplayName";
                ucReports.SecondBoundField = "ReportName";
                ucReports.CheckBoxClass = "reports";
                ucReports.DataSet = ImportProvider.GetReportsDataSet(ImportSettings);
                ucReports.Bind();
                break;
            //////////////////
            // Ecommerce
            //////////////////
            // Load data for manufacturers
            case 20:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMManufacturers.lblStepCOMManufacturers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind manufacturers
                ucCOMManufacturers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMManufacturers.lblCOMManufacturers");
                ucCOMManufacturers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMManufacturers.noCOMManufacturers");
                ucCOMManufacturers.SecondColumnHeader = ResHelper.GetString("SiteImport.wzdStepCOMManufacturers.FirstColumnHeader");
                ucCOMManufacturers.ThirdColumnHeader = ResHelper.GetString("SiteImport.wzdStepCOMManufacturers.SecondColumnHeader");
                ucCOMManufacturers.FirstBoundField = "ManufacturerDisplayName";
                //ucCOMManufacturers.SecondBoundField = "ManufactureHomepage";
                ucCOMManufacturers.CheckBoxClass = "manuf";
                ucCOMManufacturers.DataSet = ImportProvider.GetCOMManufacturersDataSet(ImportSettings);
                ucCOMManufacturers.Bind();
                break;
            // Load data for suppliers
            case 21:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMSuppliers.lblStepCOMSuppliers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind suppliers
                ucCOMSuppliers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMSuppliers.lblCOMSuppliers");
                ucCOMSuppliers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMSuppliers.noCOMSuppliers");
                ucCOMSuppliers.SecondColumnHeader = ResHelper.GetString("SiteImport.wzdStepCOMSuppliers.FirstColumnHeader");
                ucCOMSuppliers.ThirdColumnHeader = ResHelper.GetString("SiteImport.wzdStepCOMSuppliers.SecondColumnHeader");
                ucCOMSuppliers.FirstBoundField = "SupplierDisplayName";
                //ucCOMSuppliers.SecondBoundField = "SupplierEmail";
                ucCOMSuppliers.CheckBoxClass = "supp";
                ucCOMSuppliers.DataSet = ImportProvider.GetCOMSuppliersDataSet(ImportSettings);
                ucCOMSuppliers.Bind();
                break;
            // Load data for tax classes
            case 22:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMTaxClasses.lblStepCOMTaxClasses"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind tax classes
                ucCOMTaxClasses.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMTaxClasses.lblCOMTaxClasses");
                ucCOMTaxClasses.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMTaxClasses.noCOMTaxClasses");
                ucCOMTaxClasses.FirstBoundField = "TaxClassDisplayName";
                ucCOMTaxClasses.SecondBoundField = "TaxClassName";
                ucCOMTaxClasses.CheckBoxClass = "taxx";
                ucCOMTaxClasses.DataSet = ImportProvider.GetCOMTaxClassesDataSet(ImportSettings);
                ucCOMTaxClasses.Bind();
                break;
            // Load data for discount coupons
            case 23:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMDiscountCoupons.lblStepCOMDiscountCoupons"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind discount coupons
                ucCOMDiscountCoupons.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMDiscountCoupons.lblCOMDiscountCoupons");
                ucCOMDiscountCoupons.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMDiscountCoupons.noCOMDiscountCoupons");
                ucCOMDiscountCoupons.FirstBoundField = "DiscountCouponDisplayName";
                ucCOMDiscountCoupons.SecondBoundField = "DiscountCouponCode";
                ucCOMDiscountCoupons.CheckBoxClass = "discoupon";
                ucCOMDiscountCoupons.DataSet = ImportProvider.GetCOMDiscountCouponsDataSet(ImportSettings);
                ucCOMDiscountCoupons.Bind();
                break;
            // Load data for statuses
            case 24:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMStatuses.lblStepCOMStatuses"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind internal statuses
                ucCOMInternalStatuses.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMStatuses.lblCOMInternalStatuses");
                ucCOMInternalStatuses.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMStatuses.noCOMInternalStatuses");
                ucCOMInternalStatuses.FirstBoundField = "InternalStatusDisplayName";
                ucCOMInternalStatuses.SecondBoundField = "InternalStatusName";
                ucCOMInternalStatuses.CheckBoxClass = "istat";
                ucCOMInternalStatuses.DataSet = ImportProvider.GetCOMInternalStatusesDataSet(ImportSettings);
                ucCOMInternalStatuses.Bind();

                // Data bind public statuses
                ucCOMPublicStatuses.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMStatuses.lblCOMPublicStatuses");
                ucCOMPublicStatuses.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMStatuses.noCOMPublicStatuses");
                ucCOMPublicStatuses.FirstBoundField = "PublicStatusDisplayName";
                ucCOMPublicStatuses.SecondBoundField = "PublicStatusName";
                ucCOMPublicStatuses.CheckBoxClass = "pstat";
                ucCOMPublicStatuses.DataSet = ImportProvider.GetCOMPublicStatusesDataSet(ImportSettings);
                ucCOMPublicStatuses.Bind();
                break;
            // Load data for departments
            case 25:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMDepartments.lblStepCOMDepartments"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind departments
                ucCOMDepartments.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMDepartments.lblCOMDepartments");
                ucCOMDepartments.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMDepartments.noCOMDepartments");
                ucCOMDepartments.FirstBoundField = "DepartmentDisplayName";
                ucCOMDepartments.SecondBoundField = "DepartmentName";
                ucCOMDepartments.CheckBoxClass = "dept";
                ucCOMDepartments.DataSet = ImportProvider.GetCOMDepartmentsDataSet(ImportSettings);
                ucCOMDepartments.Bind();
                break;
            // Load data for exchange tables
            case 26:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMExTables.lblStepCOMExTables"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind exchange tables
                ucCOMExTables.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMExTables.lblCOMExTables");
                ucCOMExTables.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMExTables.noCOMExTables");
                ucCOMExTables.FirstBoundField = "ExchangeTableDisplayName";
                //ucCOMExTables.SecondBoundField = "ExchangeTableName";
                ucCOMExTables.CheckBoxClass = "exTbl";
                ucCOMExTables.DataSet = ImportProvider.GetCOMExTablesDataSet(ImportSettings);
                ucCOMExTables.Bind();
                break;
            // Load data for currencies
            case 27:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMCurrencies.lblStepCOMCurrencies"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind currencies
                ucCOMCurrencies.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMCurrencies.lblCOMCurrencies");
                ucCOMCurrencies.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMCurrencies.noCOMCurrencies");
                ucCOMCurrencies.FirstBoundField = "CurrencyDisplayName";
                ucCOMCurrencies.SecondBoundField = "CurrencyName";
                ucCOMCurrencies.CheckBoxClass = "curr";
                ucCOMCurrencies.DataSet = ImportProvider.GetCOMCurrenciesDataSet(ImportSettings);
                ucCOMCurrencies.Bind();
                break;
            // Load data for discount levels
            case 28:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMDiscountLevels.lblStepCOMDiscountLevels"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind discount levels
                ucCOMDiscountLevels.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMDiscountLevels.lblCOMDiscountLevels");
                ucCOMDiscountLevels.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMDiscountLevels.noCOMDiscountLevels");
                ucCOMDiscountLevels.FirstBoundField = "DiscountLevelDisplayName";
                ucCOMDiscountLevels.SecondBoundField = "DiscountLevelName";
                ucCOMDiscountLevels.CheckBoxClass = "disclevl";
                ucCOMDiscountLevels.DataSet = ImportProvider.GetCOMDiscountLevelsDataSet(ImportSettings);
                ucCOMDiscountLevels.Bind();
                break;
            // Load data for customers
            case 29:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMCustomers.lblStepCOMCustomers"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind customers
                ucCOMCustomers.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMCustomers.lblCOMCustomers");
                ucCOMCustomers.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMCustomers.noCOMCustomers");
                ucCOMCustomers.FirstBoundField = "CustomerFirstName";
                ucCOMCustomers.SecondBoundField = "CustomerLastName";
                ucCOMCustomers.CheckBoxClass = "custm";
                ucCOMCustomers.DataSet = ImportProvider.GetCOMCustomersDataSet(ImportSettings);
                ucCOMCustomers.Bind();
                break;
            // Load data for order statuses
            case 30:
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMOrderStatuses.lblStepCOMOrderStatuses"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind order statuses
                ucCOMOrderStatuses.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMOrderStatuses.lblCOMOrderStatuses");
                ucCOMOrderStatuses.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMOrderStatuses.noCOMOrderStatuses");
                ucCOMOrderStatuses.FirstBoundField = "StatusDisplayName";
                ucCOMOrderStatuses.SecondBoundField = "StatusName";
                ucCOMOrderStatuses.CheckBoxClass = "ostat";
                ucCOMOrderStatuses.DataSet = ImportProvider.GetCOMOrderStatusesDataSet(ImportSettings);
                ucCOMOrderStatuses.Bind();
                break;
            // Load data for SKUs
            case 31:
                if (LastStepFinish)
                {
                    wzdImport.StepNextButtonText = ResHelper.GetString("ImportSite.Finish");
                }
                lblStepTitle.Text = string.Format(ResHelper.GetString("ImportSite.wzdStepCOMSKUs.lblStepSKUs"), CaptionIndex + "." + WizardIndex);
                lblStepDesc.Visible = true;

                // Data bind web parts
                ucCOMSKUs.LabelCaption = ResHelper.GetString("SiteImport.wzdStepCOMSKUs.lblSKUs");
                ucCOMSKUs.LabelNoDataCaption = ResHelper.GetString("SiteImport.wzdStepCOMSKUs.noSKUs");
                ucCOMSKUs.FirstBoundField = "SKUName";
                ucCOMSKUs.SecondBoundField = "SKUNumber";
                ucCOMSKUs.CheckBoxClass = "sku";
                ucCOMSKUs.DataSet = ImportProvider.GetCOMSKUsDataSet(ImportSettings);
                ucCOMSKUs.Bind();
                break;
            default:
                break;
        }
    }


    private void HandleError(Exception ex)
    {
        --WizardIndex;
        lblError.Visible = true;
        lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
    }


    private void HandleWarning(Exception ex)
    {
        Result = ResultEnum.Warning;
        WarningMessages.Add(ex.Message);
    }


    private void SetUserCulture(string siteName)
    {
        // Set current user default culture of the site
        CMSContext.CurrentUser.PreferredCultureCode = SettingsKeyProvider.GetStringValue(siteName + ".CMSDefaultCultureCode");
    }


    /// <summary>
    /// Handle next button click in the wizard
    /// </summary>
    /// <param name="wizard">Wizard</param>
    /// <param name="e">Wizard event argument</param>
    /// <param name="settings">Import settings</param>
    public int HandleNextButtonClick(EventArgs e, SiteImportSettings settings, int wizardIndex, int activeStepIndex)
    {
        //if ((!e.Cancel) && (e.NextStepIndex == (StartIndex - 1)))
        if (activeStepIndex == StartIndex)
        {
            // Hide current wizard and display objectswizard
            ShowWizard();
            ImportSettings = settings;
            return ++wizardIndex;
        }
        return wizardIndex;
    }


    /// <summary>
    /// Handle next button click in the wizard
    /// </summary>
    /// <param name="wizard">Wizard</param>
    /// <param name="e">Wizard event argument</param>
    /// <param name="settings">Import settings</param>
    public int HandleNextButtonClick(WizardNavigationEventArgs e, SiteImportSettings settings, int wizardIndex)
    {
        if ((!e.Cancel) && (e.NextStepIndex == (StartIndex - 1)))
        {
            // Hide current wizard and display objectswizard
            ShowWizard();
            ImportSettings = settings;
            return ++wizardIndex;
        }
        return wizardIndex;
    }


    public void HideWizard()
    {
        this.Parent.Visible = false;
        Wizard.Parent.Visible = true;
    }

    public void ShowWizard()
    {
        this.Parent.Visible = true;
        Wizard.Parent.Visible = false;
    }

    private void DeleteTempFiles()
    {
        try
        {
            ImportProvider.DeleteTemporaryFiles(ImportSettings, false);
        }
        catch (TemporaryFilesDeletionException ex)
        {
            HandleWarning(ex);
        }
    }
}
