using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;

/// <summary>
/// Page to process the Content data requests
/// </summary>
public partial class CMSSiteManager_Sites_NewSite_DefineSiteStructure_request : SiteManagerPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // If action not specified, do nothing
        if (Request.QueryString["action"] == null)
        {
            return;
        }
        // Current Node ID
        int nodeId = 0;
        if (Request.QueryString["nodeid"] != null)
        {
            nodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        }
        // Target node ID (for copy, move operations)
        int targetId = 0;
        if (Request.QueryString["targetid"] != null)
        {
            targetId = ValidationHelper.GetInteger(Request.QueryString["targetid"], 0);
        }
        TreeProvider tree = new TreeProvider();
        // Process the request
        switch ((string)Request.QueryString["action"].ToLower())
        {
            case "moveup":
                // Move the document up (document order)
                try
                {
                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("DefineSiteStructure.ErrorMissingSource"));
                        return;
                    }
                    CMS.TreeEngine.TreeNode node = tree.MoveNodeUp(nodeId);
                    // Move the node
                    if ( node != null)
                    {
                        AddScript("     RefreshNode(" + node.NodeParentID + ");");
                    }
                    else
                    {
                        AddAlert(ResHelper.GetString("DefineSiteStructure.MoveFailed"));
                    }
                }
                catch (Exception ex)
                {
                    AddAlert(ResHelper.GetString("DefineSiteStructure.MoveFailed") + " : " + ex.Message);
                }
                break;
            case "movedown":
                // Move the document down (document order)
                try
                {
                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("DefineSiteStructure.ErrorMissingSource"));
                        return;
                    }
                    CMS.TreeEngine.TreeNode node = tree.MoveNodeDown(nodeId);
                    // Move the node
                    if ( node != null)
                    {
                        AddScript("     RefreshNode(" + node.NodeParentID + ");");
                    }
                    else
                    {
                        AddAlert(ResHelper.GetString("DefineSiteStructure.MoveFailed"));
                    }
                }
                catch (Exception ex)
                {
                    AddAlert(ResHelper.GetString("DefineSiteStructure.MoveFailed") + " : " + ex.Message);
                }
                break;
            case "delete":
                // Delete the document
                try
                {
                    if (nodeId == 0)
                    {
                        AddAlert(ResHelper.GetString("DefineSiteStructure.ErrorMissingSource"));
                        return;
                    }
                    // Get the node
                    CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(nodeId);
                    // Delete the node
                    if (node != null)
                    {
                        int parentId = node.NodeParentID;
                        node.Delete();
                        AddScript("     RefreshNode(" + parentId + ");");
                        if (parentId != 0)
                        {
                            AddScript("     SelectNode(" + parentId + ");");
                        }
                        else
                        {
                            AddScript("     SelectNode(" + node.NodeID + ");");
                        }
                    }
                }
                catch (Exception ex)
                {
                    AddAlert(ResHelper.GetString("DefineSiteStructure.DeleteFailed") + " : " + ex.Message);
                }
                break;
        }

    }


    /// <summary>
    /// Adds the alert message to the output request window
    /// </summary>
    /// <param name="message">Message to display</param>
    private void AddAlert(string message)
    {
        this.ltlScript.Text += ScriptHelper.GetAlertScript(message);
    }


    /// <summary>
    /// Adds the script to the output request window
    /// </summary>
    /// <param name="script">Script to add</param>
    private void AddScript(string script)
    {
        this.ltlScript.Text += ScriptHelper.GetScript(script);
    }
}
