using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Runtime.Serialization;
using System.IO;

using CMS.GlobalHelper;
using CMS.ImportExport;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.WorkflowEngine;
using CMS.ExtendedControls;

public partial class CMSSiteManager_Sites_NewSite_NewSiteWizard : System.Web.UI.UserControl
{
    /// <summary>
    /// Import settings
    /// </summary>
    public SiteImportSettings ImportSettings
    {
        get
        {
            if (ViewState["settings"] == null)
            {
                ViewState["settings"] = new SiteImportSettings();
            }
            return (SiteImportSettings)ViewState["settings"];
        }
    }


    /// <summary>
    /// Creation method
    /// </summary>
    public NewSiteCreationEnum CreationMethod
    {
        get
        {
            if (ViewState["creationMethod"] == null)
            {
                ViewState["creationMethod"] = NewSiteCreationEnum.UsingWizard;
            }
            return (NewSiteCreationEnum)ViewState["creationMethod"];
        }
        set
        {
            ViewState["creationMethod"] = value;
        }
    }


    /// <summary>
    /// Master Template Id
    /// </summary>
    public int MasterTemplateId
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["masterTemplateId"], 0);
        }
        set
        {
            ViewState["masterTemplateId"] = value;
        }
    }


    /// <summary>
    /// Culture
    /// </summary>
    public string Culture
    {
        get
        {
            return ValidationHelper.GetString(ViewState["culture"], "");
        }
        set
        {
            ViewState["culture"] = value;
        }
    }

    private bool DisplayWarnings
    {
        get
        {
            return ((Warnings.Count != 0) || (ucObjectsWizard.PermissionMessages.Count != 0));
        }
    }


    /// <summary>
    /// Web template Id
    /// </summary>
    public int WebTemplateId
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["webTemplateId"], 0);
        }
        set
        {
            ViewState["webTemplateId"] = value;
        }
    }


    /// <summary>
    /// Wizard index
    /// </summary>
    public int WizardIndex
    {
        get
        {
            return ValidationHelper.GetInteger(ViewState["wizardIndex"], 1);
        }
        set
        {
            ViewState["wizardIndex"] = value;
        }
    }

    /// <summary>
    /// Warnings
    /// </summary>
    private ArrayList Warnings
    {
        get
        {
            if (ViewState["warnings"] == null)
            {
                ViewState["warnings"] = new ArrayList();
            }

            return (ArrayList)ViewState["warnings"];
        }
        set
        {
            ViewState["warnings"] = value;
        }
    }


    /// <summary>
    /// Button on the step choose web template
    /// </summary>
    protected LocalizedButton StepChooseWebTemplateFinishButton
    {
        get
        {
            //return null;
            return (LocalizedButton)wzdStepChooseWebTemplate.FindControl("FinishNavigationTemplateContainerID").FindControl("StepNextButton");
        }
    }


    /// <summary>
    /// Page load.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        // Add refference to the wizard
        ucObjectsWizard.Wizard = wzdNewSite;
        ucObjectsWizard.OnFinish += new Import_ObjectsWizard.OnFinishHandler(OnFinish);
        ucObjectsWizard.AsyncImport = false;

        if (!Page.IsPostBack)
        {
            lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_SiteDetails.StepTitle"), WizardIndex);
            lblStepDesc.Text = ResHelper.GetString("NewSite_SiteDetails.StepDesc");

            // Set texts
            btnGoBack.Text = ResHelper.GetString("NewSiteWizard.GoBack");
        }

        NewSite_Finish.Domain = ImportSettings.NewSiteDomain;

    }


    /// <summary>
    /// On wizard finish button click.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void wzdNewSite_FinishButtonClick(object sender, WizardNavigationEventArgs e)
    {
        ++WizardIndex;
        switch (wzdNewSite.ActiveStepIndex)
        {
            // actions after step - define site structure
            case 3:
                //changes step index
                wzdNewSite.ActiveStepIndex = 5;
                // Change wizard header text.
                lblStepDesc.Text = ResHelper.GetString("NewSite_Finish.StepDesc");
                // Display button under the wizard.
                btnGoBack.Visible = true;

                // There have been problems during site creation
                if (DisplayWarnings)
                {
                    lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_Finish.StepTitleWarning"), WizardIndex);
                    NewSite_Finish.Placeholder.Visible = false;
                    lblStepDesc.Visible = false;
                    lblError.Visible = true;
                    lblError.Text = GetWarnings();
                }
                else
                {
                    lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_Finish.StepTitle"), WizardIndex);
                }

                break;
            // actions after step - choose web template
            case 4:
                WebTemplateId = ((NewSite_ChooseWebTemplate)wzdNewSite.ActiveStep.FindControl("NewSite_ChooseWebTemplate")).WebTemplateId;

                // First site
                if (ImportSettings.SiteIsFirst)
                {
                    // Import web template
                    ImportTemplateSite(e);
                }
                else
                {
                    // Set start index of the ObjectsWizard
                    ucObjectsWizard.StartIndex = 6;
                    ucObjectsWizard.CaptionIndex = 4;
                    ucObjectsWizard.LastStepFinish = true;

                    // Set source file path
                    string templatePath = WebTemplateInfoProvider.GetWebTemplateInfo(WebTemplateId).WebTemplateFileName;
                    ImportSettings.SourceFilePath = templatePath.TrimEnd('/') + "/";
                    ImportSettings.TemporaryFilesPath = ImportSettings.SourceFilePath;

                    // Change wizard header text.
                    lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_Finish.StepTitle"), WizardIndex);
                    lblStepDesc.Text = ResHelper.GetString("NewSite_Finish.StepDesc");
                    // Display button under the wizard.
                    btnGoBack.Visible = true;
                }
                break;
            default:

                break;
        }
        WizardIndex = ucObjectsWizard.HandleNextButtonClick(e, ImportSettings, WizardIndex);
    }


    /// <summary>
    /// On wizard next button click.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void wzdNewSite_NextButtonClick(object sender, WizardNavigationEventArgs e)
    {
        ++WizardIndex;
        switch (wzdNewSite.ActiveStepIndex)
        {
            // actions after step - site details
            case 0:
                lblError.Visible = false;
                string domain = ((NewSite_SiteDetails)wzdNewSite.ActiveStep.FindControl("NewSite_SiteDetails")).Domain;
                string codeName = ((NewSite_SiteDetails)wzdNewSite.ActiveStep.FindControl("NewSite_SiteDetails")).SiteCodeName;
                string displayName = ((NewSite_SiteDetails)wzdNewSite.ActiveStep.FindControl("NewSite_SiteDetails")).SiteDisplayName;
                string culture = ((NewSite_SiteDetails)wzdNewSite.ActiveStep.FindControl("NewSite_SiteDetails")).SiteCulture;

                // if all required textfields are filled and there is no site with specified site name, sets the values
                try
                {
                    SiteInfo si = SiteInfoProvider.GetSiteInfo(codeName);

                    if (si == null)
                    {
                        throw new Exception();
                    }

                    HandleError(e, ResHelper.GetString("NewSite_SiteDetails.ErrorSiteExists"));
                }
                catch
                {
                    if ((domain != "") && (codeName != "") && (displayName != ""))
                    {
                        if (!ValidationHelper.IsCodeName(codeName))
                        {
                            HandleError(e, ResHelper.GetString("NewSite_SiteDetails.ErrorValidCodeName"));
                        }
                        else
                        {
                            ImportSettings.NewSiteDomain = CorrectDomainName(domain);
                            ImportSettings.NewSiteName = codeName;
                            ImportSettings.NewSiteDisplayName = displayName;
                            Culture = culture;

                            NewSite_DefineSiteStructure.SiteName = codeName;

                            // Change wizard header text.
                            lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_ChooseSite.StepTitle"), WizardIndex);
                            lblStepDesc.Text = ResHelper.GetString("NewSite_ChooseSite.StepDesc");
                        }
                    }
                    else
                    {
                        HandleError(e, ResHelper.GetString("NewSite_SiteDetails.ErrorSiteDetails"));
                    }
                }

                break;

            // actions after step - choose site
            case 1:
                lblError.Visible = false;
                CreationMethod = ((NewSite_ChooseSite)wzdNewSite.ActiveStep.FindControl("NewSite_ChooseSite")).CreationMethod;

                // if is creating site using a wizard, changes next step
                if (CreationMethod == NewSiteCreationEnum.UsingWizard)
                {
                    // First site
                    if (ImportSettings.SiteIsFirst)
                    {
                        // using import
                        // Import blank site
                        ImportBlankSite(e);
                    }
                    else
                    {
                        // using Objects wizard
                        // Set start index of the ObjectsWizard
                        ucObjectsWizard.StartIndex = 3;
                        ucObjectsWizard.CaptionIndex = 3;
                        // Set source file path
                        ImportSettings.SourceFilePath = Path.Combine(ImportSettings.WebsitePath, ImportProvider.TEMPLATES_PATH + "\\" + ImportProvider.TEMPLATE_BLANK);
                        ImportSettings.TemporaryFilesPath = ImportSettings.SourceFilePath;
                        ImportProvider.CreateTemporaryFiles(ImportSettings);
                    }

                    // changes step index
                    wzdNewSite.ActiveStepIndex = 2;
                }
                // else if is creating site using a web template, changes next step
                else if (CreationMethod == NewSiteCreationEnum.WebSiteTemplate)
                {
                    if (!ImportSettings.SiteIsFirst)
                    {
                        // Change finish button caption
                        StepChooseWebTemplateFinishButton.Text = ResHelper.GetString("NewSiteWizard.Next");
                    }
                    // Change wizard header text.
                    lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_ChooseWebTemplate.StepTitle"), WizardIndex);
                    lblStepDesc.Text = ResHelper.GetString("NewSite_ChooseWebTemplate.StepDesc");


                    // Cahnge step index
                    wzdNewSite.ActiveStepIndex = 4;
                }

                break;

            // actions after step - choose master template
            case 2:
                lblError.Visible = false;
                MasterTemplateId = ((NewSite_ChooseMasterTemplate)wzdNewSite.ActiveStep.FindControl("NewSite_ChooseMasterTemplate")).MasterTemplateId;

                // if selected, sets master template for the root
                if (MasterTemplateId != 0)
                {
                    CMS.TreeEngine.TreeProvider tree = new CMS.TreeEngine.TreeProvider();
                    CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(ImportSettings.NewSiteName, "/", CMS.TreeEngine.TreeProvider.ALL_CULTURES);
                    if (node != null)
                    {
                        node.SetValue("DocumentPageTemplateID", MasterTemplateId);
                        DocumentHelper.UpdateDocument(node, tree);
                    }

                    // Change wizard header text.
                    lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_DefineSiteStructure.StepTitle"), WizardIndex);
                    lblStepDesc.Text = ResHelper.GetString("NewSite_DefineSiteStructure.StepDesc");
                }
                else
                {
                    HandleError(e, ResHelper.GetString("NewSite_SiteDetails.ErrorMasterTemplate"));
                }

                break;

            default:
                break;
        }
        WizardIndex = ucObjectsWizard.HandleNextButtonClick(e, ImportSettings, WizardIndex);
    }


    /// <summary>
    /// runs site
    /// </summary>
    private void RunSite()
    {
        try
        {
            // runs site
            SiteInfoProvider.RunSite(ImportSettings.NewSiteName);
        }
        catch (RunningSiteException ex)
        {
            Warnings.Add(ex.Message);
        }
    }


    /// <summary>
    /// Import blank site
    /// </summary>
    private void ImportBlankSite(WizardNavigationEventArgs e)
    {
        try
        {
            CreateSite();
            this.NewSite_ChooseMasterTemplate.BindData();

            // Change wizard header text.
            lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_ChooseMasterTemplate.StepTitle"), WizardIndex);
            lblStepDesc.Text = ResHelper.GetString("NewSite_ChooseMasterTemplate.StepDesc");

            if (!DisplayWarnings)
            {
                RunSite();
            }

            if (DisplayWarnings)
            {
                lblError.Visible = true;
                lblError.Text = GetWarnings();
            }
        }
        catch (Exception ex)
        {
            lblError.Visible = true;
            lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
            //lblError.ToolTip = ex.StackTrace;
            e.Cancel = true;
            --WizardIndex;
        }
    }


    /// <summary>
    /// Import template site
    /// </summary>
    private void ImportTemplateSite(WizardNavigationEventArgs e)
    {
        try
        {
            CreateSite();

            // Change wizard header text.
            lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_Finish.StepTitle"), WizardIndex);
            lblStepDesc.Text = ResHelper.GetString("NewSite_Finish.StepDesc");
            // Display button under the wizard.
            btnGoBack.Visible = true;

            if (!DisplayWarnings)
            {
                // Run site
                RunSite();
            }

            if (DisplayWarnings)
            {
                lblError.Visible = true;
                lblError.Text = GetWarnings();
            }
        }
        catch (Exception ex)
        {
            lblError.Visible = true;
            lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
            //lblError.ToolTip = ex.StackTrace;
            e.Cancel = true;
            --WizardIndex;
        }
    }

    /// <summary>
    /// On GoBackToSiteList button click.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnGoBack_Click(object sender, EventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/site_list.aspx");
    }

    private void SetUserCulture(string siteName)
    {
        // Set current user default culture of the site
        CMSContext.CurrentUser.PreferredCultureCode = SettingsKeyProvider.GetStringValue(siteName + ".CMSDefaultCultureCode");
    }


    /// <summary>
    /// Create new site
    /// </summary>
    private void CreateSite()
    {
        ImportSettings.IsWebTemplate = true;

        if ((WebTemplateId != 0) && (CreationMethod == NewSiteCreationEnum.WebSiteTemplate))
        {
            string templatePath = WebTemplateInfoProvider.GetWebTemplateInfo(WebTemplateId).WebTemplateFileName;
            ImportSettings.SourceFilePath = templatePath.TrimEnd('/') + "/";
            ImportSettings.TemporaryFilesPath = ImportSettings.SourceFilePath;
        }
        else
        {
            ImportSettings.SourceFilePath = Path.Combine(ImportSettings.WebsitePath, ImportProvider.TEMPLATES_PATH + "\\" + ImportProvider.TEMPLATE_BLANK);
            ImportSettings.TemporaryFilesPath = ImportSettings.SourceFilePath;
        }
        ImportProvider.ImportSite(ImportSettings);

        // Clear hashtables
        Functions.ClearHashtables();

        // Change documents culture to the default culture of the new web site
        TreeProvider tree = new TreeProvider();
        tree.ChangeSiteDefaultCulture(ImportSettings.NewSiteName, Culture);

        // Set user culture to the site culture
        SetUserCulture(ImportSettings.NewSiteName);

        // sets default culture for new site
        SettingsKeyProvider.SetValue(ImportSettings.NewSiteName + ".CMSDefaultCultureCode", Culture);
    }


    /// <summary>
    /// Handle the finish of the process
    /// </summary>
    private void OnFinish()
    {
        Warnings = ucObjectsWizard.WarningMessages;
        // If using wizard, change wizard header text.
        if (CreationMethod == NewSiteCreationEnum.UsingWizard)
        {
            lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_ChooseMasterTemplate.StepTitle"), WizardIndex);
            lblStepDesc.Text = ResHelper.GetString("NewSite_ChooseMasterTemplate.StepDesc");
        }
        else
        {
            // Change wizard header text.
            lblStepDesc.Text = ResHelper.GetString("NewSite_Finish.StepDesc");

            if (DisplayWarnings || (!SettingsKeyProvider.UsingVirtualPathProvider))
            {
                lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_Finish.StepTitleWarning"), WizardIndex);
                lblError.Visible = true;
                lblStepDesc.Visible = false;
                if (DisplayWarnings)
                {
                    lblError.Text = GetWarnings();
                }
                else
                {
                    lblError.Text = ResHelper.GetString("NewSite_Finish.lblMediumTrust");
                }
                NewSite_Finish.Placeholder.Visible = false;
            }
            else
            {
                lblStepTitle.Text = string.Format(ResHelper.GetString("NewSite_Finish.StepTitle"), WizardIndex);
            }
        }

        // Change documents culture to the default culture of the new web site
        TreeProvider tree = new TreeProvider();
        tree.ChangeSiteDefaultCulture(ImportSettings.NewSiteName, Culture);

        // Set user culture to the site culture
        SetUserCulture(ImportSettings.NewSiteName);
    }


    /// <summary>
    /// Handle error during the process
    /// </summary>
    /// <param name="e">Event arguments</param>
    /// <param name="message">Error message</param>
    private void HandleError(WizardNavigationEventArgs e, string message)
    {
        --WizardIndex;
        lblError.Visible = true;
        lblError.Text = message;
        e.Cancel = true;
    }


    /// <summary>
    /// Get warnings gathered during the process
    /// </summary>
    /// <returns></returns>
    private string GetWarnings()
    {
        string result = "";
        for (int i = 0; i < Warnings.Count; ++i)
        {
            if (i == (Warnings.Count - 1))
            {
                result += Warnings[i];
            }
            else
            {
                result += Warnings[i] + "<br/>";
            }
        }

        if (result != "")
        {
            result += "<br/>";
        }

        for (int i = 0; i < ucObjectsWizard.PermissionMessages.Count; ++i)
        {
            if (i == (ucObjectsWizard.PermissionMessages.Count - 1))
            {
                result += ucObjectsWizard.PermissionMessages[i];
            }
            else
            {
                result += ucObjectsWizard.PermissionMessages[i] + "<br/>";
            }
        }

        return result;
    }


    /// <summary>
    /// Removes white characters from the beginning and end. Also removes protocol declarations and 'www.' string from begin.
    /// </summary>
    /// <param name="domainName">String to correct</param>
    /// <returns>Corrected string</returns>
    protected string CorrectDomainName(string domainName)
    {
        string result = domainName;
        result = result.Trim();
        string lowcaseResult = result.ToLower();

        while (lowcaseResult.IndexOf("https://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("https://"), 8);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("https://"), 8);
        }

        while (lowcaseResult.IndexOf("http://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("http://"), 7);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("http://"), 7);
        }

        while (lowcaseResult.StartsWith("www.", true, null))
        {
            result = result.Remove(lowcaseResult.IndexOf("www."), 4);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("www."), 4);
        }

        return result;
    }

}
