using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.SiteProvider;

public partial class NewSite_SiteDetails : System.Web.UI.UserControl
{
    /// <summary>
    /// access to domain textbox
    /// </summary>
    public string Domain
    {
        get { return CorrectDomainName(txtDomain.Text); }
        set { txtDomain.Text = value; }
    }


    /// <summary>
    /// access to site code name textbox
    /// </summary>
    public string SiteCodeName
    {
        get { return txtSiteCodeName.Text.Trim(); }
        set { txtSiteCodeName.Text = value; }
    }


    /// <summary>
    /// access to site display name textbox
    /// </summary>
    public string SiteDisplayName
    {
        get { return txtSiteDisplayName.Text.Trim(); }
        set { txtSiteDisplayName.Text = value; }
    }


    /// <summary>
    /// access to site default culture listbox
    /// </summary>
    public string SiteCulture
    {
        get { return drpDefalutCulture.SelectedValue; }
        set { drpDefalutCulture.SelectedValue = value; }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        // sets caption labels
        lblSiteDisplayName.Text = ResHelper.GetString("NewSite_SiteDetails.SiteDisplayName");
        lblSiteCodeName.Text = ResHelper.GetString("NewSite_SiteDetails.SiteCodeName");
        lblDomain.Text = ResHelper.GetString("NewSite_SiteDetails.DomainName");
        lblDefaultCulture.Text = ResHelper.GetString("NewSite_SiteDetails.DefaultCulture");

        // validators texts
        rqDomain.ErrorMessage = ResHelper.GetString("NewSite_SiteDetails.ErrorDomain");
        rqSiteDisplayName.ErrorMessage = ResHelper.GetString("NewSite_SiteDetails.ErrorSiteDisplayName");
        rqSiteCodeName.ErrorMessage = ResHelper.GetString("NewSite_SiteDetails.ErrorSiteCodeName");

        // if is postback, binds data for default culture
        if (!Page.IsPostBack)
        {
            string hostName = HttpContext.Current.Request.Url.Host.ToLower();
            string www = "www.";
            if(hostName.StartsWith(www))
            {
                hostName = hostName.Remove(0, www.Length);
            }

            // sets current domain name
            if (HttpContext.Current.Request.Url.IsDefaultPort)
            {
                txtDomain.Text = hostName;
            }
            else
            {
                txtDomain.Text = hostName + ":" + HttpContext.Current.Request.Url.Port;
            }

            drpDefalutCulture.DataTextField = "CultureName";
            drpDefalutCulture.DataValueField = "CultureCode";
            DataSet ds = CultureInfoProvider.GetAllCultures();
            if (ds != null)
            {
                ds.Tables[0].DefaultView.Sort = "CultureName ASC";
                drpDefalutCulture.DataSource = ds.Tables[0].DefaultView;
                drpDefalutCulture.DataBind();

                // sets English as default culture
                int index = drpDefalutCulture.Items.IndexOf(new ListItem("English - United States", "en-US"));
                if (index >= 0)
                {
                    drpDefalutCulture.SelectedIndex = index;
                }
                else
                {
                    drpDefalutCulture.SelectedIndex = 0;
                }
            }
        }
    }


    /// <summary>
    /// Removes white characters from the beginning and end. Also removes protocol declarations and 'www.' string from begin.
    /// </summary>
    /// <param name="domainName">String to correct</param>
    /// <returns>Corrected string</returns>
    protected string CorrectDomainName(string domainName)
    {
        string result = domainName;
        result = result.Trim();
        string lowcaseResult = result.ToLower();

        while (lowcaseResult.IndexOf("https://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("https://"), 8);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("https://"), 8);
        }

        while (lowcaseResult.IndexOf("http://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("http://"), 7);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("http://"), 7);
        }

        while (lowcaseResult.StartsWith("www.", true, null))
        {
            result = result.Remove(lowcaseResult.IndexOf("www."), 4);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("www."), 4);
        }

        return result;
    }

}
