using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Threading;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.WorkflowEngine;
using CMS.ImportExport;

/// <summary>
/// Deletion info
/// </summary>
[Serializable]
public static class DeletionInfo
{
    // Deletion log
    private static string mDeletionLog = "I" + SiteManager_Sites_Delete.SEPARATOR + "" + SiteManager_Sites_Delete.SEPARATOR;
    private static string mWebRootFullPath = null;

    /// <summary>
    /// Keep information about deletion progress
    /// </summary>
    public static string DeletionLog
    {
        get { return mDeletionLog; }
        set { mDeletionLog = value; }
    }


    /// <summary>
    /// Web root full path
    /// </summary>
    public static string WebRootFullPath
    {
        get
        {
            return mWebRootFullPath;
        }

        set
        {
            mWebRootFullPath = value;
        }
    }
}



public partial class SiteManager_Sites_Delete : SiteManagerPage, ICallbackEventHandler
{
    public const string SEPARATOR = "<#>";

    // Site ID
    private int siteId = 0;

    // Site name
    private string siteName = "";

    // Site display name
    private string siteDisplayName = "";

    SiteInfo si = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsCallback)
        {
            // Register the script to perform get flags for showing buttons retrieval callback
            Page.ClientScript.RegisterClientScriptBlock(GetType(), "GetState", ScriptHelper.GetScript("function GetState(cancel){ return " + this.Page.ClientScript.GetCallbackEventReference(this, "cancel", "SetStateMssg", null) + " } \n"));

            //initialize PageTitle
            string[,] pageTitleTabs = new string[2, 3];
            pageTitleTabs[0, 0] = ResHelper.GetString("Site_Edit.Sites");
            pageTitleTabs[0, 1] = "~/CMSSiteManager/Sites/site_list.aspx";
            pageTitleTabs[0, 2] = "cmsdesktop";
            pageTitleTabs[1, 0] = ResHelper.GetString("Site_Edit.DeleteSite");
            pageTitleTabs[1, 1] = "";
            ptDeleteSite.Breadcrumbs = pageTitleTabs;
            ptDeleteSite.TitleText = ResHelper.GetString("Site_Edit.DeleteSite");
            ptDeleteSite.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/deletesite.gif";

            // Get site ID
            siteId = ValidationHelper.GetInteger(Request.QueryString["siteId"], 0);

            si = SiteInfoProvider.GetSiteInfo(siteId);
            if (si != null)
            {
                siteName = si.SiteName;
                siteDisplayName = si.DisplayName;

                // Initialize web root path
                DeletionInfo.WebRootFullPath = HttpContext.Current.Server.MapPath("~/");

                DeletionInfo.DeletionLog = string.Format("I" + SEPARATOR + ResHelper.GetString("Site_Delete.DeletingSite") + SEPARATOR, siteName);

                this.lblConfirmation.Text = string.Format(ResHelper.GetString("Site_Edit.Confirmation"), si.DisplayName);
                this.btnYes.Text = ResHelper.GetString("General.Yes");
                this.btnNo.Text = ResHelper.GetString("General.No");
                this.btnOK.Text = ResHelper.GetString("General.OK");
                this.lblLog.Text = string.Format(ResHelper.GetString("Site_Delete.DeletingSite"), si.DisplayName);
            }

            this.btnYes.Click += new EventHandler(btnYes_Click);
            this.btnNo.Click += new EventHandler(btnNo_Click);
            this.btnOK.Click += new EventHandler(btnOK_Click);
        }
    }


    void btnOK_Click(object sender, EventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/site_list.aspx");
    }


    void btnNo_Click(object sender, EventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/site_list.aspx");
    }


    void btnYes_Click(object sender, EventArgs e)
    {
        pnlConfirmation.Visible = false;
        pnlDeleteSite.Visible = true;

        // Start the timer for the callbacks
        ltlScript.Text = ScriptHelper.GetScript("StartStateTimer();");

        ThreadStart ts = new ThreadStart(RunAsync);
        Thread thread = new Thread(ts);
        thread.Start();
    }


    /// <summary>
    /// Delete site asynchronously
    /// </summary>
    private void RunAsync()
    {
        try
        {
            //// deletes records in CMS_Tree and CMS_Document
            DocumentHelper.DeleteSiteTree(siteName, null, UpdateDeleteLog, DeletionInfo.WebRootFullPath);
            LogDeletionState(LogStatusEnum.Info, ResHelper.GetString("Site_Delete.DeletingRest"));
            //// deletes other dependences and the site
            SiteInfoProvider.DeleteSite(siteName);
            // Clear all hashtables
            Functions.ClearHashtables();
            LogDeletionState(LogStatusEnum.Finish, string.Format(ResHelper.GetString("Site_Delete.DeletionFinished"), siteDisplayName));
        }
        catch (Exception ex)
        {
            LogDeletionState(LogStatusEnum.Error, string.Format(ResHelper.GetString("Site_Delete.DeletionError"), ex.Message, ex.StackTrace));
        }
    }


    /// <summary>
    /// Update the delete log
    /// </summary>
    /// <param name="node">Node that is about to be deleted</param>
    private void UpdateDeleteLog(CMS.TreeEngine.TreeNode node)
    {
        LogDeletionState(LogStatusEnum.Info, string.Format(ResHelper.GetString("Site_Delete.DeletingDocument"), node.NodeAliasPath, node.DocumentCulture));
    }


    /// <summary>
    /// Callback event handler
    /// </summary>
    /// <param name="argument">Callback argument</param>
    public void RaiseCallbackEvent(string argument)
    {
        hdnLog.Value = DeletionInfo.DeletionLog;
    }


    /// <summary>
    /// Callback result retrieving handler
    /// </summary>
    public string GetCallbackResult()
    {
        return hdnLog.Value;
    }


    /// <summary>
    /// Log deletion state
    /// </summary>
    /// <param name="type">Type of the message</param>
    /// <param name="message">Message to be logged</param>
    public void LogDeletionState(LogStatusEnum type, string message)
    {
        string[] status = DeletionInfo.DeletionLog.Split(new string[] { SEPARATOR }, StringSplitOptions.None);

        // Wrong format of the internal status
        if (status.Length != 3)
        {
            DeletionInfo.DeletionLog = "F" + SEPARATOR + "" + SEPARATOR;
        }

        switch (type)
        {
            case LogStatusEnum.Info:
                status[0] = "I";
                status[1] = message + "<br />" + status[1];
                break;
            case LogStatusEnum.Error:
                status[0] = "E";
                status[2] = message + "<br />";
                break;
            case LogStatusEnum.Warning:
                break;
            case LogStatusEnum.Finish:
                status[0] = "F";
                status[1] = "<b>" + message + "</b><br />" + status[1];
                break;
        }

        DeletionInfo.DeletionLog = status[0] + SEPARATOR + status[1] + SEPARATOR + status[2];
    }

}