using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.LicenseProvider;
using CMS.TreeEngine;

public partial class SiteManager_Sites_Site_Edit_Cultures : SiteManagerPage
{
    protected int siteID = 0;
    protected string mSave = null;
    string imagesUrl = null;

    //data set of all cultures with JOINED column SiteID from CMS_SiteCulture table            
    protected DataSet ds = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        imagesUrl = ResolveUrl("~/App_Themes/" + this.Page.Theme + "/Images/General/");

        this.imgSave.ImageUrl = imagesUrl + "save.gif";
        mSave = ResHelper.GetString("EditMenu.IconSave");

        if ((Request.QueryString["siteID"] != null) && (Request.QueryString["siteID"] != ""))
        {
            siteID = Convert.ToInt32(Request.QueryString["siteID"]);

            if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
            {
                LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.Multilingual);
            }

            lblCultureTitle.Text = ResHelper.GetString("Site_Edit_Cultures.CultureTitle");
            //btnOK.Text = ResHelper.GetString("Site_Edit_Cultures.OK");
            gvCultureList.Columns[0].HeaderText = ResHelper.GetString("Site_Edit_Cultures.Select");
            gvCultureList.Columns[1].HeaderText = ResHelper.GetString("Site_Edit_Cultures.CultureName");

            //data set of all cultures with JOINED column SiteID from CMS_SiteCulture table 
            ds = CultureInfoProvider.GetSiteCultureList(siteID);
            gvCultureList.DataSource = ds.Tables[0];

            // make column with CultureID visible to set CultureID correctly
            gvCultureList.Columns[2].Visible = true;

            gvCultureList.DataBind();

            // hide column with siteID
            gvCultureList.Columns[2].Visible = false;

            gvCultureList.GridLines = GridLines.Horizontal;
        }
    }

    protected void gvSites_DataBound(object sender, EventArgs e)
    {
        for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
        {

            CheckBox hasThisCulture = new CheckBox();
            hasThisCulture.Checked = (ds.Tables[0].Rows[i]["SiteID"] == DBNull.Value) ? false : true;
            gvCultureList.Rows[i].Cells[0].Controls.Add(hasThisCulture);

        }

        // hide column with siteID
        gvCultureList.Columns[2].Visible = false;
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {

        // int cultureIDFromCMSCulture;
        string cultureCode = "";
        string cultureName = "";
        int siteIDFromCMSSiteCulture;

        SiteInfo si = SiteInfoProvider.GetSiteInfo(siteID);
        if (si != null)
        {
            string defaultCulture = CultureHelper.GetDefaultCulture(si.SiteName).ToLower();

            // make column with siteID visible to get siteID
            gvCultureList.Columns[2].Visible = true;

            for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
            {

                // get siteID from CMS_SiteCulture table
                if (ds.Tables[0].Rows[i]["SiteID"] == DBNull.Value)
                {
                    siteIDFromCMSSiteCulture = 0;
                }
                else
                {
                    siteIDFromCMSSiteCulture = Convert.ToInt32(ds.Tables[0].Rows[i]["SiteID"]);
                }

                // get culture code of the current culture
                cultureCode = Convert.ToString(ds.Tables[0].Rows[i]["CultureCode"]);
                cultureName = Convert.ToString(ds.Tables[0].Rows[i]["CultureName"]);

                CheckBox chkBox = (CheckBox)gvCultureList.Rows[i].Cells[0].Controls[0];
                if ((cultureCode.ToLower() == defaultCulture) && !chkBox.Checked)
                {
                    this.lblError.Text = String.Format(ResHelper.GetString("Site_Edit_Cultures.DefaultRequired"), cultureName);
                    this.lblError.Visible = true;
                    chkBox.Checked = true;
                }

                // site has not specified current culture
                if (siteIDFromCMSSiteCulture == 0)
                {
                    // if checkebox is checked, add culture to the site
                    if (chkBox.Checked)
                    {
                        CultureInfoProvider.AddCultureToSite(cultureCode, si.SiteName);
                    }
                }

                // site has specified current culture
                else
                {
                    // if checkebox is not checked, remove culture from the site
                    if (!chkBox.Checked)
                    {
                        TreeProvider treeProv = new TreeProvider();
                        DataSet nodes = treeProv.SelectNodes(si.SiteName, "/%", cultureCode, false, null, null, null, -1, false);
                        if (DataHelper.DataSourceIsEmpty(nodes))
                        {
                            CultureInfoProvider.RemoveCultureFromSite(cultureCode, si.SiteName);
                        }
                        else
                        {
                            lblError.Visible = true;
                            lblError.Text += String.Format(ResHelper.GetString("Site_Edit_Cultures.ErrorRemoveCultureFromSite"), cultureName) + '\n';
                            chkBox.Checked = true;
                        }
                    }
                }

            }

            // hide column with siteID
            gvCultureList.Columns[2].Visible = false;

            if (!lblError.Visible)
            {
                lblInfo.Visible = true;
                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            }
        }
    }

}
