using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;

public partial class CMSSiteManager_Sites_Site_Edit_DomainAlias_Edit : SiteManagerPage
{
    /// <summary>
    /// Site Id
    /// </summary>
    protected int siteId = 0;


    /// <summary>
    /// Site info
    /// </summary>
    protected SiteInfo si = null;


    /// <summary>
    /// Domain alias Id
    /// </summary>
    protected int domainAliasId = 0;

    /// <summary>
    /// DomainAlias DataSet
    /// </summary>
    protected DataSet mDs = new DataSet();

    protected void Page_Load(object sender, EventArgs e)
    {
        int Save = 0;

        string mDomainAlias = "";
        string mVisitorCulture = "";

        lblDomainName.Text = ResHelper.GetString("SiteDomain.DomainName");
        lblVisitorCulture.Text = ResHelper.GetString("SiteDomain.VisitorCulture");
        btnOk.Text = ResHelper.GetString("SiteDomain.btnOk");
        PageTitle.TitleText = ResHelper.GetString("SiteDomain.NewAlias");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/DomainAliases/newalias.gif";
        rfvDomainName.Text = ResHelper.GetString("Site_Edit.AliasRequired");

        // Text fro actual breadcrumb
        string mBread = ResHelper.GetString("SiteDomain.NewAlias");

        if ((Request.QueryString["Save"] != null) && (Request.QueryString["Save"].ToString() != "") && (!Page.IsPostBack))
        {
            Save = Convert.ToInt32(Request.QueryString["Save"]);
        }

        if (ValidationHelper.GetString(Request.QueryString["saved"], "") != "")
        {
            lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
            lblInfo.Visible = true;
        }

        if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"].ToString() != ""))
        {
            siteId = Convert.ToInt32(Request.QueryString["siteid"]);
        }



        if ((Request.QueryString["domainaliasid"] != null) && (Request.QueryString["domainaliasid"].ToString() != ""))
        {
            domainAliasId = Convert.ToInt32(Request.QueryString["domainaliasid"]);

            mDs = SiteInfoProvider.GetDomainAliases(siteId).Copy();

            if (mDs != null)
            {
                // Get actual domain alias data
                foreach (DataRow mDr in mDs.Tables[0].Rows)
                {
                    if (DataHelper.GetDataRowValue(mDr, "SiteDomainAliasID") != DBNull.Value)
                    {
                        if (Convert.ToInt32(DataHelper.GetDataRowValue(mDr, "SiteDomainAliasID")) == domainAliasId)
                        {
                            mDomainAlias = DataHelper.GetNotEmpty(DataHelper.GetDataRowValue(mDr, "SiteDomainAliasName"), "");
                            mVisitorCulture = DataHelper.GetNotEmpty(DataHelper.GetDataRowValue(mDr, "SiteDefaultVisitorCulture"), "");

                            mBread = mDomainAlias;
                            PageTitle.TitleText = ResHelper.GetString("SiteDomain.DomainAliasProperties");
                            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/DomainAliases/alias.gif";
                        }
                    }
                }
            }
        }

        if (siteId > 0)
        {
            si = SiteInfoProvider.GetSiteInfo(siteId);

            if ((Request.QueryString["Save"] == null) && (!IsPostBack))
            {
                txtDomainName.Text = mDomainAlias;
                FillDrpList(mVisitorCulture);
            }

            if (!IsPostBack || (Save >0))
            {
                if (Save > 1)
                {
                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    txtDomainName.Text = mDomainAlias;
                    FillDrpList(mVisitorCulture);
                }
            }
        }

        // Initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("SiteDomain.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Sites/Site_Edit_DomainAliases.aspx?siteid=" + siteId;
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = mBread;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
    }

    protected void FillDrpList(string mVisitorCulture)
    {
        DataSet mDataSet = new DataSet();
        mDataSet = CultureInfoProvider.GetSiteCultures(si.SiteName);

        // Fill culture dropdown list
        if (mDataSet != null)
        {
            drpVisitorCulture.DataSource = mDataSet;
            drpVisitorCulture.DataTextField = mDataSet.Tables[0].Columns["CultureName"].ColumnName.ToString();
            drpVisitorCulture.DataValueField = mDataSet.Tables[0].Columns["CultureCode"].ColumnName.ToString();

            drpVisitorCulture.DataBind();
        }

        // Add first item "(Automatic)" to dropdownlist
        drpVisitorCulture.Items.Insert(0, ResHelper.GetString("Site_Edit.Automatic"));
        drpVisitorCulture.Items[0].Value = "";

        //Set actual culture
        if (mVisitorCulture != null && mVisitorCulture != "")
        {
            for (int i = 0; i < drpVisitorCulture.Items.Count; i++)
            {
                if (drpVisitorCulture.Items[i].Value == mVisitorCulture)
                {
                    drpVisitorCulture.Items[i].Selected = true;
                }
            }
        }
    }

    /// <summary>
    /// Save or update domain alias
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnOk_Click(object sender, EventArgs e)
    {

        string result = new Validator().NotEmpty(txtDomainName.Text, ResHelper.GetString("Site_Edit.AliasRequired")).Result;

        if (result == "")
        {
            if (domainAliasId == 0) // Insert new
            {
                txtDomainName.Text = CorrectDomainName(txtDomainName.Text);
                if (!SiteInfoProvider.DomainAliasExists(txtDomainName.Text))
                {
                    SiteInfo si = SiteInfoProvider.GetSiteInfo(siteId);

                    if (si == null) return;

                    SiteInfoProvider.AddDomainAlias(si.SiteName, txtDomainName.Text, drpVisitorCulture.SelectedItem.Value);

                    DataSet mDs = new DataSet();
                    int mAliasId = 0;

                    mDs = SiteInfoProvider.GetDomainAliases(siteId);

                    // Domain alias Id
                    if (mDs != null)
                    {
                        foreach (DataRow mDr in mDs.Tables[0].Rows)
                        {
                            if ((DataHelper.GetDataRowValue(mDr, "SiteDomainAliasName") != null) && (DataHelper.GetDataRowValue(mDr, "SiteDomainAliasName") != DBNull.Value))
                            {
                                if (DataHelper.GetDataRowValue(mDr, "SiteDomainAliasName").ToString() == txtDomainName.Text)
                                {
                                    mAliasId = ValidationHelper.GetInteger(DataHelper.GetDataRowValue(mDr, "SiteDomainAliasID"), 0);
                                }
                            }
                        }

                        Response.Redirect("Site_Edit_DomainAlias_Edit.aspx?siteId=" + siteId.ToString() + "&domainaliasid=" + mAliasId.ToString() + "&saved=1");
                    }
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Site_Edit.AliasExists");
                }
            }
            else // Update
            {

                bool isUnique = true;
                // mDs

                if (SiteInfoProvider.DomainAliasExists(txtDomainName.Text))
                {
                    isUnique = false;
                    // Get actual domain alias data
                    foreach (DataRow mDr in mDs.Tables[0].Rows)
                    {
                        if (DataHelper.GetDataRowValue(mDr, "SiteDomainAliasID") != DBNull.Value)
                        {
                            if ((Convert.ToInt32(DataHelper.GetDataRowValue(mDr, "SiteDomainAliasID")) == domainAliasId) && (DataHelper.GetDataRowValue(mDr, "SiteDomainAliasName").ToString() == txtDomainName.Text ))
                            {
                                isUnique = true;
                            }
                        }
                    }

                }

                if (isUnique)
                {
                    SiteInfoProvider.SetDomainAlias(siteId, domainAliasId, txtDomainName.Text, drpVisitorCulture.SelectedItem.Value);
                    Response.Redirect("Site_Edit_DomainAlias_Edit.aspx?siteId=" + siteId.ToString() + "&domainaliasid=" + domainAliasId.ToString() + "&Save=2&saved=1");
                }
                else
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Site_Edit.AliasExists");
                }
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }

    /// <summary>
    /// Removes white characters from the beginning and end. Also removes protocol declarations and 'www.' string from begin.
    /// </summary>
    /// <param name="domainName">String to correct</param>
    /// <returns>Corrected string</returns>
    protected string CorrectDomainName(string domainName)
    {
        string result = domainName;
        result = result.Trim();
        string lowcaseResult = result.ToLower();

        while (lowcaseResult.IndexOf("https://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("https://"), 8);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("https://"), 8);
        }

        while (lowcaseResult.IndexOf("http://") > -1)
        {
            result = result.Remove(lowcaseResult.IndexOf("http://"), 7);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("http://"), 7);
        }

        while (lowcaseResult.StartsWith("www.", true, null))
        {
            result = result.Remove(lowcaseResult.IndexOf("www."), 4);
            lowcaseResult = lowcaseResult.Remove(lowcaseResult.IndexOf("www."), 4);
        }

        return result;
    }
}


