using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Globalization;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.WorkflowEngine;

public partial class SiteManager_site_list : SiteManagerPage
{
    

    protected void Page_Load(object sender, EventArgs e)
    {
        string imagesUrl = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/";
        string title = ResHelper.GetString("Site_List.Title");
        HyperlinkNewSite.Text = ResHelper.GetString("Site_List.NewSite");
        HyperlinkImportSite.Text = ResHelper.GetString("Site_List.ImportSite");
        HyperlinkExportSettings.Text = ResHelper.GetString("Site_List.ExportSettings");

        PageTitleSites.TitleText = title;
        PageTitleSites.TitleImage = imagesUrl + "sites.gif";
        ImageNewSite.ImageUrl = imagesUrl + "addsite.gif";
        ImageImportSite.ImageUrl = imagesUrl + "importsite.gif";
        ImageExportSettings.ImageUrl = imagesUrl + "exportobjects.gif";
        UniGridSites.GridView.GridLines = GridLines.Horizontal;
        UniGridSites.OnAction += new OnActionEventHandler(UniGridSites_OnAction);
        UniGridSites.OnExternalDataBound += new OnExternalDataBoundEventHandler(UniGridSites_OnExternalDataBound);
        lblErrorMsg.Visible = false;
    }


    System.Globalization.CultureInfo ci = new System.Globalization.CultureInfo("en-us");

    /// <summary>
    /// External data binding handler
    /// </summary>
    object UniGridSites_OnExternalDataBound(object sender, string sourceName, object parameter)
    {
        switch (sourceName.ToLower())
        {
            case "sitestatus":
                bool running = (ValidationHelper.GetString(parameter, "").ToLower() == "running");
                if (running)
                {
                    return "<span class=\"SiteStatusRunning\">" + ci.TextInfo.ToTitleCase(parameter.ToString().ToLower()) +"</span>";
                }
                else
                {
                    return "<span class=\"SiteStatusStopped\">" + ci.TextInfo.ToTitleCase(parameter.ToString().ToLower()) + "</span>";
                }
                //break;
        }
        return parameter;
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that throws event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void UniGridSites_OnAction(string actionName, object actionArgument)
    {
        SiteInfo si = SiteInfoProvider.GetSiteInfo(Convert.ToInt32(actionArgument));
        if (si != null)
        {
            string siteName = si.SiteName;

            if (actionName == "editSite")
            {
                Response.Redirect("Site_Edit_Frameset.aspx?siteid=" + actionArgument.ToString());
            }
            else if (actionName == "delete")
            {
                Response.Redirect("site_delete.aspx?siteid=" + actionArgument.ToString());

                //// deletes records in CMS_Tree and CMS_Document
                //DocumentHelper.DeleteSiteTree(siteName, null);
                //// deletes other dependences and the site
                //SiteInfoProvider.DeleteSite(siteName);
            }
            // Open CMSDesk of the site in new window.
            else if (actionName == "editContent")
            {
                // Make url for site in form 'http(s)://sitedomain/application/cmsdesk'.
                string sitedomain = si.DomainName;
                // application includes string '/cmsdesk'.
                string application = ResolveUrl("~/cmsdesk");
                string url = Request.Url.Scheme + "://" + sitedomain + application;

                ltlScript.Text = ScriptHelper.GetScript("window.open('" + url + "');");

            }
            // Open the web site in new window.
            else if (actionName == "openLiveSite")
            {
                // Make url for site in form 'http(s)://sitedomain/application'.
                string sitedomain = si.DomainName;
                string application = ResolveUrl("~/.");
                string url = Request.Url.Scheme + "://" + sitedomain + application;

                ltlScript.Text = ScriptHelper.GetScript("window.open('" + url + "');");
            }
            else if (actionName == "start")
            {
                try
                {
                    SiteInfoProvider.RunSite(siteName);
                }
                catch (Exception ex)
                {
                    lblErrorMsg.Visible = true;
                    lblErrorMsg.Text = ResHelper.GetString("Site_List.ErrorMsg") + ex.Message;
                }
            }
            else if (actionName == "stop")
            {
                SiteInfoProvider.StopSite(siteName);
            }
            else if (actionName == "export")
            {
                Response.Redirect("Export/ExportSite.aspx?siteid=" + actionArgument.ToString());
            }
        }
    }




/*    /// <summary>
    /// Handles the ButtonNewSite's onClick event
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void ButtonNewSite_Click(object sender, EventArgs e)
    {
        Response.Redirect("Site_Edit_Frameset.aspx");
    }*/
}
