using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.Blogs;
using CMS.PortalEngine;

public partial class CMSWebParts_Blog_CommentView : CMSAbstractWebPart
{
    #region "Properties" 

    /// <summary>
    /// Indicates whether permissions should be checked.
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), this.commentView.BlogProperties.CheckPermissions);
        }
        set
        {
            this.SetValue("CheckPermissions", value);
            this.commentView.BlogProperties.CheckPermissions = value;
        }
    }


    /// <summary>
    /// Indicates whether 'Edit' button should be displayed in comment view while editing comments on the live site.
    /// </summary>
    public bool ShowEditButton
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowEditButton"), this.commentView.BlogProperties.ShowEditButton);
        }
        set
        {
            this.SetValue("ShowEditButton", value);
            this.commentView.BlogProperties.ShowEditButton = value;
        }
    }


    /// <summary>
    /// Indicates whether 'Delete' button should be displayed in comment view while editing comments on the live site.
    /// </summary>
    public bool ShowDeleteButton
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowDeleteButton"), this.commentView.BlogProperties.ShowDeleteButton);
        }
        set
        {
            this.SetValue("ShowDeleteButton", value);
            this.commentView.BlogProperties.ShowDeleteButton = value;
        }
    }


    /// <summary>
    /// Indicates whether user pictures should be displayed in comment detail.
    /// </summary>
    public bool EnableUserPictures
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("EnableUserPictures"), this.commentView.BlogProperties.EnableUserPictures);
        }
        set
        {
            this.SetValue("EnableUserPictures", value);
            this.commentView.BlogProperties.EnableUserPictures = value;
        }
    }


    /// <summary>
    /// User picture max width.
    /// </summary>
    public int UserPictureMaxWidth
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("UserPictureMaxWidth"), this.commentView.BlogProperties.UserPictureMaxWidth);
        }
        set
        {
            this.SetValue("UserPictureMaxWidth", value);
            this.commentView.BlogProperties.UserPictureMaxWidth = value;
        }
    }


    /// <summary>
    /// User picture max height.
    /// </summary>
    public int UserPictureMaxHeight
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("UserPictureMaxHeight"), this.commentView.BlogProperties.UserPictureMaxHeight);
        }
        set
        {
            this.SetValue("UserPictureMaxHeight", value);
            this.commentView.BlogProperties.UserPictureMaxHeight = value;
        }
    }


    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
           
            this.commentView.BlogProperties.StopProcessing = true; // Do nothing
        }
        else
        {
            PageInfo currentPage = CMSContext.CurrentPageInfo;

            this.commentView.PostNode = CMSContext.CurrentDocument;

            // Get current parent blog
            CMS.TreeEngine.TreeNode blogNode = BlogHelper.GetParentBlog(currentPage.NodeAliasPath, CMSContext.CurrentSiteName);
            if (blogNode != null)
            {
                this.commentView.BlogProperties.AllowAnonymousComments = ValidationHelper.GetBoolean(blogNode.GetValue("BlogAllowAnonymousComments"), true);
                this.commentView.BlogProperties.ModerateComments = ValidationHelper.GetBoolean(blogNode.GetValue("BlogModerateComments"), false);
                this.commentView.BlogProperties.OpenCommentsFor = ValidationHelper.GetInteger(blogNode.GetValue("BlogOpenCommentsFor"), BlogProperties.OPEN_COMMENTS_ALWAYS);
                this.commentView.BlogProperties.SendCommentsToEmail = ValidationHelper.GetString(blogNode.GetValue("BlogSendCommentsToEmail"), "");
                this.commentView.BlogProperties.UseCaptcha = ValidationHelper.GetBoolean(blogNode.GetValue("BlogUseCAPTCHAForComments"), true);
                this.commentView.BlogProperties.CheckPermissions = this.CheckPermissions;
                this.commentView.BlogProperties.ShowDeleteButton = this.ShowDeleteButton;
                this.commentView.BlogProperties.ShowEditButton = this.ShowEditButton;
                this.commentView.BlogProperties.EnableUserPictures = this.EnableUserPictures;
                this.commentView.BlogProperties.UserPictureMaxHeight = this.UserPictureMaxHeight;
                this.commentView.BlogProperties.UserPictureMaxWidth = this.UserPictureMaxWidth;
            }

        }
    }


}
