using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.Blogs;
using CMS.PortalEngine;

public partial class CMSWebParts_Blogs_PostArchive : CMSAbstractWebPart
{
    #region "Properties"

    /// <summary>
    /// Select TOP N items.
    /// </summary>
    public int SelectTopN
    {
        get
        {
            return ValidationHelper.GetInteger(this.GetValue("SelectTopN"), this.rptPostArchive.SelectTopN);
        }
        set
        {
            this.SetValue("SelectTopN", value);
            this.rptPostArchive.SelectTopN = value;
        }
    }


    /// <summary>
    /// Transformation name
    /// </summary>
    public string TransformationName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("TransformationName"), this.rptPostArchive.TransformationName);
        }
        set
        {
            this.SetValue("TransformationName", value);
            this.rptPostArchive.TransformationName = value;
        }
    }

    #endregion

    private DataSet dsBlogPosts = null;

    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();                
    }
    


    protected void rptPostArchive_ItemDataBound(object sender, RepeaterItemEventArgs e)
    {
        // Get month NodeID        
        int parentId = ValidationHelper.GetInteger((DataHelper.GetDataRowValue(((DataRowView)e.Item.DataItem).Row, "NodeID")), 0);
        int count = 0;

        if ((dsBlogPosts != null) && (dsBlogPosts.Tables.Count > 0))
        {
            dsBlogPosts.Tables[0].DefaultView.RowFilter = "NodeParentID = " + parentId.ToString();
            count = dsBlogPosts.Tables[0].DefaultView.Count;
        }

        // Set post count as text to the label control in repeater transformation
        if (e.Item.Controls.Count > 0)
        {
            Control ctrl = e.Item.Controls[0].FindControl("lblPostCount");
            if (ctrl != null)
            {
                ((Label)ctrl).Text = count.ToString();
            }
        }
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {            
        }
        else
        {
            PageInfo currentPage = CMSContext.CurrentPageInfo;

            // Get blog posts
            bool selectOnlyPublished = (this.PageManager.ViewMode == ViewModeEnum.LiveSite);
            dsBlogPosts = BlogHelper.GetBlogPosts(CMSContext.CurrentSiteName, "/%", TreeProvider.ALL_CULTURES, false, "'" + CMSContext.CurrentAliasPath + "' LIKE NodeAliasPath + '%'", "", selectOnlyPublished);

            // Get current parent blog
            CMS.TreeEngine.TreeNode blogNode = BlogHelper.GetParentBlog(currentPage.NodeAliasPath, CMSContext.CurrentSiteName);
            if (blogNode != null)
            {
                this.rptPostArchive.Path = blogNode.NodeAliasPath + "/%";
            }

            this.rptPostArchive.TransformationName = this.TransformationName;
            this.rptPostArchive.SelectTopN = this.SelectTopN;            

        }
    }

}
