
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.TreeEngine;
using CMS.SiteProvider;

public partial class CMSWebParts_Designers_RoleSelection : CMSModalPage
{
    protected int nodeId = 0;
    protected string mtitle;
    protected bool showOnlyRoles = true;
    protected bool showOnlyUsers = false;



    protected void Page_Load(Object sender, EventArgs e)
    {
        SiteInfo currentSite = CMSContext.CurrentSite;
        UserInfo currentUser = CMSContext.CurrentUser;
        showOnlyRoles = true;//ValidationHelper.GetBoolean(Request.QueryString["onlyroles"], false);

        string onlyUsers = ValidationHelper.GetString(Request.QueryString["mode"], "");
        if (onlyUsers == "user")
        {
            this.showOnlyUsers = true;
        }

        lblSite.Text = ResHelper.GetString("SecurityAddOperator.Site");
        lblUserName.Text = ResHelper.GetString("SecurityAddOperator.UserName");

        this.SetTitleElem();
        
        btnSearch.Text = ResHelper.GetString("SecurityAddOperator.SearchButton");
        btnOK.Text = ResHelper.GetString("SecurityAddOperator.OK");
        btnCancel.Text = ResHelper.GetString("SecurityAddOperator.Cancel");
        mtitle = ResHelper.GetString("SecurityAddOperator.Title");

        if (((showOnlyUsers) || (showOnlyRoles)) && (currentSite != null))
        {
            dropSites.Items.Add(new ListItem(currentSite.SiteName, currentSite.SiteID.ToString()));
            dropSites.SelectedValue = currentSite.SiteID.ToString();
            this.dropSites.Enabled = false;
            if (showOnlyUsers)
            {
                this.pnlSite.Visible = false;
            }
        }
        else
        {
            // fill in the site list
            if (this.dropSites.Items.Count == 0)
            {
                if (currentUser.IsGlobalAdministrator)
                {
                    this.dropSites.DataSource = SiteInfoProvider.GetAllSites();
                }
                else
                {
                    this.dropSites.DataSource = UserInfoProvider.GetUserSites(currentUser.UserID);
                }
                this.dropSites.DataBind();
                try
                {
                    this.dropSites.SelectedValue = currentSite.SiteID.ToString();
                }
                catch
                {
                }
            }
        }

        // check permissions
        if ((!CMSContext.CurrentUser.IsAuthorizedPerResource("cms.content", "ModifyPermissions")) && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.ModifyPermissions)!=AuthorizationResultEnum.Allowed))
        {
            RedirectToAccessDenied(nodeId, "Modify permissions (security.aspx)");
            return;
        }
    }


   protected void btnSearch_Click(Object sender, EventArgs e)
    {
        GeneralConnection cn = ConnectionHelper.GetConnection();
        DataSet ds = null;
        object[,] searchParams = new object[2, 3];
        searchParams[0, 0] = "@search";
        searchParams[0, 1] = "%" + txtSearch.Text + "%";
        searchParams[1, 0] = "@siteID";
        searchParams[1, 1] = Convert.ToInt32(dropSites.SelectedValue);

        if (this.showOnlyUsers)
        {
            // find all users whose name contains specified string
            ds = cn.ExecuteQuery("cms.role.SelectUsersForSite", searchParams);
            lstItems.DataSource = ds.Tables[0];
            lstItems.DataTextField = "OperatorName";
            lstItems.DataValueField = "OperatorID";
            lstItems.DataBind();
            this.lstItems.SelectionMode = ListSelectionMode.Single;
        }
        else if (showOnlyRoles)
        {
            // find all roles whose name contains specified string
            ds = cn.ExecuteQuery("cms.role.SelectRolesForSite", searchParams);
            lstItems.DataSource = ds.Tables[0];
            lstItems.DataTextField = "OperatorName";
            lstItems.DataValueField = "OperatorID";
            lstItems.DataBind();
            this.lstItems.SelectionMode = ListSelectionMode.Multiple;
        }
        else
        {
            // find all users and roles whose name contains specified string
            ds = cn.ExecuteQuery("cms.role.SelectRolesAndUsersForSite", searchParams);
            lstItems.DataSource = ds.Tables[0];
            lstItems.DataTextField = "OperatorName";
            lstItems.DataValueField = "OperatorID";
            lstItems.DataBind();
            this.lstItems.SelectionMode = ListSelectionMode.Multiple;
        }
    }



    protected void btnOK_Click(Object sender, EventArgs e)
    {
        object[,] queryParams = new object[2, 3];
        TreeProvider treeProvider = new TreeProvider(CMSContext.CurrentUser);
        CMS.TreeEngine.TreeNode node = treeProvider.SelectSingleNode(nodeId);
        AclProvider aclProv = new AclProvider(treeProvider);

        string mText = "";
        string Id = "";

        if (Request.QueryString["elemId"] != null && Request.QueryString["elemId"] != "")
        {
            Id = ValidationHelper.GetString(Request.QueryString["elemId"], "");
        }

        // get IDs of the selected users/roles and save changes
        foreach (ListItem item in lstItems.Items)
        {
            if (item.Selected)
            {
                if (item.Value.ToLower().StartsWith("r"))
                {
                    item.Value = item.Value.ToLower().Replace("r", "");
                }
                else if (item.Value.ToLower().StartsWith("u"))
                {
                    item.Value = item.Value.ToLower().Replace("u", "");
                }

                if (this.showOnlyUsers)// only one user can be selected
                {
                    string hiddenId = String.Empty;
                    if (Request.QueryString["hiddenId"] != null && Request.QueryString["hiddenId"] != String.Empty)
                    {
                        hiddenId = ValidationHelper.GetString(Request.QueryString["hiddenId"], String.Empty);
                    }

                    UserInfo ui = UserInfoProvider.GetUserInfo(ValidationHelper.GetInteger(item.Value, 0));
                    if (ui != null)
                    {
                        if (mText.Trim() == "")
                        {
                            mText = ui.FullName;
                        }
                    }
                    ltlScript.Text += ScriptHelper.GetScript(" CloseAndRefreshUser('" + mText + "','" + Id + "','" + ui.UserID + "','" + hiddenId + "'); ");
                    return;
                }
                else if (this.showOnlyRoles)
                {
                    RoleInfo ri = RoleInfoProvider.GetRoleInfo(ValidationHelper.GetInteger(item.Value, 0));
                    if (ri != null)
                    {
                        if (mText.Trim() == "")
                        {
                            mText = ri.RoleName;
                        }
                        else
                        {
                            mText = mText + ";" + ri.RoleName;
                        }
                    }
                }
            }
        }
        ltlScript.Text += ScriptHelper.GetScript(" CloseAndRefreshRole('"+ mText+"','"+ Id +"'); ");
    }


    /// <summary>
    /// Sets the page title
    /// </summary>
    private void SetTitleElem()
    {
        if (this.showOnlyUsers)
        {
            this.titleElem.TitleText = ResHelper.GetString("SecurityAddOperator.OnlyUsersHeader");
        }
        else if (showOnlyRoles)
        {
            titleElem.TitleText = ResHelper.GetString("SecurityAddOperator.OnlyRolesHeader");
        }
        else
        {
            titleElem.TitleText = ResHelper.GetString("SecurityAddOperator.Header");
        }
        titleElem.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/Roles/selectuser.gif";
    }


    protected void btnCancel_Click(System.Object sender, System.EventArgs e)
    {
        ltlScript.Text = ScriptHelper.GetScript("Close();");
    }

}


