using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.Ecommerce;

public partial class CMSWebParts_Ecommerce_MyAccountWebPart : CMSAbstractWebPart
{
    protected string page = "";

    #region "Public properties"

    /// <summary>
    /// Menu css class
    /// </summary>
    public string CssClass
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("CssClass"), "");
        }
        set
        {
            this.SetValue("CssClass", value);
            this.pnlBody.CssClass = value;
        }
    }


    /// <summary>
    /// Query string parameter name
    /// </summary>
    public string ParameterName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("ParameterName"), "page");
        }
        set
        {
            this.SetValue("ParameterName", value);
        }
    }


    /// <summary>
    /// Indicates whether to allow to save empty password
    /// </summary>
    public bool AllowEmptyPassword
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("AllowEmptyPassword"), false);
        }
        set
        {
            this.SetValue("AllowEmptyPassword", value);
        }
    }


    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible) || (CMSContext.CurrentUser.IsPublic()))
        {
        }
        else
        {
            int index = Request.RawUrl.IndexOf('?');
            string queryString = index == -1 ? "" : Request.RawUrl.Substring(index);
            string uri = index == -1 ? Request.RawUrl : Request.RawUrl.Substring(0, index);
            string absoluteUri = uri + UrlHelper.RemoveUrlParameter(queryString, "saved");

            // Get customer info.
            CustomerInfo customer = CustomerInfoProvider.GetCustomerInfoByUserId(CMSContext.CurrentUser.UserID);

            // Menu initialization
            tabMenu.UrlTarget = "_self";
            tabMenu.Tabs = new string[4, 4];
            tabMenu.Tabs[0, 0] = ResHelper.GetString("MyAccount.MyDetails");
            tabMenu.Tabs[0, 2] = UrlHelper.AddParameterToUrl(absoluteUri, ParameterName, "details");
            if (customer != null)
            {
                tabMenu.Tabs[1, 0] = ResHelper.GetString("MyAccount.MyAddresses");
                tabMenu.Tabs[1, 2] = UrlHelper.AddParameterToUrl(absoluteUri, ParameterName, "addresses");
                tabMenu.Tabs[2, 0] = ResHelper.GetString("MyAccount.MyOrders");
                tabMenu.Tabs[2, 2] = UrlHelper.AddParameterToUrl(absoluteUri, ParameterName, "orders");
                tabMenu.Tabs[3, 0] = ResHelper.GetString("MyAccount.ChangePassword");
                tabMenu.Tabs[3, 2] = UrlHelper.AddParameterToUrl(absoluteUri, ParameterName, "password");
            }

            this.pnlBody.CssClass = this.CssClass;

            page = ValidationHelper.GetString(Request.QueryString[ParameterName], "details");

            ucChangePassword.Visible = false;
            ucMyAddresses.Visible = false;
            ucMyAddresses.StopProcessing = true;
            ucMyOrders.Visible = false;
            ucMyOrders.StopProcessing = true;
            ucMyDetails.Visible = false;
            ucMyDetails.StopProcessing = true;

            switch (page)
            {
                case "details":
                    tabMenu.SelectedTab = 0;
                    ucMyDetails.Visible = true;
                    ucMyDetails.Customer = customer;
                    ucMyDetails.StopProcessing = false;
                    break;

                case "addresses":
                    tabMenu.SelectedTab = 1;
                    ucMyAddresses.Visible = true;
                    ucMyAddresses.CustomerId = customer.CustomerID;
                    ucMyAddresses.StopProcessing = false;
                    break;

                case "orders":
                    tabMenu.SelectedTab = 2;
                    ucMyOrders.Visible = true;
                    ucMyOrders.CustomerId = customer.CustomerID;
                    ucMyOrders.StopProcessing = false;
                    break;

                case "password":
                    tabMenu.SelectedTab = 3;
                    ucChangePassword.Visible = true;
                    ucChangePassword.AllowEmptyPassword = this.AllowEmptyPassword;
                    break;
            }
        }
    }
}
