using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.SettingsProvider;
using CMS.ExtendedControls;
using CMS.DataEngine;
using CMS.EmailEngine;
using CMS.SiteProvider;
using CMS.EventLog;

public partial class CMSWebParts_Membership_LogonForm : CMSAbstractWebPart
{
    private string mDefaultTargetUrl = "";

    #region "Public properties"

    /// <summary>
    /// True if password retrieval is enabled
    /// </summary>
    public bool AllowPasswordRetrieval
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("AllowPasswordRetrieval"), true);
        }
        set
        {
            this.SetValue("AllowPasswordRetrieval", value);
            this.lnkPasswdRetrieval.Visible = value;
        }
    }


    /// <summary>
    /// Send email from
    /// </summary>
    public string SendEmailFrom
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("SendEmailFrom"), "admin@domain.com"), "admin@domain.com");
        }
        set
        {
            this.SetValue("SendEmailFrom", value);
        }
    }


    /// <summary>
    /// Default target url
    /// </summary>
    public string DefaultTargetUrl
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("DefaultTargetUrl"), mDefaultTargetUrl);
        }
        set
        {
            this.SetValue("SendEmailFrom", value);
            this.mDefaultTargetUrl = value;
        }
    }


    /// <summary>
    /// Skin ID
    /// </summary>
    public override string SkinID
    {
        get
        {
            return base.SkinID;
        }
        set
        {
            base.SkinID = value;
            SetSkinID(value);
        }
    }


    /// <summary>
    /// Logon failure text
    /// </summary>
    public string FailureText
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("FailureText"), "");
        }
        set
        {
            if (value.ToString().Trim() != "")
            {
                this.SetValue("FailureText", value);
                this.Login1.FailureText = value;
            }
        }
    }


    #endregion


    #region "Web part properties"


    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            this.rqValue.Visible = false;
            // Do not process
        }
        else
        {
            if (this.FailureText != "")
            {
                Login1.FailureText = ResHelper.LocalizeString(this.FailureText);
            }
            else
            {
                Login1.FailureText = ResHelper.GetString("Login_FailureText");
            }

            // Set strings
            lnkPasswdRetrieval.Text = ResHelper.GetString("LogonForm.lnkPasswordRetrieval");
            lblPasswdRetrieval.Text = ResHelper.GetString("LogonForm.lblPasswordRetrieval");
            btnPasswdRetrieval.Text = ResHelper.GetString("LogonForm.btnPasswordRetrieval");
            rqValue.ErrorMessage = ResHelper.GetString("LogonForm.rqValue");

            // Set logon strings
            LocalizedLabel lblItem = (LocalizedLabel)Login1.FindControl("lblUserName");
            if (lblItem != null)
            {
                lblItem.Text = "{$LogonForm.UserName$}";
            }
            lblItem = (LocalizedLabel)Login1.FindControl("lblPassword");
            if (lblItem != null)
            {
                lblItem.Text = "{$LogonForm.Password$}";
            }
            LocalizedCheckBox chkItem = (LocalizedCheckBox)Login1.FindControl("chkRememberMe");
            if (chkItem != null)
            {
                chkItem.Text = "{$LogonForm.RememberMe$}";
            }
            LocalizedButton btnItem = (LocalizedButton)Login1.FindControl("LoginButton");
            if (btnItem != null)
            {
                btnItem.Text = "{$LogonForm.LogOnButton$}";
            }

            this.ltlScript.Text = ScriptHelper.GetScript("function ShowPasswdRetrieve(id){var hdnDispl = document.getElementById('" + this.hdnPasswDisplayed.ClientID + "'); style=document.getElementById(id).style;style.display=(style.display == 'block')?'none':'block'; if(hdnDispl != null){ if(style.display == 'block'){hdnDispl.value='1';}else{hdnDispl.value='';}}}");
            this.lnkPasswdRetrieval.Attributes.Add("onclick", "ShowPasswdRetrieve('" + pnlPasswdRetrieval.ClientID + "'); return false;");

            this.lnkPasswdRetrieval.Visible = this.AllowPasswordRetrieval;

            Login1.LoggedIn += new EventHandler(Login1_LoggedIn);
            Login1.LoggingIn += new LoginCancelEventHandler(Login1_LoggingIn);

            btnPasswdRetrieval.Click += new EventHandler(btnPasswdRetrieval_Click);
            
            
            
            if (!IsPostBack)
            {
                    

                Login1.UserName = ValidationHelper.GetString(Request.QueryString["username"], "");
                // Set SkinID properties
                if (!this.StandAlone && (this.PageCycle < PageCycleEnum.Loaded))
                {
                    SetSkinID(this.SkinID);
                }
            }

            if (!this.AllowPasswordRetrieval)
            {
                pnlPasswdRetrieval.Visible = false;
            }
        }
    }

    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);

        if (hdnPasswDisplayed.Value == "")
        {
            this.pnlPasswdRetrieval.Attributes.Add("style", "display:none;");
        }
        else
        {
            this.pnlPasswdRetrieval.Attributes.Add("style", "display:block;");
        }
    }

    void SetSkinID(string skinId)
    {
        if (skinId != "")
        {
            LocalizedLabel lbl = (LocalizedLabel)this.Login1.FindControl("lblUserName");
            if (lbl != null)
            {
                lbl.SkinID = skinId;
            }
            lbl = (LocalizedLabel)this.Login1.FindControl("lblPassword");
            if (lbl != null)
            {
                lbl.SkinID = skinId;
            }

            TextBox txt = (TextBox)this.Login1.FindControl("UserName");
            if (txt != null)
            {
                txt.SkinID = skinId;
            }
            txt = (TextBox)this.Login1.FindControl("Password");
            if (txt != null)
            {
                txt.SkinID = skinId;
            }

            LocalizedCheckBox chk = (LocalizedCheckBox)this.Login1.FindControl("chkRememberMe");
            if (chk != null)
            {
                chk.SkinID = skinId;
            }

            LocalizedButton btn = (LocalizedButton)this.Login1.FindControl("LoginButton");
            if (btn != null)
            {
                btn.SkinID = skinId;
            }
        }
    }


    // Retrieve the user password
    void btnPasswdRetrieval_Click(object sender, EventArgs e)
    {
        string value = txtPasswordRetrieval.Text.Trim();
        if (value != "")
        {
            object[,] parameters = new object[1, 3];
            parameters[0, 0] = "User";
            parameters[0, 1] = txtPasswordRetrieval.Text.Trim();

            GeneralConnection conn = ConnectionHelper.GetConnection();
            DataSet ds = conn.ExecuteQuery("cms.user.selectuserbynameoremail", parameters);

            // User exists, send email with password
            if (!DataHelper.DataSourceIsEmpty(ds))
            {
                string siteName = CMSContext.CurrentSite.SiteName;
                // Get user info
                UserInfo user = new UserInfo(ds.Tables[0].Rows[0], null, null);

                // Quit if user do not have an email
                if (user.Email == null || user.Email == "")
                {
                    lblResult.Text = ResHelper.GetString("LogonForm.NoEmail");
                    this.pnlPasswdRetrieval.Attributes.Add("style", "display:block;");
                    lblResult.Visible = true;
                    return;
                }

                // Send password
                EmailTemplateInfo emailTemplate = EmailTemplateProvider.GetEmailTemplate("forgottenPassword", siteName);

                if (emailTemplate != null)
                {
                    EmailMessage message = new EmailMessage();
                    message.From = this.SendEmailFrom;
                    message.Subject = ResHelper.GetString("LogonForm.ForgottenPasswordSubject");
                    message.Recipients = user.Email;
                    message.EmailFormat = EmailFormatEnum.Html;

                    // Get the password
                    string password = ValidationHelper.GetString(user.GetValue("UserPassword"), "");
                    switch (user.PasswordFormat.ToLower())
                    {
                        // SHA1 hash of the password, generate new
                        case "sha1":
                            password = UserInfoProvider.GenerateNewPassword();
                            break;
                    }

                    // Macros
                    string[,] macros = new string[3, 2];
                    macros[0, 0] = "LogonUrl";
                    macros[0, 1] = HttpContext.Current.Request.UrlReferrer.AbsoluteUri;
                    macros[1, 0] = "UserName";
                    macros[1, 1] = user.UserName;
                    macros[2, 0] = "Password";
                    macros[2, 1] = password;

                    try
                    {
                        // Send email
                        EmailSender.SendEmailWithTemplateText(siteName, message, emailTemplate.TemplateText, macros);

                        // Set new password after email was send successfully
                        UserInfoProvider.SetPassword(user.UserName, password);
                        lblResult.Text = ResHelper.GetString("LogonForm.PasswordSent") + " " + user.Email + ".";
                    }
                    catch (Exception ex)
                    {
                        EventLogProvider eventLog = new EventLogProvider();
                        eventLog.LogEvent("Password retrieval", "LOGONFORM", ex);
                        lblResult.Text = "Failed to send the password: " +  ex.Message;
                    }
                }
                
                this.pnlPasswdRetrieval.Attributes.Add("style", "display:none;");
            }
            // Wrong username or email, inform user
            else
            {
                lblResult.Text = ResHelper.GetString("LogonForm.NoUser");
                this.pnlPasswdRetrieval.Attributes.Add("style", "display:block;");
            }
            lblResult.Visible = true;
        }
    }


    void Login1_LoggedIn(object sender, EventArgs e)
    {
        if (Response.Cookies.Count > 0)
        {
            foreach (string s in Response.Cookies.AllKeys)
            {
                if (s == FormsAuthentication.FormsCookieName)
                {
                    if (Login1.RememberMeSet == true)
                    {
                        // Change the value to increase the cookies expiration by
                        Response.Cookies[s].Expires = DateTime.Now.AddYears(1);
                    }
                }
            }
        }
        if (ValidationHelper.GetString(Request.QueryString["ReturnURL"], "") != "")
        {
            Response.Redirect(ResolveUrl(ValidationHelper.GetString(Request.QueryString["ReturnURL"], "")));
        }
        else
        {
            if (this.DefaultTargetUrl != "")
            {
                Response.Redirect(ResolveUrl(this.DefaultTargetUrl));
            }
            else
            {
                Response.Redirect(Request.UrlReferrer.AbsoluteUri);
            }
        }
    }

    

    void Login1_LoggingIn(object sender, LoginCancelEventArgs e)
    {
        if (((CheckBox)Login1.FindControl("chkRememberMe")).Checked)
        {
            Login1.RememberMeSet = true;
        }
        else
        {
            Login1.RememberMeSet = false;
        }
    }


    ///<summary>Overrides the generation of the SPAN tag with custom tag.</summary>
    protected HtmlTextWriterTag TagKey
    {
        get
        {
            if (CMSContext.CurrentSite != null)
            {
                if (SettingsKeyProvider.GetStringValue(CMSContext.CurrentSite.SiteName + ".CMSControlElement").ToLower().Trim() == "div")
                {
                    return HtmlTextWriterTag.Div;
                }
                else
                {
                    return HtmlTextWriterTag.Span;
                }
            }
            return HtmlTextWriterTag.Span;
        }
    }
}
