using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text.RegularExpressions;

using CMS.GlobalHelper;
using CMS.ExtendedControls;
using CMS.Newsletter;
using CMS.CMSHelper;
using CMS.WebAnalytics;

public partial class CMSWebParts_Newsletters_NewsletterSubscription : System.Web.UI.UserControl
{
    private bool mDisplayFirstName = false;
    private bool mDisplayLastName = false;
    //private bool mDisplayFullName = false;
    private string mNewsletterName = ""; //code name of newsletter
    private string mTrackConversionName = "";

    public LocalizedLabel LabelFirstName
    {
        get
        {
            return this.lblFirstName;
        }
    }

    public LocalizedLabel LabelLastName
    {
        get
        {
            return this.lblLastName;
        }
    }

    public LocalizedLabel LabelEmail
    {
        get
        {
            return this.lblEmail;
        }
    }

    public TextBox TextBoxFirstName
    {
        get
        {
            return this.txtFirstName;
        }
    }

    public TextBox TextBoxLastName
    {
        get
        {
            return this.txtLastName;
        }
    }

    public TextBox TextBoxEmail
    {
        get
        {
            return this.txtEmail;
        }
    }

    public LocalizedButton ButtonOK
    {
        get
        {
            return this.btnSubmit;
        }
    }

    public bool DisplayFirstName
    {
        get
        {
            return mDisplayFirstName;
        }
        set
        {
            mDisplayFirstName = value;
        }
    }
    
    public bool DisplayLastName
    {
        get
        {
            return mDisplayLastName;
        }
        set
        {
            mDisplayLastName = value;
        }
    }
    
    /*public bool DisplayFullName
    {
        get
        {
            return mDisplayFullName;
        }
        set
        {
            mDisplayFullName = value;
        }
    }*/

    public string NewsletterName
    {
        get
        {
            return mNewsletterName;
        }
        set
        {
            mNewsletterName = value;
        }
    }


    /// <summary>
    /// Conversion track name used after successful subscription.
    /// </summary>
    public string TrackConversionName
    {
        get
        {
            return mTrackConversionName; ;
        }
        set
        {
            mTrackConversionName = value;
        }
    }


    protected void Page_Load(object sender, EventArgs e)
    {
        if (!DisplayFirstName)
        {
            lblFirstName.Visible = false;
            txtFirstName.Visible = false;
        }
        
        if (!DisplayLastName)
        {
            lblLastName.Visible = false;
            txtLastName.Visible = false;
        }
    }

    /////<summary>Indicates whether the input string is a valid e-mail address.</summary>
    /////<param name="value">The string value to check.</param>
    /////<returns>Returns true if the parameter contains valid e-mail address; otherwise, false.</returns>
    //private static bool IsEmail(string value)
    //{
    //    if ((value != null) && (value != ""))
    //    {
    //        return Regex.IsMatch(value, @"^[a-zA-Z0-9]([_\.\-]?[a-zA-Z0-9]+)*@[a-zA-Z0-9]([\.\-]?[a-zA-Z0-9]+)*\.[a-zA-Z]{2,6}$");
    //    }
    //    return false;
    //}



    ///<summary>Indicates whether the control form fields contain a valid data.</summary>
    ///<returns>Returns true if the form data are valid; otherwise, false.</returns>
    private bool IsValid()
    {
        string errorText = "";
        bool result = true;

        // E-mail address validation
        //if (IsEmail(txtEmail.Text) == false)
        if ((!ValidationHelper.IsEmail(txtEmail.Text)) || (txtEmail.Text.Trim().Length == 0))
        {
            errorText += ResHelper.GetString("NewsletterSubscription.ErrorInvalidEmail") + "<br>";
            result = false;
        }

        // Additional fields validation
        /*if (this.DisplayFullName)
        {
            if (txtFullName.Text == null || txtFullName.Text.Trim().Length == 0)
            {
                errorText += ResHelper.GetString("NewsletterSubscription.ErrorEmptyFullName") + "<br>";
                result = false;
            }
        }*/
        if (this.DisplayFirstName)
        {
            if (txtFirstName.Text == null || txtFirstName.Text.Trim().Length == 0)
            {
                errorText += ResHelper.GetString("NewsletterSubscription.ErrorEmptyFirstName") + "<br>";
                result = false;
            }
        }
        if (this.DisplayLastName)
        {
            if (txtLastName.Text == null || txtLastName.Text.Trim().Length == 0)
            {
                errorText += ResHelper.GetString("NewsletterSubscription.ErrorEmptyLastName") + "<br>";
                result = false;
            }
        }

        // Assign validation result text.
        if (errorText != "")
        {
            lblError.Visible = true;
            lblError.Text = errorText;
        }

        return result;
    }
    
    protected void btnSubmit_Click(object sender, EventArgs e)
    {
        if (IsValid())
        {
            Subscriber sb = SubscriberProvider.GetSubscriber(txtEmail.Text);
            if (sb == null) 
            {
                sb = new Subscriber();
                sb.SubscriberEmail = txtEmail.Text;
                if (DisplayFirstName)
                {
                    sb.SubscriberFirstName = txtFirstName.Text;
                }
                else
                {
                    sb.SubscriberFirstName = "";
                }
                if (DisplayLastName)
                {
                    sb.SubscriberLastName = txtLastName.Text;
                }
                else
                {
                    sb.SubscriberLastName = "";
                }
                sb.SubscriberGUID = Guid.NewGuid();
                sb.SubscriberSiteID = CMSContext.CurrentSite.SiteID;
                SubscriberProvider.SetSubscriber(sb);
                lblLastName.Visible = false;
                txtLastName.Visible = false;
                lblFirstName.Visible = false;
                txtFirstName.Visible = false;
                txtEmail.Visible = false;
                lblEmail.Visible = false;
                btnSubmit.Visible = false;

            }

            int siteId = 0;
            if (CMSContext.CurrentSite != null)
            {
                siteId = CMSContext.CurrentSite.SiteID;
            }

            Newsletter news = NewsletterProvider.GetNewsletter(NewsletterName, siteId);
            if (news != null)
            {
                try
                {
                    if (!SubscriberProvider.IsSubscribed(sb.SubscriberGUID, news.NewsletterGUID, siteId))
                    {
                        SubscriberProvider.Subscribe(sb.SubscriberGUID, news.NewsletterID);
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("NewsletterSubscription.Subscribed");

                        // Track successful subscription conversion
                        if (this.TrackConversionName != string.Empty)
                        {
                            string siteName = CMSContext.CurrentSite.SiteName;

                            if (AnalyticsHelper.AnalyticsEnabled(siteName) && !AnalyticsHelper.IsIPExcluded(siteName, HttpContext.Current.Request.UserHostAddress))
                            {
                                string objectName = new ContextResolver().ResolveMacros(this.TrackConversionName);
                                HitLogProvider.LogHit("conversion", siteName, CMSContext.CurrentUser.PreferredCultureCode, objectName, 0);
                            }
                        }
                    }
                    else
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("NewsletterSubscription.SubscriberIsAlreadySubscribed");
                    }

                }
                catch (Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = ex.Message;
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("NewsletterSubscription.NewsletterDoesNotExist");
            }
        }
    }
}
