using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;
using CMS.Polls;

public partial class CMSWebParts_Polls_Poll : CMSAbstractWebPart
{

    #region "Properties"

    /// <summary>
    /// Code name of the poll, which should be displayed.
    /// </summary>
    public string PollCodeName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("PollCodeName"), "");
        }
        set
        {
            this.SetValue("PollCodeName", value);
        }
    }


    /// <summary>
    /// If true, graph of the poll is displayed.
    /// </summary>
    public bool ShowGraph
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("ShowGraph"), this.PollView1.ShowGraph); }
        set
        {
            this.SetValue("ShowGraph", value);
        }
    }


    /// <summary>
    /// Type of the representation of the answers count in the graph.
    /// </summary>
    public CountTypeEnum CountType
    {
        get
        {
            int countTypeInt = ValidationHelper.GetInteger(this.GetValue("CountType"), 0);
            if (countTypeInt == 1)
            {
                return CountTypeEnum.Absolute;
            }
            else if (countTypeInt == 2)
            {
                return CountTypeEnum.Percentage;
            }
            else
            {
                return CountTypeEnum.None;
            }
        }
        set
        {
            if (value == CountTypeEnum.Absolute)
            {
                this.SetValue("CountType", 1);
            }
            else if (value == CountTypeEnum.Percentage)
            {
                this.SetValue("CountType", 2);
            }
            else
            {
                this.SetValue("CountType", 0);
            }
        }
    }


    /// <summary>
    /// If true, graph is displayed after answering the poll.
    /// </summary>
    public bool ShowResultsAfterVote
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("ShowResultsAfterVote"), this.PollView1.ShowResultsAfterVote); }
        set
        {
            this.SetValue("ShowResultsAfterVote", value);
        }
    }


    /// <summary>
    /// Check whether current user has voted.
    /// </summary>
    public bool CheckVoted
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("CheckVoted"), this.PollView1.CheckVoted); }
        set
        {
            this.SetValue("CheckVoted", value);
        }
    }


    /// <summary>
    /// Check permissions.
    /// </summary>
    public bool CheckPermissions
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), this.PollView1.CheckPermissions); }
        set
        {
            this.SetValue("CheckPermissions", value);
        }
    }


    /// <summary>
    /// If true, the control hides when not authorized, 
    /// otherwise the control displays the message and does not allow to vote.
    /// </summary>
    public bool HideWhenNotAuthorized
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("HideWhenNotAuthorized"), this.PollView1.HideWhenNotAuthorized); }
        set
        {
            this.SetValue("HideWhenNotAuthorized", value);
        }
    }


    /// <summary>
    /// If true, the control hides when not opened, 
    /// otherwise the control does not allow to vote.
    /// </summary>
    public bool HideWhenNotOpened
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("HideWhenNotOpened"), this.PollView1.HideWhenNotOpened); }
        set
        {
            this.SetValue("HideWhenNotOpened", value);
        }
    }


    /// <summary>
    /// Text of the vote button.
    /// </summary>
    public string ButtonText
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("ButtonText"), this.PollView1.ButtonText);
        }
        set
        {
            this.SetValue("ButtonText", value);
        }
    }

    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            // Do nothing
            this.PollView1.Visible = false;
        }
        else
        {
            this.PollView1.PollCodeName = this.PollCodeName;
            this.PollView1.CheckPermissions = this.CheckPermissions;
            this.PollView1.CheckVoted = this.CheckVoted;
            this.PollView1.CountType = this.CountType;
            this.PollView1.HideWhenNotAuthorized = this.HideWhenNotAuthorized;
            this.PollView1.ShowGraph = this.ShowGraph;
            this.PollView1.ShowResultsAfterVote = this.ShowResultsAfterVote;
            this.PollView1.HideWhenNotOpened = this.HideWhenNotOpened;
            this.PollView1.ButtonText = this.ButtonText;
        }
    }


    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        this.Visible = this.PollView1.Visible;
    }
}
