using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.DataEngine;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.TreeEngine;
using CMS.SettingsProvider;

public partial class CMSWebParts_UserContributions_EditContribution : CMSAbstractWebPart
{

    #region "Public properties"

    /// <summary>
    /// Indicates whether deleting document is allowed.
    /// </summary>
    public bool AllowDelete
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("AllowDelete"), this.editForm.AllowDelete);
        }
        set
        {
            this.SetValue("AllowDelete", value);
            this.editForm.AllowDelete = value;
        }
    }


    /// <summary>
    /// Which group of users can work with the documents
    /// </summary>
    public UserContributionAllowUserEnum AllowUsers
    {
        get
        {
            return (UserContributionAllowUserEnum)(ValidationHelper.GetInteger(this.GetValue("AllowUsers"), 2));
        }
        set
        {
            this.SetValue("AllowUsers", value);
        }
    }


    /// <summary>
    /// Indicates whether permissions should be checked.
    /// </summary>
    public bool CheckPermissions
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("CheckPermissions"), true);
        }
        set
        {
            this.SetValue("CheckPermissions", value);
        }
    }


    #endregion


    #region "Document properties"

    /// <summary>
    /// Culture code
    /// </summary>
    public string CultureCode
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("CultureCode"), ""), CMSContext.CurrentUser.PreferredCultureCode);
        }
    }


    /// <summary>
    /// Nodes path 
    /// </summary>
    public string Path
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("Path"), ""), CMSContext.CurrentAliasPath);
        }
    }


    /// <summary>
    /// Site name
    /// </summary>
    public string SiteName
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("SiteName"), ""), CMSContext.CurrentSiteName);
        }
    }

    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            this.editForm.Visible = false;
        }
        else
        {
            this.Visible = false;

            CurrentUserInfo currentUser = CMSContext.CurrentUser;
            TreeProvider tree = new TreeProvider(currentUser);

            // Get the document
            CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(this.SiteName, this.Path, this.CultureCode, false, null, false);
            if (node != null)
            {
                bool authorized = false;

                // Check user group
                switch (this.AllowUsers)
                {
                    case UserContributionAllowUserEnum.All:
                        authorized = true;
                        break;

                    case UserContributionAllowUserEnum.Authenticated:
                        authorized = currentUser.IsAuthenticated();
                        break;

                    case UserContributionAllowUserEnum.DocumentOwner:
                        authorized = (node.NodeOwner == currentUser.UserID);
                        break;
                }

                // Check control access permissions
                if (this.CheckPermissions)
                {
                    authorized &= (currentUser.IsAuthorizedPerDocument(node, new NodePermissionsEnum[] { NodePermissionsEnum.Read, NodePermissionsEnum.Modify }) == AuthorizationResultEnum.Allowed);
                }
                else
                {
                    authorized |= currentUser.IsGlobalAdministrator;
                }

                // Display form if authorized
                if (authorized)
                {
                    this.Visible = true;

                    this.btnDelete.Visible = this.btnDelete.Visible && this.AllowDelete;

                    if ((!IsPostBack) || (this.btnEdit.Text.Trim() == string.Empty) || (this.btnDelete.Text.Trim() == string.Empty))
                    {
                        this.btnEdit.Text = ResHelper.GetString("EditContribution.EditButton");
                        this.btnEdit.CssClass = "EditContributionEdit";
                        this.btnDelete.Text = ResHelper.GetString("EditContribution.DeleteButton");
                        this.btnDelete.CssClass = "EditContributionDelete";
                    }

                    if (this.pnlForm.Visible)
                    {
                        this.editForm.FunctionsPrefix = this.ID + "_";
                        this.editForm.AllowDelete = this.AllowDelete;
                        this.editForm.CheckPermissions = this.CheckPermissions;
                        this.editForm.NodeID = node.NodeID;
                    }
                }
            }
        }
    }


    /// <summary>
    /// On btnEdit click event handler.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnEdit_Click(object sender, EventArgs e)
    {
        // Close edit form
        if (this.pnlForm.Visible)
        {
            this.pnlForm.Visible = false;
            this.btnDelete.Visible = true;

            this.btnDelete.Text = ResHelper.GetString("EditContribution.DeleteButton");
            this.btnDelete.CssClass = "EditContributionDelete";
            this.btnEdit.Text = ResHelper.GetString("EditContribution.EditButton");
            this.btnEdit.CssClass = "EditContributionEdit";
        }
        // Show edit form
        else
        {
            this.editForm.Action = "edit";
            this.pnlForm.Visible = true;
            this.btnDelete.Visible = false;

            this.btnEdit.Text = ResHelper.GetString("EditContribution.CloseButton");
            this.btnEdit.CssClass = "EditContributionClose";
        }
        this.ReloadData();
    }


    /// <summary>
    /// On btnDelete click event handler.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnDelete_Click(object sender, EventArgs e)
    {
        // Close delete form
        if (this.pnlForm.Visible)
        {
            this.pnlForm.Visible = false;
            this.btnEdit.Visible = true;

            this.btnDelete.Text = ResHelper.GetString("EditContribution.DeleteButton");
            this.btnDelete.CssClass = "EditContributionDelete";
            this.btnEdit.Text = ResHelper.GetString("EditContribution.EditButton");
            this.btnEdit.CssClass = "EditContributionEdit";
        }
        // Show delete form
        else
        {
            this.editForm.Action = "delete";
            this.pnlForm.Visible = true;

            this.btnEdit.Visible = false;
            this.btnDelete.Text = ResHelper.GetString("EditContribution.CloseButton");
            this.btnDelete.CssClass = "EditContributionClose";
        }
        this.ReloadData();
    }


    public override void ReloadData()
    {
        base.ReloadData();
        this.SetupControl();
        this.editForm.ReloadData();
    }
}
