using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSWebParts_WebServices_GridForWebService : CMSAbstractWebPart
{
    // Web service URL
    protected string wsURL = "";
    // Web service parameters
    protected string wsParameters = "";

    #region Public properties

    /// <summary>
    /// Hide control for zero rows
    /// </summary>
    public bool HideControlForZeroRows
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("HideControlForZeroRows"), this.basicDataGrid.HideControlForZeroRows);
        }
        set
        {
            this.SetValue("HideControlForZeroRows", value);
            this.basicDataGrid.HideControlForZeroRows = value;
        }
    }


    /// <summary>
    /// Zero rows text
    /// </summary>
    public string ZeroRowsText
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("ZeroRowsText"), this.basicDataGrid.ZeroRowsText), this.basicDataGrid.ZeroRowsText);
        }
        set
        {
            this.SetValue("ZeroRowsText", value);
            this.basicDataGrid.ZeroRowsText = value;
        }
    }


    /// <summary>
    /// True if the sorting is ascending
    /// </summary>
    public bool SortAscending
    {
        get { return (ValidationHelper.GetBoolean(this.GetValue("SortAscending"), this.basicDataGrid.SortAscending)); }
        set
        {
            this.SetValue("SortAscending", value);
            this.basicDataGrid.SortAscending = value;
        }
    }


    /// <summary>
    /// True if the sorting is allowed
    /// </summary>
    public bool AllowSorting
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("AllowSorting"), this.basicDataGrid.AllowSorting); }
        set
        {
            this.SetValue("AllowSorting", value);
            this.basicDataGrid.AllowSorting = value;
        }
    }


    /// <summary>
    /// True if the sorting process is in the code
    /// </summary>
    public bool ProcessSorting
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("ProcessSorting"), this.basicDataGrid.ProcessSorting); }
        set
        {
            this.SetValue("ProcessSorting", value);
            this.basicDataGrid.ProcessSorting = value;
        }
    }


    /// <summary>
    /// Sort field
    /// </summary>
    public string SortField
    {
        get { return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("SortField"), this.basicDataGrid.SortField), this.basicDataGrid.SortField); }
        set
        {
            this.SetValue("SortField", value);
            this.basicDataGrid.SortField = value;
        }
    }


    /// <summary>
    /// True if the paging should be allowed
    /// </summary>
    public bool AllowPaging
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("AllowPaging"), this.basicDataGrid.AllowPaging); }
        set
        {
            this.SetValue("AllowPaging", value);
            this.basicDataGrid.AllowPaging = value;
        }
    }


    /// <summary>
    /// Allow custom paging
    /// </summary>
    public bool AllowCustomPaging
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("AllowCustomPaging"), this.basicDataGrid.AllowCustomPaging); }
        set
        {
            this.SetValue("AllowCustomPaging", value);
            this.basicDataGrid.AllowCustomPaging = value;
        }
    }


    /// <summary>
    /// Size of the page if the paging is allowed
    /// </summary>
    public int PageSize
    {
        get { return ValidationHelper.GetInteger(this.GetValue("PageSize"), this.basicDataGrid.PageSize); }
        set
        {
            this.SetValue("PageSize", value);
            this.basicDataGrid.PageSize = value;
        }
    }


    /// <summary>
    /// If true, the databind is automatic
    /// </summary>
    public bool DataBindByDefault
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("DataBindByDefault"), this.basicDataGrid.DataBindByDefault); }
        set
        {
            this.SetValue("DataBindByDefault", value);
            this.basicDataGrid.DataBindByDefault = value;
        }
    }


    /// <summary>
    /// Pager mode
    /// </summary>
    public PagerMode PagingMode
    {
        get { return this.basicDataGrid.GetPagerMode(ValidationHelper.GetString(this.GetValue("Mode"), "")); }
        set
        {
            this.SetValue("Mode", value);
        }
    }


    /// <summary>
    /// True if the header should be shown
    /// </summary>
    public bool ShowHeader
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("ShowHeader"), this.basicDataGrid.ShowHeader); }
        set
        {
            this.SetValue("ShowHeader", value);
            this.basicDataGrid.ShowHeader = value;
        }
    }


    /// <summary>
    /// True if the footer should be shown
    /// </summary>
    public bool ShowFooter
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("ShowFooter"), this.basicDataGrid.ShowFooter); }
        set
        {
            this.SetValue("ShowFooter", value);
            this.basicDataGrid.ShowFooter = value;
        }
    }


    /// <summary>
    /// Tool tip
    /// </summary>
    public string ToolTip
    {
        get { return DataHelper.GetNotEmpty(this.GetValue("ToolTip"), this.basicDataGrid.ToolTip); }
        set
        {
            this.SetValue("ToolTip", value);
            this.basicDataGrid.ToolTip = value;
        }
    }


    /// <summary>
    /// If true, the columns are generated automatically
    /// </summary>
    public bool AutoGenerateColumns
    {
        get { return ValidationHelper.GetBoolean(this.GetValue("AutoGenerateColumns"), this.basicDataGrid.AutoGenerateColumns); }
        set
        {
            this.SetValue("AutoGenerateColumns", value);
            this.basicDataGrid.AutoGenerateColumns = value;
        }
    }
    #endregion

    #region Webservices properties

    /// <summary>
    /// Parameters of the web service
    /// </summary>
    public string WebServiceParameters
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("WebServiceParameters"), wsParameters).Replace("\"", "'");
        }
        set
        {
            this.SetValue("WebServiceParameters", value);
            this.wsParameters = value;
        }
    }


    /// <summary>
    /// Url of the web service
    /// </summary>
    public string WebServiceURL
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("WebServiceURL"), wsURL);
        }
        set
        {
            this.SetValue("WebServiceURL", value);
            this.wsURL = value;
        }
    }
    #endregion

    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
            this.basicDataGrid.Visible = false;
        }
        else
        {
            // Setup the control
            // Setup paging
            this.basicDataGrid.AllowPaging = this.AllowPaging;
            this.basicDataGrid.PageSize = this.PageSize;
            this.basicDataGrid.AllowCustomPaging = this.AllowCustomPaging;
            this.basicDataGrid.PagerStyle.Mode = this.PagingMode;
            this.basicDataGrid.ShowHeader = this.ShowHeader;
            this.basicDataGrid.ShowFooter = this.ShowFooter;

            this.basicDataGrid.ToolTip = this.ToolTip;
            this.basicDataGrid.SkinID = this.SkinID;
            this.basicDataGrid.EnableViewState = true;

            // Setup sorting
            this.basicDataGrid.AllowSorting = this.AllowSorting;
            this.basicDataGrid.ProcessSorting = this.ProcessSorting;
            this.basicDataGrid.SortAscending = this.SortAscending;
            this.basicDataGrid.SortField = this.SortField;

            this.basicDataGrid.AutoGenerateColumns = this.AutoGenerateColumns;
            this.basicDataGrid.DataBindByDefault = this.DataBindByDefault;

            this.basicDataGrid.HideControlForZeroRows = this.HideControlForZeroRows;
            this.basicDataGrid.ZeroRowsText = this.ZeroRowsText;
            
            // Get web service URL and parameters
            this.wsURL = this.WebServiceURL;
            this.wsParameters = this.WebServiceParameters;

            if (wsURL != "")
            {
                // Get data from web service
                DataLoad();
            }
        }
    }


    /// <summary>
    /// Load data from web service to DataGrid.
    /// </summary>
    protected void DataLoad()
    {
        // Web service object
        WS.WebService webService = new WS.WebService();
        // Set web service url
        if (!wsURL.Contains("http://"))
        {
            webService.Url = "http://" + wsURL;
        }
        else
        {
            webService.Url = wsURL;
        }

        try
        {
            // Get dataset from web service
            DataSet ds = webService.GetDataSet(wsParameters);
            if (ds != null && ds.Tables.Count > 0 && ds.Tables[0].Rows.Count > 0)
            {
                this.basicDataGrid.DataSource = ds;
            }
        }
        catch(Exception ex)
        {
            this.basicDataGrid.Visible = false;

            Label lblError = new Label();
            lblError.Text = "Error occurred: " + ex.Message;

            Controls.Add(lblError);
        }
    }


    /// <summary>
    /// Reload control's data.
    /// </summary>
    public override void ReloadData()
    {
        base.ReloadData();
        this.SetupControl();
    }
}
