using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.Controls;

public partial class CMSWebParts_WebServices_RepeaterForWebService : CMSAbstractWebPart
{
    // Web service URL
    protected string wsURL = "";
    // Web service parameters
    protected string wsParameters = "";
    // Transformation name
    protected string transformationName = "";

    #region "Public properties"

    /// <summary>
    /// Hide control for zero rows
    /// </summary>
    public bool HideControlForZeroRows
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("HideControlForZeroRows"), this.basicRepeater.HideControlForZeroRows);
        }
        set
        {
            this.SetValue("HideControlForZeroRows", value);
            this.basicRepeater.HideControlForZeroRows = value;
        }
    }


    /// <summary>
    /// Zero rows text
    /// </summary>
    public string ZeroRowsText
    {
        get
        {
            return DataHelper.GetNotEmpty(ValidationHelper.GetString(this.GetValue("ZeroRowsText"), this.basicRepeater.ZeroRowsText), this.basicRepeater.ZeroRowsText);
        }
        set
        {
            this.SetValue("ZeroRowsText", value);
            this.basicRepeater.ZeroRowsText = value;
        }
    }
    #endregion

    #region "Data binding properties"

    /// <summary>
    /// Databind by default
    /// </summary>
    public bool DataBindByDefault
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("DataBindByDefault"), this.basicRepeater.DataBindByDefault);
        }
        set
        {
            this.SetValue("DataBindByDefault", value);
            this.basicRepeater.DataBindByDefault = value;
        }
    }

    #endregion

    #region Webservices properties

    /// <summary>
    /// Parameters of the web service
    /// </summary>
    public string WebServiceParameters
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("WebServiceParameters"), wsParameters).Replace("\"", "'");
        }
        set
        {
            this.SetValue("WebServiceParameters", value);
            this.wsParameters = value;
        }
    }


    /// <summary>
    /// Url of the web service
    /// </summary>
    public string WebServiceURL
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("WebServiceURL"), wsURL);
        }
        set
        {
            this.SetValue("WebServiceURL", value);
            this.wsURL = value;
        }
    }


    /// <summary>
    /// Transformation name
    /// </summary>
    public string TransformationName
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("TransformationName"), transformationName);
        }
        set
        {
            this.SetValue("TransformationName", value);
            this.transformationName = value;
        }
    }

    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
        base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == CMS.CMSHelper.ViewModeEnum.Design) || this.HideOnCurrentPage || (!this.IsVisible))
        {
            this.basicRepeater.Visible = false;
        }
        else
        {
            // Setup the control
            // Public
            this.basicRepeater.HideControlForZeroRows = this.HideControlForZeroRows;
            this.basicRepeater.ZeroRowsText = this.ZeroRowsText;
            this.basicRepeater.DataBindByDefault = this.DataBindByDefault;

            // Get web service URL, parameters and transformation name
            wsURL = this.WebServiceURL;
            wsParameters = this.WebServiceParameters;
            transformationName = this.TransformationName;

            if (wsURL != "")
            {
                // Get data from web service
                DataLoad();
            }
        }
    }


    /// <summary>
    /// Load data from web service to Repeater.
    /// </summary>
    protected void DataLoad()
    {
        // Web service object
        WS.WebService webService = new WS.WebService();
        // Set web service url
        if (!wsURL.Contains("http://"))
        {
            webService.Url = "http://" + wsURL;
        }
        else
        {
            webService.Url = wsURL;
        }

        try
        {
            // Get dataset from web service
            DataSet ds = webService.GetDataSet(wsParameters);
            if (ds != null && ds.Tables.Count > 0 && ds.Tables[0].Rows.Count > 0)
            {
                this.basicRepeater.DataSource = ds;
                if ((transformationName != null) && (transformationName.Trim() != ""))
                {
                    // Get url to transformation and load it
                    this.basicRepeater.ItemTemplate = CMSDataProperties.LoadTransformation(this.basicRepeater, transformationName, false);
                }
            }
        }
        catch (Exception ex)
        {
            this.basicRepeater.Visible = false;

            Label lblError = new Label();
            lblError.Text = "Error occurred: " + ex.Message;

            Controls.Add(lblError);
        }
    }


    /// <summary>
    /// Reload control's data.
    /// </summary>
    public override void ReloadData()
    {
        base.ReloadData();
        this.SetupControl();
        this.basicRepeater.ReloadData(true);
    }
}
