-- Upgrade sql script from version 2.2 to 2.3

-- Prerequisites

-- Remove unused class ecommerce.store
DELETE FROM CMS_Query WHERE ClassID=(SELECT TOP 1 ClassID FROM CMS_Class WHERE classname='ecommerce.store')
GO

DELETE FROM CMS_Class WHERE classname = 'ecommerce.store'
GO

-- remove duplicated queries
DELETE FROM CMS_Query WHERE QueryID IN 
(SELECT dup_rows.QueryID FROM CMS_Query AS dup_rows 
INNER JOIN 
(
 SELECT QueryName, ClassID, MIN(QueryID) AS min_id
 FROM CMS_Query
 GROUP BY QueryName, ClassID
 HAVING COUNT(*) > 1
) AS rows_to_keep
ON rows_to_keep.QueryName = dup_rows.QueryName AND
   rows_to_keep.ClassID = dup_rows.ClassID AND
   rows_to_keep.min_id <> dup_rows.QueryID
)


-- New tables

CREATE TABLE [Analytics_DayHits]
(
    [HitsID] [int] NOT NULL IDENTITY (1, 1),
    [HitsStatisticsID] [int] NOT NULL,
    [HitsStartTime] [datetime] NOT NULL,
    [HitsEndTime] [datetime] NOT NULL,
    [HitsCount] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Analytics_HourHits]
(
    [HitsID] [int] NOT NULL IDENTITY (1, 1),
    [HitsStatisticsID] [int] NOT NULL,
    [HitsStartTime] [datetime] NOT NULL,
    [HitsEndTime] [datetime] NOT NULL,
    [HitsCount] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Analytics_Index]
(
    [IndexID] [int] NOT NULL IDENTITY (1, 1),
    [IndexZero] [int] NULL,
    [IndexMonthName] [nvarchar] (50) NULL,
    [IndexDayName] [nvarchar] (50) NULL
) ON [PRIMARY]


CREATE TABLE [Analytics_MonthHits]
(
    [HitsID] [int] NOT NULL IDENTITY (1, 1),
    [HitsStatisticsID] [int] NOT NULL,
    [HitsStartTime] [datetime] NOT NULL,
    [HitsEndTime] [datetime] NOT NULL,
    [HitsCount] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Analytics_Statistics]
(
    [StatisticsID] [int] NOT NULL IDENTITY (1, 1),
    [StatisticsSiteID] [int] NULL,
    [StatisticsCode] [nvarchar] (50) NOT NULL,
    [StatisticsObjectName] [nvarchar] (450) NULL,
    [StatisticsObjectID] [int] NULL,
    [StatisticsObjectCulture] [nvarchar] (10) NULL
) ON [PRIMARY]

	
CREATE TABLE [Analytics_WeekHits]
(
    [HitsID] [int] NOT NULL IDENTITY (1, 1),
    [HitsStatisticsID] [int] NOT NULL,
    [HitsStartTime] [datetime] NOT NULL,
    [HitsEndTime] [datetime] NOT NULL,
    [HitsCount] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Analytics_YearHits]
(
    [HitsID] [int] NOT NULL IDENTITY (1, 1),
    [HitsStatisticsID] [int] NOT NULL,
    [HitsStartTime] [datetime] NOT NULL,
    [HitsEndTime] [datetime] NOT NULL,
    [HitsCount] [int] NOT NULL
) ON [PRIMARY]

	
CREATE TABLE [Blog_Comment]
(
    [CommentID] [int] NOT NULL IDENTITY (1, 1),
    [CommentUserName] [nvarchar] (200) NOT NULL,
    [CommentUserID] [int] NULL,
    [CommentUrl] [nvarchar] (450) NULL,
    [CommentText] [ntext] NOT NULL,
    [CommentApprovedByUserID] [int] NULL,
    [CommentPostDocumentID] [int] NOT NULL,
    [CommentDate] [datetime] NOT NULL
) ON [PRIMARY]

CREATE TABLE [COM_DiscountLevel]
(
    [DiscountLevelID] [int] NOT NULL IDENTITY (1, 1),
    [DiscountLevelDisplayName] [nvarchar] (200) NOT NULL,
    [DiscountLevelName] [nvarchar] (100) NOT NULL,
    [DiscountLevelValue] [float] NOT NULL,
    [DiscountLevelEnabled] [bit] NOT NULL,
    [DiscountLevelValidFrom] [datetime] NULL,
    [DiscountLevelValidTo] [datetime] NULL
) ON [PRIMARY]


CREATE TABLE [COM_PaymentShipping]
(
    [PaymentOptionID] [int] NOT NULL,
    [ShippingOptionID] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [COM_TaxClassState]
(
    [TaxClassID] [int] NOT NULL,
    [StateID] [int] NOT NULL,
    [TaxValue] [float] NOT NULL,
    [IsFlatValue] [bit] NOT NULL
) ON [PRIMARY]



CREATE TABLE [COM_VolumeDiscount]
(
    [VolumeDiscountID] [int] NOT NULL IDENTITY (1, 1),
    [VolumeDiscountSKUID] [int] NOT NULL,
    [VolumeDiscountMinCount] [int] NOT NULL,
    [VolumeDiscountValue] [float] NOT NULL,
    [VolumeDiscountIsFlatValue] [bit] NOT NULL
) ON [PRIMARY]


CREATE TABLE [COM_Wishlist]
(
    [UserID] [int] NOT NULL,
    [SKUID] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Polls_Poll]
(
    [PollID] [int] NOT NULL IDENTITY (1, 1),
    [PollCodeName] [nvarchar] (200) NOT NULL,
    [PollDisplayName] [nvarchar] (200) NOT NULL,
    [PollTitle] [nvarchar] (100) NULL,
    [PollOpenFrom] [datetime] NULL,
    [PollOpenTo] [datetime] NULL,
    [PollAllowMultipleAnswers] [bit] NOT NULL,
    [PollQuestion] [nvarchar] (450) NOT NULL,
    [PollAccess] [int] NOT NULL,
    [PollResponseMessage] [nvarchar] (450) NULL
) ON [PRIMARY]


CREATE TABLE [Polls_PollAnswer]
(
    [AnswerID] [int] NOT NULL IDENTITY (1, 1),
    [AnswerText] [nvarchar] (200) NOT NULL,
    [AnswerOrder] [int] NULL,
    [AnswerCount] [int] NULL,
    [AnswerEnabled] [bit] NULL,
    [AnswerPollID] [int] NOT NULL
) ON [PRIMARY]



CREATE TABLE [Polls_PollRoles]
(
    [PollID] [int] NOT NULL,
    [RoleID] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Polls_PollSite]
(
    [PollID] [int] NOT NULL,
    [SiteID] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Reporting_Report]
(
    [ReportID] [int] NOT NULL IDENTITY (1, 1),
    [ReportName] [nvarchar] (100) NOT NULL,
    [ReportDisplayName] [nvarchar] (450) NOT NULL,
    [ReportLayout] [ntext] NOT NULL,
    [ReportParameters] [ntext] NOT NULL,
    [ReportCategoryID] [int] NOT NULL,
    [ReportAccess] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Reporting_ReportCategory]
(
    [CategoryID] [int] NOT NULL IDENTITY (1, 1),
    [CategoryDisplayName] [nvarchar] (200) NOT NULL,
    [CategoryCodeName] [nvarchar] (200) NOT NULL
) ON [PRIMARY]


CREATE TABLE [Reporting_ReportGraph]
(
    [GraphID] [int] NOT NULL IDENTITY (1, 1),
    [GraphName] [nvarchar] (100) NOT NULL,
    [GraphDisplayName] [nvarchar] (450) NOT NULL,
    [GraphQuery] [ntext] NOT NULL,
    [GraphQueryIsStoredProcedure] [bit] NOT NULL,
    [GraphType] [nvarchar] (50) NOT NULL,
    [GraphReportID] [int] NOT NULL,
    [GraphTitle] [nvarchar] (200) NULL,
    [GraphXAxisTitle] [nvarchar] (200) NULL,
    [GraphYAxisTitle] [nvarchar] (200) NULL,
    [GraphWidth] [int] NULL,
    [GraphHeight] [int] NULL,
    [GraphLegendPosition] [int] NULL
) ON [PRIMARY]

CREATE TABLE [Reporting_ReportTable]
(
    [TableID] [int] NOT NULL IDENTITY (1, 1),
    [TableName] [nvarchar] (100) NOT NULL,
    [TableDisplayName] [nvarchar] (450) NOT NULL,
    [TableQuery] [ntext] NOT NULL,
    [TableQueryIsStoredProcedure] [bit] NOT NULL,
    [TableReportID] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Reporting_ReportValue]
(
    [ValueID] [int] NOT NULL IDENTITY (1, 1),
    [ValueName] [nvarchar] (100) NOT NULL,
    [ValueDisplayName] [nvarchar] (450) NOT NULL,
    [ValueQuery] [ntext] NOT NULL,
    [ValueQueryIsStoredProcedure] [bit] NOT NULL,
    [ValueFormatString] [nvarchar] (200) NULL,
    [ValueReportID] [int] NOT NULL
) ON [PRIMARY]


CREATE TABLE [Reporting_SavedGraph]
(
    [SavedGraphID] [int] NOT NULL IDENTITY (1, 1),
    [SavedGraphSavedReportID] [int] NOT NULL,
    [SavedGraphGUID] [uniqueidentifier] NOT NULL,
    [SavedGraphBinary] [image] NOT NULL,
    [SavedGraphMimeType] [nvarchar] (100) NOT NULL
) ON [PRIMARY]


CREATE TABLE [Reporting_SavedReport]
(
    [SavedReportID] [int] NOT NULL IDENTITY (1, 1),
    [SavedReportReportID] [int] NOT NULL,
    [SavedReportGUID] [uniqueidentifier] NOT NULL,
    [SavedReportTitle] [nvarchar] (200) NULL,
    [SavedReportDate] [datetime] NOT NULL,
    [SavedReportHTML] [ntext] NOT NULL,
    [SavedReportParameters] [ntext] NOT NULL,
    [SavedReportCreatedByUserID] [int] NULL
) ON [PRIMARY]

GO
--------------------------------------------------------------------- Altering existing tables
ALTER TABLE [CMS_Attachment] ADD [AttachmentSiteID] [int] NULL  

ALTER TABLE [CMS_AttachmentHistory] ALTER COLUMN [AttachmentMimeType] [nvarchar] (100) NOT NULL 

ALTER TABLE [CMS_Class] ADD 
[ClassNodeAliasSource] [nvarchar] (100) NULL,
[ClassDefaultPageTemplateID] [int] NULL,
[ClassSKUDefaultDepartmentID] [int] NULL

ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuStyle] [nvarchar] (100) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuJavascript] [nvarchar] (450) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuRedirectUrl] [nvarchar] (450) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuClass] [nvarchar] (100) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuStyleOver] [nvarchar] (200) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuClassOver] [nvarchar] (100) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuStyleHighlighted] [nvarchar] (200) NULL 
ALTER TABLE [CMS_Document] ALTER COLUMN [DocumentMenuClassHighlighted] [nvarchar] (100) NULL 
ALTER TABLE [CMS_Document] ADD [DocumentCustomData] [ntext] NULL  

ALTER TABLE [CMS_EventLog] ADD [EventMachineName] [nvarchar] (100) NULL  

ALTER TABLE [CMS_Form] ADD 
[FormConfirmationEmailField] [nvarchar] (100) NULL,
[FormConfirmationTemplate] [ntext] NULL,
[FormConfirmationSendFromEmail] [nvarchar] (400) NULL,
[FormConfirmationEmailSubject] [nvarchar] (250) NULL 

ALTER TABLE [CMS_ScheduledTask] ADD [TaskServerName] [nvarchar] (100) NULL  
 
ALTER TABLE [CMS_SettingsKey] ALTER COLUMN  [KeyCategoryID] [int] NULL 

ALTER TABLE [CMS_Tree] ADD 
[NodeLinkedNodeID] [int] NULL,
[NodeOwner] [int] NULL,
[NodeCustomData] [ntext] NULL  

ALTER TABLE [CMS_User] ADD 
[UserURLReferrer] [nvarchar] (200) NULL,
[UserCampaign] [nvarchar] (100) NULL  

ALTER TABLE [COM_Customer] ADD [CustomerDiscountLevelID] [int] NULL  

ALTER TABLE [COM_OrderStatus] ADD [StatusColor] [nvarchar] (7) NULL  

ALTER TABLE [COM_SKU] ADD 
[SKUAvailableItems] [int] NULL,
[SKUSellOnlyAvailable] [bit] NULL  

ALTER TABLE [COM_TaxClass] ADD 
[TaxClassZeroIfIDSupplied] [bit] NULL  

ALTER TABLE [Forums_Forum] ADD 
[ForumUseCAPTCHA] [bit] NULL  

ALTER TABLE [Forums_ForumSubscription] ADD 
[SubscriptionGUID] [uniqueidentifier] NULL  

ALTER TABLE [Newsletter_EmailTemplate] ADD 
[TemplateStylesheetText] [ntext] NULL  

GO
-------------------------------------------------------------------indexes and constraints



CREATE NONCLUSTERED INDEX [IX_CMS_ACLItem_3] ON [CMS_ACLItem] ([LastModifiedByUserID]) ON [PRIMARY] 
	
CREATE NONCLUSTERED INDEX [FK_CMS_Class_ClassDefaultPageTemplateID] ON [CMS_Class] ([ClassDefaultPageTemplateID]) ON [PRIMARY]	

ALTER TABLE [CMS_CssStylesheet] ADD CONSTRAINT [FK_CMS_CssStylesheet_CMS_User] 
FOREIGN KEY ([StylesheetCheckedOutByUserID]) REFERENCES [CMS_User] ([UserID]) NOT FOR REPLICATION

CREATE NONCLUSTERED INDEX [FK_CMS_CssStylesheet] ON [CMS_CssStylesheet] ([StylesheetCheckedOutByUserID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_CMS_Document_17] ON [CMS_Document] ([DocumentPageTemplateID]) ON [PRIMARY]


declare @nid int
Set @nid = (SELECT TOP 1 DocumentNodeID FROM CMS_Document Group By DocumentCulture, DocumentNodeID HAVING COUNT(*) > 0 )
if (@nid IS NULL)
begin
CREATE UNIQUE NONCLUSTERED INDEX [IX_Document_DocumentNodeID_DocumentCulture] ON [CMS_Document] ([DocumentCulture], [DocumentNodeID]) ON [PRIMARY]
end

CREATE NONCLUSTERED INDEX [IX_CMS_EventLog_7] ON [CMS_EventLog] ([SiteID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_CMS_Layout_2] ON [CMS_Layout] ([LayoutCheckedOutByUserID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_CMS_PageTemplate_7] ON [CMS_PageTemplate] ([PageTemplateCategoryID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_CMS_PageTemplate_8] ON [CMS_PageTemplate] ([PageTemplateLayoutCheckedOutByUserID]) ON [PRIMARY]

CREATE UNIQUE NONCLUSTERED INDEX [IX_CMS_Query_ClassID_QueryName] ON [CMS_Query] ([QueryName], [ClassID]) ON [PRIMARY] 

ALTER TABLE [CMS_Role] DROP CONSTRAINT [FK__CMS_Role__SiteID__08EA5793]  

DROP INDEX [CMS_Site].[IX_CMS_Site_3]

CREATE NONCLUSTERED INDEX [FK_CMS_State] ON [CMS_State] ([CountryID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [IX_CMS_Transformation_3] ON [CMS_Transformation] ([TransformationCheckedOutByUserID]) ON [PRIMARY]

ALTER TABLE [CMS_Tree] ADD
CONSTRAINT [FK_CMS_Tree_CMS_Tree] FOREIGN KEY ([NodeLinkedNodeID]) REFERENCES [CMS_Tree] ([NodeID]),
CONSTRAINT [FK_CMS_Tree_CMS_Tree1] FOREIGN KEY ([NodeID]) REFERENCES [CMS_Tree] ([NodeID]),
CONSTRAINT [FK_CMS_Tree_CMS_User] FOREIGN KEY ([NodeOwner]) REFERENCES [CMS_User] ([UserID])

CREATE NONCLUSTERED INDEX [IX_CMS_Tree_10] ON [CMS_Tree] ([NodeLinkedNodeID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_CMS_Tree_11] ON [CMS_Tree] ([NodeOwner]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [IX_CMS_VersionHistory_10] ON [CMS_VersionHistory] ([ModifiedByUserID]) ON [PRIMARY]

DROP INDEX [CMS_Workflow].[IX_CMS_Workflow_1]
CREATE UNIQUE NONCLUSTERED INDEX [IX_CMS_Workflow_1] ON [CMS_Workflow] (WorkflowName ASC)


DROP INDEX [COM_Address].[IX_COM_Address_1]
CREATE NONCLUSTERED INDEX [FK_COM_Address] ON [COM_Address] ([AddressCustomerID]) ON [PRIMARY]           
CREATE NONCLUSTERED INDEX [FK_COM_Address_1] ON [COM_Address] ([AddressCountryID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Address_2] ON [COM_Address] ([AddressStateID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_COM_CurrencyExchangeRate] ON [COM_CurrencyExchangeRate] ([ExchangeRateToCurrencyID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_CurrencyExchangeRate_1] ON [COM_CurrencyExchangeRate] ([ExchangeTableID]) ON [PRIMARY]

DROP INDEX [COM_Customer].[IX_COM_Customer_2]
DROP INDEX [COM_Customer].[IX_COM_Customer_3]
CREATE NONCLUSTERED INDEX [FK_COM_Customer] ON [COM_Customer] ([CustomerPreferredCurrencyID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Customer_0] ON [COM_Customer] ([CustomerUserID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Customer_1] ON [COM_Customer] ([CustomerPreferredShippingOptionID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Customer_2] ON [COM_Customer] ([CustomerCountryID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Customer_3] ON [COM_Customer] ([CustomerPrefferedPaymentOptionID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Customer_4] ON [COM_Customer] ([CustomerStateID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_Customer_5] ON [COM_Customer] ([CustomerDiscountLevelID]) ON [PRIMARY] 
CREATE NONCLUSTERED INDEX [IX_COM_Customer_2] ON [COM_Customer] ([CustomerGUID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [IX_COM_DiscountCoupon_1] ON [COM_DiscountCoupon] ([DiscountCouponCode]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [IX_COM_Order] ON [COM_Order] ([OrderBillingAddressID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_1] ON [COM_Order] ([OrderShippingAddressID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_2] ON [COM_Order] ([OrderShippingOptionID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_3] ON [COM_Order] ([OrderStatusID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_4] ON [COM_Order] ([OrderCurrencyID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_5] ON [COM_Order] ([OrderCustomerID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_6] ON [COM_Order] ([OrderCreatedByUserID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_7] ON [COM_Order] ([OrderSiteID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_8] ON [COM_Order] ([OrderPaymentOptionID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_COM_Order_9] ON [COM_Order] ([OrderDiscountCouponID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_COM_OrderItem] ON [COM_OrderItem] ([OrderItemOrderID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_OrderItem_1] ON [COM_OrderItem] ([OrderItemSKUID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_COM_OrderStatusUser] ON [COM_OrderStatusUser] ([ChangedByUserID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_OrderStatusUser_1] ON [COM_OrderStatusUser] ([OrderID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_OrderStatusUser_2] ON [COM_OrderStatusUser] ([FromStatusID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_OrderStatusUser_3] ON [COM_OrderStatusUser] ([ToStatusID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_COM_PaymentOption] ON [COM_PaymentOption] ([PaymentOptionSiteID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_COM_ShippingOption] ON [COM_ShippingOption] ([ShippingOptionSiteID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart] ON [COM_ShoppingCart] ([ShoppingCartUserID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_1] ON [COM_ShoppingCart] ([ShoppingCartSiteID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_2]  ON [COM_ShoppingCart] ([ShoppingCartCurrencyID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_3]  ON [COM_ShoppingCart] ([ShoppingCartPaymentOptionID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_4]  ON [COM_ShoppingCart] ([ShoppingCartShippingOptionID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_5]  ON [COM_ShoppingCart] ([ShoppingCartDiscountCouponID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_6]  ON [COM_ShoppingCart] ([ShoppingCartBillingAddressID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_7] ON [COM_ShoppingCart] ([ShoppingCartShippingAddressID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_ShoppingCart_8] ON [COM_ShoppingCart] ([ShoppingCartCustomerID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_COM_SKU] ON [COM_SKU] ([SKUDepartmentID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_SKU_1] ON [COM_SKU] ([SKUManufacturerID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_SKU_2] ON [COM_SKU] ([SKUInternalStatusID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_SKU_3] ON [COM_SKU] ([SKUPublicStatusID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_COM_SKU_4] ON [COM_SKU] ([SKUSupplierID]) ON [PRIMARY]

--ALTER TABLE [COM_SKUTaxClasses] DROP CONSTRAINT [PK_COM_SKUTaxClasses]
ALTER TABLE [COM_SKUTaxClasses] ADD CONSTRAINT [PK_COM_SKUTaxClasses] PRIMARY KEY CLUSTERED ([SKUID], [TaxClassID]) 

CREATE NONCLUSTERED INDEX [FK_Forums_Forum] ON [Forums_Forum] ([ForumGroupID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_Forums_Forum] ON [Forums_Forum] ([ForumName]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_Forums_Forum_1] ON [Forums_Forum] ([ForumDocumentID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_Forums_ForumGroup] ON [Forums_ForumGroup] ([GroupSiteID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [IX_Forums_ForumGroup] ON [Forums_ForumGroup] ([GroupName]) ON [PRIMARY] 
                                                                                                            
CREATE NONCLUSTERED INDEX [FK_Forums_ForumModerators_CMS_User] ON [Forums_ForumModerators] ([UserID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_Forums_ForumModerators_Forums_Forum] ON [Forums_ForumModerators] ([ForumID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_Forums_ForumPost] ON [Forums_ForumPost] ([PostForumID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_Forums_ForumPost_1] ON [Forums_ForumPost] ([PostParentID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_Forums_ForumRoles_CMS_Role] ON [Forums_ForumRoles] ([RoleID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_Forums_ForumRoles_Forums_Forum] ON [Forums_ForumRoles] ([ForumID]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_Forums_ForumSubscription] ON [Forums_ForumSubscription] ([SubscriptionForumID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_Staging_Server_ServerName] ON [Staging_Server] ([ServerName]) ON [PRIMARY] 

CREATE NONCLUSTERED INDEX [FK_Staging_Synchronization_Server] ON [Staging_Synchronization] ([SynchronizationServerID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_Staging_Synchronization_Task] ON [Staging_Synchronization] ([SynchronizationTaskID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_Staging_SyncLog_Staging_Task] ON [Staging_SyncLog] ([SyncLogTaskID]) ON [PRIMARY]
CREATE NONCLUSTERED INDEX [FK_Staging_SyncLog_Staging_Server] ON [Staging_SyncLog] ([SyncLogServerID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_Staging_Task_CMS_Site] ON [Staging_Task] ([TaskSiteID]) ON [PRIMARY] 

GO

--------------------------------------------------------------------- Constraints and indexes of new tables

ALTER TABLE [Analytics_DayHits] ADD

CONSTRAINT [PK_Analytics_DayHits]
    PRIMARY KEY CLUSTERED ([HitsID])

CREATE NONCLUSTERED INDEX [FK_Analytics_DayHits_HitsStatisticsID]
    ON [Analytics_DayHits] ([HitsStatisticsID]) ON [PRIMARY]

--

ALTER TABLE [Analytics_HourHits] ADD

CONSTRAINT [PK_Analytics_HourHits]
    PRIMARY KEY CLUSTERED ([HitsID])

CREATE NONCLUSTERED INDEX [FK_Analytics_HourHits_HitsStatisticsID]
    ON [Analytics_HourHits] ([HitsStatisticsID]) ON [PRIMARY]

--

ALTER TABLE [Analytics_Index] ADD

CONSTRAINT [PK_Analytics_Index]
    PRIMARY KEY CLUSTERED ([IndexID])

--

ALTER TABLE [Analytics_MonthHits] ADD

CONSTRAINT [PK_Analytics_MonthHits]
    PRIMARY KEY CLUSTERED ([HitsID])

CREATE NONCLUSTERED INDEX [FK_Analytics_MonthHits_HitsStatisticsID]
    ON [Analytics_MonthHits] ([HitsStatisticsID]) ON [PRIMARY]

--

ALTER TABLE [Analytics_Statistics] ADD

CONSTRAINT [FK_Analytics_Statistics_CMS_Site]
    FOREIGN KEY ([StatisticsSiteID]) REFERENCES [CMS_Site] ([SiteID]),

CONSTRAINT [PK_Analytics_Statistics]
    PRIMARY KEY CLUSTERED ([StatisticsID])

CREATE NONCLUSTERED INDEX [FK_Analytics_Statistics_StatisticsSiteID]
    ON [Analytics_Statistics] ([StatisticsSiteID]) ON [PRIMARY]

--

ALTER TABLE [Analytics_WeekHits] ADD

CONSTRAINT [PK_Analytics_WeekHits]
    PRIMARY KEY CLUSTERED ([HitsID])

CREATE NONCLUSTERED INDEX [FK_Analytics_WeekHits_HitsStatisticsID]
    ON [Analytics_WeekHits] ([HitsStatisticsID]) ON [PRIMARY]

--

ALTER TABLE [Analytics_YearHits] ADD

CONSTRAINT [PK_Analytics_YearHits]
    PRIMARY KEY CLUSTERED ([HitsID])

CREATE NONCLUSTERED INDEX [FK_Analytics_YearHits_HitsStatisticsID]
    ON [Analytics_YearHits] ([HitsStatisticsID]) ON [PRIMARY]
	
--

ALTER TABLE [Blog_Comment] ADD

CONSTRAINT [FK_Blog_Comment_CMS_Document]
    FOREIGN KEY ([CommentPostDocumentID]) REFERENCES [CMS_Document] ([DocumentID]),

CONSTRAINT [FK_Blog_Comment_CMS_User]
    FOREIGN KEY ([CommentUserID]) REFERENCES [CMS_User] ([UserID]),

CONSTRAINT [FK_Blog_Comment_CMS_User1]
    FOREIGN KEY ([CommentApprovedByUserID]) REFERENCES [CMS_User] ([UserID]),

CONSTRAINT [PK_Blog_Comment]
    PRIMARY KEY CLUSTERED ([CommentID])

CREATE NONCLUSTERED INDEX [FK_Blog_Comment_CommentApprovedByUserID]
    ON [Blog_Comment] ([CommentApprovedByUserID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_Blog_Comment_CommentPostDocumentID]
    ON [Blog_Comment] ([CommentPostDocumentID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_Blog_Comment_CommentUserID]
    ON [Blog_Comment] ([CommentUserID]) ON [PRIMARY]
	
--

ALTER TABLE [COM_DiscountLevel] ADD

CONSTRAINT [PK_COM_DiscountLevel]
    PRIMARY KEY CLUSTERED ([DiscountLevelID])

CREATE NONCLUSTERED INDEX [IX_COM_DiscountLevel]
    ON [COM_DiscountLevel] ([DiscountLevelName]) ON [PRIMARY]
	
--

ALTER TABLE [COM_PaymentShipping] ADD

CONSTRAINT [FK_COM_PaymentShipping_COM_PaymentOption]
    FOREIGN KEY ([PaymentOptionID]) REFERENCES [COM_PaymentOption] ([PaymentOptionID]),

CONSTRAINT [FK_COM_PaymentShipping_COM_ShippingOption]
    FOREIGN KEY ([ShippingOptionID]) REFERENCES [COM_ShippingOption] ([ShippingOptionID]),

CONSTRAINT [PK_COM_PaymentShipping]
    PRIMARY KEY CLUSTERED ([PaymentOptionID], [ShippingOptionID])

--

ALTER TABLE [COM_TaxClassState] ADD

CONSTRAINT [FK_COM_TaxClassState_CMS_State]
    FOREIGN KEY ([StateID]) REFERENCES [CMS_State] ([StateID]),

CONSTRAINT [FK_COM_TaxClassState_COM_TaxClass]
    FOREIGN KEY ([TaxClassID]) REFERENCES [COM_TaxClass] ([TaxClassID]),

CONSTRAINT [PK_COM_TaxClassState]
    PRIMARY KEY CLUSTERED ([TaxClassID],[StateID])

--

ALTER TABLE [COM_VolumeDiscount] ADD

CONSTRAINT [FK_COM_VolumeDiscount_COM_SKU]
    FOREIGN KEY ([VolumeDiscountSKUID]) REFERENCES [COM_SKU] ([SKUID]),

CONSTRAINT [PK_COM_VolumeDiscount]
    PRIMARY KEY CLUSTERED ([VolumeDiscountID])

CREATE UNIQUE NONCLUSTERED INDEX [IX_COM_VolumeDiscount_SKUID_MinCount]
    ON [COM_VolumeDiscount] ([VolumeDiscountSKUID], [VolumeDiscountMinCount]) ON [PRIMARY]

-- 

ALTER TABLE [COM_Wishlist] ADD

CONSTRAINT [FK_COM_Wishlist_CMS_User]
    FOREIGN KEY ([UserID]) REFERENCES [CMS_User] ([UserID]),

CONSTRAINT [FK_COM_Wishlist_COM_SKU]
    FOREIGN KEY ([SKUID]) REFERENCES [COM_SKU] ([SKUID]),

CONSTRAINT [PK_COM_Wishlist]
    PRIMARY KEY CLUSTERED ([UserID],[SKUID])
	
--

ALTER TABLE [Polls_Poll] ADD

CONSTRAINT [PK_Polls_Poll]
    PRIMARY KEY CLUSTERED ([PollID])

CREATE UNIQUE NONCLUSTERED INDEX [IX_Polls_Poll_CodeName]
    ON [Polls_Poll] ([PollCodeName]) ON [PRIMARY]
	
--

ALTER TABLE [Polls_PollAnswer] ADD

CONSTRAINT [FK_Polls_PollAnswer_Polls_Poll]
    FOREIGN KEY ([AnswerPollID]) REFERENCES [Polls_Poll] ([PollID]),

CONSTRAINT [PK_Polls_PollAnswer]
    PRIMARY KEY CLUSTERED ([AnswerID])

CREATE NONCLUSTERED INDEX [FK_Polls_PollAnswer]
    ON [Polls_PollAnswer] ([AnswerPollID]) ON [PRIMARY]
	
--

ALTER TABLE [Polls_PollRoles] ADD

CONSTRAINT [FK_Polls_PollRoles_CMS_Role]
    FOREIGN KEY ([RoleID]) REFERENCES [CMS_Role] ([RoleID]),

CONSTRAINT [FK_Polls_PollRoles_Polls_Poll]
    FOREIGN KEY ([PollID]) REFERENCES [Polls_Poll] ([PollID])

CREATE UNIQUE CLUSTERED INDEX [FK_Polls_PollRoles]
    ON [Polls_PollRoles] ([PollID], [RoleID]) ON [PRIMARY]

--

ALTER TABLE [Polls_PollSite] ADD

CONSTRAINT [FK_Polls_PollSite_CMS_Site]
    FOREIGN KEY ([SiteID]) REFERENCES [CMS_Site] ([SiteID]),

CONSTRAINT [FK_Polls_PollSite_Polls_Poll]
    FOREIGN KEY ([PollID]) REFERENCES [Polls_Poll] ([PollID])

CREATE UNIQUE CLUSTERED INDEX [FK_Polls_PollSite]
    ON [Polls_PollSite] ([PollID], [SiteID]) ON [PRIMARY]
	
--

ALTER TABLE [Reporting_Report] ADD

CONSTRAINT [PK_Reporting_Report]
    PRIMARY KEY CLUSTERED ([ReportID])

CREATE NONCLUSTERED INDEX [FK_Reporting_Report]
    ON [Reporting_Report] ([ReportCategoryID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_Reporting_Report]
    ON [Reporting_Report] ([ReportName]) ON [PRIMARY]
	
--

ALTER TABLE [Reporting_ReportCategory] ADD

CONSTRAINT [PK_Reporting_ReportCategory]
    PRIMARY KEY CLUSTERED ([CategoryID])

CREATE NONCLUSTERED INDEX [IX_Reporting_ReportCategory]
    ON [Reporting_ReportCategory] ([CategoryCodeName]) ON [PRIMARY]
	
--

ALTER TABLE [Reporting_ReportGraph] ADD

CONSTRAINT [FK_Reporting_ReportGraph_Reporting_Report]
    FOREIGN KEY ([GraphReportID]) REFERENCES [Reporting_Report] ([ReportID]),

CONSTRAINT [PK_Reporting_ReportGraph]
    PRIMARY KEY CLUSTERED ([GraphID])

CREATE NONCLUSTERED INDEX [FK_Reporting_ReportingGraph]
    ON [Reporting_ReportGraph] ([GraphReportID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_Reporting_ReportGraph]
    ON [Reporting_ReportGraph] ([GraphName]) ON [PRIMARY]

--

ALTER TABLE [Reporting_ReportTable] ADD

CONSTRAINT [FK_Reporting_ReportTable_Reporting_Report]
    FOREIGN KEY ([TableReportID]) REFERENCES [Reporting_Report] ([ReportID]),

CONSTRAINT [PK_Reporting_ReportTable]
    PRIMARY KEY CLUSTERED ([TableID])

CREATE NONCLUSTERED INDEX [FK_Reporting_ReportTable]
    ON [Reporting_ReportTable] ([TableReportID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_Reporting_ReportTable]
    ON [Reporting_ReportTable] ([TableName]) ON [PRIMARY]
	
--

ALTER TABLE [Reporting_ReportValue] ADD

CONSTRAINT [FK_Reporting_ReportValue_Reporting_Report]
    FOREIGN KEY ([ValueReportID]) REFERENCES [Reporting_Report] ([ReportID]),

CONSTRAINT [PK_Reporting_ReportValue]
    PRIMARY KEY CLUSTERED ([ValueID])

CREATE NONCLUSTERED INDEX [FK_Reporting_ReportValue]
    ON [Reporting_ReportValue] ([ValueReportID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_Reporting_ReportValue]
    ON [Reporting_ReportValue] ([ValueName]) ON [PRIMARY]
	
--
	
ALTER TABLE [Reporting_SavedGraph] ADD

CONSTRAINT [PK_Reporting_SavedGraph]
    PRIMARY KEY CLUSTERED ([SavedGraphID])

CREATE NONCLUSTERED INDEX [FK_Reporting_SavedGraph]
    ON [Reporting_SavedGraph] ([SavedGraphSavedReportID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_Reporting_SavedGraph]
    ON [Reporting_SavedGraph] ([SavedGraphGUID]) ON [PRIMARY]

--

ALTER TABLE [Reporting_SavedReport] ADD

CONSTRAINT [FK_Reporting_SavedReport_CMS_User]
    FOREIGN KEY ([SavedReportCreatedByUserID]) REFERENCES [CMS_User] ([UserID]),

CONSTRAINT [FK_Reporting_SavedReport_Reporting_Report]
    FOREIGN KEY ([SavedReportReportID]) REFERENCES [Reporting_Report] ([ReportID]),

CONSTRAINT [PK_Reporting_SavedReport_1]
    PRIMARY KEY CLUSTERED ([SavedReportID])

CREATE NONCLUSTERED INDEX [FK_Reporting_SavedReport]
    ON [Reporting_SavedReport] ([SavedReportReportID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [FK_Reporting_SavedReport_1]
    ON [Reporting_SavedReport] ([SavedReportCreatedByUserID]) ON [PRIMARY]

CREATE NONCLUSTERED INDEX [IX_Reporting_SavedReport]
    ON [Reporting_SavedReport] ([SavedReportGUID]) ON [PRIMARY]	

GO	

----------------------------------------------------------------- New stored procedures
GO

CREATE PROCEDURE [Proc_Analytics_ProcessLog]
	@SiteID int,
	@Codename nvarchar(50),
	@Culture nvarchar(10),
    @ObjectName nvarchar(450),
    @ObjectID int,
    @Hits int,
    @HourStart datetime,
	@HourEnd datetime,
    @DayStart datetime,
	@DayEnd datetime,
    @WeekStart datetime,
	@WeekEnd datetime,
    @MonthStart datetime,
	@MonthEnd datetime,
    @YearStart datetime,
	@YearEnd datetime
AS
BEGIN
	/* Declare the @statisticsID variable */
	DECLARE @statisticsID int;
	SET @statisticsID = 0;
    SELECT @StatisticsID = StatisticsID FROM Analytics_Statistics
	WHERE (StatisticsSiteID = @SiteID) AND (StatisticsCode = @Codename) AND ((StatisticsObjectName = @ObjectName) OR (StatisticsObjectName IS NULL AND @ObjectName IS NULL))
		AND	((StatisticsObjectID = @ObjectID) OR (StatisticsObjectID IS NULL OR @ObjectID IS NULL)) AND ((StatisticsObjectCulture = @Culture) OR (StatisticsObjectCulture IS NULL AND @Culture IS NULL));
	
	/* If @statisticsID is 0 insert new record */
	IF @statisticsID = 0
	BEGIN
		INSERT INTO Analytics_Statistics (StatisticsSiteID, StatisticsCode, StatisticsObjectName, StatisticsObjectID, StatisticsObjectCulture)
		VALUES (@SiteID, @Codename, @ObjectName, @ObjectID, @Culture);
		/* Get StatisticsID */
        SELECT @StatisticsID = StatisticsID FROM Analytics_Statistics
     	WHERE (StatisticsSiteID = @SiteID) AND (StatisticsCode = @Codename) AND ((StatisticsObjectName = @ObjectName) OR (StatisticsObjectName IS NULL AND @ObjectName IS NULL))
	  		AND	((StatisticsObjectID = @ObjectID) OR (StatisticsObjectID IS NULL OR @ObjectID IS NULL)) AND ((StatisticsObjectCulture = @Culture) OR (StatisticsObjectCulture IS NULL AND @Culture IS NULL));
	END
	/* Declare @hitsID and @hitsCount variables */
	DECLARE @hitsID int, @hitsCount int;
	SET @hitsCount = 0;
	SET @hitsID = 0;
	/* HOURS */	
	SELECT @hitsID = HitsID, @hitsCount = HitsCount FROM [Analytics_HourHits]
	WHERE HitsStatisticsID=@statisticsID AND HitsStartTime=@HourStart AND HitsEndTime=@HourEnd;
	IF @hitsID > 0
		UPDATE [Analytics_HourHits] SET HitsCount=(@hitsCount+@Hits) WHERE HitsID=@hitsID;
	ELSE
		INSERT INTO [Analytics_HourHits] ([HitsStatisticsID],[HitsStartTime],[HitsEndTime],[HitsCount])
		VALUES (@statisticsID,@HourStart,@HourEnd,@Hits);
	/* DAYS */
	SET @hitsID = 0;
	SELECT @hitsID = HitsID, @hitsCount = HitsCount FROM [Analytics_DayHits]
	WHERE HitsStatisticsID=@statisticsID AND HitsStartTime=@DayStart AND HitsEndTime=@DayEnd;
	IF @hitsID > 0
		UPDATE [Analytics_DayHits] SET HitsCount=(@hitsCount+@Hits) WHERE HitsID=@hitsID;
	ELSE
		INSERT INTO [Analytics_DayHits] ([HitsStatisticsID],[HitsStartTime],[HitsEndTime],[HitsCount])
		VALUES (@statisticsID,@DayStart,@DayEnd,@Hits);
	/* WEEKS */
	SET @hitsID = 0;
	SELECT @hitsID = HitsID, @hitsCount = HitsCount FROM [Analytics_WeekHits]
	WHERE HitsStatisticsID=@statisticsID AND HitsStartTime=@WeekStart AND HitsEndTime=@WeekEnd;
	IF @hitsID > 0
		UPDATE [Analytics_WeekHits] SET HitsCount=(@hitsCount+@Hits) WHERE HitsID=@hitsID;
	ELSE
		INSERT INTO [Analytics_WeekHits] ([HitsStatisticsID],[HitsStartTime],[HitsEndTime],[HitsCount])
		VALUES (@statisticsID,@WeekStart,@WeekEnd,@Hits);
	/* MONTHS */
	SET @hitsID = 0;
	SELECT @hitsID = HitsID, @hitsCount = HitsCount FROM [Analytics_MonthHits]
	WHERE HitsStatisticsID=@statisticsID AND HitsStartTime=@MonthStart AND HitsEndTime=@MonthEnd;
	IF @hitsID > 0
		UPDATE [Analytics_MonthHits] SET HitsCount=(@hitsCount+@Hits) WHERE HitsID=@hitsID;
	ELSE
		INSERT INTO [Analytics_MonthHits] ([HitsStatisticsID],[HitsStartTime],[HitsEndTime],[HitsCount])
		VALUES (@statisticsID,@MonthStart,@MonthEnd,@Hits);
	
	/* YEARS */
	SET @hitsID = 0;
	SELECT @hitsID = HitsID, @hitsCount = HitsCount FROM [Analytics_YearHits]
	WHERE HitsStatisticsID=@statisticsID AND HitsStartTime=@YearStart AND HitsEndTime=@YearEnd;
	IF @hitsID > 0
		UPDATE [Analytics_YearHits] SET HitsCount=(@hitsCount+@Hits) WHERE HitsID=@hitsID;
	ELSE
		INSERT INTO [Analytics_YearHits] ([HitsStatisticsID],[HitsStartTime],[HitsEndTime],[HitsCount])
		VALUES (@statisticsID,@YearStart,@YearEnd,@Hits);
END

GO

CREATE PROCEDURE [Proc_Analytics_Statistics_RemoveDependencies] 
	@StatisticsID int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	BEGIN TRANSACTION;
	DELETE FROM Analytics_DayHits WHERE HitsStatisticsID=@StatisticsID
	DELETE FROM Analytics_HourHits WHERE HitsStatisticsID=@StatisticsID
	DELETE FROM Analytics_MonthHits WHERE HitsStatisticsID=@StatisticsID
	DELETE FROM Analytics_WeekHits WHERE HitsStatisticsID=@StatisticsID
	DELETE FROM Analytics_YearHits WHERE HitsStatisticsID=@StatisticsID
    COMMIT TRANSACTION;
END

GO

CREATE PROCEDURE Proc_CMS_Class_GetClassesOnSite
	@SiteID int
AS
BEGIN
	SET NOCOUNT ON;
	SELECT * FROM CMS_Class WHERE ClassID IN (SELECT ClassID FROM CMS_ClassSite WHERE SiteID = @SiteID)
END

GO

CREATE PROCEDURE [proc_CMS_Tree_MoveNodeAlphabetical]
	@NodeID int
AS
BEGIN
	/* Declare the selection table */
	DECLARE @nodesTable TABLE (
		NodeID int,
		NodeOrder int,
		NodeName nvarchar(100),
		NodeAlias nvarchar(50)
	);
	
	/* Get parent node ID */
	DECLARE @NodeParentID int, @NodeName nvarchar(100);
	SELECT @NodeParentID = NodeParentID, @NodeName = NodeName FROM CMS_Tree WHERE NodeID = @NodeID;
	/* Get the nodes list */
	INSERT INTO @nodesTable SELECT NodeID, NodeOrder, NodeName, NodeAlias FROM CMS_Tree WHERE NodeParentID = @NodeParentID AND NodeID <> @NodeID;
	
	/* Declare the cursor to loop through the table */
	DECLARE @nodeCursor CURSOR;
    SET @nodeCursor = CURSOR FOR SELECT NodeID, NodeOrder, NodeName FROM @nodesTable ORDER BY NodeOrder ASC, NodeName ASC, NodeAlias ASC;
	/* Assign the numbers to the nodes */
	DECLARE @currentIndex int, @currentNodeOrder int, @currentNodeName nvarchar(100);
	SET @currentIndex = 1;
	DECLARE @currentNodeId int;
	DECLARE @nodePlaced bit;
	SET @nodePlaced = 0;
	
	/* Loop through the table */
	OPEN @nodeCursor
	FETCH NEXT FROM @nodeCursor INTO @currentNodeId, @currentNodeOrder, @currentNodeName;
	WHILE @@FETCH_STATUS = 0
	BEGIN
		/* If current node should be next, place it */
		IF @nodePlaced = 0 AND @currentNodeName > @NodeName
		BEGIN
			UPDATE CMS_Tree SET NodeOrder = @currentIndex WHERE NodeId = @NodeID;
  			SET @currentIndex = @currentIndex + 1;
			SET @nodePlaced = 1;
		END
		/* Set the Node index if different */
		IF @currentNodeOrder IS NULL OR @currentNodeOrder <> @currentIndex
			UPDATE CMS_Tree SET NodeOrder = @currentIndex WHERE NodeId = @currentNodeId;
		/* Get next record */
		SET @currentIndex = @currentIndex + 1;
		FETCH NEXT FROM @nodeCursor INTO @currentNodeId, @currentNodeOrder, @currentNodeName;
	END
	CLOSE @nodeCursor;
	DEALLOCATE @nodeCursor;
	RETURN @currentIndex;
END

GO

CREATE PROCEDURE [Proc_CMS_Tree_MoveNodeFirst]
	@NodeID int 
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	-- Set node as first one
	UPDATE CMS_Tree SET NodeOrder = 0 WHERE NodeID = @NodeID
	-- Init the orders
	DECLARE @NodeParentID int;
	SELECT @NodeParentID = NodeParentID FROM CMS_Tree WHERE NodeID = @NodeID;
	EXECUTE Proc_CMS_Tree_InitNodeOrders @NodeParentID;
	-- Get new node order
	SELECT NodeOrder FROM CMS_Tree WHERE NodeID = @NodeID
END

GO

CREATE PROCEDURE [Proc_CMS_Tree_MoveNodeLast]
	@NodeID int 
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	-- Set node as last one (high node order)
	UPDATE CMS_Tree SET NodeOrder = 1000000 WHERE NodeID = @NodeID
	-- Init the orders
	DECLARE @NodeParentID int;
	SELECT @NodeParentID = NodeParentID FROM CMS_Tree WHERE NodeID = @NodeID;
	EXECUTE Proc_CMS_Tree_InitNodeOrders @NodeParentID;
	-- Get new node order
	SELECT NodeOrder FROM CMS_Tree WHERE NodeID = @NodeID
END

GO

CREATE PROCEDURE Proc_CMS_Tree_UpdateLinks
	@NodeID int,
	@NodeName nvarchar(100),
	@NodeSKUID int
AS
BEGIN
	SET NOCOUNT ON;
    UPDATE CMS_Tree SET 
		NodeName = @NodeName, 
		NodeSKUID = @NodeSKUID
	WHERE NodeID = @NodeID OR NodeLinkedNodeID = @NodeID
END

GO

CREATE PROCEDURE [Proc_COM_PaymentOption_RemoveDependences] 
	
	@PaymentOptionId int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRANSACTION;
    DELETE FROM COM_PaymentShipping WHERE PaymentOptionID = @PaymentOptionId;
	COMMIT TRANSACTION;
END

GO

CREATE PROCEDURE [Proc_COM_ShippingOption_RemoveDependences] 
	
	@ShippingOptionId int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRANSACTION;
    DELETE FROM COM_PaymentShipping WHERE ShippingOptionID = @ShippingOptionId;
	COMMIT TRANSACTION;
END

GO

CREATE PROCEDURE [Proc_Polls_Poll_RemoveDependences]
	@PollID int
AS
BEGIN
	DELETE FROM Polls_PollRoles WHERE PollID=@PollID;
	DELETE FROM Polls_PollSite WHERE PollID=@PollID;
	DELETE FROM Polls_PollAnswer WHERE AnswerPollID=@PollID;
END

GO

CREATE PROCEDURE [Proc_Polls_PollAnswer_InitOrders]
	@ID int
AS
BEGIN
	/* Declare the selection table */
	DECLARE @pollanswerTable TABLE (
		AnswerID int NOT NULL,
		AnswerText nvarchar(200) NOT NULL,
		AnswerOrder int NULL,
		AnswerCount int NULL,
		AnswerEnabled bit NULL,
		AnswerPollID int NULL
	);
	
	/* Get the steps list */
	INSERT INTO @pollanswerTable SELECT AnswerID, AnswerText, AnswerOrder, AnswerCount, AnswerEnabled, AnswerPollID FROM Polls_PollAnswer WHERE AnswerPollID=@ID
	
	/* Declare the cursor to loop through the table */
	DECLARE @cursor CURSOR;
    SET @cursor = CURSOR FOR SELECT AnswerID, AnswerOrder FROM @pollanswerTable ORDER BY AnswerOrder ASC, AnswerID ASC;
	/* Assign the numbers to the steps */
	DECLARE @currentIndex int, @currentOrder int;
	SET @currentIndex = 1;
	DECLARE @currentId int;
	
	/* Loop through the table */
	OPEN @cursor
	FETCH NEXT FROM @cursor INTO @currentId, @currentOrder;
	WHILE @@FETCH_STATUS = 0
	BEGIN
		/* Set the step index if different */
		IF @currentOrder IS NULL OR @currentOrder <> @currentIndex
			UPDATE Polls_PollAnswer SET AnswerOrder = @currentIndex WHERE AnswerID = @currentId;
		/* Get next record */
		SET @currentIndex = @currentIndex + 1;
		FETCH NEXT FROM @cursor INTO @currentId, @currentOrder;
	END
	CLOSE @cursor;
	DEALLOCATE @cursor;
END

GO

CREATE PROCEDURE [Proc_Polls_PollAnswer_MoveDown] 
	@PollID int,
    @AnswerID int
AS
BEGIN
	DECLARE @MaxAnswerOrder int
	SET @MaxAnswerOrder = (SELECT TOP 1 AnswerOrder FROM Polls_PollAnswer WHERE AnswerPollID = @PollID ORDER BY AnswerOrder DESC);
	/* Move the next step(s) up */
	UPDATE Polls_PollAnswer SET AnswerOrder = AnswerOrder - 1 WHERE AnswerOrder = (SELECT AnswerOrder FROM Polls_PollAnswer WHERE AnswerPollID=@PollID AND AnswerID = @AnswerID) + 1 
	/* Move the current step down */
	UPDATE Polls_PollAnswer SET AnswerOrder = AnswerOrder + 1 WHERE AnswerPollID = @PollID AND AnswerID = @AnswerID AND AnswerOrder < @MaxAnswerOrder
END

GO

CREATE PROCEDURE [Proc_Polls_PollAnswer_MoveUp] 
	@PollID int,
    @AnswerID int
AS
BEGIN
    /* Move the previous step(s) down */
	UPDATE Polls_PollAnswer SET AnswerOrder = AnswerOrder + 1 WHERE AnswerPollID = @PollID AND AnswerOrder = (SELECT AnswerOrder FROM Polls_PollAnswer WHERE AnswerPollID = @PollID AND AnswerID = @AnswerID) - 1 
	/* Move the current step up */
	UPDATE Polls_PollAnswer SET AnswerOrder = AnswerOrder - 1 WHERE AnswerPollID = @PollID AND AnswerID = @AnswerID AND AnswerOrder > 1
END

GO

CREATE PROCEDURE [Proc_Reporting_FileDownloads] 
	-- @CMSContextCurrentSiteID int,
    @CodeName nvarchar(50),
    @FromDate datetime,
    @ToDate datetime
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
    SELECT TOP 100 DocumentNamePath AS '@NamePathHeader', HitsCount AS '@HitsCountHeader'
    FROM Analytics_Statistics, Analytics_DayHits, CMS_Tree, CMS_Document WHERE
    (StatisticsSiteID = 1) AND (StatisticsCode=@CodeName)
    AND (StatisticsID = HitsStatisticsID)
    AND (DocumentID = NodeID)
    AND (StatisticsObjectID = NodeId)
    AND (HitsStartTime >= @FromDate)
    AND (HitsEndTime <= @ToDate)
    GROUP BY DocumentNamePath, HitsCount
    ORDER BY HitsCount DESC
END

GO

CREATE PROCEDURE [Proc_Reporting_Report_RemoveDependencies]
	@ID int
AS
BEGIN
	DELETE FROM Reporting_ReportValue WHERE ValueReportID=@ID;
	DELETE FROM Reporting_ReportTable WHERE TableReportID=@ID;
	DELETE FROM Reporting_ReportGraph WHERE GraphReportID=@ID;
	-- SavedReport
	DELETE FROM Reporting_SavedGraph WHERE SavedGraphSavedReportID IN (
		SELECT SavedReportID FROM Reporting_SavedReport WHERE SavedReportReportID=@ID);
	DELETE FROM Reporting_SavedReport WHERE SavedReportReportID=@ID;
END

GO

CREATE PROCEDURE [Proc_Reporting_ReportCategory_RemoveDependencies] 
	@CategoryID int
AS
BEGIN
	DELETE FROM Reporting_ReportValue WHERE ValueReportID IN (
		SELECT ReportID FROM Reporting_Report WHERE ReportCategoryID=@CategoryID);
	DELETE FROM Reporting_ReportTable WHERE TableReportID IN (
		SELECT ReportID FROM Reporting_Report WHERE ReportCategoryID=@CategoryID);
	DELETE FROM Reporting_ReportGraph WHERE GraphReportID IN (
		SELECT ReportID FROM Reporting_Report WHERE ReportCategoryID=@CategoryID);
	-- SavedReport
	DELETE FROM Reporting_SavedGraph WHERE SavedGraphSavedReportID IN (
		SELECT SavedReportID FROM Reporting_SavedReport WHERE SavedReportReportID IN (
			SELECT ReportID FROM Reporting_Report WHERE ReportCategoryID=@CategoryID)
		);
	DELETE FROM Reporting_SavedReport WHERE SavedReportReportID IN (
		SELECT ReportID FROM Reporting_Report WHERE ReportCategoryID=@CategoryID);
	-- Report
	DELETE FROM Reporting_Report WHERE ReportCategoryID=@CategoryID;
END

GO

CREATE PROCEDURE [Proc_Reporting_SavedReports_RemoveDependencies]
	@ID int
AS
BEGIN
	DELETE FROM Reporting_SavedGraph WHERE SavedGraphSavedReportID IN (SELECT SavedReportID FROM Reporting_SavedReport WHERE [SavedReportID] = @ID)	
END

GO

------------------------------------------------------------------- Changed stored procedures
GO

ALTER PROCEDURE [Proc_CMS_Class_Insert]
	@ClassID int = NULL,
	@ClassDisplayName nvarchar(100),
    @ClassName nvarchar(100),
    @ClassUsesVersioning bit,
    @ClassIsDocumentType bit,
    @ClassIsCoupledClass bit,
    @ClassXmlSchema ntext,
    @ClassFormDefinition ntext,
    @ClassNewPageUrl nvarchar(100),
    @ClassEditingPageUrl nvarchar(100),
    @ClassListPageUrl nvarchar(100),
    @ClassNodeNameSource nvarchar(100),
    @ClassTableName nvarchar(100),
	@ClassViewPageUrl nvarchar(450),
	@ClassPreviewPageUrl nvarchar(450),
	@ClassFormLayout ntext,
	@ClassShowAsSystemTable bit,
	@ClassUsePublishFromTo bit,
	@ClassShowTemplateSelection bit,
	@ClassSKUMappings nvarchar(500),
	@ClassIsMenuItemType bit,
	@ClassNodeAliasSource nvarchar(100),
	@ClassDefaultPageTemplateID int,	
	@ClassSKUDefaultDepartmentID int
AS
INSERT INTO [CMS_Class] (
	[ClassDisplayName],
	[ClassName],
	[ClassUsesVersioning],
	[ClassIsDocumentType],
	[ClassIsCoupledClass],
	[ClassXmlSchema],
	[ClassFormDefinition],
	[ClassNewPageUrl],
	[ClassEditingPageUrl],
	[ClassListPageUrl],
	[ClassNodeNameSource],	
	[ClassTableName],
	[ClassViewPageUrl],
	[ClassPreviewPageUrl],
	[ClassFormLayout],
	[ClassShowAsSystemTable],
	[ClassUsePublishFromTo],
	[ClassShowTemplateSelection],
    [ClassSKUMappings],
	[ClassIsMenuItemType],
	[ClassNodeAliasSource],
	[ClassDefaultPageTemplateID],	
	[ClassSKUDefaultDepartmentID]
)
VALUES (
	@ClassDisplayName, 
	@ClassName, 
	@ClassUsesVersioning, 
	@ClassIsDocumentType, 
	@ClassIsCoupledClass, 
	@ClassXmlSchema, 
	@ClassFormDefinition, 
	@ClassNewPageUrl, 
	@ClassEditingPageUrl, 
	@ClassListPageUrl, 
	@ClassNodeNameSource, 
	@ClassTableName,
	@ClassViewPageUrl,
	@ClassPreviewPageUrl,
	@ClassFormLayout,
	@ClassShowAsSystemTable,
	@ClassUsePublishFromTo,
	@ClassShowTemplateSelection,
	@ClassSKUMappings,
	@ClassIsMenuItemType,
	@ClassNodeAliasSource,
	@ClassDefaultPageTemplateID,	
	@ClassSKUDefaultDepartmentID
)
SELECT @@identity

GO

ALTER PROCEDURE [Proc_CMS_Class_Update]
	@ClassID int,
    @ClassDisplayName nvarchar(100),
    @ClassName nvarchar(100),
    @ClassUsesVersioning bit,
    @ClassIsDocumentType bit,
    @ClassIsCoupledClass bit,
    @ClassXmlSchema ntext,
    @ClassFormDefinition ntext,
    @ClassNewPageUrl nvarchar(100),
    @ClassEditingPageUrl nvarchar(100),
    @ClassListPageUrl nvarchar(100),
    @ClassNodeNameSource nvarchar(100),
    @ClassTableName nvarchar(100),
	@ClassViewPageUrl nvarchar(450),
	@ClassPreviewPageUrl nvarchar(450),
	@ClassFormLayout ntext,
	@ClassShowAsSystemTable bit,
	@ClassUsePublishFromTo bit,
	@ClassShowTemplateSelection bit,
	@ClassSKUMappings nvarchar(450),
	@ClassIsMenuItemType bit,
	@ClassNodeAliasSource nvarchar(100),
	@ClassDefaultPageTemplateID int,	
	@ClassSKUDefaultDepartmentID int
AS
UPDATE [CMS_Class] 
SET 
	ClassDisplayName = @ClassDisplayName,
	ClassName = @ClassName,
	ClassUsesVersioning = ClassUsesVersioning,
	ClassIsDocumentType = @ClassIsDocumentType,
	ClassIsCoupledClass = @ClassIsCoupledClass,
	ClassXmlSchema = @ClassXmlSchema,
	ClassFormDefinition = @ClassFormDefinition,
	ClassNewPageUrl = @ClassNewPageUrl,
	ClassEditingPageUrl = @ClassEditingPageUrl,
	ClassListPageUrl = @ClassListPageUrl,
	ClassNodeNameSource = @ClassNodeNameSource,
	ClassTableName = @ClassTableName,
	ClassViewPageUrl = @ClassViewPageUrl,
	ClassPreviewPageUrl = @ClassPreviewPageUrl,
	ClassFormLayout = @ClassFormLayout,
	ClassShowAsSystemTable = @ClassShowAsSystemTable,
	ClassUsePublishFromTo = @ClassUsePublishFromTo,
	ClassShowTemplateSelection = @ClassShowTemplateSelection,
	ClassSKUMappings = @ClassSKUMappings,
	ClassIsMenuItemType = @ClassIsMenuItemType,
	ClassNodeAliasSource = @ClassNodeAliasSource,
	ClassDefaultPageTemplateID = @ClassDefaultPageTemplateID,	
	ClassSKUDefaultDepartmentID = @ClassSKUDefaultDepartmentID
WHERE
	ClassID = @ClassID
	
GO

ALTER PROCEDURE [Proc_CMS_Role_RemoveDependences]
	@RoleID int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	
	BEGIN TRANSACTION;
	
    DELETE FROM CMS_UserRole WHERE RoleID=@RoleID;
	DELETE FROM CMS_RolePermission WHERE RoleID=@RoleID; 
	DELETE FROM CMS_ACLItem WHERE RoleID=@RoleID;
	DELETE FROM CMS_WorkflowStepRoles WHERE RoleID=@RoleID; 
    DELETE FROM FORUMS_ForumRoles WHERE RoleID = @RoleID;
	DELETE FROM Polls_PollRoles WHERE RoleID = @RoleID;

	COMMIT TRANSACTION;
END

GO 

ALTER PROCEDURE [Proc_CMS_ScheduledTask_FetchTasksToRun]
	@TaskSiteID int,
	@DateTime datetime,
	@TaskServerName nvarchar(100)
AS
BEGIN
	DECLARE @TaskIDs TABLE (TaskID int);

	BEGIN TRAN

	INSERT INTO @TaskIDs SELECT TaskID FROM CMS_ScheduledTask WHERE TaskNextRunTime IS NOT NULL AND TaskNextRunTime <= @DateTime AND TaskEnabled = 1 AND (TaskSiteID = @TaskSiteID OR TaskSiteID IS NULL) AND (TaskServerName IS NULL OR TaskServerName = '' OR TaskServerName = @TaskServerName);
	
	UPDATE CMS_ScheduledTask SET TaskNextRunTime = NULL WHERE TaskID IN (SELECT TaskID FROM @TaskIDs);

	COMMIT TRAN

	SELECT * FROM @TaskIDs;
END

GO

ALTER PROCEDURE [Proc_CMS_SettingsCategory_Insert] 
	@CategoryDisplayName nvarchar(200)
AS
BEGIN
	INSERT INTO CMS_SettingsCategory (CategoryDisplayName) VALUES (@CategoryDisplayName)
END

GO

ALTER PROCEDURE [Proc_CMS_Site_DeleteRoot]
	@SiteID int
AS
BEGIN
	-- Delete complete site workflow history
	DELETE FROM CMS_WorkflowHistory WHERE 
		VersionHistoryID IN (SELECT VersionHistoryID FROM CMS_VersionHistory WHERE 
			DocumentID IN (SELECT DocumentID FROM CMS_Document WHERE 
				DocumentNodeID IN (SELECT NodeID FROM CMS_Tree WHERE NodeSiteID=@SiteID)));

	-- Update the documents
	UPDATE CMS_Document SET DocumentCheckedOutVersionHistoryID = NULL, DocumentCheckedOutByUserID = NULL, 
		DocumentCheckedOutWhen = NULL WHERE 
			DocumentCheckedOutVersionHistoryID IN (SELECT VersionHistoryID FROM CMS_VersionHistory WHERE 
				DocumentID IN (SELECT DocumentID FROM CMS_Document WHERE 
					DocumentNodeID IN (SELECT NodeID FROM CMS_Tree WHERE NodeSiteID=@SiteID)));

	UPDATE CMS_Document SET DocumentPublishedVersionHistoryID = NULL WHERE
		DocumentPublishedVersionHistoryID IN (SELECT VersionHistoryID FROM CMS_VersionHistory WHERE 
			DocumentID IN (SELECT DocumentID FROM CMS_Document WHERE 
				DocumentNodeID IN (SELECT NodeID FROM CMS_Tree WHERE NodeSiteID=@SiteID)));

	-- Delete complete version history
	DELETE FROM CMS_VersionHistory WHERE 
		DocumentID IN (SELECT DocumentID FROM CMS_Document WHERE 
			DocumentNodeID IN (SELECT NodeID FROM CMS_Tree WHERE NodeSiteID=@SiteID));

	-- Delete the document data
	DELETE FROM CMS_Document WHERE 
		DocumentNodeID IN (SELECT NodeID FROM CMS_Tree WHERE NodeSiteID=@SiteID);

	-- Delete root eventlog data
	DELETE FROM CMS_EventLog WHERE NodeID IN (SELECT NodeID FROM CMS_Tree WHERE NodeSiteID=@SiteID);

	-- Delete the node data
	DELETE FROM CMS_Tree WHERE NodeSiteID=@SiteID;
END

GO

ALTER PROCEDURE [Proc_CMS_Site_RemoveDependences] 
	@SiteID int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	-- removes VersionHistory dependences from VersionAttachment
	DELETE FROM [CMS_VersionAttachment] WHERE VersionHistoryID IN (
		SELECT VersionHistoryID FROM [CMS_VersionHistory] WHERE NodeSiteID = @SiteID
	);
	-- removes VersionHistory dependences from WorkflowHistory
	DELETE FROM [CMS_WorkflowHistory] WHERE VersionHistoryID IN (
		SELECT VersionHistoryID FROM [CMS_VersionHistory] WHERE NodeSiteID = @SiteID
	);
	-- deletes site's VersionHistory
	DELETE FROM [CMS_VersionHistory] WHERE NodeSiteID = @SiteID;

	-- deletes site's SettingKeys
	DELETE FROM [CMS_SettingsKey] WHERE SiteID=@SiteID;
	-- deletes site's EmailTemplates
	DELETE FROM [CMS_EmailTemplate] WHERE EmailTemplateSiteID=@SiteID;
	-- deletes site's DomainAliases
	DELETE FROM [CMS_SiteDomainAlias] WHERE SiteID=@SiteID;
	-- deletes site's cultures
	DELETE FROM [CMS_SiteCulture] WHERE SiteID=@SiteID;
	-- deletes site's PageTemplates
	DELETE FROM [CMS_PageTemplateSite] WHERE SiteID=@SiteID;
	-- deletes site's Users
	DELETE FROM [CMS_UserSite] WHERE SiteID=@SiteID;

	-- removes Role's dependences when site's Roles are deleted
	DELETE FROM [Forums_ForumRoles ] WHERE RoleID IN (
		SELECT RoleID FROM [CMS_Role] WHERE SiteID = @SiteID
	);
	DELETE FROM [CMS_UserRole] WHERE RoleID IN (
		SELECT RoleID FROM [CMS_Role] WHERE SiteID=@SiteID
	);
	DELETE FROM [CMS_RolePermission] WHERE RoleID IN (
		SELECT RoleID FROM [CMS_Role] WHERE SiteID=@SiteID
	);
	DELETE FROM [CMS_WorkflowStepRoles] WHERE RoleID IN (
		SELECT RoleID FROM [CMS_Role] WHERE SiteID=@SiteID
	);
	DELETE FROM [Polls_PollRoles] WHERE RoleID IN (
		SELECT RoleID FROM [CMS_Role] WHERE SiteID = @SiteID
	);
	-- deletes site's Roles
	DELETE FROM [CMS_Role] WHERE SiteID=@SiteID;
	-- deletes site's Resources
	DELETE FROM [CMS_ResourceSite] WHERE SiteID=@SiteID;
	-- deletes site's Classes
	DELETE FROM [CMS_ClassSite] WHERE SiteID=@SiteID;
	-- deletes Events of the site
	DELETE FROM [CMS_EventLog] WHERE SiteID=@SiteID;
	-- deletes site's RelationshipNames
	DELETE FROM [CMS_RelationshipNameSite] WHERE SiteID=@SiteID;
	-- deletes site's WorkflowScopes
	DELETE FROM [CMS_WorkflowScope] WHERE ScopeSiteID=@SiteID;
	-- deletes site's CSSStylesheets
	DELETE FROM CMS_CssStylesheetSite WHERE SiteID=@SiteID;
	-- deletes site's InlineControls
	DELETE FROM [CMS_InlineControlSite] WHERE SiteID=@SiteID;
	-- deletes site's ScheduledTasks
	DELETE FROM [CMS_ScheduledTask] WHERE TaskSiteID=@SiteID;
	-- remove site's assignment to Polls
	DELETE FROM [Polls_PollSite] WHERE SiteID=@SiteID;
	
	-- removes Newsletter_Subscriber's dependences when site's Newsletter_Subscribers are deleted
	DELETE FROM [Newsletter_Emails] WHERE EmailSubscriberID IN (
		SELECT SubscriberID FROM [Newsletter_Subscriber] WHERE SubscriberSiteID=@SiteID
	);
	DELETE FROM [Newsletter_SubscriberNewsletter] WHERE SubscriberID IN (
		SELECT SubscriberID FROM [Newsletter_Subscriber] WHERE SubscriberSiteID=@SiteID
	);
	-- deletes site's Newsletter_Subscribers
	DELETE FROM [Newsletter_Subscriber] WHERE SubscriberSiteID=@SiteID;
	-- removes Newsletter_Newsletter's dependences when site's Newsletter_Newsletters are deleted
	DELETE FROM [Newsletter_Emails] WHERE EmailNewsletterIssueID IN (
		SELECT IssueID FROM [Newsletter_NewsletterIssue] WHERE IssueNewsletterID IN (
			SELECT NewsletterID FROM [Newsletter_Newsletter] WHERE NewsletterSiteID=@SiteID
		)
	);
	DELETE FROM [Newsletter_NewsletterIssue] WHERE IssueNewsletterID IN (
		SELECT NewsletterID FROM [Newsletter_Newsletter] WHERE NewsletterSiteID=@SiteID
	);
	DELETE FROM [Newsletter_SubscriberNewsletter] WHERE NewsletterID IN (
		SELECT NewsletterID FROM [Newsletter_Newsletter] WHERE NewsletterSiteID=@SiteID
	);
	-- deletes site's Newsletter_Newsletters
	DELETE FROM [Newsletter_Newsletter] WHERE NewsletterSiteID=@SiteID;
	-- removes Newsletter_EmailTemplate's dependences when site's Newsletter_EmailTemplates are deleted
	DELETE FROM [Newsletter_Emails] WHERE EmailNewsletterIssueID IN (
		SELECT IssueID FROM [Newsletter_NewsletterIssue] WHERE IssueTemplateID IN (
			SELECT TemplateID FROM [Newsletter_EmailTemplate] WHERE TemplateSiteID=@SiteID
		)
	);
	DELETE FROM [Newsletter_NewsletterIssue] WHERE IssueTemplateID IN (
			SELECT TemplateID FROM [Newsletter_EmailTemplate] WHERE TemplateSiteID=@SiteID
	);
	-- deletes site's Newsletter_EmailTemplates
	DELETE FROM [Newsletter_EmailTemplate] WHERE TemplateSiteID=@SiteID;
	-- removes CMS_Class's dependences when BizForms are deleted
	DELETE FROM [CMS_Query] WHERE ClassID IN (
		SELECT FormClassID FROM [CMS_Form] WHERE FormSiteID=@SiteID
	);
	-- insert ClassIDs of BizForms into the temporaty table
	SELECT FormClassID INTO [TempTable] FROM [CMS_Form] WHERE FormSiteID=@SiteID;
	-- deletes site's BizForms from CMS_Form
	DELETE FROM [CMS_Form] WHERE FormSiteID=@SiteID;
	-- deletes BizForm's records in CMS_Class
	DELETE FROM [CMS_Class] WHERE ClassID IN (
		SELECT FormClassID FROM [TempTable]
	);

	-- FORUM
	UPDATE [Forums_ForumPost]  SET PostParentID=NULL WHERE PostForumId IN (
		SELECT ForumID FROM [Forums_Forum] WHERE ForumGroupID IN (
		SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID
		));

	DELETE FROM [Forums_ForumPost] WHERE PostForumId IN (
		SELECT ForumID FROM [Forums_Forum] WHERE ForumGroupID IN (
		SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID)
	);

	DELETE FROM [Forums_ForumRoles ] WHERE ForumId IN (
		SELECT ForumID FROM [Forums_Forum] WHERE ForumGroupID IN (
		SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID)
	);

	DELETE FROM [Forums_ForumModerators] WHERE ForumID IN (
		SELECT ForumID FROM [Forums_Forum] WHERE ForumGroupID  IN (
		SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID)
	);

	DELETE FROM [Forums_ForumSubscription] WHERE SubscriptionForumId IN (
		SELECT ForumID FROM [Forums_Forum] WHERE ForumGroupID  IN (
		SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID)
	);
	
	DELETE FROM [Forums_Forum] WHERE ForumGroupId  IN (
		SELECT GroupID FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID);	

	DELETE FROM [Forums_ForumGroup] WHERE GroupSiteID = @SiteID;

	-- delete Staging dependences
	DELETE FROM [Staging_Synchronization] WHERE SynchronizationTaskID IN (
		SELECT TaskID FROM [Staging_Task] WHERE TaskSiteID = @SiteID
	);

	DELETE FROM [Staging_SyncLog] WHERE SyncLogTaskID IN (
		SELECT TaskID FROM [Staging_Task] WHERE TaskSiteID = @SiteID
	);
	-- delete StagingTasks
	DELETE FROM [Staging_Task] WHERE TaskSiteID = @SiteID;

	-- ECOMMERCE
	-- delete COM_ShoppingCart dependences
	DELETE FROM [COM_ShoppingCartSKU] WHERE ShoppingCartID IN (
		SELECT ShoppingCartID FROM [COM_ShoppingCart] WHERE ShoppingCartSiteID = @SiteID
	);
	-- delete COM_ShoppingCart
	DELETE FROM [COM_ShoppingCart] WHERE ShoppingCartSiteID = @SiteID;

	-- delete COM_Order dependences
	DELETE FROM [COM_OrderStatusUser] WHERE OrderID IN (
		SELECT OrderID FROM [COM_Order] WHERE OrderSiteID = @SiteID
	);
	DELETE FROM [COM_OrderItem] WHERE OrderItemOrderID IN (
		SELECT OrderID FROM [COM_Order] WHERE OrderSiteID = @SiteID
	);
	-- delete COM_Order
	DELETE FROM [COM_Order] WHERE OrderSiteID = @SiteID;

	-- delete COM_ShippingOption dependences
	DELETE FROM [COM_ShoppingCart] WHERE ShoppingCartShippingOptionID IN (
		SELECT ShippingOptionID FROM [COM_ShippingOption] WHERE ShippingOptionSiteID = @SiteID
	);
	UPDATE [COM_Customer] SET CustomerPreferredShippingOptionID=NULL WHERE CustomerPreferredShippingOptionID IN (
		SELECT ShippingOptionID FROM [COM_ShippingOption] WHERE ShippingOptionSiteID = @SiteID
	);
	DELETE FROM [COM_PaymentShipping] WHERE ShippingOptionID IN (
		SELECT ShippingOptionID FROM [COM_ShippingOption] WHERE ShippingOptionSiteID = @SiteID
	);
	-- delete COM_ShippingOption
	DELETE FROM [COM_ShippingOption] WHERE ShippingOptionSiteID = @SiteID;

	-- delete COM_PaymentOption dependences
	DELETE FROM [COM_ShoppingCart] WHERE ShoppingCartPaymentOptionID IN (
		SELECT PaymentOptionID FROM [COM_PaymentOption] WHERE PaymentOptionSiteID = @SiteID
	);
	UPDATE [COM_Customer] SET CustomerPrefferedPaymentOptionID=NULL WHERE CustomerPrefferedPaymentOptionID IN (
		SELECT PaymentOptionID FROM [COM_PaymentOption] WHERE PaymentOptionSiteID = @SiteID
	);
	DELETE FROM [COM_PaymentShipping] WHERE PaymentOptionID IN (
		SELECT PaymentOptionID FROM [COM_PaymentOption] WHERE PaymentOptionSiteID = @SiteID
	);
	-- delete COM_PaymentOption
	DELETE FROM [COM_PaymentOption] WHERE PaymentOptionSiteID = @SiteID;

	-- WEB ANALYTICS
	-- delete Analytics_Statistics dependences
	DELETE FROM Analytics_DayHits WHERE HitsStatisticsID IN (
		SELECT StatisticsID FROM Analytics_Statistics WHERE StatisticsSiteID=@SiteID);
	DELETE FROM Analytics_HourHits WHERE HitsStatisticsID IN (
		SELECT StatisticsID FROM Analytics_Statistics WHERE StatisticsSiteID=@SiteID);
	DELETE FROM Analytics_MonthHits WHERE HitsStatisticsID IN (
		SELECT StatisticsID FROM Analytics_Statistics WHERE StatisticsSiteID=@SiteID);
	DELETE FROM Analytics_WeekHits WHERE HitsStatisticsID IN (
		SELECT StatisticsID FROM Analytics_Statistics WHERE StatisticsSiteID=@SiteID);
	DELETE FROM Analytics_YearHits WHERE HitsStatisticsID IN (
		SELECT StatisticsID FROM Analytics_Statistics WHERE StatisticsSiteID=@SiteID);

	-- delete Analytics_Statistics
	DELETE FROM Analytics_Statistics WHERE StatisticsSiteID=@SiteID;

	-- POLLS
	DELETE FROM Polls_PollSite WHERE SiteID=@SiteID;

	-- drops temporary table
	DROP TABLE [TempTable];
END

GO

ALTER PROCEDURE [proc_CMS_Tree_InitNodeOrders]
	@NodeParentID int
AS
BEGIN
	/* Declare the selection table */
	DECLARE @nodesTable TABLE (
		NodeID int,
		NodeOrder int,
		NodeName nvarchar(100),
		NodeAlias nvarchar(50)
	);
	
	/* Get the nodes list */
	INSERT INTO @nodesTable SELECT NodeID, NodeOrder, NodeName, NodeAlias FROM CMS_Tree WHERE NodeParentID = @NodeParentID;
	
	/* Declare the cursor to loop through the table */
	DECLARE @nodeCursor CURSOR;
    SET @nodeCursor = CURSOR FOR SELECT NodeID, NodeOrder FROM @nodesTable ORDER BY NodeOrder ASC, NodeName ASC, NodeAlias ASC;
	/* Assign the numbers to the nodes */
	DECLARE @currentIndex int, @currentNodeOrder int;
	SET @currentIndex = 1;
	DECLARE @currentNodeId int;
	
	/* Loop through the table */
	OPEN @nodeCursor
	FETCH NEXT FROM @nodeCursor INTO @currentNodeId, @currentNodeOrder;
	WHILE @@FETCH_STATUS = 0
	BEGIN
		/* Set the Node index if different */
		IF @currentNodeOrder IS NULL OR @currentNodeOrder <> @currentIndex
			UPDATE CMS_Tree SET NodeOrder = @currentIndex WHERE NodeId = @currentNodeId;
		/* Get next record */
		SET @currentIndex = @currentIndex + 1;
		FETCH NEXT FROM @nodeCursor INTO @currentNodeId, @currentNodeOrder;
	END
	CLOSE @nodeCursor;
	DEALLOCATE @nodeCursor;

	RETURN @currentIndex;
END

GO

ALTER PROCEDURE [Proc_CMS_Tree_SelectParentCacheNode]
	@SiteID int,
	@NodeAliasPath nvarchar(450)
AS
BEGIN
SELECT TOP 1 * FROM CMS_Tree WHERE
	(NodeSiteID=@SiteID AND NodeCacheMinutes IS NOT NULL AND (NodeAliasPath='/' OR @NodeAliasPath LIKE NodeAliasPath+'/%')) ORDER BY NodeAliasPath DESC
END

GO

ALTER PROCEDURE [Proc_CMS_Tree_SelectParentWithPageTemplate]
	@SiteID int,
	@CultureCode nvarchar(20),
	@NodeAliasPath nvarchar(450)
AS
BEGIN
	SELECT TOP 1 * FROM View_CMS_Tree_Joined INNER JOIN CMS_PageTemplate ON View_CMS_Tree_Joined.DocumentPageTemplateID=CMS_PageTemplate.PageTemplateID WHERE
	(NodeSiteID=@SiteID AND DocumentCulture=@CultureCode AND DocumentPageTemplateID IS NOT NULL AND (NodeAliasPath='/' OR @NodeAliasPath LIKE NodeAliasPath+'/%')) ORDER BY NodeAliasPath DESC
END

GO

ALTER PROCEDURE [Proc_CMS_Tree_SelectParentWithSecuredNode]
	@SiteID int,
	@NodeAliasPath nvarchar(450)
AS
BEGIN
SELECT TOP 1 * FROM CMS_Tree WHERE
	(NodeSiteID=@SiteID AND IsSecuredNode IS NOT NULL AND (NodeAliasPath='/' OR @NodeAliasPath LIKE NodeAliasPath+'/%')) ORDER BY NodeAliasPath DESC
END

GO

ALTER PROCEDURE [Proc_CMS_Tree_SelectParentWithSSLNode]
	@SiteID int,
	@NodeAliasPath nvarchar(450)
AS
BEGIN
SELECT TOP 1 * FROM CMS_Tree WHERE
	(NodeSiteID=@SiteID AND RequiresSSL IS NOT NULL AND (NodeAliasPath='/' OR @NodeAliasPath LIKE NodeAliasPath+'/%')) ORDER BY NodeAliasPath DESC
END

GO

ALTER PROCEDURE [Proc_CMS_User_RemoveDependences]
	@ID int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	BEGIN TRANSACTION;
	-- deletes dependences in CMS_UserSite and CMS_UserRole
    DELETE FROM [CMS_UserSite] WHERE UserID=@ID;
	DELETE FROM [CMS_UserRole] WHERE UserID=@ID;
	-- delete dependences in Forums_ForumModerators
	DELETE FROM [Forums_ForumModerators] WHERE UserID=@ID;
	-- updates dependences in CMS_EventLog, CMC_Document, CMS_VersionHistory and CMS_WorkflowHistory
	UPDATE [CMS_Document] SET DocumentCreatedByUserID=NULL WHERE DocumentCreatedByUserID=@ID;
	UPDATE [CMS_Document] SET DocumentCheckedOutByUserID=NULL WHERE DocumentCheckedOutByUserID=@ID;
	UPDATE [CMS_Document] SET DocumentModifiedByUserID=NULL WHERE DocumentModifiedByUserID=@ID;
	UPDATE [CMS_EventLog] SET UserID=NULL WHERE UserID=@ID
	UPDATE CMS_VersionHistory SET ModifiedByUserID=NULL WHERE ModifiedByUserID=@ID;
	UPDATE CMS_WorkflowHistory SET ApprovedByUserID=NULL WHERE ApprovedByUserID=@ID;
	-- remove dependences in NodeOwner
	UPDATE [CMS_Tree] SET NodeOwner=NULL WHERE NodeOwner=@ID;
	-- remove dependences in CMS_ACLItem
	DELETE FROM CMS_ACLItem WHERE UserID = @ID;
	UPDATE CMS_ACLItem SET LastModifiedByUserID=NULL WHERE LastModifiedByUserID=@ID;
	-- update dependences in COM_Customer, COM_OrderStatusUser, COM_ShoppingCart
	UPDATE COM_Customer SET CustomerUserID=NULL WHERE CustomerUserID=@ID;
	UPDATE COM_OrderStatusUser SET ChangedByUserID=NULL WHERE ChangedByUserID=@ID;
	UPDATE COM_ShoppingCart SET ShoppingCartUserID=NULL WHERE ShoppingCartUserID=@ID;
	-- remove dependences in COM_UserDepartment
	DELETE FROM COM_UserDepartment WHERE UserID=@ID;
	-- remove dependences in [COM_Wishlist]
	DELETE FROM [COM_Wishlist] WHERE UserID=@ID;
	
	-- set null to saved reports
	UPDATE Reporting_SavedReport SET SavedReportCreatedByUserID = NULL WHERE SavedReportCreatedByUserID=@ID

	-- set null to checkouted templates, layouts and css styles
	UPDATE CMS_PageTemplate SET PageTemplateLayoutCheckedOutByUserID = NULL WHERE PageTemplateLayoutCheckedOutByUserID = @ID;
	UPDATE CMS_Layout SET LayoutCheckedOutByUserID = NULL WHERE LayoutCheckedOutByUserID=@ID;
	UPDATE CMS_CssStyleSheet SET StylesheetCheckedOutByUserID = NULL WHERE StylesheetCheckedOutByUserID=@ID;

	-- Blog_Comment - set CommentUserID a CommentApprovedByUserID to null
	UPDATE Blog_Comment SET CommentUserID = NULL WHERE CommentUserID=@ID;
	UPDATE Blog_Comment SET CommentApprovedByUserID = NULL WHERE CommentApprovedByUserID=@ID;

	COMMIT TRANSACTION;
END

GO

ALTER PROCEDURE [Proc_COM_SKU_RemoveDependences]
	@ID int
AS
BEGIN
	UPDATE [CMS_TREE] SET NODESKUID=NULL WHERE NODESKUID=@ID;
	DELETE FROM [COM_ShoppingCartSKU] WHERE SKUID=@ID;
	DELETE FROM [COM_SKUTaxClasses] WHERE SKUID=@ID;
	DELETE FROM [COM_SKUDiscountCoupon] WHERE SKUID=@ID;
	DELETE FROM [COM_Wishlist] WHERE SKUID=@ID;
	DELETE FROM [COM_VolumeDiscount] WHERE VolumeDiscountSKUID=@ID;
END

GO

ALTER PROCEDURE [Proc_COM_TaxClasses_RemoveDependences]
	@TaxClassID int
AS
BEGIN
	DELETE FROM COM_TaxClassCountry WHERE [TaxClassID] = @TaxClassID;
	DELETE FROM COM_TaxClassState   WHERE [TaxClassID] = @TaxClassID;
	DELETE FROM [COM_SKUTaxClasses] WHERE [TaxClassID] = @TaxClassID;
END

GO

ALTER PROCEDURE [Proc_Ecommerce_Order_RemoveDependences]
	@OrderID int
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;
	BEGIN TRANSACTION;

	-- COM_OrderItem - Deleted by special method
	--DELETE FROM COM_OrderItem WHERE OrderItemOrderID = @OrderID;

	-- COM_OrderStatusUser
	DELETE FROM COM_OrderStatusUser WHERE OrderID = @OrderID;

	COMMIT TRANSACTION;
END

GO

-------------------------------------------------------- Views

DROP VIEW View_CMS_Tree_Joined 
GO 

CREATE VIEW View_CMS_Tree_Joined
AS
SELECT     CASE WHEN ((DocumentCheckedOutVersionHistoryID IS NULL AND DocumentPublishedVersionHistoryID IS NULL) OR
                      (DocumentCheckedOutVersionHistoryID IS NOT NULL AND DocumentPublishedVersionHistoryID IS NOT NULL)) AND (DocumentPublishFrom IS NULL OR
                      (DocumentPublishFrom IS NOT NULL AND DocumentPublishFrom <= getdate())) AND (DocumentPublishTo IS NULL OR
                      (DocumentPublishTo IS NOT NULL AND DocumentPublishTo >= getdate())) AND ((StepName <> 'archived') OR
                      (StepName IS NULL)) THEN 1 ELSE 0 END AS Published, CMS_Site.SiteName, CMS_Class.ClassName, CMS_Class.ClassDisplayName, 
                      CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentModifiedWhen, CMS_Document.DocumentModifiedByUserID, CMS_Document.DocumentForeignKeyValue, 
                      CMS_Document.DocumentCreatedByUserID, CMS_Document.DocumentCreatedWhen, CMS_Document.DocumentCheckedOutByUserID, 
                      CMS_Document.DocumentCheckedOutWhen, CMS_Document.DocumentCheckedOutVersionHistoryID, 
                      CMS_Document.DocumentPublishedVersionHistoryID, CMS_Document.DocumentWorkflowStepID, CMS_Document.DocumentPublishFrom, 
                      CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, CMS_Document.DocumentCulture, 
                      CMS_Document.DocumentNodeID, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentShowInSiteMap, 
                      CMS_Document.DocumentMenuItemHideInNavigation, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentMenuStyle, 
                      CMS_Document.DocumentMenuItemImage, CMS_Document.DocumentMenuItemLeftImage, 
                      CMS_Document.DocumentMenuItemRightImage, CMS_Document.DocumentPageTemplateID, CMS_Document.DocumentMenuJavascript, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_Document.DocumentUseNamePathForUrlPath, CMS_Document.DocumentStylesheetID, 
                      CMS_Document.DocumentContent, CMS_Tree.IsSecuredNode, CMS_Document.DocumentMenuClass, 
                      CMS_Document.DocumentMenuStyleOver, CMS_Document.DocumentMenuClassOver, CMS_Document.DocumentMenuItemImageOver, 
                      CMS_Document.DocumentMenuItemLeftImageOver, CMS_Document.DocumentMenuItemRightImageOver, 
                      CMS_Document.DocumentMenuStyleHighlighted, CMS_Document.DocumentMenuClassHighlighted, 
                      CMS_Document.DocumentMenuItemImageHighlighted, CMS_Document.DocumentMenuItemLeftImageHighlighted, 
                      CMS_Document.DocumentMenuItemRightImageHighlighted, CMS_Tree.NodeCacheMinutes, CMS_Tree.NodeSKUID, 
                      CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, COM_SKU.SKUID, COM_SKU.SKUNumber, COM_SKU.SKUName, 
                      COM_SKU.SKUDescription, COM_SKU.SKUPrice, COM_SKU.SKUEnabled, COM_SKU.SKUDepartmentID, COM_SKU.SKUManufacturerID, 
                      COM_SKU.SKUInternalStatusID, COM_SKU.SKUPublicStatusID, COM_SKU.SKUSupplierID, COM_SKU.SKUAvailableInDays, COM_SKU.SKUGUID, 
                      CMS_Tree.NodeInheritPageLevels, CMS_Document.DocumentMenuItemInactive, CMS_Tree.NodeChildNodesCount, 
                      CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, CMS_Tree.NodeOwner, 
                      CMS_Tree.NodeCustomData, CMS_Document.DocumentCustomData
FROM         CMS_Tree INNER JOIN
                      CMS_Document ON CMS_Tree.NodeLinkedNodeID IS NOT NULL AND 
                      CMS_Tree.NodeLinkedNodeID = CMS_Document.DocumentNodeID OR CMS_Tree.NodeLinkedNodeID IS NULL AND 
                      CMS_Tree.NodeID = CMS_Document.DocumentNodeID INNER JOIN
                      CMS_Site ON CMS_Tree.NodeSiteID = CMS_Site.SiteID INNER JOIN
                      CMS_Class ON CMS_Tree.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_WorkflowStep ON CMS_Document.DocumentWorkflowStepID = CMS_WorkflowStep.StepID LEFT OUTER JOIN
                      View_COM_SKU AS COM_SKU ON CMS_Tree.NodeSKUID = COM_SKU.SKUID
GO	

DROP VIEW View_CMS_Tree_Joined_Versions 
GO 

CREATE VIEW View_CMS_Tree_Joined_Versions
AS
SELECT     CASE WHEN ((DocumentCheckedOutVersionHistoryID IS NULL AND DocumentPublishedVersionHistoryID IS NULL) OR
                      (DocumentCheckedOutVersionHistoryID IS NOT NULL AND DocumentPublishedVersionHistoryID IS NOT NULL)) AND (DocumentPublishFrom IS NULL OR
                      (DocumentPublishFrom IS NOT NULL AND DocumentPublishFrom <= getdate())) AND (DocumentPublishTo IS NULL OR
                      (DocumentPublishTo IS NOT NULL AND DocumentPublishTo >= getdate())) AND ((StepName <> 'archived') OR
                      (StepName IS NULL)) THEN 1 ELSE 0 END AS Published, CMS_Site.SiteName, CMS_Class.ClassName, CMS_Class.ClassDisplayName, 
                      CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentModifiedWhen, CMS_Document.DocumentModifiedByUserID, CMS_Document.DocumentForeignKeyValue, 
                      CMS_Document.DocumentCreatedByUserID, CMS_Document.DocumentCreatedWhen, CMS_Document.DocumentCheckedOutByUserID, 
                      CMS_Document.DocumentCheckedOutWhen, CMS_Document.DocumentCheckedOutVersionHistoryID, 
                      CMS_Document.DocumentPublishedVersionHistoryID, CMS_Document.DocumentWorkflowStepID, CMS_Document.DocumentPublishFrom, 
                      CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, CMS_Document.DocumentCulture, 
                      CMS_Document.DocumentNodeID, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentShowInSiteMap, 
                      CMS_Document.DocumentMenuItemHideInNavigation, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentMenuStyle, 
                      CMS_Document.DocumentMenuItemImage, CMS_Document.DocumentMenuItemLeftImage, 
                      CMS_Document.DocumentMenuItemRightImage, CMS_Document.DocumentPageTemplateID, CMS_Document.DocumentMenuJavascript, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_Document.DocumentUseNamePathForUrlPath, CMS_Document.DocumentStylesheetID, 
                      CMS_Document.DocumentContent, CMS_VersionHistory.NodeXML, CMS_Tree.IsSecuredNode, CMS_Document.DocumentMenuClass, 
                      CMS_Document.DocumentMenuStyleOver, CMS_Document.DocumentMenuClassOver, CMS_Document.DocumentMenuItemImageOver, 
                      CMS_Document.DocumentMenuItemLeftImageOver, CMS_Document.DocumentMenuItemRightImageOver, 
                      CMS_Document.DocumentMenuStyleHighlighted, CMS_Document.DocumentMenuClassHighlighted, 
                      CMS_Document.DocumentMenuItemImageHighlighted, CMS_Document.DocumentMenuItemLeftImageHighlighted, 
                      CMS_Document.DocumentMenuItemRightImageHighlighted, CMS_Tree.NodeCacheMinutes, CMS_Tree.NodeSKUID, 
                      CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, COM_SKU.SKUID, COM_SKU.SKUNumber, COM_SKU.SKUName, 
                      COM_SKU.SKUDescription, COM_SKU.SKUPrice, COM_SKU.SKUEnabled, COM_SKU.SKUDepartmentID, COM_SKU.SKUManufacturerID, 
                      COM_SKU.SKUInternalStatusID, COM_SKU.SKUPublicStatusID, COM_SKU.SKUSupplierID, COM_SKU.SKUAvailableInDays, COM_SKU.SKUGUID, 
                      CMS_Tree.NodeInheritPageLevels, CMS_Document.DocumentMenuItemInactive, CMS_Tree.NodeChildNodesCount, 
                      CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, CMS_Tree.NodeOwner, 
                      CMS_Tree.NodeCustomData, CMS_Document.DocumentCustomData
FROM         CMS_Tree INNER JOIN
                      CMS_Document ON CMS_Tree.NodeLinkedNodeID IS NOT NULL AND 
                      CMS_Tree.NodeLinkedNodeID = CMS_Document.DocumentNodeID OR CMS_Tree.NodeLinkedNodeID IS NULL AND 
                      CMS_Tree.NodeID = CMS_Document.DocumentNodeID INNER JOIN
                      CMS_Site ON CMS_Tree.NodeSiteID = CMS_Site.SiteID INNER JOIN
                      CMS_Class ON CMS_Tree.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_VersionHistory ON 
                      CMS_Document.DocumentCheckedOutVersionHistoryID = CMS_VersionHistory.VersionHistoryID LEFT OUTER JOIN
                      CMS_WorkflowStep ON CMS_Document.DocumentWorkflowStepID = CMS_WorkflowStep.StepID LEFT OUTER JOIN
                      View_COM_SKU AS COM_SKU ON CMS_Tree.NodeSKUID = COM_SKU.SKUID

GO

DROP VIEW View_COM_Order_Joined
GO

CREATE VIEW View_COM_Order_Joined
AS
SELECT     COM_Order.OrderID, COM_Order.OrderBillingAddressID, COM_Order.OrderShippingAddressID, COM_Order.OrderShippingOptionID, 
                      COM_Order.OrderTotalShipping, COM_Order.OrderTotalPrice, COM_Order.OrderTotalTax, COM_Order.OrderDate, 
                      COM_Order.OrderStatusID, COM_Order.OrderCurrencyID, COM_Order.OrderCustomerID, COM_Order.OrderCreatedByUserID, 
                      COM_Order.OrderNote, COM_Order.OrderSiteID, COM_Order.OrderPaymentOptionID, COM_Order.OrderInvoice, 
                      COM_Order.OrderInvoiceNumber, COM_Order.OrderDiscountCouponID, COM_Customer.CustomerID, 
                      COM_Customer.CustomerFirstName, COM_Customer.CustomerLastName, COM_Customer.CustomerEmail, 
                      COM_Customer.CustomerPhone, COM_Customer.CustomerFax, COM_Customer.CustomerCompany, COM_Customer.CustomerUserID, 
                      COM_Customer.CustomerPreferredCurrencyID, COM_Customer.CustomerPreferredShippingOptionID, COM_Customer.CustomerCountryID, 
                      COM_Customer.CustomerEnabled, COM_Customer.CustomerPrefferedPaymentOptionID, COM_Customer.CustomerStateID, 
                      COM_Customer.CustomerGUID, COM_Customer.CustomerTaxRegistrationID, COM_Customer.CustomerOrganizationID, 
                      COM_OrderStatus.StatusID, COM_OrderStatus.StatusName, COM_OrderStatus.StatusDisplayName, COM_OrderStatus.StatusOrder, 
                      COM_OrderStatus.StatusEnabled, COM_Currency.CurrencyID, COM_Currency.CurrencyName, COM_Currency.CurrencyDisplayName, 
                      COM_Currency.CurrencyCode, COM_Currency.CurrencyRoundTo, COM_Currency.CurrencyEnabled, 
                      COM_Currency.CurrencyFormatString, COM_Currency.CurrencyIsMain, COM_OrderStatus.StatusColor
FROM         COM_Order INNER JOIN
                      COM_Customer ON COM_Order.OrderCustomerID = COM_Customer.CustomerID INNER JOIN
                      COM_OrderStatus ON COM_Order.OrderStatusID = COM_OrderStatus.StatusID INNER JOIN
                      COM_Currency ON COM_Order.OrderCurrencyID = COM_Currency.CurrencyID
GO


DROP VIEW View_PageInfo
GO

CREATE VIEW View_PageInfo
AS
SELECT     CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentPublishFrom, CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, 
                      CMS_Document.DocumentCulture, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentPageTemplateID, 
                      CMS_PageTemplate.PageTemplateID, CMS_PageTemplate.PageTemplateDisplayName, CMS_PageTemplate.PageTemplateDescription, 
                      CMS_PageTemplate.PageTemplateFile, CMS_PageTemplate.PageTemplateIsPortal, CMS_PageTemplate.PageTemplateCategoryID, 
                      CMS_PageTemplate.PageTemplateLayoutID, CMS_PageTemplate.PageTemplateWebParts, 
                      CMS_PageTemplate.PageTemplateIsReusable, CMS_Class.ClassName, CMS_Document.DocumentContent, 
                      CMS_PageTemplate.PageTemplateCodeName, CMS_Document.DocumentStylesheetID, CMS_Tree.IsSecuredNode, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_PageTemplate.PageTemplateInheritPageLevels, 
                      CMS_PageTemplate.PageTemplateShowAsMasterTemplate, CMS_Document.DocumentMenuJavascript, CMS_Tree.NodeCacheMinutes, 
                      CMS_Tree.NodeSKUID, CMS_Tree.NodeSKUID AS Expr1, CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, 
                      CMS_Tree.NodeInheritPageLevels, CMS_PageTemplate.PageTemplateLayout, 
                      CMS_PageTemplate.PageTemplateLayoutCheckedOutFileName, CMS_PageTemplate.PageTemplateLayoutCheckedOutByUserID, 
                      CMS_PageTemplate.PageTemplateLayoutCheckedOutMachineName, CMS_Document.DocumentMenuItemInactive, 
                      CMS_Document.DocumentMenuStyle, CMS_Document.DocumentMenuItemHideInNavigation, CMS_Tree.NodeChildNodesCount, 
                      CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, CMS_Tree.NodeOwner, 
                      CMS_Document.DocumentMenuClass
FROM         CMS_Tree INNER JOIN
                      CMS_Document ON CMS_Tree.NodeLinkedNodeID IS NOT NULL AND 
                      CMS_Tree.NodeLinkedNodeID = CMS_Document.DocumentNodeID OR CMS_Tree.NodeLinkedNodeID IS NULL AND 
                      CMS_Tree.NodeID = CMS_Document.DocumentNodeID INNER JOIN
                      CMS_Class ON CMS_Tree.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_PageTemplate ON CMS_Document.DocumentPageTemplateID = CMS_PageTemplate.PageTemplateID
GO

					  
DROP VIEW View_PageInfo_Blank
GO

CREATE VIEW View_PageInfo_Blank
AS
SELECT     CMS_Tree.NodeID, CMS_Tree.NodeAliasPath, CMS_Tree.NodeName, CMS_Tree.NodeAlias, CMS_Tree.NodeClassID, 
                      CMS_Tree.NodeParentID, CMS_Tree.NodeLevel, CMS_Tree.NodeACLID, CMS_Tree.NodeSiteID, CMS_Tree.NodeGUID, 
                      CMS_Tree.NodeOrder, CMS_Document.DocumentID, CMS_Document.DocumentName, CMS_Document.DocumentNamePath, 
                      CMS_Document.DocumentPublishFrom, CMS_Document.DocumentPublishTo, CMS_Document.DocumentUrlPath, 
                      CMS_Document.DocumentCulture, CMS_Document.DocumentPageTitle, CMS_Document.DocumentPageKeyWords, 
                      CMS_Document.DocumentPageDescription, CMS_Document.DocumentMenuCaption, CMS_Document.DocumentPageTemplateID, 
                      CMS_PageTemplate.PageTemplateID, CMS_PageTemplate.PageTemplateDisplayName, CMS_PageTemplate.PageTemplateDescription, 
                      CMS_PageTemplate.PageTemplateFile, CMS_PageTemplate.PageTemplateIsPortal, CMS_PageTemplate.PageTemplateCategoryID, 
                      CMS_PageTemplate.PageTemplateLayoutID, CMS_PageTemplate.PageTemplateWebParts, 
                      CMS_PageTemplate.PageTemplateIsReusable, CMS_Class.ClassName, CMS_Document.DocumentContent, 
                      CMS_PageTemplate.PageTemplateCodeName, CMS_Document.DocumentStylesheetID, CMS_Tree.IsSecuredNode, 
                      CMS_Document.DocumentMenuRedirectUrl, CMS_PageTemplate.PageTemplateInheritPageLevels, 
                      CMS_PageTemplate.PageTemplateShowAsMasterTemplate, CMS_Document.DocumentMenuJavascript, CMS_Tree.NodeCacheMinutes, 
                      CMS_Tree.NodeSKUID, CMS_Tree.NodeSKUID AS Expr1, CMS_Tree.NodeDocType, CMS_Tree.NodeHeadTags, 
                      CMS_Tree.NodeInheritPageLevels, CMS_PageTemplate.PageTemplateLayout, 
                      CMS_PageTemplate.PageTemplateLayoutCheckedOutFileName, CMS_PageTemplate.PageTemplateLayoutCheckedOutByUserID, 
                      CMS_PageTemplate.PageTemplateLayoutCheckedOutMachineName, CMS_Document.DocumentMenuItemInactive, 
                      CMS_Document.DocumentMenuClass, CMS_Document.DocumentMenuStyle, CMS_Document.DocumentMenuItemHideInNavigation, 
                      CMS_Tree.NodeChildNodesCount, CMS_Tree.NodeBodyElementAttributes, CMS_Tree.RequiresSSL, CMS_Tree.NodeLinkedNodeID, 
                      CMS_Tree.NodeOwner
FROM         CMS_Tree INNER JOIN
                      CMS_Class ON CMS_Tree.NodeClassID = CMS_Class.ClassID LEFT OUTER JOIN
                      CMS_Document ON 1 = 0 LEFT OUTER JOIN
                      CMS_PageTemplate ON 1 = 0
GO
					  
----------------------------------------------------------------------
------    DATA ----------------------------------------------------
----------------------------------------------------------------------

UPDATE [CMS_Attachment] SET AttachmentSiteID = (SELECT    NodeSiteID FROM View_CMS_Tree_Joined WHERE (DocumentID = CMS_Attachment.AttachmentDocumentID))
GO

INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (0, 'January', 'Monday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (1, 'February', 'Tuesday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (2, 'March', 'Wednesday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (3, 'April', 'Thursday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (4, 'May', 'Friday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (5, 'June', 'Saturday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (6, 'July', 'Sunday')
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (7, 'August', NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (8, 'September', NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (9, 'October', NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (10, 'November', NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (11, 'December', NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (12, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (13, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (14, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (15, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (16, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (17, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (18, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (19, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (20, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (21, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (22, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (23, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (24, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (25, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (26, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (27, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (28, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (29, NULL, NULL)
INSERT [Analytics_Index] ([IndexZero], [IndexMonthName], [IndexDayName]) VALUES (30, NULL, NULL)
GO

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0 WHERE ClassName = 'cms.culture'

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = '', [ClassIsMenuItemType] = 0, [ClassNodeAliasSource] = '' WHERE ClassName = 'cms.site'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = '' WHERE ClassName='cms.Role'

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = '', [ClassIsMenuItemType] = 0, [ClassNodeAliasSource] = ''  WHERE ClassName='cms.user'

UPDATE [CMS_Class] SET [ClassViewPageUrl]='', [ClassPreviewPageUrl]='',  [ClassNewPageUrl]='',  [ClassUsePublishFromTo]=0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='' , [ClassXmlSchema] ='<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_EventLog">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="EventID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="EventType">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="5" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="EventTime" type="xs:dateTime" />
              <xs:element name="Source">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="EventCode">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="UserID" type="xs:int" minOccurs="0" />
              <xs:element name="UserName" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="IPAddress" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentName" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="EventDescription" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SiteID" type="xs:int" minOccurs="0" />
              <xs:element name="EventUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="2000" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="EventMachineName" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_EventLog" />
      <xs:field xpath="EventID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'cms.eventLog'


UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_Tree">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="NodeID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="NodeAliasPath">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeAlias">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeClassID" type="xs:int" />
              <xs:element name="NodeParentID" type="xs:int" />
              <xs:element name="NodeLevel" type="xs:int" />
              <xs:element name="NodeACLID" type="xs:int" minOccurs="0" />
              <xs:element name="NodeSiteID" type="xs:int" />
              <xs:element name="NodeGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" minOccurs="0" />
              <xs:element name="NodeOrder" type="xs:int" minOccurs="0" />
              <xs:element name="IsSecuredNode" type="xs:boolean" minOccurs="0" />
              <xs:element name="NodeCacheMinutes" type="xs:int" minOccurs="0" />
              <xs:element name="NodeSKUID" type="xs:int" minOccurs="0" />
              <xs:element name="NodeDocType" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeHeadTags" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeBodyElementAttributes" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeInheritPageLevels" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="NodeChildNodesCount" type="xs:int" minOccurs="0" />
              <xs:element name="RequiresSSL" type="xs:boolean" minOccurs="0" />
              <xs:element name="NodeLinkedNodeID" type="xs:int" minOccurs="0" />
              <xs:element name="NodeOwner" type="xs:int" minOccurs="0" />
              <xs:element name="NodeCustomData" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_Tree" />
      <xs:field xpath="NodeID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName='CMS.Tree'

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_Document">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="DocumentID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="DocumentName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentNamePath" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1500" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentModifiedWhen" type="xs:dateTime" minOccurs="0" />
              <xs:element name="DocumentModifiedByUserID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentForeignKeyValue" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentCreatedByUserID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentCreatedWhen" type="xs:dateTime" minOccurs="0" />
              <xs:element name="DocumentCheckedOutByUserID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentCheckedOutWhen" type="xs:dateTime" minOccurs="0" />
              <xs:element name="DocumentCheckedOutVersionHistoryID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentPublishedVersionHistoryID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentWorkflowStepID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentPublishFrom" type="xs:dateTime" minOccurs="0" />
              <xs:element name="DocumentPublishTo" type="xs:dateTime" minOccurs="0" />
              <xs:element name="DocumentUrlPath" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentCulture">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="10" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentNodeID" type="xs:int" />
              <xs:element name="DocumentPageTitle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentPageKeyWords" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentPageDescription" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentShowInSiteMap" type="xs:boolean" />
              <xs:element name="DocumentMenuItemHideInNavigation" type="xs:boolean" minOccurs="0" />
              <xs:element name="DocumentMenuCaption" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuStyle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemImage" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemLeftImage" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemRightImage" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentPageTemplateID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentMenuJavascript" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuRedirectUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentUseNamePathForUrlPath" type="xs:boolean" minOccurs="0" />
              <xs:element name="DocumentStylesheetID" type="xs:int" minOccurs="0" />
              <xs:element name="DocumentContent" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuClass" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuStyleOver" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuClassOver" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemImageOver" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemLeftImageOver" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemRightImageOver" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuStyleHighlighted" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuClassHighlighted" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemImageHighlighted" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemLeftImageHighlighted" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemRightImageHighlighted" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DocumentMenuItemInactive" type="xs:boolean" minOccurs="0" />
              <xs:element name="DocumentCustomData" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_Document" />
      <xs:field xpath="DocumentID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName ='cms.document'


UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_Class">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="ClassID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="ClassDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassUsesVersioning" type="xs:boolean" />
              <xs:element name="ClassIsDocumentType" type="xs:boolean" />
              <xs:element name="ClassIsCoupledClass" type="xs:boolean" />
              <xs:element name="ClassXmlSchema">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassFormDefinition">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassEditingPageUrl">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassListPageUrl">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassNodeNameSource">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassTableName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassViewPageUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassPreviewPageUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassFormLayout" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassNewPageUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassShowAsSystemTable" type="xs:boolean" />
              <xs:element name="ClassUsePublishFromTo" type="xs:boolean" minOccurs="0" />
              <xs:element name="ClassShowTemplateSelection" type="xs:boolean" minOccurs="0" />
              <xs:element name="ClassSKUMappings" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="500" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassIsMenuItemType" type="xs:boolean" minOccurs="0" />
              <xs:element name="ClassNodeAliasSource" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ClassDefaultPageTemplateID" type="xs:int" minOccurs="0" />
              <xs:element name="ClassSKUDefaultDepartmentID" type="xs:int" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_Class" />
      <xs:field xpath="ClassID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName='cms.class'

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = '', [ClassIsMenuItemType] = 0 WHERE ClassName = 'cms.pagetemplate'

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = ''  WHERE ClassName = 'cms.transformation'

UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = ''  WHERE ClassName = 'cms.layout'

UPDATE [CMS_Class] SET [ClassNewPageUrl]='', [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_Attachment">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="AttachmentID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="AttachmentName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="255" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AttachmentExtension">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AttachmentSize" type="xs:int" />
              <xs:element name="AttachmentMimeType">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AttachmentBinary" type="xs:base64Binary" minOccurs="0" />
              <xs:element name="AttachmentImageWidth" type="xs:int" minOccurs="0" />
              <xs:element name="AttachmentImageHeight" type="xs:int" minOccurs="0" />
              <xs:element name="AttachmentDocumentID" type="xs:int" />
              <xs:element name="AttachmentGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" />
              <xs:element name="AttachmentLastHistoryID" type="xs:int" minOccurs="0" />
              <xs:element name="AttachmentSiteID" type="xs:int" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_Attachment" />
      <xs:field xpath="AttachmentID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE CLassName='cms.attachment'


UPDATE [CMS_Class] SET [ClassNewPageUrl]='', [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_AttachmentHistory">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="AttachmentHistoryID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="AttachmentName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="255" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AttachmentExtension">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AttachmentSize" type="xs:int" />
              <xs:element name="AttachmentMimeType">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AttachmentBinary" type="xs:base64Binary" minOccurs="0" />
              <xs:element name="AttachmentImageWidth" type="xs:int" minOccurs="0" />
              <xs:element name="AttachmentImageHeight" type="xs:int" minOccurs="0" />
              <xs:element name="AttachmentDocumentID" type="xs:int" />
              <xs:element name="AttachmentGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_AttachmentHistory" />
      <xs:field xpath="AttachmentHistoryID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName='cms.attachmenthistory'


UPDATE [CMS_Class] SET [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0, [ClassSKUMappings] = '' WHERE ClassName = 'cms.cssstylesheet'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="cms_form">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="FormID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="FormDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormSendToEmail" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="400" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormSendFromEmail" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="400" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormEmailSubject" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="250" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormClassID" type="xs:int" />
              <xs:element name="FormItems" type="xs:int" />
              <xs:element name="FormReportFields" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormRedirectToUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="400" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormDisplayText" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormClearAfterSave" type="xs:boolean" />
              <xs:element name="FormSubmitButtonText" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="400" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormSiteID" type="xs:int" />
              <xs:element name="FormConfirmationEmailField" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormConfirmationTemplate" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormConfirmationSendFromEmail" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="400" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="FormConfirmationEmailSubject" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="250" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//cms_form" />
      <xs:field xpath="FormID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'cms.form'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] =  '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Newsletter_EmailTemplate">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="TemplateID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="TemplateDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="250" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TemplateName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="250" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TemplateBody">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TemplateSiteID" type="xs:int" />
              <xs:element name="TemplateHeader">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TemplateFooter">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TemplateType">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TemplateStylesheetText" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Newsletter_EmailTemplate" />
      <xs:field xpath="TemplateID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'Newsletter.EmailTemplate'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='' WHERE ClassName='Newsletter.subscriber'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="CMS_ScheduledTask">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="TaskID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="TaskName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskAssemblyName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskClass" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskInterval">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1000" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskData">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskLastRunTime" type="xs:dateTime" minOccurs="0" />
              <xs:element name="TaskNextRunTime" type="xs:dateTime" minOccurs="0" />
              <xs:element name="TaskProgress" type="xs:int" minOccurs="0" />
              <xs:element name="TaskLastResult" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaskEnabled" type="xs:boolean" />
              <xs:element name="TaskSiteID" type="xs:int" minOccurs="0" />
              <xs:element name="TaskDeleteAfterLastRun" type="xs:boolean" minOccurs="0" />
              <xs:element name="TaskServerName" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//CMS_ScheduledTask" />
      <xs:field xpath="TaskID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'cms.scheduledtask'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0  WHERE ClassName='Newsletter.SubscriberNewsletter'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0  WHERE ClassName='Newsletter.Newsletter'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0  WHERE ClassName='Newsletter.Emails'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0  WHERE ClassName='Forums.ForumGroup'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Forums_Forum">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="ForumID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="ForumGroupID" type="xs:int" />
              <xs:element name="ForumName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ForumDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ForumDescription" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ForumOrder" type="xs:int" minOccurs="0" />
              <xs:element name="ForumDocumentID" type="xs:int" minOccurs="0" />
              <xs:element name="ForumOpen" type="xs:boolean" />
              <xs:element name="ForumModerated" type="xs:boolean" />
              <xs:element name="ForumDisplayEmails" type="xs:boolean" />
              <xs:element name="ForumRequireEmail" type="xs:boolean" />
              <xs:element name="ForumAccess" type="xs:int" />
              <xs:element name="ForumThreads" type="xs:int" />
              <xs:element name="ForumPosts" type="xs:int" />
              <xs:element name="ForumLastPostTime" type="xs:dateTime" minOccurs="0" />
              <xs:element name="ForumLastPostUserName" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ForumBaseUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ForumAllowChangeName" type="xs:boolean" minOccurs="0" />
              <xs:element name="ForumHTMLEditor" type="xs:boolean" minOccurs="0" />
              <xs:element name="ForumUseCAPTCHA" type="xs:boolean" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Forums_Forum" />
      <xs:field xpath="ForumID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE CLassName = 'Forums.Forum'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0  WHERE ClassName='Forums.ForumPost'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] =  '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Forums_ForumSubscription">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="SubscriptionID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="SubscriptionUserID" type="xs:int" minOccurs="0" />
              <xs:element name="SubscriptionEmail" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SubscriptionForumID" type="xs:int" />
              <xs:element name="SubscriptionPostID" type="xs:int" minOccurs="0" />
              <xs:element name="SubscriptionGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Forums_ForumSubscription" />
      <xs:field xpath="SubscriptionID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName ='Forums.ForumSubscription'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'cms.country'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'cms.state'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'staging.synchronization'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'staging.server'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'staging.synclog'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'staging.task'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0 WHERE ClassName = 'ecommerce.supplier'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0 WHERE ClassName = 'ecommerce.manufacturer'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.currency'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0 WHERE ClassName = 'ecommerce.paymentoption'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.publicstatus'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassXmlSchema] =  '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_OrderStatus">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="StatusID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="StatusName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="StatusDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="StatusOrder" type="xs:int" minOccurs="0" />
              <xs:element name="StatusEnabled" type="xs:boolean" />
              <xs:element name="StatusColor" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="7" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_OrderStatus" />
      <xs:field xpath="StatusID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName='ecommerce.orderstatus'


UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.internalstatus'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.department'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection] = 0 WHERE ClassName = 'ecommerce.discountcoupon'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] =  '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_ShippingOption">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="ShippingOptionID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="ShippingOptionName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ShippingOptionDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ShippingOptionCharge" type="xs:double" />
              <xs:element name="ShippingOptionEnabled" type="xs:boolean" />
              <xs:element name="ShippingOptionSiteID" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_ShippingOption" />
      <xs:field xpath="ShippingOptionID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName='ecommerce.shippingoption'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0 WHERE ClassName = 'ecommerce.exchangetable'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] = '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_TaxClass">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="TaxClassID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="TaxClassName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaxClassDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TaxClassZeroIfIDSupplied" type="xs:boolean" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_TaxClass" />
      <xs:field xpath="TaxClassID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'ecommerce.taxclass'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.taxclasscountry'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.address'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] =  '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_Customer">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="CustomerID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="CustomerFirstName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerLastName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerEmail" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerPhone" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerFax" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerCompany" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerUserID" type="xs:int" minOccurs="0" />
              <xs:element name="CustomerPreferredCurrencyID" type="xs:int" minOccurs="0" />
              <xs:element name="CustomerPreferredShippingOptionID" type="xs:int" minOccurs="0" />
              <xs:element name="CustomerCountryID" type="xs:int" minOccurs="0" />
              <xs:element name="CustomerEnabled" type="xs:boolean" />
              <xs:element name="CustomerPrefferedPaymentOptionID" type="xs:int" minOccurs="0" />
              <xs:element name="CustomerStateID" type="xs:int" minOccurs="0" />
              <xs:element name="CustomerGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" />
              <xs:element name="CustomerTaxRegistrationID" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerOrganizationID" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CustomerDiscountLevelID" type="xs:int" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_Customer" />
      <xs:field xpath="CustomerID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'ecommerce.customer'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.order'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0, [ClassSKUMappings]='', [ClassIsMenuItemType]=0, [ClassNodeAliasSource]='', [ClassXmlSchema] =  '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_SKU">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="SKUID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="SKUNumber" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SKUName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SKUDescription" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SKUPrice" type="xs:double" />
              <xs:element name="SKUEnabled" type="xs:boolean" />
              <xs:element name="SKUDepartmentID" type="xs:int" />
              <xs:element name="SKUManufacturerID" type="xs:int" minOccurs="0" />
              <xs:element name="SKUInternalStatusID" type="xs:int" minOccurs="0" />
              <xs:element name="SKUPublicStatusID" type="xs:int" minOccurs="0" />
              <xs:element name="SKUSupplierID" type="xs:int" minOccurs="0" />
              <xs:element name="SKUAvailableInDays" type="xs:int" minOccurs="0" />
              <xs:element name="SKUGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" />
              <xs:element name="SKUImagePath" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SKUWeight" type="xs:double" minOccurs="0" />
              <xs:element name="SKUWidth" type="xs:double" minOccurs="0" />
              <xs:element name="SKUDepth" type="xs:double" minOccurs="0" />
              <xs:element name="SKUHeight" type="xs:double" minOccurs="0" />
              <xs:element name="SKUAvailableItems" type="xs:int" minOccurs="0" />
              <xs:element name="SKUSellOnlyAvailable" type="xs:boolean" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_SKU" />
      <xs:field xpath="SKUID" />
    </xs:unique>
  </xs:element>
</xs:schema>' WHERE ClassName = 'ecommerce.SKU'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0 WHERE ClassName = 'ecommerce.orderitem'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0 WHERE ClassName = 'ecommerce.shoppingcart'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0 WHERE ClassName = 'ecommerce.orderstatususer'

UPDATE [CMS_Class] SET  [ClassUsePublishFromTo] = 0, [ClassShowTemplateSelection]=0,  [ClassSKUMappings]='' WHERE ClassName = 'ecommerce.exchangerate'

GO

INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Polls - Poll', 'polls.poll', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Polls_Poll">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="PollID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="PollCodeName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="PollDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="PollTitle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="PollOpenFrom" type="xs:dateTime" minOccurs="0" />
              <xs:element name="PollOpenTo" type="xs:dateTime" minOccurs="0" />
              <xs:element name="PollAllowMultipleAnswers" type="xs:boolean" />
              <xs:element name="PollQuestion">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="PollAccess" type="xs:int" />
              <xs:element name="PollResponseMessage" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Polls_Poll" />
      <xs:field xpath="PollID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Polls_Poll', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Polls - PollAnswer', 'polls.pollanswer', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Polls_PollAnswer">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="AnswerID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="AnswerText">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="AnswerOrder" type="xs:int" minOccurs="0" />
              <xs:element name="AnswerCount" type="xs:int" minOccurs="0" />
              <xs:element name="AnswerEnabled" type="xs:boolean" minOccurs="0" />
              <xs:element name="AnswerPollID" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Polls_PollAnswer" />
      <xs:field xpath="AnswerID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Polls_PollAnswer', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Report', 'Reporting.Report', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_Report">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="ReportID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="ReportName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ReportDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ReportLayout">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ReportParameters">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ReportCategoryID" type="xs:int" />
              <xs:element name="ReportAccess" type="xs:int" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_Report" />
      <xs:field xpath="ReportID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_Report', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'ReportGraph', 'Reporting.ReportGraph', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_ReportGraph">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="GraphID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="GraphName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphQuery">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphQueryIsStoredProcedure" type="xs:boolean" />
              <xs:element name="GraphType">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphReportID" type="xs:int" />
              <xs:element name="GraphTitle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphXAxisTitle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphYAxisTitle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="GraphWidth" type="xs:int" minOccurs="0" />
              <xs:element name="GraphHeight" type="xs:int" minOccurs="0" />
              <xs:element name="GraphLegendPosition" type="xs:int" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_ReportGraph" />
      <xs:field xpath="GraphID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_ReportGraph', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'ReportTable', 'Reporting.ReportTable', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_ReportTable">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="TableID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="TableName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TableDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TableQuery">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="TableQueryIsStoredProcedure" type="xs:boolean" />
              <xs:element name="TableReportID" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_ReportTable" />
      <xs:field xpath="TableID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_ReportTable', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'ReportValue', 'Reporting.ReportValue', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_ReportValue">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="ValueID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="ValueName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ValueDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ValueQuery">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ValueQueryIsStoredProcedure" type="xs:boolean" />
              <xs:element name="ValueFormatString" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="ValueReportID" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_ReportValue" />
      <xs:field xpath="ValueID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_ReportValue', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'ReportingSavedGraph', 'Reporting.SavedGraph', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_SavedGraph">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="SavedGraphID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="SavedGraphSavedReportID" type="xs:int" />
              <xs:element name="SavedGraphGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" />
              <xs:element name="SavedGraphBinary" type="xs:base64Binary" />
              <xs:element name="SavedGraphMimeType">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_SavedGraph" />
      <xs:field xpath="SavedGraphID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_SavedGraph', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'ReportingSavedReport', 'Reporting.SavedReport', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_SavedReport">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="SavedReportID" type="xs:int" />
              <xs:element name="SavedReportReportID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="SavedReportGUID" msdata:DataType="System.Guid, mscorlib, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089" type="xs:string" />
              <xs:element name="SavedReportTitle" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SavedReportDate" type="xs:dateTime" />
              <xs:element name="SavedReportHTML">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SavedReportParameters">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="SavedReportCreatedByUserID" type="xs:int" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_SavedReport" />
      <xs:field xpath="SavedReportID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_SavedReport', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Blog comment', 'blog.comment', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Blog_Comment">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="CommentID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="CommentUserName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CommentUserID" type="xs:int" minOccurs="0" />
              <xs:element name="CommentUrl" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CommentText">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="1073741823" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CommentApprovedByUserID" type="xs:int" minOccurs="0" />
              <xs:element name="CommentPostDocumentID" type="xs:int" />
              <xs:element name="CommentDate" type="xs:dateTime" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Blog_Comment" />
      <xs:field xpath="CommentID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Blog_Comment', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ('Analytics statistics', 'analytics.statistics', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Analytics_Statistics">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="StatisticsID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="StatisticsSiteID" type="xs:int" minOccurs="0" />
              <xs:element name="StatisticsCode">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="50" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="StatisticsObjectName" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="450" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="StatisticsObjectID" type="xs:int" minOccurs="0" />
              <xs:element name="StatisticsObjectCulture" minOccurs="0">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="10" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Analytics_Statistics" />
      <xs:field xpath="StatisticsID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Analytics_Statistics', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ('Analytics hour hits', 'analytics.hitshour', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Analytics_HourHits">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="HitsID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="HitsStatisticsID" type="xs:int" />
              <xs:element name="HitsStartTime" type="xs:dateTime" />
              <xs:element name="HitsEndTime" type="xs:dateTime" />
              <xs:element name="HitsCount" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Analytics_HourHits" />
      <xs:field xpath="HitsID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Analytics_HourHits', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Analytics day hits', 'analytics.hitsday', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Analytics_DayHits">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="HitsID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="HitsStatisticsID" type="xs:int" />
              <xs:element name="HitsStartTime" type="xs:dateTime" />
              <xs:element name="HitsEndTime" type="xs:dateTime" />
              <xs:element name="HitsCount" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Analytics_DayHits" />
      <xs:field xpath="HitsID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Analytics_DayHits', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Analytics month hits', 'analytics.hitsmonth', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Analytics_MonthHits">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="HitsID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="HitsStatisticsID" type="xs:int" />
              <xs:element name="HitsStartTime" type="xs:dateTime" />
              <xs:element name="HitsEndTime" type="xs:dateTime" />
              <xs:element name="HitsCount" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Analytics_MonthHits" />
      <xs:field xpath="HitsID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Analytics_MonthHits', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Analytics week hits', 'analytics.hitsweek', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Analytics_WeekHits">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="HitsID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="HitsStatisticsID" type="xs:int" />
              <xs:element name="HitsStartTime" type="xs:dateTime" />
              <xs:element name="HitsEndTime" type="xs:dateTime" />
              <xs:element name="HitsCount" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Analytics_WeekHits" />
      <xs:field xpath="HitsID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Analytics_WeekHits', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Analytics year hits', 'analytics.hitsyear', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Analytics_YearHits">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="HitsID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="HitsStatisticsID" type="xs:int" />
              <xs:element name="HitsStartTime" type="xs:dateTime" />
              <xs:element name="HitsEndTime" type="xs:dateTime" />
              <xs:element name="HitsCount" type="xs:int" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Analytics_YearHits" />
      <xs:field xpath="HitsID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Analytics_YearHits', '', '', NULL, '', 0, 0, 0, '', 0, NULL, NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ('Ecommerce - Volume discount', 'ecommerce.volumediscount', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_VolumeDiscount">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="VolumeDiscountID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="VolumeDiscountSKUID" type="xs:int" />
              <xs:element name="VolumeDiscountMinCount" type="xs:int" />
              <xs:element name="VolumeDiscountValue" type="xs:double" />
              <xs:element name="VolumeDiscountIsFlatValue" type="xs:boolean" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_VolumeDiscount" />
      <xs:field xpath="VolumeDiscountID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'COM_VolumeDiscount', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Discount level', 'ecommerce.discountlevel', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_DiscountLevel">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="DiscountLevelID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="DiscountLevelDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DiscountLevelName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="100" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="DiscountLevelValue" type="xs:double" />
              <xs:element name="DiscountLevelEnabled" type="xs:boolean" />
              <xs:element name="DiscountLevelValidFrom" type="xs:dateTime" minOccurs="0" />
              <xs:element name="DiscountLevelValidTo" type="xs:dateTime" minOccurs="0" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_DiscountLevel" />
      <xs:field xpath="DiscountLevelID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'COM_DiscountLevel', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'ReportCategory', 'Reporting.ReportCategory', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="Reporting_ReportCategory">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="CategoryID" msdata:ReadOnly="true" msdata:AutoIncrement="true" type="xs:int" />
              <xs:element name="CategoryDisplayName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
              <xs:element name="CategoryCodeName">
                <xs:simpleType>
                  <xs:restriction base="xs:string">
                    <xs:maxLength value="200" />
                  </xs:restriction>
                </xs:simpleType>
              </xs:element>
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//Reporting_ReportCategory" />
      <xs:field xpath="CategoryID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'Reporting_ReportCategory', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)
INSERT [CMS_Class] ( [ClassDisplayName], [ClassName], [ClassUsesVersioning], [ClassIsDocumentType], [ClassIsCoupledClass], [ClassXmlSchema], [ClassFormDefinition], [ClassEditingPageUrl], [ClassListPageUrl], [ClassNodeNameSource], [ClassTableName], [ClassViewPageUrl], [ClassPreviewPageUrl], [ClassFormLayout], [ClassNewPageUrl], [ClassShowAsSystemTable], [ClassUsePublishFromTo], [ClassShowTemplateSelection], [ClassSKUMappings], [ClassIsMenuItemType], [ClassNodeAliasSource], [ClassDefaultPageTemplateID], [ClassSKUDefaultDepartmentID]) VALUES ( 'Ecommerce - Tax class state', 'ecommerce.taxclassstate', 0, 0, 1, '<?xml version="1.0" encoding="utf-8"?>
<xs:schema id="NewDataSet" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
  <xs:element name="NewDataSet" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
    <xs:complexType>
      <xs:choice minOccurs="0" maxOccurs="unbounded">
        <xs:element name="COM_TaxClassState">
          <xs:complexType>
            <xs:sequence>
              <xs:element name="TaxClassID" type="xs:int" />
              <xs:element name="StateID" type="xs:int" />
              <xs:element name="TaxValue" type="xs:double" />
              <xs:element name="IsFlatValue" type="xs:boolean" />
            </xs:sequence>
          </xs:complexType>
        </xs:element>
      </xs:choice>
    </xs:complexType>
    <xs:unique name="Constraint1" msdata:PrimaryKey="true">
      <xs:selector xpath=".//COM_TaxClassState" />
      <xs:field xpath="TaxClassID" />
      <xs:field xpath="StateID" />
    </xs:unique>
  </xs:element>
</xs:schema>', '', '', '', '', 'COM_TaxClassState', '', '', NULL, '', 0, 0, 0, '', 0, '', NULL, NULL)

GO


UPDATE [CMS_EmailTemplate] SET  [EmailTemplateText] = '<html>
	<head>
	</head>
	<body style="FONT-SIZE: 12px; FONT-FAMILY: arial">
		<p>
		This an automatic notification sent by Kentico CMS. The following document is waiting for your approval. Please sign in to Kentico CMS Desk and approve it.
		</p>
		<p>
		<b>Document:</b> <a href="{%applicationurl%}/CMSDesk/default.aspx?section=content&action=edit&nodeid={%nodeid%}&culture={%documentculture%}">{%documentname%}</a>
		<br>
		<b>Last approved by:</b> {%approvedby%}
		<br>
		<b>Last approved when:</b> {%approvedwhen%}
		<br>
		<b>Original step:</b> {%originalstep%}
		<br>
		<b>Current step:</b> {%currentstep%}
		<br>
		<b>Comment:</b>
		<br>
		{%comment%}
		</p>
	</body>
</html>' WHERE EmailTemplateName = 'Workflow.ReadyForApproval' AND EmailTemplateSiteID IS NULL

UPDATE [CMS_EmailTemplate] SET  [EmailTemplateText] = '<html>
	<head>
	</head>
	<body style="FONT-SIZE: 12px; FONT-FAMILY: arial">
		<p>
		This an automatic notification sent by Kentico CMS. The following document was rejected.
		</p>
		<p>
		<b>Document:</b> <a href="{%applicationurl%}/cmsdesk/default.aspx?section=content&action=edit&nodeid={%nodeid%}&culture={%documentculture%}">{%documentname%}</a>
		<br>
		<b>Rejected by:</b> {%approvedby%}
		<br>
		<b>Rejected when:</b> {%approvedwhen%}
		<br>
		<b>Original step:</b> {%originalstep%}
		<br>
		<b>Current step:</b> {%currentstep%}
		<br>
		<b>Comment:</b>
		<br>
		{%comment%}
		</p>
	</body>
</html>'  WHERE EmailTemplateName = 'Workflow.Rejected' AND EmailTemplateSiteID IS NULL

UPDATE [CMS_EmailTemplate] SET  [EmailTemplateText] = '<html>
	<head>
	</head>
	<body style="FONT-SIZE: 12px; FONT-FAMILY: arial">
		<p>
		This an automatic notification sent by Kentico CMS. The following document has been archived.</p>
		<p>
		<b>Document:</b> <a href="{%applicationurl%}/cmsdesk/default.aspx?section=content&action=edit&nodeid={%nodeid%}&culture={%documentculture%}">{%documentname%}</a>
		<br>
		<b>Archived by:</b> {%approvedby%}
		<br>
		<b>Archived when:</b> {%approvedwhen%}
		<br>
		<b>Comment:</b>
		<br>
		{%comment%}
		</p>
	</body>
</html>' WHERE EmailTemplateName = 'Workflow.Archived' AND EmailTemplateSiteID IS NULL

UPDATE [CMS_EmailTemplate] SET  [EmailTemplateText] = '<html>
	<head>
	</head>
	<body style="FONT-SIZE: 12px; FONT-FAMILY: arial">
		<p>
		This an automatic notification sent by Kentico CMS. The following document was published.
		</p>
		<p>
		<b>Document:</b> <a href="{%applicationurl%}/cmsdesk/default.aspx?section=content&action=edit&nodeid={%nodeid%}&culture={%documentculture%}">{%documentname%}</a>
		<br>
		<b>Last approved by:</b> {%approvedby%}
		<br>
		<b>Last approved when:</b> {%approvedwhen%}
		<br>
		<b>Original step:</b> {%originalstep%}
		<br>
		<b>Comment:</b>
		<br>
		{%comment%}
		</p>
	</body>
</html>' WHERE EmailTemplateName = 'Workflow.Published' AND EmailTemplateSiteID IS NULL

UPDATE [CMS_EmailTemplate] SET  [EmailTemplateText] = '<html>
	<head>
	</head>
	<body style="FONT-SIZE: 12px; FONT-FAMILY: arial">
		<p>
		This an automatic notification sent by Kentico CMS. The following document was approved.
		</p>
		<p>
		<b>Document:</b> <a href="{%applicationurl%}/cmsdesk/default.aspx?section=content&action=edit&nodeid={%nodeid%}&culture={%documentculture%}">{%documentname%}</a>
		<br>
		<b>Approved by:</b> {%approvedby%}
		<br>
		<b>Approved when:</b> {%approvedwhen%}
		<br>
		<b>Original step:</b> {%originalstep%}
		<br>
		<b>Current step:</b> {%currentstep%}
		<br>
		<b>Comment:</b>
		<br>
		{%comment%}
		</p>
	</body>
</html>' WHERE EmailTemplateName = 'Workflow.Approved' AND EmailTemplateSiteID IS NULL

GO

INSERT [CMS_EmailTemplate] ( [EmailTemplateName], [EmailTemplateDisplayName], [EmailTemplateText], [EmailTemplateSiteID]) VALUES ( 'Blog.NewCommentNotification', 'Blog new comment notification', '<html>
	<head>
	</head>
	<body style="FONT-SIZE: 12px; FONT-FAMILY: arial">
		<p>
		New blog comment to post ''{%BlogPostTitle%}'':
		</p>
		<p>
		User name: {%UserFullName%}
		</p>
		<p>
		Comment url: <a href="{%CommentUrl%}">{%CommentUrl%}</a>
		</p>
		<p>
                Comments: {%Comments%}
		</p>
	</body>
</html>', NULL)

GO

-------------------- Form controls

INSERT [CMS_FormUserControl] ([UserControlDisplayName], [UserControlCodeName], [UserControlFileName], [UserControlForText], [UserControlForLongText], [UserControlForInteger], [UserControlForDecimal], [UserControlForDateTime], [UserControlForBoolean], [UserControlForFile], [UserControlShowInBizForms], [UserControlDefaultDataType], [UserControlDefaultDataTypeSize], [UserControlShowInDocumentTypes], [UserControlShowInSystemTables], [UserControlShowInWebParts]) VALUES ( 'Poll selector', 'pollselector', 'pollselector.ascx', 1, 0, 0, 0, 0, 0, 0, 0, 'Text', NULL, 0, 0, 1)
INSERT [CMS_FormUserControl] ([UserControlDisplayName], [UserControlCodeName], [UserControlFileName], [UserControlForText], [UserControlForLongText], [UserControlForInteger], [UserControlForDecimal], [UserControlForDateTime], [UserControlForBoolean], [UserControlForFile], [UserControlShowInBizForms], [UserControlDefaultDataType], [UserControlDefaultDataTypeSize], [UserControlShowInDocumentTypes], [UserControlShowInSystemTables], [UserControlShowInWebParts]) VALUES ( 'User Selector', 'UserSelector', 'selectuser.ascx', 1, 0, 1, 0, 0, 0, 0, 0, 'Text', NULL, 1, 0, 1)
INSERT [CMS_FormUserControl] ([UserControlDisplayName], [UserControlCodeName], [UserControlFileName], [UserControlForText], [UserControlForLongText], [UserControlForInteger], [UserControlForDecimal], [UserControlForDateTime], [UserControlForBoolean], [UserControlForFile], [UserControlShowInBizForms], [UserControlDefaultDataType], [UserControlDefaultDataTypeSize], [UserControlShowInDocumentTypes], [UserControlShowInSystemTables], [UserControlShowInWebParts]) VALUES ( 'Security code', 'SecurityCode', 'SecurityCode.ascx', 1, 0, 0, 0, 0, 0, 0, 1, 'Text', 10, 1, 0, 0)
INSERT [CMS_FormUserControl] ([UserControlDisplayName], [UserControlCodeName], [UserControlFileName], [UserControlForText], [UserControlForLongText], [UserControlForInteger], [UserControlForDecimal], [UserControlForDateTime], [UserControlForBoolean], [UserControlForFile], [UserControlShowInBizForms], [UserControlDefaultDataType], [UserControlDefaultDataTypeSize], [UserControlShowInDocumentTypes], [UserControlShowInSystemTables], [UserControlShowInWebParts]) VALUES ( 'Report selector', 'selectreport', 'SelectReport.ascx', 1, 0, 0, 0, 0, 0, 0, 0, 'Text', NULL, 0, 0, 1)
INSERT [CMS_FormUserControl] ([UserControlDisplayName], [UserControlCodeName], [UserControlFileName], [UserControlForText], [UserControlForLongText], [UserControlForInteger], [UserControlForDecimal], [UserControlForDateTime], [UserControlForBoolean], [UserControlForFile], [UserControlShowInBizForms], [UserControlDefaultDataType], [UserControlDefaultDataTypeSize], [UserControlShowInDocumentTypes], [UserControlShowInSystemTables], [UserControlShowInWebParts]) VALUES ( 'CSS stylesheet selector', 'CssStylesheetSelector', 'SelectCssStylesheet.ascx', 1, 0, 0, 0, 0, 0, 0, 0, 'Text', NULL, 0, 0, 1)
INSERT [CMS_FormUserControl] ([UserControlDisplayName], [UserControlCodeName], [UserControlFileName], [UserControlForText], [UserControlForLongText], [UserControlForInteger], [UserControlForDecimal], [UserControlForDateTime], [UserControlForBoolean], [UserControlForFile], [UserControlShowInBizForms], [UserControlDefaultDataType], [UserControlDefaultDataTypeSize], [UserControlShowInDocumentTypes], [UserControlShowInSystemTables], [UserControlShowInWebParts]) VALUES ( 'BizForm selector', 'BizFormSelector', 'SelectBizForm.ascx', 1, 0, 0, 0, 0, 0, 0, 0, 'Text', NULL, 0, 0, 1)

GO

INSERT [CMS_PageTemplateCategory] ([CategoryDisplayName], [CategoryParentID]) VALUES ( 'Blogs', NULL)
GO

----------------Resources

INSERT [CMS_Resource] ( [ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ('Polls', 'CMS.Polls', 1, '~/CMSDesk/Tools/Polls/Polls_List.aspx')
INSERT [CMS_Resource] ( [ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ( 'Reporting', 'CMS.Reporting', 1, '~/CMSDesk/Tools/Reporting/ReportCategory_List.aspx')
INSERT [CMS_Resource] ( [ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ( 'Web Analytics', 'CMS.WebAnalytics', 1, '~/CMSDesk/Tools/Analytics/default.aspx')
INSERT [CMS_Resource] ( [ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ( 'CMS User Interface', 'CMS.UserInterface', 0, '')
INSERT [CMS_Resource] ( [ResourceDisplayName], [ResourceName], [ShowInToolsMenu], [ResourceURL]) VALUES ( 'Blogs', 'CMS.Blog', 0, '')

------------------ Add new resources to all existing sites

DECLARE @resourceid int
DECLARE @setts int;

DECLARE @statusCursor CURSOR;
SET @statusCursor = CURSOR FOR SELECT SiteID FROM [CMS_Site];
	
	
DECLARE @cSiteId int;
/* Loop through all sites and add them settings */
OPEN @statusCursor
FETCH NEXT FROM @statusCursor INTO @cSiteId;
WHILE @@FETCH_STATUS = 0
BEGIN

set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.Polls')
if @resourceid<>0
begin
INSERT [CMS_ResourceSite] (ResourceID, SiteID) VALUES (@resourceId, @cSiteId)
End

set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.Reporting')
if @resourceid<>0
begin
INSERT [CMS_ResourceSite] (ResourceID, SiteID) VALUES (@resourceId, @cSiteId)
End

set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.WebAnalytics')
if @resourceid<>0
begin
INSERT [CMS_ResourceSite] (ResourceID, SiteID) VALUES (@resourceId, @cSiteId)
End

set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.UserInterface')
if @resourceid<>0
begin
INSERT [CMS_ResourceSite] (ResourceID, SiteID) VALUES (@resourceId, @cSiteId)
End
		
set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.Blog')
if @resourceid<>0
begin
INSERT [CMS_ResourceSite] (ResourceID, SiteID) VALUES (@resourceId, @cSiteId)
End		
		
FETCH NEXT FROM @statusCursor INTO @cSiteId;
END
CLOSE @statusCursor;
DEALLOCATE @statusCursor;
	
GO	

------------------Permisions
DECLARE @resourceid int
set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.Polls')
if @resourceid<>0
begin
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Modify', 'Modiry', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Read', 'Read', NULL, @resourceid)
END
GO

DECLARE @resourceid int
set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.UserInterface')
if @resourceid<>0
begin
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties Tab', 'PropertiesTab', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - General', 'PropertiesGeneral', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Template', 'PropertiesTemplate', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Metadata', 'PropertiesMetadata', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Menu', 'PropertiesMenu', NULL, 116)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Workflow', 'PropertiesWorkflow', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Versions', 'PropertiesVersions', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Related docs', 'PropertiesRelatedDocs', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Properties - Security', 'PropertiesSecurity', NULL, @resourceid)
END
GO

DECLARE @resourceid int
set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.Reporting')
if @resourceid<>0
begin
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Read', 'Read', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Modify', 'Modify', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Save reports', 'SaveReports', NULL, @resourceid)
END
GO

DECLARE @resourceid int
set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.Blog')
if @resourceid<>0
begin
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Manage', 'Manage', NULL, @resourceid)
END
GO

DECLARE @resourceid int
set @resourceid = (SELECT ResourceID FROM CMS_Resource WHERE ResourceName='CMS.WebAnalytics')
if @resourceid<>0
begin
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Read', 'Read', NULL, @resourceid)
INSERT [CMS_Permission] ( [PermissionDisplayName], [PermissionName], [ClassID], [ResourceID]) VALUES ( 'Save reports', 'SaveReports', NULL, @resourceid)
END
GO

-------------------------------queries

------------------------------ Update queries

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.root')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = '/* 
Uncomment the following query after you configure Kentico CMS for full-text search as described in Developers Guide -> Installation and deployment -> Configuration of full-text search in files
*/

/*
SELECT view_cms_tree_joined.*, view_cms_tree_joined.NodeName AS SearchResultName
FROM CMS_Attachment INNER JOIN view_cms_tree_joined 
ON view_cms_tree_joined.DocumentID = CMS_Attachment.AttachmentDocumentID
WHERE (##WHERE##) AND
([AttachmentName] Like N''%''+ @Expression + N''%'' OR FREETEXT(attachmentbinary, @expression))
ORDER BY ##ORDERBY##
*/

SELECT view_cms_tree_joined.*, view_cms_tree_joined.NodeName AS SearchResultName
FROM CMS_Attachment INNER JOIN view_cms_tree_joined 
ON view_cms_tree_joined.DocumentID = CMS_Attachment.AttachmentDocumentID
WHERE (##WHERE##) AND ([AttachmentName] Like N''%''+ @Expression + N''%'') ORDER BY ##ORDERBY##
' WHERE QueryName='searchattachments' AND ClassID=@classid AND QueryIsLocked = 0
end
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.user')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO CMS_User ( [UserName], [FirstName], [MiddleName], [LastName], [FullName], [Email], [UserPassword], [PreferredCultureCode], [PreferredUICultureCode], [UserEnabled], [UserIsEditor], [UserIsGlobalAdministrator], [UserIsExternal], [UserPasswordFormat], [UserCreated], [LastLogon], [UserNickName], [UserPicture], [UserSignature], [UserURLReferrer], [UserCampaign] ) VALUES (  @UserName, @FirstName, @MiddleName, @LastName, @FullName, @Email, @UserPassword, @PreferredCultureCode, @PreferredUICultureCode, @UserEnabled, @UserIsEditor, @UserIsGlobalAdministrator, @UserIsExternal, @UserPasswordFormat, @UserCreated, @LastLogon, @UserNickName, @UserPicture, @UserSignature, @UserURLReferrer, @UserCampaign); SELECT @@identity AS [UserID]' WHERE QueryName='insert' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] = 'UPDATE CMS_User SET  [UserName] = @UserName, [FirstName] = @FirstName, [MiddleName] = @MiddleName, [LastName] = @LastName, [FullName] = @FullName, [Email] = @Email, [UserPassword] = @UserPassword, [PreferredCultureCode] = @PreferredCultureCode, [PreferredUICultureCode] = @PreferredUICultureCode, [UserEnabled] = @UserEnabled, [UserIsEditor] = @UserIsEditor, [UserIsGlobalAdministrator] = @UserIsGlobalAdministrator, [UserIsExternal] = @UserIsExternal, [UserPasswordFormat] = @UserPasswordFormat, [UserCreated] = @UserCreated, [LastLogon] = @LastLogon, [UserNickName] = @UserNickName, [UserPicture] = @UserPicture, [UserSignature] = @UserSignature, [UserURLReferrer] = @UserURLReferrer, [UserCampaign] = @UserCampaign WHERE [UserID] = @UserID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.eventlog')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'SELECT * FROM CMS_EventLog WHERE [EventID] = @ID' WHERE QueryName='select' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] ='INSERT INTO CMS_EventLog ( [EventType], [EventTime], [Source], [EventCode], [UserID], [UserName], [IPAddress], [NodeID], [DocumentName], [EventDescription], [SiteID], [EventUrl], [EventMachineName] ) VALUES (  @EventType, @EventTime, @Source, @EventCode, @UserID, @UserName, @IPAddress, @NodeID, @DocumentName, @EventDescription, @SiteID, @EventUrl, @EventMachineName); SELECT @@identity AS [EventID]' WHERE QueryName='insert' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] = 'UPDATE CMS_EventLog SET  [EventType] = @EventType, [EventTime] = @EventTime, [Source] = @Source, [EventCode] = @EventCode, [UserID] = @UserID, [UserName] = @UserName, [IPAddress] = @IPAddress, [NodeID] = @NodeID, [DocumentName] = @DocumentName, [EventDescription] = @EventDescription, [SiteID] = @SiteID, [EventUrl] = @EventUrl, [EventMachineName] = @EventMachineName WHERE [EventID] = @EventID'  WHERE QueryName='update' AND ClassID=@classid
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.tree')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO CMS_Tree ( [NodeAliasPath], [NodeName], [NodeAlias], [NodeClassID], [NodeParentID], [NodeLevel], [NodeACLID], [NodeSiteID], [NodeGUID], [NodeOrder], [IsSecuredNode], [NodeCacheMinutes], [NodeSKUID], [NodeDocType], [NodeHeadTags], [NodeBodyElementAttributes], [NodeInheritPageLevels], [NodeChildNodesCount], [RequiresSSL], [NodeLinkedNodeID], [NodeOwner], [NodeCustomData] ) VALUES (  @NodeAliasPath, @NodeName, @NodeAlias, @NodeClassID, @NodeParentID, @NodeLevel, @NodeACLID, @NodeSiteID, @NodeGUID, @NodeOrder, @IsSecuredNode, @NodeCacheMinutes, @NodeSKUID, @NodeDocType, @NodeHeadTags, @NodeBodyElementAttributes, @NodeInheritPageLevels, @NodeChildNodesCount, @RequiresSSL, @NodeLinkedNodeID, @NodeOwner, @NodeCustomData); SELECT @@identity AS [NodeID]'WHERE QueryName='insert' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] ='UPDATE CMS_Tree SET  [NodeAliasPath] = @NodeAliasPath, [NodeName] = @NodeName, [NodeAlias] = @NodeAlias, [NodeClassID] = @NodeClassID, [NodeParentID] = @NodeParentID, [NodeLevel] = @NodeLevel, [NodeACLID] = @NodeACLID, [NodeSiteID] = @NodeSiteID, [NodeGUID] = @NodeGUID, [NodeOrder] = @NodeOrder, [IsSecuredNode] = @IsSecuredNode, [NodeCacheMinutes] = @NodeCacheMinutes, [NodeSKUID] = @NodeSKUID, [NodeDocType] = @NodeDocType, [NodeHeadTags] = @NodeHeadTags, [NodeBodyElementAttributes] = @NodeBodyElementAttributes, [NodeInheritPageLevels] = @NodeInheritPageLevels, [NodeChildNodesCount] = @NodeChildNodesCount, [RequiresSSL] = @RequiresSSL, [NodeLinkedNodeID] = @NodeLinkedNodeID, [NodeOwner] = @NodeOwner, [NodeCustomData] = @NodeCustomData WHERE [NodeID] = @NodeID' WHERE QueryName='update' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] ='SELECT DISTINCT ClassName FROM View_CMS_Tree_Joined WHERE (##WHERE##)' WHERE QueryName='selectdistinctclassnames' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] ='SELECT TOP 1 * FROM View_CMS_Tree_Joined WHERE ((DocumentNodeID IN (SELECT NodeID FROM CMS_TREE WHERE NodeSiteID = @SiteID ))AND(NodeAliasPath=''/'' OR @AliasPath LIKE NodeAliasPath+''/%'')AND(##WHERE##) ) ORDER BY NodeAliasPath DESC' WHERE QueryName='GetParentProperty' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.document')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO CMS_Document ( [DocumentName], [DocumentNamePath], [DocumentModifiedWhen], [DocumentModifiedByUserID], [DocumentForeignKeyValue], [DocumentCreatedByUserID], [DocumentCreatedWhen], [DocumentCheckedOutByUserID], [DocumentCheckedOutWhen], [DocumentCheckedOutVersionHistoryID], [DocumentPublishedVersionHistoryID], [DocumentWorkflowStepID], [DocumentPublishFrom], [DocumentPublishTo], [DocumentUrlPath], [DocumentCulture], [DocumentNodeID], [DocumentPageTitle], [DocumentPageKeyWords], [DocumentPageDescription], [DocumentShowInSiteMap], [DocumentMenuItemHideInNavigation], [DocumentMenuCaption], [DocumentMenuStyle], [DocumentMenuItemImage], [DocumentMenuItemLeftImage], [DocumentMenuItemRightImage], [DocumentPageTemplateID], [DocumentMenuJavascript], [DocumentMenuRedirectUrl], [DocumentUseNamePathForUrlPath], [DocumentStylesheetID], [DocumentContent], [DocumentMenuClass], [DocumentMenuStyleOver], [DocumentMenuClassOver], [DocumentMenuItemImageOver], [DocumentMenuItemLeftImageOver], [DocumentMenuItemRightImageOver], [DocumentMenuStyleHighlighted], [DocumentMenuClassHighlighted], [DocumentMenuItemImageHighlighted], [DocumentMenuItemLeftImageHighlighted], [DocumentMenuItemRightImageHighlighted], [DocumentMenuItemInactive], [DocumentCustomData] ) VALUES (  @DocumentName, @DocumentNamePath, @DocumentModifiedWhen, @DocumentModifiedByUserID, @DocumentForeignKeyValue, @DocumentCreatedByUserID, @DocumentCreatedWhen, @DocumentCheckedOutByUserID, @DocumentCheckedOutWhen, @DocumentCheckedOutVersionHistoryID, @DocumentPublishedVersionHistoryID, @DocumentWorkflowStepID, @DocumentPublishFrom, @DocumentPublishTo, @DocumentUrlPath, @DocumentCulture, @DocumentNodeID, @DocumentPageTitle, @DocumentPageKeyWords, @DocumentPageDescription, @DocumentShowInSiteMap, @DocumentMenuItemHideInNavigation, @DocumentMenuCaption, @DocumentMenuStyle, @DocumentMenuItemImage, @DocumentMenuItemLeftImage, @DocumentMenuItemRightImage, @DocumentPageTemplateID, @DocumentMenuJavascript, @DocumentMenuRedirectUrl, @DocumentUseNamePathForUrlPath, @DocumentStylesheetID, @DocumentContent, @DocumentMenuClass, @DocumentMenuStyleOver, @DocumentMenuClassOver, @DocumentMenuItemImageOver, @DocumentMenuItemLeftImageOver, @DocumentMenuItemRightImageOver, @DocumentMenuStyleHighlighted, @DocumentMenuClassHighlighted, @DocumentMenuItemImageHighlighted, @DocumentMenuItemLeftImageHighlighted, @DocumentMenuItemRightImageHighlighted, @DocumentMenuItemInactive, @DocumentCustomData); SELECT @@identity AS [DocumentID]'  WHERE QueryName='insert' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] = 'UPDATE CMS_Document SET  [DocumentName] = @DocumentName, [DocumentNamePath] = @DocumentNamePath, [DocumentModifiedWhen] = @DocumentModifiedWhen, [DocumentModifiedByUserID] = @DocumentModifiedByUserID, [DocumentForeignKeyValue] = @DocumentForeignKeyValue, [DocumentCreatedByUserID] = @DocumentCreatedByUserID, [DocumentCreatedWhen] = @DocumentCreatedWhen, [DocumentCheckedOutByUserID] = @DocumentCheckedOutByUserID, [DocumentCheckedOutWhen] = @DocumentCheckedOutWhen, [DocumentCheckedOutVersionHistoryID] = @DocumentCheckedOutVersionHistoryID, [DocumentPublishedVersionHistoryID] = @DocumentPublishedVersionHistoryID, [DocumentWorkflowStepID] = @DocumentWorkflowStepID, [DocumentPublishFrom] = @DocumentPublishFrom, [DocumentPublishTo] = @DocumentPublishTo, [DocumentUrlPath] = @DocumentUrlPath, [DocumentCulture] = @DocumentCulture, [DocumentNodeID] = @DocumentNodeID, [DocumentPageTitle] = @DocumentPageTitle, [DocumentPageKeyWords] = @DocumentPageKeyWords, [DocumentPageDescription] = @DocumentPageDescription, [DocumentShowInSiteMap] = @DocumentShowInSiteMap, [DocumentMenuItemHideInNavigation] = @DocumentMenuItemHideInNavigation, [DocumentMenuCaption] = @DocumentMenuCaption, [DocumentMenuStyle] = @DocumentMenuStyle, [DocumentMenuItemImage] = @DocumentMenuItemImage, [DocumentMenuItemLeftImage] = @DocumentMenuItemLeftImage, [DocumentMenuItemRightImage] = @DocumentMenuItemRightImage, [DocumentPageTemplateID] = @DocumentPageTemplateID, [DocumentMenuJavascript] = @DocumentMenuJavascript, [DocumentMenuRedirectUrl] = @DocumentMenuRedirectUrl, [DocumentUseNamePathForUrlPath] = @DocumentUseNamePathForUrlPath, [DocumentStylesheetID] = @DocumentStylesheetID, [DocumentContent] = @DocumentContent, [DocumentMenuClass] = @DocumentMenuClass, [DocumentMenuStyleOver] = @DocumentMenuStyleOver, [DocumentMenuClassOver] = @DocumentMenuClassOver, [DocumentMenuItemImageOver] = @DocumentMenuItemImageOver, [DocumentMenuItemLeftImageOver] = @DocumentMenuItemLeftImageOver, [DocumentMenuItemRightImageOver] = @DocumentMenuItemRightImageOver, [DocumentMenuStyleHighlighted] = @DocumentMenuStyleHighlighted, [DocumentMenuClassHighlighted] = @DocumentMenuClassHighlighted, [DocumentMenuItemImageHighlighted] = @DocumentMenuItemImageHighlighted, [DocumentMenuItemLeftImageHighlighted] = @DocumentMenuItemLeftImageHighlighted, [DocumentMenuItemRightImageHighlighted] = @DocumentMenuItemRightImageHighlighted, [DocumentMenuItemInactive] = @DocumentMenuItemInactive, [DocumentCustomData] = @DocumentCustomData WHERE [DocumentID] = @DocumentID' WHERE QueryName='update' AND ClassID=@classid
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.attachment')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] ='SELECT * FROM CMS_Attachment WHERE AttachmentGUID = @AttachmentGUID AND AttachmentSiteID = @AttachmentSiteID'WHERE QueryName='selectbyguid' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] ='SELECT * FROM CMS_Attachment WHERE [AttachmentID] = @ID'WHERE QueryName='select' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'SELECT AttachmentName, AttachmentExtension, AttachmentSize, AttachmentMimeType, AttachmentImageWidth, AttachmentImageHeight, AttachmentDocumentID, AttachmentGUID, AttachmentLastHistoryID FROM CMS_Attachment WHERE AttachmentGUID = @AttachmentGUID AND AttachmentSiteID = @AttachmentSiteID'WHERE QueryName='selectbyguidnobinary' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'DELETE FROM CMS_Attachment WHERE [AttachmentID] = @ID'WHERE QueryName='delete' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO CMS_Attachment ( [AttachmentName], [AttachmentExtension], [AttachmentSize], [AttachmentMimeType], [AttachmentBinary], [AttachmentImageWidth], [AttachmentImageHeight], [AttachmentDocumentID], [AttachmentGUID], [AttachmentLastHistoryID], [AttachmentSiteID] ) VALUES (  @AttachmentName, @AttachmentExtension, @AttachmentSize, @AttachmentMimeType, @AttachmentBinary, @AttachmentImageWidth, @AttachmentImageHeight, @AttachmentDocumentID, @AttachmentGUID, @AttachmentLastHistoryID, @AttachmentSiteID); SELECT @@identity AS [AttachmentID]'WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE CMS_Attachment SET  [AttachmentName] = @AttachmentName, [AttachmentExtension] = @AttachmentExtension, [AttachmentSize] = @AttachmentSize, [AttachmentMimeType] = @AttachmentMimeType, [AttachmentBinary] = @AttachmentBinary, [AttachmentImageWidth] = @AttachmentImageWidth, [AttachmentImageHeight] = @AttachmentImageHeight, [AttachmentDocumentID] = @AttachmentDocumentID, [AttachmentGUID] = @AttachmentGUID, [AttachmentLastHistoryID] = @AttachmentLastHistoryID, [AttachmentSiteID] = @AttachmentSiteID WHERE [AttachmentID] = @AttachmentID'WHERE QueryName='update' AND ClassID=@classid
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.attachmenthistory')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'SELECT * FROM CMS_AttachmentHistory WHERE [AttachmentHistoryID] = @ID' WHERE QueryName='select' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'DELETE FROM CMS_AttachmentHistory WHERE [AttachmentHistoryID] = @ID' WHERE QueryName='delete' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO CMS_AttachmentHistory ( [AttachmentName], [AttachmentExtension], [AttachmentSize], [AttachmentMimeType], [AttachmentBinary], [AttachmentImageWidth], [AttachmentImageHeight], [AttachmentDocumentID], [AttachmentGUID] ) VALUES (  @AttachmentName, @AttachmentExtension, @AttachmentSize, @AttachmentMimeType, @AttachmentBinary, @AttachmentImageWidth, @AttachmentImageHeight, @AttachmentDocumentID, @AttachmentGUID); SELECT @@identity AS [AttachmentHistoryID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] ='UPDATE CMS_AttachmentHistory SET  [AttachmentName] = @AttachmentName, [AttachmentExtension] = @AttachmentExtension, [AttachmentSize] = @AttachmentSize, [AttachmentMimeType] = @AttachmentMimeType, [AttachmentBinary] = @AttachmentBinary, [AttachmentImageWidth] = @AttachmentImageWidth, [AttachmentImageHeight] = @AttachmentImageHeight, [AttachmentDocumentID] = @AttachmentDocumentID, [AttachmentGUID] = @AttachmentGUID WHERE [AttachmentHistoryID] = @AttachmentHistoryID' WHERE QueryName='update' AND ClassID=@classid
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.form')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] ='INSERT INTO cms_form ( [FormDisplayName], [FormName], [FormSendToEmail], [FormSendFromEmail], [FormEmailSubject], [FormClassID], [FormItems], [FormReportFields], [FormRedirectToUrl], [FormDisplayText], [FormClearAfterSave], [FormSubmitButtonText], [FormSiteID], [FormConfirmationEmailField], [FormConfirmationTemplate], [FormConfirmationSendFromEmail], [FormConfirmationEmailSubject] ) VALUES (  @FormDisplayName, @FormName, @FormSendToEmail, @FormSendFromEmail, @FormEmailSubject, @FormClassID, @FormItems, @FormReportFields, @FormRedirectToUrl, @FormDisplayText, @FormClearAfterSave, @FormSubmitButtonText, @FormSiteID, @FormConfirmationEmailField, @FormConfirmationTemplate, @FormConfirmationSendFromEmail, @FormConfirmationEmailSubject); SELECT @@identity AS [FormID]' WHERE QueryName='insert' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] = 'UPDATE cms_form SET  [FormDisplayName] = @FormDisplayName, [FormName] = @FormName, [FormSendToEmail] = @FormSendToEmail, [FormSendFromEmail] = @FormSendFromEmail, [FormEmailSubject] = @FormEmailSubject, [FormClassID] = @FormClassID, [FormItems] = @FormItems, [FormReportFields] = @FormReportFields, [FormRedirectToUrl] = @FormRedirectToUrl, [FormDisplayText] = @FormDisplayText, [FormClearAfterSave] = @FormClearAfterSave, [FormSubmitButtonText] = @FormSubmitButtonText, [FormSiteID] = @FormSiteID, [FormConfirmationEmailField] = @FormConfirmationEmailField, [FormConfirmationTemplate] = @FormConfirmationTemplate, [FormConfirmationSendFromEmail] = @FormConfirmationSendFromEmail, [FormConfirmationEmailSubject] = @FormConfirmationEmailSubject WHERE [FormID] = @FormID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='newsletter.emailtemplate')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO Newsletter_EmailTemplate ( [TemplateDisplayName], [TemplateName], [TemplateBody], [TemplateSiteID], [TemplateHeader], [TemplateFooter], [TemplateType], [TemplateStylesheetText] ) VALUES (  @TemplateDisplayName, @TemplateName, @TemplateBody, @TemplateSiteID, @TemplateHeader, @TemplateFooter, @TemplateType, @TemplateStylesheetText); SELECT @@identity AS [TemplateID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE Newsletter_EmailTemplate SET  [TemplateDisplayName] = @TemplateDisplayName, [TemplateName] = @TemplateName, [TemplateBody] = @TemplateBody, [TemplateSiteID] = @TemplateSiteID, [TemplateHeader] = @TemplateHeader, [TemplateFooter] = @TemplateFooter, [TemplateType] = @TemplateType, [TemplateStylesheetText] = @TemplateStylesheetText WHERE [TemplateID] = @TemplateID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.ScheduledTask')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO CMS_ScheduledTask ( [TaskName], [TaskDisplayName], [TaskAssemblyName], [TaskClass], [TaskInterval], [TaskData], [TaskLastRunTime], [TaskNextRunTime], [TaskProgress], [TaskLastResult], [TaskEnabled], [TaskSiteID], [TaskDeleteAfterLastRun], [TaskServerName] ) VALUES (  @TaskName, @TaskDisplayName, @TaskAssemblyName, @TaskClass, @TaskInterval, @TaskData, @TaskLastRunTime, @TaskNextRunTime, @TaskProgress, @TaskLastResult, @TaskEnabled, @TaskSiteID, @TaskDeleteAfterLastRun, @TaskServerName); SELECT @@identity AS [TaskID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE CMS_ScheduledTask SET  [TaskName] = @TaskName, [TaskDisplayName] = @TaskDisplayName, [TaskAssemblyName] = @TaskAssemblyName, [TaskClass] = @TaskClass, [TaskInterval] = @TaskInterval, [TaskData] = @TaskData, [TaskLastRunTime] = @TaskLastRunTime, [TaskNextRunTime] = @TaskNextRunTime, [TaskProgress] = @TaskProgress, [TaskLastResult] = @TaskLastResult, [TaskEnabled] = @TaskEnabled, [TaskSiteID] = @TaskSiteID, [TaskDeleteAfterLastRun] = @TaskDeleteAfterLastRun, [TaskServerName] = @TaskServerName WHERE [TaskID] = @TaskID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='newsletter.emails')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'SELECT EmailID, NewsletterDisplayName, EmailSubject, SubscriberEmail , ErrorMessage, SiteDisplayName FROM CMS_Site INNER JOIN Newsletter_Newsletter ON SiteID = NewsletterSiteID INNER JOIN Newsletter_NewsletterIssue ON NewsletterID = IssueNewsletterID INNER JOIN Newsletter_Emails ON IssueID = EmailNewsletterIssueID INNER JOIN Newsletter_Subscriber ON Newsletter_Emails.EmailSubscriberID = Newsletter_Subscriber.SubscriberID  WHERE ##WHERE##' WHERE QueryName='selectqueue' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='newsletter.newsletter')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'SELECT * FROM Newsletter_Newsletter WHERE NewsletterGUID = @NewsletterGUID AND NewsletterSiteID=@NewsletterSiteID'  WHERE QueryName='selectbynewsletterguid' AND ClassID=@classid
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Forums.Forum')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO Forums_Forum ( [ForumGroupID], [ForumName], [ForumDisplayName], [ForumDescription], [ForumOrder], [ForumDocumentID], [ForumOpen], [ForumModerated], [ForumDisplayEmails], [ForumRequireEmail], [ForumAccess], [ForumThreads], [ForumPosts], [ForumLastPostTime], [ForumLastPostUserName], [ForumBaseUrl], [ForumAllowChangeName], [ForumHTMLEditor], [ForumUseCAPTCHA] ) VALUES (  @ForumGroupID, @ForumName, @ForumDisplayName, @ForumDescription, @ForumOrder, @ForumDocumentID, @ForumOpen, @ForumModerated, @ForumDisplayEmails, @ForumRequireEmail, @ForumAccess, @ForumThreads, @ForumPosts, @ForumLastPostTime, @ForumLastPostUserName, @ForumBaseUrl, @ForumAllowChangeName, @ForumHTMLEditor, @ForumUseCAPTCHA); SELECT @@identity AS [ForumID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE Forums_Forum SET  [ForumGroupID] = @ForumGroupID, [ForumName] = @ForumName, [ForumDisplayName] = @ForumDisplayName, [ForumDescription] = @ForumDescription, [ForumOrder] = @ForumOrder, [ForumDocumentID] = @ForumDocumentID, [ForumOpen] = @ForumOpen, [ForumModerated] = @ForumModerated, [ForumDisplayEmails] = @ForumDisplayEmails, [ForumRequireEmail] = @ForumRequireEmail, [ForumAccess] = @ForumAccess, [ForumThreads] = @ForumThreads, [ForumPosts] = @ForumPosts, [ForumLastPostTime] = @ForumLastPostTime, [ForumLastPostUserName] = @ForumLastPostUserName, [ForumBaseUrl] = @ForumBaseUrl, [ForumAllowChangeName] = @ForumAllowChangeName, [ForumHTMLEditor] = @ForumHTMLEditor, [ForumUseCAPTCHA] = @ForumUseCAPTCHA WHERE [ForumID] = @ForumID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Forums.ForumSubscription')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] =  'SELECT * FROM Forums_ForumSubscription WHERE [SubscriptionID] = @ID' WHERE QueryName='select' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] =  'DELETE FROM Forums_ForumSubscription WHERE [SubscriptionID] = @ID' WHERE QueryName='delete' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] =  'INSERT INTO Forums_ForumSubscription ( [SubscriptionUserID], [SubscriptionEmail], [SubscriptionForumID], [SubscriptionPostID], [SubscriptionGUID] ) VALUES (  @SubscriptionUserID, @SubscriptionEmail, @SubscriptionForumID, @SubscriptionPostID, @SubscriptionGUID); SELECT @@identity AS [SubscriptionID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE Forums_ForumSubscription SET  [SubscriptionUserID] = @SubscriptionUserID, [SubscriptionEmail] = @SubscriptionEmail, [SubscriptionForumID] = @SubscriptionForumID, [SubscriptionPostID] = @SubscriptionPostID, [SubscriptionGUID] = @SubscriptionGUID WHERE [SubscriptionID] = @SubscriptionID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Forums.ForumPost')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'SELECT *  FROM  [Forums_ForumPost] WHERE PostIDPath LIKE @Path + ''/%''' WHERE QueryName='getchildposts' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.orderstatus')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] =  'INSERT INTO COM_OrderStatus ( [StatusName], [StatusDisplayName], [StatusOrder], [StatusEnabled], [StatusColor] ) VALUES (  @StatusName, @StatusDisplayName, @StatusOrder, @StatusEnabled, @StatusColor); SELECT @@identity AS [StatusID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] =  'UPDATE COM_OrderStatus SET  [StatusName] = @StatusName, [StatusDisplayName] = @StatusDisplayName, [StatusOrder] = @StatusOrder, [StatusEnabled] = @StatusEnabled, [StatusColor] = @StatusColor WHERE [StatusID] = @StatusID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.taxclass')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO COM_TaxClass ( [TaxClassName], [TaxClassDisplayName], [TaxClassZeroIfIDSupplied] ) VALUES (  @TaxClassName, @TaxClassDisplayName, @TaxClassZeroIfIDSupplied); SELECT @@identity AS [TaxClassID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE COM_TaxClass SET  [TaxClassName] = @TaxClassName, [TaxClassDisplayName] = @TaxClassDisplayName, [TaxClassZeroIfIDSupplied] = @TaxClassZeroIfIDSupplied WHERE [TaxClassID] = @TaxClassID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.customer')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] = 'INSERT INTO COM_Customer ( [CustomerFirstName], [CustomerLastName], [CustomerEmail], [CustomerPhone], [CustomerFax], [CustomerCompany], [CustomerUserID], [CustomerPreferredCurrencyID], [CustomerPreferredShippingOptionID], [CustomerCountryID], [CustomerEnabled], [CustomerPrefferedPaymentOptionID], [CustomerStateID], [CustomerGUID], [CustomerTaxRegistrationID], [CustomerOrganizationID], [CustomerDiscountLevelID] ) VALUES (  @CustomerFirstName, @CustomerLastName, @CustomerEmail, @CustomerPhone, @CustomerFax, @CustomerCompany, @CustomerUserID, @CustomerPreferredCurrencyID, @CustomerPreferredShippingOptionID, @CustomerCountryID, @CustomerEnabled, @CustomerPrefferedPaymentOptionID, @CustomerStateID, @CustomerGUID, @CustomerTaxRegistrationID, @CustomerOrganizationID, @CustomerDiscountLevelID); SELECT @@identity AS [CustomerID]' WHERE QueryName='insert' AND ClassID=@classid
UPDATE [CMS_Query] SET [QueryText] = 'UPDATE COM_Customer SET  [CustomerFirstName] = @CustomerFirstName, [CustomerLastName] = @CustomerLastName, [CustomerEmail] = @CustomerEmail, [CustomerPhone] = @CustomerPhone, [CustomerFax] = @CustomerFax, [CustomerCompany] = @CustomerCompany, [CustomerUserID] = @CustomerUserID, [CustomerPreferredCurrencyID] = @CustomerPreferredCurrencyID, [CustomerPreferredShippingOptionID] = @CustomerPreferredShippingOptionID, [CustomerCountryID] = @CustomerCountryID, [CustomerEnabled] = @CustomerEnabled, [CustomerPrefferedPaymentOptionID] = @CustomerPrefferedPaymentOptionID, [CustomerStateID] = @CustomerStateID, [CustomerGUID] = @CustomerGUID, [CustomerTaxRegistrationID] = @CustomerTaxRegistrationID, [CustomerOrganizationID] = @CustomerOrganizationID, [CustomerDiscountLevelID] = @CustomerDiscountLevelID WHERE [CustomerID] = @CustomerID' WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.SKU')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] =  'INSERT INTO COM_SKU ( [SKUNumber], [SKUName], [SKUDescription], [SKUPrice], [SKUEnabled], [SKUDepartmentID], [SKUManufacturerID], [SKUInternalStatusID], [SKUPublicStatusID], [SKUSupplierID], [SKUAvailableInDays], [SKUGUID], [SKUImagePath], [SKUWeight], [SKUWidth], [SKUDepth], [SKUHeight], [SKUAvailableItems], [SKUSellOnlyAvailable] ) VALUES (  @SKUNumber, @SKUName, @SKUDescription, @SKUPrice, @SKUEnabled, @SKUDepartmentID, @SKUManufacturerID, @SKUInternalStatusID, @SKUPublicStatusID, @SKUSupplierID, @SKUAvailableInDays, @SKUGUID, @SKUImagePath, @SKUWeight, @SKUWidth, @SKUDepth, @SKUHeight, @SKUAvailableItems, @SKUSellOnlyAvailable); SELECT @@identity AS [SKUID]'  WHERE QueryName='insert' AND ClassID=@classid

UPDATE [CMS_Query] SET [QueryText] =  'UPDATE COM_SKU SET  [SKUNumber] = @SKUNumber, [SKUName] = @SKUName, [SKUDescription] = @SKUDescription, [SKUPrice] = @SKUPrice, [SKUEnabled] = @SKUEnabled, [SKUDepartmentID] = @SKUDepartmentID, [SKUManufacturerID] = @SKUManufacturerID, [SKUInternalStatusID] = @SKUInternalStatusID, [SKUPublicStatusID] = @SKUPublicStatusID, [SKUSupplierID] = @SKUSupplierID, [SKUAvailableInDays] = @SKUAvailableInDays, [SKUGUID] = @SKUGUID, [SKUImagePath] = @SKUImagePath, [SKUWeight] = @SKUWeight, [SKUWidth] = @SKUWidth, [SKUDepth] = @SKUDepth, [SKUHeight] = @SKUHeight, [SKUAvailableItems] = @SKUAvailableItems, [SKUSellOnlyAvailable] = @SKUSellOnlyAvailable WHERE [SKUID] = @SKUID'  WHERE QueryName='update' AND ClassID=@classid
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.shoppingcart')
if @classid<>0
begin
UPDATE [CMS_Query] SET [QueryText] =  'SELECT COM_SKUTaxClasses.SKUID, COM_TaxClassCountry.IsFlatValue, COM_TaxClassCountry.TaxValue, COM_TaxClass.TaxClassID, COM_TaxClass.TaxClassDisplayName, COM_TaxClass.TaxClassZeroIfIDSupplied FROM (COM_SKUTaxClasses INNER JOIN COM_TaxClass ON COM_SKUTaxClasses.TaxClassID = COM_TaxClass.TaxClassID) INNER JOIN COM_TaxClassCountry ON COM_TaxClass.TaxClassID = COM_TaxClassCountry.TaxClassID WHERE (COM_TaxClassCountry.CountryID = @CountryID) AND (##WHERE##) ORDER BY ##ORDERBY##' WHERE QueryName='selecttaxclasses' AND ClassID=@classid 
END
GO


------------------------new queries
DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.country')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectcountrieswithstates', 0, 'SELECT DISTINCT CMS_Country.* FROM CMS_Country,CMS_State WHERE CMS_Country.CountryID=CMS_State.CountryID;', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.eventlog')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM CMS_EventLog WHERE [EventID] = @ID', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.tree')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM CMS_Tree WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'updatelinks', 1, 'Proc_CMS_Tree_UpdateLinks', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'movenodelast', 1, 'Proc_CMS_Tree_MoveNodeLast', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'movenodefirst', 1, 'Proc_CMS_Tree_MoveNodeFirst', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'movenodealphabetical', 1, 'Proc_CMS_Tree_MoveNodeAlphabetical', 1, @classid, 1)
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.document')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectOwned', 0, 'SELECT CMS_Tree.*, CMS_Document.*, CMS_Class.ClassName, CMS_Class.ClassDisplayName, CMS_WorkflowStep.StepDisplayName FROM CMS_Tree LEFT JOIN CMS_Document ON CMS_Tree.NodeID = CMS_Document.DocumentNodeID LEFT JOIN CMS_Class ON CMS_Tree.NodeClassID=CMS_Class.ClassID LEFT OUTER JOIN CMS_WorkflowStep ON CMS_Document.DocumentWorkflowStepID=CMS_WorkflowStep.StepID WHERE CMS_Tree.NodeOwner = @UserID AND CMS_Tree.NodeSIteID=@SiteID ORDER BY ##orderby##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectOutdated', 0, 'SELECT CMS_Tree.*, CMS_Document.*, CMS_Class.ClassName, CMS_Class.ClassDisplayName, CMS_WorkflowStep.StepDisplayName FROM CMS_Tree LEFT JOIN CMS_Document ON CMS_Tree.NodeID = CMS_Document.DocumentNodeID LEFT JOIN CMS_Class ON CMS_Tree.NodeClassID=CMS_Class.ClassID LEFT OUTER JOIN CMS_WorkflowStep ON CMS_Document.DocumentWorkflowStepID=CMS_WorkflowStep.StepID WHERE ((CMS_Document.DocumentCreatedByUserID = @UserID OR CMS_Document.DocumentModifiedByUserID = @UserID OR CMS_Document.DocumentCheckedOutByUserID = @UserID) AND CMS_Document.DocumentModifiedWhen<=@OlderThan AND CMS_Tree.NodeSIteID=@SiteID) ORDER BY ##orderby##', 0, @classid, 0)
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.workflowstep')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM [CMS_WorkflowStep] WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO

DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.versionhistory')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'updatesiteid', 0, 'UPDATE CMS_VersionHistory SET NodeSiteID = @NewSiteID WHERE DocumentID = @DocumentID', 1, @classid, 1)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.attachmenthistory')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'getversionwithoutbinary', 0, 'SELECT AttachmentHistoryID, AttachmentName, AttachmentExtension, AttachmentSize, AttachmentMimeType, AttachmentImageWidth, AttachmentImageHeight, AttachmentDocumentID, AttachmentGUID FROM CMS_AttachmentHistory WHERE AttachmentGUID = @AttachmentGUID AND AttachmentHistoryID IN (SELECT AttachmentHistoryID FROM CMS_VersionAttachment WHERE VersionHistoryID = @VersionHistoryID)', 0, @classid, 1)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='newsletter.subscriber')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'SelectAllForSubExport', 0, 'SELECT DISTINCT SubscriberEmail, SubscriberFirstName, SubscriberLastName FROM Newsletter_Subscriber WHERE (SubscriberSiteID = @SiteID)', 0, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'SelectForSubExport', 0, 'SELECT DISTINCT SubscriberEmail, SubscriberFirstName,SubscriberLastName FROM Newsletter_Subscriber WHERE (SubscriberID IN (SELECT SubscriberID FROM Newsletter_SubscriberNewsletter WHERE ##WHERE##)) ORDER BY SubscriberEmail', 0, @classid, 1)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Forums.ForumSubscription')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectByGuid', 0, 'SELECT * FROM Forums_ForumSubscription WHERE [SubscriptionGuid] = @Guid', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.paymentoption')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'addPaymentToShipping', 0, 'INSERT INTO COM_PaymentShipping ([paymentOptionId], [shippingOptionId]) VALUES ( @paymentId, @shippingId);', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'RemovePaymentFromShipping', 0, 'DELETE FROM COM_PaymentShipping WHERE ([paymentOptionId] = @paymentId) AND ([shippingOptionId] = @shippingId);', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'SelectPaymentForShipping', 0, 'SELECT COM_PaymentOption.PaymentOptionDisplayName, COM_PaymentOption.PaymentOptionSiteId , COM_PaymentShipping.ShippingOptionID, COM_PaymentOption.PaymentOptionID FROM COM_PaymentOption LEFT JOIN COM_PaymentShipping ON ((COM_PaymentShipping.PaymentOptionID = COM_PaymentOption.PaymentOptionID) AND COM_PaymentShipping.ShippingOptionID = @ShippingOptionID ) WHERE COM_PaymentOption.PaymentOptionSiteID = (SELECT ShippingOptionSiteID FROM COM_ShippingOption WHERE ShippingOptionID = @ShippingOptionID)  ORDER BY PaymentOptionDisplayName;', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'RemoveDependencies', 1, 'Proc_COM_PaymentOption_RemoveDependences', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectPaymentShippingForExport', 0, 'SELECT * FROM COM_PaymentShipping WHERE ##WHERE## AND PaymentOptionID IN (SELECT PaymentOptionID FROM COM_PaymentOption WHERE PaymentOptionSiteID=@SiteID) AND ShippingOptionID IN (SELECT ShippingOptionID FROM COM_ShippingOption WHERE ShippingOptionSiteID=@SiteID)', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'IsPaymentInShipping', 0, 'SELECT * FROM COM_PaymentShipping WHERE PaymentOptionID=@paymentID AND ShippingOptionID=@shippingID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectshippingpayments', 0, 'SELECT * FROM COM_PaymentOption,COM_PaymentShipping  WHERE COM_PaymentOption.PaymentOptionID=COM_PaymentShipping.PaymentOptionID AND COM_PaymentShipping.ShippingOptionID=@ShippingID AND (##WHERE##) ORDER BY PaymentOptionDisplayName;', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.orderstatus')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectnextenabledstatus', 0, 'SELECT TOP 1 * FROM COM_OrderStatus WHERE StatusOrder >(SELECT StatusOrder FROM COM_OrderStatus WHERE StatusID = @StatusID) AND StatusEnabled = 1 ORDER BY StatusOrder', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectpreviousenabledstatus', 0, 'SELECT TOP 1 * FROM COM_OrderStatus WHERE StatusOrder < (SELECT StatusOrder FROM COM_OrderStatus WHERE StatusID = @StatusID) AND StatusEnabled = 1 ORDER BY StatusOrder DESC', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Ecommerce.ShippingOption')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'RemoveDependencies', 1, 'Proc_COM_ShippingOption_RemoveDependences', 1, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Ecommerce.SKU')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'addskutowishlist', 0, 'INSERT INTO COM_Wishlist(UserID, SKUID) VALUES (@UserID, @SKUID)', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removeskufromwishlist', 0, 'DELETE FROM COM_Wishlist WHERE UserID = @UserID AND SKUID = @SKUID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectwishlistforuser', 0, 'SELECT COM_SKU.* FROM COM_SKU, COM_Wishlist WHERE COM_Wishlist.UserID = @UserID AND COM_Wishlist.SKUID = COM_SKU.SKUID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'IsInUserWishlist', 0, 'SELECT * FROM COM_Wishlist WHERE SKUID = @SKUID AND UserID = @UserID', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.orderitem')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectallbyorderid', 0, 'SELECT * FROM COM_OrderItem WHERE OrderItemOrderID = @OrderId', 0, @classid, 0)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.shoppingcart')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectstatetaxclasses', 0, 'SELECT COM_SKUTaxClasses.SKUID, COM_TaxClass.TaxClassID, COM_TaxClass.TaxClassDisplayName, COM_TaxClass.TaxClassZeroIfIDSupplied, COM_TaxClassState.StateID, COM_TaxClassState.TaxValue, COM_TaxClassState.IsFlatValue FROM (COM_SKUTaxClasses INNER JOIN COM_TaxClass ON COM_SKUTaxClasses.TaxClassID = COM_TaxClass.TaxClassID)  INNER JOIN COM_TaxClassState ON COM_TaxClass.TaxClassID = COM_TaxClassState.TaxClassID WHERE COM_TaxClassState.StateID IN (SELECT StateID FROM CMS_State WHERE CountryID = @CountryID) AND (##WHERE##) ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='polls.poll')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ('select', 0, 'SELECT * FROM Polls_Poll WHERE [PollID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Polls_Poll WHERE [PollID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Polls_Poll ( [PollCodeName], [PollDisplayName], [PollTitle], [PollOpenFrom], [PollOpenTo], [PollAllowMultipleAnswers], [PollQuestion], [PollAccess], [PollResponseMessage] ) VALUES (  @PollCodeName, @PollDisplayName, @PollTitle, @PollOpenFrom, @PollOpenTo, @PollAllowMultipleAnswers, @PollQuestion, @PollAccess, @PollResponseMessage); SELECT @@identity AS [PollID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Polls_Poll SET  [PollCodeName] = @PollCodeName, [PollDisplayName] = @PollDisplayName, [PollTitle] = @PollTitle, [PollOpenFrom] = @PollOpenFrom, [PollOpenTo] = @PollOpenTo, [PollAllowMultipleAnswers] = @PollAllowMultipleAnswers, [PollQuestion] = @PollQuestion, [PollAccess] = @PollAccess, [PollResponseMessage] = @PollResponseMessage WHERE [PollID] = @PollID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Polls_Poll WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'RemoveDependencies', 1, 'Proc_Polls_Poll_RemoveDependences', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectbyname', 0, 'SELECT * FROM Polls_Poll WHERE [PollCodeName]=@Name', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'addtosite', 0, 'INSERT INTO Polls_PollSite (PollID,SiteID) VALUES (@PollID,@SiteID)', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'addrole', 0, 'INSERT INTO Polls_PollRoles (PollID,RoleID) VALUES (@PollID,@RoleID)', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removefromsite', 0, 'DELETE FROM Polls_PollSite WHERE PollID=@PollID AND SiteID=@SiteID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removerole', 0, 'DELETE FROM Polls_PollRoles WHERE PollID=@PollID AND RoleID=@RoleID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectroles', 0, 'SELECT * FROM CMS_Role INNER JOIN Polls_PollRoles ON CMS_Role.RoleID=Polls_PollRoles.RoleID WHERE Polls_PollRoles.PollID=@PollID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectlist', 0, 'SELECT Polls_Poll.*, SUM(Polls_PollAnswer.AnswerCount) as AnswerCount FROM Polls_Poll LEFT JOIN Polls_PollAnswer ON PollID=AnswerPollID GROUP BY PollID,PollCodeName,PollDisplayName,PollTitle,PollOpenFrom,PollOpenTo,PollAllowMultipleAnswers,PollQuestion,PollAccess,PollResponseMessage', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectallofsite', 0, 'SELECT * FROM Polls_Poll WHERE PollID IN (SELECT PollID FROM Polls_PollSite WHERE SiteID=@SiteID) ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectsites', 0, 'SELECT * FROM CMS_Site INNER JOIN Polls_PollSite ON CMS_Site.SiteID=Polls_PollSite.SiteID WHERE Polls_PollSite.PollID=@PollID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectPollPollsForExport', 0, 'SELECT * FROM Polls_Poll WHERE ##WHERE## AND (PollID IN (SELECT PollID FROM Polls_PollSite WHERE SiteID=@SiteID) OR @SiteID=0)', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectPollRolesForExport', 0, 'SELECT * FROM Polls_PollRoles WHERE ##WHERE## AND PollID IN (SELECT PollID FROM Polls_Poll WHERE (PollID IN (SELECT PollID FROM Polls_PollSite WHERE SiteID=@SiteID) OR @SiteID=0))', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='polls.pollanswer')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Polls_PollAnswer WHERE [AnswerID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Polls_PollAnswer WHERE [AnswerID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Polls_PollAnswer ( [AnswerText], [AnswerOrder], [AnswerCount], [AnswerEnabled], [AnswerPollID] ) VALUES (  @AnswerText, @AnswerOrder, @AnswerCount, @AnswerEnabled, @AnswerPollID); SELECT @@identity AS [AnswerID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Polls_PollAnswer SET  [AnswerText] = @AnswerText, [AnswerOrder] = @AnswerOrder, [AnswerCount] = @AnswerCount, [AnswerEnabled] = @AnswerEnabled, [AnswerPollID] = @AnswerPollID WHERE [AnswerID] = @AnswerID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Polls_PollAnswer WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'initorders', 1, 'Proc_Polls_PollAnswer_InitOrders', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'moveup', 1, 'Proc_Polls_PollAnswer_MoveUp', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'movedown', 1, 'Proc_Polls_PollAnswer_MoveDown', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectPollAnswersForExport', 0, 'SELECT * FROM Polls_PollAnswer WHERE ##WHERE## AND AnswerPollID IN (SELECT PollID FROM Polls_Poll WHERE (PollID IN (SELECT PollID FROM Polls_PollSite WHERE SiteID=@SiteID) OR @SiteID=0))', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'deleteanswers', 0, 'DELETE FROM Polls_PollAnswer WHERE AnswerPollID=@ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'resetanswers', 0, 'UPDATE Polls_PollAnswer SET [AnswerCount] = 0 WHERE [AnswerPollID] = @ID', 0, @classid, 0)
END
GO



/*
DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='cms.versionhistory')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM TestFormPetrVoTable1 WHERE [TestFormPetrVo1ID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM TestFormPetrVoTable1 WHERE [TestFormPetrVo1ID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO TestFormPetrVoTable1 ( [FormInserted], [FormUpdated], [fff] ) VALUES (  @FormInserted, @FormUpdated, @fff); SELECT @@identity AS [TestFormPetrVo1ID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE TestFormPetrVoTable1 SET  [FormInserted] = @FormInserted, [FormUpdated] = @FormUpdated, [fff] = @fff WHERE [TestFormPetrVo1ID] = @TestFormPetrVo1ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM TestFormPetrVoTable1 WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, 1332, 0)
END
GO*/



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.Report')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_Report WHERE [ReportID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_Report WHERE [ReportID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_Report ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess] ) VALUES (  @ReportName, @ReportDisplayName, @ReportLayout, @ReportParameters, @ReportCategoryID, @ReportAccess); SELECT @@identity AS [ReportID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_Report SET  [ReportName] = @ReportName, [ReportDisplayName] = @ReportDisplayName, [ReportLayout] = @ReportLayout, [ReportParameters] = @ReportParameters, [ReportCategoryID] = @ReportCategoryID, [ReportAccess] = @ReportAccess WHERE [ReportID] = @ReportID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_Report WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingReportsForExport', 0, 'SELECT * FROM Reporting_Report WHERE ##WHERE##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removeDependencies', 1, 'Proc_Reporting_Report_RemoveDependencies', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectCategoryAndReport', 0, 'SELECT CategoryDisplayName + '' - '' + ReportDisplayName AS ''CategoryAndReportName'', ReportId FROM Reporting_Report INNER JOIN Reporting_ReportCategory ON Reporting_Report.ReportCategoryID = Reporting_ReportCategory.CategoryID ORDER BY Reporting_ReportCategory.CategoryDisplayName, Reporting_Report.ReportDisplayName', 0, @classid, 0)
END
GO




DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.ReportGraph')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_ReportGraph WHERE [GraphID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_ReportGraph WHERE [GraphID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_ReportGraph ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition] ) VALUES (  @GraphName, @GraphDisplayName, @GraphQuery, @GraphQueryIsStoredProcedure, @GraphType, @GraphReportID, @GraphTitle, @GraphXAxisTitle, @GraphYAxisTitle, @GraphWidth, @GraphHeight, @GraphLegendPosition); SELECT @@identity AS [GraphID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_ReportGraph SET  [GraphName] = @GraphName, [GraphDisplayName] = @GraphDisplayName, [GraphQuery] = @GraphQuery, [GraphQueryIsStoredProcedure] = @GraphQueryIsStoredProcedure, [GraphType] = @GraphType, [GraphReportID] = @GraphReportID, [GraphTitle] = @GraphTitle, [GraphXAxisTitle] = @GraphXAxisTitle, [GraphYAxisTitle] = @GraphYAxisTitle, [GraphWidth] = @GraphWidth, [GraphHeight] = @GraphHeight, [GraphLegendPosition] = @GraphLegendPosition WHERE [GraphID] = @GraphID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_ReportGraph WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'deleteReportGraphs', 0, 'DELETE FROM Reporting_ReportGraph WHERE [GraphReportId] = @ID;', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingGraphsForExport', 0, 'SELECT * FROM Reporting_ReportGraph WHERE ##WHERE##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.ReportTable')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_ReportTable WHERE [TableID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_ReportTable WHERE [TableID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_ReportTable ( [TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID] ) VALUES (  @TableName, @TableDisplayName, @TableQuery, @TableQueryIsStoredProcedure, @TableReportID); SELECT @@identity AS [TableID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_ReportTable SET  [TableName] = @TableName, [TableDisplayName] = @TableDisplayName, [TableQuery] = @TableQuery, [TableQueryIsStoredProcedure] = @TableQueryIsStoredProcedure, [TableReportID] = @TableReportID WHERE [TableID] = @TableID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_ReportTable WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingTablesForExport', 0, 'SELECT * FROM Reporting_ReportTable WHERE ##WHERE##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'deleteReportTables', 0, 'DELETE FROM Reporting_ReportTable WHERE [TableReportId] = @ID;', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.ReportValue')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_ReportValue WHERE [ValueID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_ReportValue WHERE [ValueID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_ReportValue ( [ValueName], [ValueDisplayName], [ValueQuery], [ValueQueryIsStoredProcedure], [ValueFormatString], [ValueReportID] ) VALUES (  @ValueName, @ValueDisplayName, @ValueQuery, @ValueQueryIsStoredProcedure, @ValueFormatString, @ValueReportID); SELECT @@identity AS [ValueID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_ReportValue SET  [ValueName] = @ValueName, [ValueDisplayName] = @ValueDisplayName, [ValueQuery] = @ValueQuery, [ValueQueryIsStoredProcedure] = @ValueQueryIsStoredProcedure, [ValueFormatString] = @ValueFormatString, [ValueReportID] = @ValueReportID WHERE [ValueID] = @ValueID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_ReportValue WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'deleteReportValues', 0, 'DELETE FROM Reporting_ReportValue WHERE [ValueReportId] = @ID;', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingValuesForExport', 0, 'SELECT * FROM Reporting_ReportValue WHERE ##WHERE##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.SavedGraph')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_SavedGraph WHERE [SavedGraphID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_SavedGraph WHERE [SavedGraphID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_SavedGraph ( [SavedGraphSavedReportID], [SavedGraphGUID], [SavedGraphBinary], [SavedGraphMimeType] ) VALUES (  @SavedGraphSavedReportID, @SavedGraphGUID, @SavedGraphBinary, @SavedGraphMimeType); SELECT @@identity AS [SavedGraphID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_SavedGraph SET  [SavedGraphSavedReportID] = @SavedGraphSavedReportID, [SavedGraphGUID] = @SavedGraphGUID, [SavedGraphBinary] = @SavedGraphBinary, [SavedGraphMimeType] = @SavedGraphMimeType WHERE [SavedGraphID] = @SavedGraphID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_SavedGraph WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingSavedGraphsForExport', 0, 'SELECT * FROM Reporting_SavedGraph WHERE ##WHERE##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.SavedReport')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_SavedReport WHERE [SavedReportID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_SavedReport WHERE [SavedReportID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_SavedReport ( [SavedReportReportID], [SavedReportGUID], [SavedReportTitle], [SavedReportDate], [SavedReportHTML], [SavedReportParameters], [SavedReportCreatedByUserID] ) VALUES (  @SavedReportReportID, @SavedReportGUID, @SavedReportTitle, @SavedReportDate, @SavedReportHTML, @SavedReportParameters, @SavedReportCreatedByUserID); SELECT @@identity AS [SavedReportID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_SavedReport SET  [SavedReportReportID] = @SavedReportReportID, [SavedReportGUID] = @SavedReportGUID, [SavedReportTitle] = @SavedReportTitle, [SavedReportDate] = @SavedReportDate, [SavedReportHTML] = @SavedReportHTML, [SavedReportParameters] = @SavedReportParameters, [SavedReportCreatedByUserID] = @SavedReportCreatedByUserID WHERE [SavedReportID] = @SavedReportID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_SavedReport WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingSavedReportsForExport', 0, 'SELECT * FROM Reporting_SavedReport WHERE ##WHERE##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removeDependencies', 1, 'Proc_Reporting_SavedReports_RemoveDependencies', 1, @classid, 1)
END
GO


DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='blog.comment')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Blog_Comment WHERE [CommentID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Blog_Comment WHERE [CommentID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Blog_Comment ( [CommentUserName], [CommentUserID], [CommentUrl], [CommentText], [CommentApprovedByUserID], [CommentPostDocumentID], [CommentDate] ) VALUES (  @CommentUserName, @CommentUserID, @CommentUrl, @CommentText, @CommentApprovedByUserID, @CommentPostDocumentID, @CommentDate); SELECT @@identity AS [CommentID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Blog_Comment SET  [CommentUserName] = @CommentUserName, [CommentUserID] = @CommentUserID, [CommentUrl] = @CommentUrl, [CommentText] = @CommentText, [CommentApprovedByUserID] = @CommentApprovedByUserID, [CommentPostDocumentID] = @CommentPostDocumentID, [CommentDate] = @CommentDate WHERE [CommentID] = @CommentID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Blog_Comment WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectBlogCommentsForExport', 0, 'SELECT * FROM Blog_Comment WHERE ##WHERE## AND CommentPostDocumentID IN (SELECT DocumentID FROM View_CMS_Tree_Joined WHERE NodeSiteID=@SiteID)', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectforpost', 0, 'SELECT * FROM Blog_Comment WHERE CommentPostDocumentID = @CommentPostDocumentID AND (##WHERE##) ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'deletepostblogcomments', 0, 'DELETE FROM Blog_Comment WHERE CommentPostDocumentID = @CommentPostDocumentID', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='analytics.statistics')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Analytics_Statistics WHERE [StatisticsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Analytics_Statistics WHERE [StatisticsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Analytics_Statistics ( [StatisticsSiteID], [StatisticsCode], [StatisticsObjectName], [StatisticsObjectID], [StatisticsObjectCulture] ) VALUES (  @StatisticsSiteID, @StatisticsCode, @StatisticsObjectName, @StatisticsObjectID, @StatisticsObjectCulture); SELECT @@identity AS [StatisticsID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Analytics_Statistics SET  [StatisticsSiteID] = @StatisticsSiteID, [StatisticsCode] = @StatisticsCode, [StatisticsObjectName] = @StatisticsObjectName, [StatisticsObjectID] = @StatisticsObjectID, [StatisticsObjectCulture] = @StatisticsObjectCulture WHERE [StatisticsID] = @StatisticsID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Analytics_Statistics WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectspec', 0, 'SELECT * FROM Analytics_Statistics, ##WHERE## WHERE StatisticsSiteID=@SiteID AND StatisticsCode=@CodeName AND StatisticsID=HitsStatisticsID AND HitsStartTime <= @Time AND @Time < HitsEndTime', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'processlog', 1, 'Proc_Analytics_ProcessLog', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectspecbetween', 0, 'SELECT * FROM Analytics_Statistics, ##WHERE## WHERE StatisticsSiteID=@SiteID AND StatisticsCode=@CodeName AND StatisticsID=HitsStatisticsID AND HitsStartTime >= @TimeFrom', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'getcodenames', 0, 'SELECT DISTINCT StatisticsCode FROM Analytics_Statistics', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removedependencies', 1, 'Proc_Analytics_Statistics_RemoveDependencies', 1, @classid, 1)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectbycodename', 0, 'SELECT DISTINCT * FROM Analytics_Statistics WHERE StatisticsCode=@StatisticsCode', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='analytics.hitshour')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Analytics_HourHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Analytics_HourHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Analytics_HourHits ( [HitsStatisticsID], [HitsStartTime], [HitsEndTime], [HitsCount] ) VALUES (  @HitsStatisticsID, @HitsStartTime, @HitsEndTime, @HitsCount); SELECT @@identity AS [HitsID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Analytics_HourHits SET  [HitsStatisticsID] = @HitsStatisticsID, [HitsStartTime] = @HitsStartTime, [HitsEndTime] = @HitsEndTime, [HitsCount] = @HitsCount WHERE [HitsID] = @HitsID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Analytics_HourHits WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='analytics.hitsday')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Analytics_DayHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Analytics_DayHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Analytics_DayHits ( [HitsStatisticsID], [HitsStartTime], [HitsEndTime], [HitsCount] ) VALUES (  @HitsStatisticsID, @HitsStartTime, @HitsEndTime, @HitsCount); SELECT @@identity AS [HitsID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Analytics_DayHits SET  [HitsStatisticsID] = @HitsStatisticsID, [HitsStartTime] = @HitsStartTime, [HitsEndTime] = @HitsEndTime, [HitsCount] = @HitsCount WHERE [HitsID] = @HitsID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Analytics_DayHits WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='analytics.hitsmonth')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Analytics_MonthHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Analytics_MonthHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Analytics_MonthHits ( [HitsStatisticsID], [HitsStartTime], [HitsEndTime], [HitsCount] ) VALUES (  @HitsStatisticsID, @HitsStartTime, @HitsEndTime, @HitsCount); SELECT @@identity AS [HitsID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Analytics_MonthHits SET  [HitsStatisticsID] = @HitsStatisticsID, [HitsStartTime] = @HitsStartTime, [HitsEndTime] = @HitsEndTime, [HitsCount] = @HitsCount WHERE [HitsID] = @HitsID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ('selectall', 0, 'SELECT * FROM Analytics_MonthHits WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO





DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='analytics.hitsweek')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Analytics_WeekHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Analytics_WeekHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Analytics_WeekHits ( [HitsStatisticsID], [HitsStartTime], [HitsEndTime], [HitsCount] ) VALUES (  @HitsStatisticsID, @HitsStartTime, @HitsEndTime, @HitsCount); SELECT @@identity AS [HitsID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Analytics_WeekHits SET  [HitsStatisticsID] = @HitsStatisticsID, [HitsStartTime] = @HitsStartTime, [HitsEndTime] = @HitsEndTime, [HitsCount] = @HitsCount WHERE [HitsID] = @HitsID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Analytics_WeekHits WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='analytics.hitsyear')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Analytics_YearHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Analytics_YearHits WHERE [HitsID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Analytics_YearHits ( [HitsStatisticsID], [HitsStartTime], [HitsEndTime], [HitsCount] ) VALUES (  @HitsStatisticsID, @HitsStartTime, @HitsEndTime, @HitsCount); SELECT @@identity AS [HitsID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Analytics_YearHits SET  [HitsStatisticsID] = @HitsStatisticsID, [HitsStartTime] = @HitsStartTime, [HitsEndTime] = @HitsEndTime, [HitsCount] = @HitsCount WHERE [HitsID] = @HitsID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Analytics_YearHits WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
END
GO




DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.volumediscount')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM COM_VolumeDiscount WHERE [VolumeDiscountID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM COM_VolumeDiscount WHERE [VolumeDiscountID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO COM_VolumeDiscount ( [VolumeDiscountSKUID], [VolumeDiscountMinCount], [VolumeDiscountValue], [VolumeDiscountIsFlatValue] ) VALUES (  @VolumeDiscountSKUID, @VolumeDiscountMinCount, @VolumeDiscountValue, @VolumeDiscountIsFlatValue); SELECT @@identity AS [VolumeDiscountID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE COM_VolumeDiscount SET  [VolumeDiscountSKUID] = @VolumeDiscountSKUID, [VolumeDiscountMinCount] = @VolumeDiscountMinCount, [VolumeDiscountValue] = @VolumeDiscountValue, [VolumeDiscountIsFlatValue] = @VolumeDiscountIsFlatValue WHERE [VolumeDiscountID] = @VolumeDiscountID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM COM_VolumeDiscount WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectforsku', 0, 'SELECT * FROM COM_VolumeDiscount WHERE VolumeDiscountSKUID = @VolumeDiscountSKUID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectVolumeDiscountsForExport', 0, 'SELECT * FROM COM_VolumeDiscount WHERE ##WHERE## AND VolumeDiscountSKUID IN (SELECT SKUID FROM COM_SKU WHERE SKUID IN (SELECT NodeSKUID FROM CMS_Tree WHERE NodeSiteID=@SiteID))', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'deleteforsku', 0, 'DELETE FROM COM_VolumeDiscount WHERE VolumeDiscountSKUID=@SKUId', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'SelectForSKUUnits', 0, 'SELECT TOP 1 *  FROM COM_VolumeDiscount WHERE VolumeDiscountSKUID = @VolumeDiscountSKUID AND VolumeDiscountMinCount <= @Units ORDER BY VolumeDiscountMinCount DESC', 0, @classid, 0)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.discountlevel')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM COM_DiscountLevel WHERE [DiscountLevelID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM COM_DiscountLevel WHERE [DiscountLevelID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO COM_DiscountLevel ( [DiscountLevelDisplayName], [DiscountLevelName], [DiscountLevelValue], [DiscountLevelEnabled], [DiscountLevelValidFrom], [DiscountLevelValidTo] ) VALUES (  @DiscountLevelDisplayName, @DiscountLevelName, @DiscountLevelValue, @DiscountLevelEnabled, @DiscountLevelValidFrom, @DiscountLevelValidTo); SELECT @@identity AS [DiscountLevelID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE COM_DiscountLevel SET  [DiscountLevelDisplayName] = @DiscountLevelDisplayName, [DiscountLevelName] = @DiscountLevelName, [DiscountLevelValue] = @DiscountLevelValue, [DiscountLevelEnabled] = @DiscountLevelEnabled, [DiscountLevelValidFrom] = @DiscountLevelValidFrom, [DiscountLevelValidTo] = @DiscountLevelValidTo WHERE [DiscountLevelID] = @DiscountLevelID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM COM_DiscountLevel WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectbycodename', 0, 'SELECT * FROM COM_DiscountLevel WHERE [DiscountLevelName] = @discountLevelCodeName', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectDiscounLevelsForExport', 0, 'SELECT * FROM COM_DiscountLevel WHERE ##WHERE##', 0, @classid, 0)
END
GO




DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='Reporting.ReportCategory')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM Reporting_ReportCategory WHERE [CategoryID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM Reporting_ReportCategory WHERE [CategoryID] = @ID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO Reporting_ReportCategory ( [CategoryDisplayName], [CategoryCodeName] ) VALUES (  @CategoryDisplayName, @CategoryCodeName); SELECT @@identity AS [CategoryID]', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE Reporting_ReportCategory SET  [CategoryDisplayName] = @CategoryDisplayName, [CategoryCodeName] = @CategoryCodeName WHERE [CategoryID] = @CategoryID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM Reporting_ReportCategory WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectReportingCategoriesForExport', 0, 'SELECT * FROM Reporting_ReportCategory WHERE ##WHERE##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'removedependencies', 1, 'Proc_Reporting_ReportCategory_RemoveDependencies', 1, @classid, 1)
END
GO



DECLARE @classid int
set @classid = (SELECT ClassID FROM CMS_Class WHERE ClassName='ecommerce.taxclassstate')
if @classid<>0
begin
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'select', 0, 'SELECT * FROM COM_TaxClassState WHERE [TaxClassID] = @TaxClassID AND [StateID] = @StateID;', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'delete', 0, 'DELETE FROM COM_TaxClassState WHERE (([TaxClassID] = @TaxClassID) AND ([StateID] = @StateID));', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'insert', 0, 'INSERT INTO COM_TaxClassState ([TaxClassID], [StateID], [TaxValue], [IsFlatValue] ) VALUES (@TaxClassID,  @StateID, @TaxValue, @IsFlatValue);', 1, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'update', 0, 'UPDATE COM_TaxClassState SET  [TaxValue] = @TaxValue, [IsFlatValue] = @IsFlatValue WHERE (([TaxClassID] = @TaxClassID) AND ( [StateID] = @StateID));', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectall', 0, 'SELECT * FROM COM_TaxClassState WHERE ##WHERE## ORDER BY ##ORDERBY##', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectByTaxClassID', 0, 'SELECT * FROM COM_TaxClassState WHERE TaxClassID = @TaxClassID', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectTaxClassStates', 0, 'SELECT * FROM CMS_State LEFT OUTER JOIN COM_TaxClassState ON CMS_State.StateID = COM_TaxClassState.StateID AND COM_TaxClassState.TaxClassID = @TaxClassId WHERE CMS_State.CountryID=@CountryID;', 0, @classid, 0)
INSERT [CMS_Query] ([QueryName], [QueryTypeID], [QueryText], [QueryRequiresTransaction], [ClassID], [QueryIsLocked]) VALUES ( 'selectTaxClassStatesForExport', 0, 'SELECT * FROM COM_TaxClassState WHERE ##WHERE##', 0, @classid, 0)
END
GO


------------------------- scheduled task

INSERT [CMS_ScheduledTask] ([TaskName], [TaskDisplayName], [TaskAssemblyName], [TaskClass], [TaskInterval], [TaskData], [TaskLastRunTime], [TaskNextRunTime], [TaskProgress], [TaskLastResult], [TaskEnabled], [TaskSiteID], [TaskDeleteAfterLastRun], [TaskServerName]) VALUES ( 'Analytics.LogProcessing', 'Analytics log processing', 'CMS.WebAnalytics', 'CMS.WebAnalytics.HitLogProcessor', 'minute;1/1/2007 12:00:00 AM;1;00:00:00;23:59:00;Monday,Tuesday,Wednesday,Thursday,Friday,Saturday,Sunday', '', '9/11/2007 6:59:19 PM', '9/11/2007 7:00:19 PM', NULL, NULL, 1, NULL, 0, '')
GO

-------------------------- settings category

INSERT [CMS_SettingsCategory] ([CategoryDisplayName]) VALUES ('Web analytics')
GO

INSERT [CMS_SettingsCategory] ([CategoryDisplayName]) VALUES ('Blogs')
GO

--UPDATE [CMS_SettingsKey] [KeyValue] = 'List of additional characters that can''t be used in document alias and in the file system. The following characters are forbidden by default: \/:*?"<>|&%.''#[]+ =' WHERE KeyName='CMSForbiddenURLCharacters'

------------------------------ New settings keys

INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSDBVersion', 'Database version', NULL, '2.3', 'string', NULL, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSDataVersion', 'Data version', NULL, '2.2', 'string', NULL, NULL)
GO

DECLARE @categoryid int
set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='Blogs')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ([KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSSendBlogEmailsFrom', 'Send Blog Emails From', 'E-mail address of the blog comment e-mails sender. You can use format "Some name <email@domain.com>".', 'admin@mydomainXY.com', 'string', @categoryid, NULL)
END
GO

DECLARE @categoryid int
set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='Content Management')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ([KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSNewDocumentOrder', 'New document order', 'Specifies the default order of new inserted document (values: FIRST, LAST, ALPHABETICAL - default)', 'ALPHABETICAL', 'string', @categoryid, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSPersonalizeUserInterface', 'Personalize user interface by permissions', 'Allows user to personalize user interface by permissions', '0', 'boolean', @categoryid, NULL)
END
GO

DECLARE @categoryid int
set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='E-commerce')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSShoppingCartURL', 'Shopping cart URL', 'Shopping cart page URL (virtual path)', '', 'string', @categoryid, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSWishlistURL', 'Wishlist URL', 'Wishlist page URL (virtual path)', '', 'string', @categoryid, NULL)
END
GO


DECLARE @categoryid int
set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='Web analytics')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSCampaignTrackingParameter', 'Campaign tracking URL parameter', 'URL parameter name to identify the campaign.', '', 'string', 19, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludedIPs', 'Excluded IP addresses:', 'List of the IP addresses excluded from the logging by the analytics module, separated by semicolon', '', 'string', @categoryid, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludedURLs', 'Excluded URLs:', 'List of the URLs excluded from the logging by the analytics module, separated by semicolon. All child URLs are also excluded.', '', 'string', @categoryid, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludedFileExtensions', 'Excluded file extensions:', 'List of the file extensions excluded from logging by the analytics module, separated by semicolon', '', 'string', @categoryid, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludeSearchEngines', 'Exclude search engines:', 'If true, search engine access is excluded from the analytics log.', '1', 'boolean', @categoryid, NULL)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsEnabled', 'Enable Web Analytics', 'If true, web analytics module logs the events', '0', 'boolean', @categoryid, NULL)
END
GO


--------------------- Add new settings keys to the existing sites

DECLARE @categoryid int
DECLARE @setts int;

DECLARE @statusCursor CURSOR;
SET @statusCursor = CURSOR FOR SELECT SiteID FROM [CMS_Site];
	
	
DECLARE @cSiteId int;
/* Loop through all sites and add them settings */
OPEN @statusCursor
FETCH NEXT FROM @statusCursor INTO @cSiteId;
WHILE @@FETCH_STATUS = 0
BEGIN


set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='Blogs')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ([KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSSendBlogEmailsFrom', 'Send Blog Emails From', 'E-mail address of the blog comment e-mails sender. You can use format "Some name <email@domain.com>".', NULL, 'string', @categoryid, @cSiteId)
END


set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='Content Management')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ([KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSNewDocumentOrder', 'New document order', 'Specifies the default order of new inserted document (values: FIRST, LAST, ALPHABETICAL - default)', 'ALPHABETICAL', 'string', @categoryid, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSPersonalizeUserInterface', 'Personalize user interface by permissions', 'Allows user to personalize user interface by permissions', '0', 'boolean', @categoryid, @cSiteId)
END


set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='E-commerce')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSShoppingCartURL', 'Shopping cart URL', 'Shopping cart page URL (virtual path)', NULL, 'string', @categoryid, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSWishlistURL', 'Wishlist URL', 'Wishlist page URL (virtual path)', NULL, 'string', @categoryid, @cSiteId)
END


set @categoryid = (SELECT CategoryID FROM CMS_SettingsCategory WHERE CategoryDisplayName='Web analytics')
if @categoryid<>0
begin
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSCampaignTrackingParameter', 'Campaign tracking URL parameter', 'URL parameter name to identify the campaign.', '', 'string', 19, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludedIPs', 'Excluded IP addresses:', 'List of the IP addresses excluded from the logging by the analytics module, separated by semicolon', '', 'string', @categoryid, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludedURLs', 'Excluded URLs:', 'List of the URLs excluded from the logging by the analytics module, separated by semicolon. All child URLs are also excluded.', '', 'string', @categoryid, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludedFileExtensions', 'Excluded file extensions:', 'List of the file extensions excluded from logging by the analytics module, separated by semicolon', '', 'string', @categoryid, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsExcludeSearchEngines', 'Exclude search engines:', 'If true, search engine access is excluded from the analytics log.', '1', 'boolean', @categoryid, @cSiteId)
INSERT [CMS_SettingsKey] ( [KeyName], [KeyDisplayName], [KeyDescription], [KeyValue], [KeyType], [KeyCategoryID], [SiteID]) VALUES ( 'CMSAnalyticsEnabled', 'Enable Web Analytics', 'If true, web analytics module logs the events', NULL, 'boolean', @categoryid, @cSiteId)
END

		
FETCH NEXT FROM @statusCursor INTO @cSiteId;
END
CLOSE @statusCursor;
DEALLOCATE @statusCursor;
	
GO	

UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectpath</controlname></settings></field><field column="HighlightedNodePath" fieldcaption="Highlighted document path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="Design" /><field column="CSSPrefix" fieldcaption="CSS prefix" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="Cursor" fieldcaption="Cursor" visible="true" columntype="text" fieldtype="dropdownlist" allowempty="true" columnsize="1" fielddescription="" defaultvalue="1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="0" text="Standard" /><item value="1" text="Hand" /></options></settings></field><field column="HighlightAllItemsInPath" fieldcaption="Highlight all items in path" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="ExternalScriptPath" fieldcaption="External script path" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="Layout" fieldcaption="Layout" visible="true" columntype="text" fieldtype="dropdownlist" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="vertical" text="Vertical" /><item value="horizontal" text="Horizontal" /></options></settings></field><field column="Padding" fieldcaption="Padding" visible="true" defaultvalue="2" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="RenderItemName" fieldcaption="Render item name" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="RenderImageAlt" fieldcaption="Render image alt" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Spacing" fieldcaption="Spacing" visible="true" defaultvalue="2" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SubmenuIndicator" fieldcaption="Submenu indicator image" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="UseAlternatingStyles" fieldcaption="Use alternating styles" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="UseItemImagesForHiglightedItem" fieldcaption="Use item images for higlighted item" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ApplyMenuDesign" fieldcaption="Apply menu design" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="EnableRTLBehaviour" fieldcaption="Enable RTL behaviour" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="EnableMouseUpDownClass" fieldcaption="Enable mouse up/down class" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="Menu item separator" /><field column="SeparatorCSS" fieldcaption="Separator CSS class" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SeparatorHeight" fieldcaption="Separator height" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SeparatorText" fieldcaption="Separator text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmsmenu'

UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ItemIDPrefix" fieldcaption="Item ID prefix" visible="true" defaultvalue="" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectpath</controlname></settings></field><field column="HighlightedNodePath" fieldcaption="Highlighted document path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="Design" /><field column="CellPadding" fieldcaption="Cell padding" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="CellSpacing" fieldcaption="Cell spacing" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CollapseSelectedNodeOnClick" fieldcaption="Collapse selected item on click" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CSSPrefix" fieldcaption="CSS prefix" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="DisplayHighlightedItemAsLink" fieldcaption="Display highlighted item as link" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="GenerateIndentationInsideLink" fieldcaption="Generate indentation inside link" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="GenerateOnlyOuterLink" fieldcaption="Generate only outer link" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="HighlightAllItemsInPath" fieldcaption="Highlight all items in path" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="Indentation" fieldcaption="Indentation" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="3" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="MenuItemImageUrl" fieldcaption="Item image url" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="MenuItemOpenImageUrl" fieldcaption="Open item image url" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OnMouseOutScript" fieldcaption="OnMouseOut script" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OnMouseOverScript" fieldcaption="OnMouseOver script" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SubmenuIndicator" fieldcaption="Sub-menu indicator image" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="UrlTarget" fieldcaption="Target frame" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="UseAlternatingStyles" fieldcaption="Use alternating styles" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="UseItemImagesForHiglightedItem" fieldcaption="Use item images for higlighted item" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ApplyMenuDesign" fieldcaption="Apply menu design" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="RenderImageAlt" fieldcaption="Render image alt" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="RenderLinkTitle" fieldcaption="Render link title" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="If true, renders the accessibility title attribute." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmstreemenu'


UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Design" /><field column="RegionTitle" fieldcaption="Editable region title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="RegionType" fieldcaption="Editable region type" visible="true" defaultvalue="HtmlEditor" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="TextBox" text="Text box" /><item value="TextArea" text="Text area" /><item value="HtmlEditor" text="HTML Editor" /></options></settings></field><field column="DialogWidth" fieldcaption="Editable region width" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="DialogHeight" fieldcaption="Editable region height" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HtmlEditorCssStylesheet" fieldcaption="HTML editor css stylesheet" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>cssstylesheetselector</controlname></settings></field><category name="Behavior" /><field column="HtmlAreaToolbar" fieldcaption="HTML editor toolbar set" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HtmlAreaToolbarLocation" fieldcaption="HTML editor toolbar location" visible="true" defaultvalue="Out:FCKToolbar" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="Out:FCKToolbar" text="Shared toolbar" /><item value="In" text="In-line toolbar" /></options></settings></field><field column="MinLength" fieldcaption="Minimum length" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="MaxLength" fieldcaption="Maximum length" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="WordWrap" fieldcaption="Word wrap (text area only)" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><category name="Security" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'editabletext'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectpath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="5" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="20" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectTopN" fieldcaption="Select top N documents" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="FilterOutDuplicates" fieldcaption="Filter out duplicate documents" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Transformations" /><field column="TransformationName" fieldcaption="Transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selecttransformation</controlname></settings></field><field column="AlternatingTransformationName" fieldcaption="Alternating transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selecttransformation</controlname></settings></field><field column="SelectedItemTransformationName" fieldcaption="Selected item transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selecttransformation</controlname></settings></field><field column="ItemSeparator" fieldcaption="Item separator" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="NestedRepeaterID" fieldcaption="Nested repeater ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="NestedDataListID" fieldcaption="Nested datalist ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Paging" /><field column="EnablePaging" fieldcaption="Enable paging" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="PagingMode" fieldcaption="Paging mode" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="10" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="querystring" text="Query string" /><item value="postback" text="Postback" /></options></settings></field><field column="PagerPosition" fieldcaption="Pager position" visible="true" columntype="text" fieldtype="dropdownlist" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="bottom" text="Bottom" /><item value="top" text="Top" /></options></settings></field><field column="PageSize" fieldcaption="Page size" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="10" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="QueryStringKey" fieldcaption="Query string key" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowFirstLast" fieldcaption="Show first and last buttons" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Relationships" /><field column="RelationshipWithNodeGuid" fieldcaption="Main document" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>relationshipconfiguration</controlname></settings></field><field column="RelatedNodeIsOnTheLeftSide" fieldcaption="Main document is on the left side" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="RelationshipName" fieldcaption="Relationship  name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectrelationshipname</controlname></settings></field><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="No data behavior" /><field column="HideControlForZeroRows" fieldcaption="Hide if no record found" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ZeroRowsText" fieldcaption="No record found text" visible="true" defaultvalue="No data found" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Editing buttons" /><field column="ShowNewButton" fieldcaption="Show New button" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="NewButtonText" fieldcaption="New button text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowEditDeleteButtons" fieldcaption="Show Edit and Delete buttons" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'repeater'



UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectTopN" fieldcaption="Select top N documents" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="FilterOutDuplicates" fieldcaption="Filter out duplicate documents" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Transformations" /><field column="TransformationName" fieldcaption="Transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><field column="AlternatingTransformationName" fieldcaption="Alternating transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><field column="SelectedItemTransformationName" fieldcaption="Selected item transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><field column="NestedRepeaterID" fieldcaption="Nested repeater ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="NestedDataListID" fieldcaption="Nested datalist ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Layout" /><field column="RepeatColumns" fieldcaption="Repeat columns" visible="true" defaultvalue="3" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="RepeatDirection" fieldcaption="Repeat direction" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="horizontal" text="Horizontal" /><item value="vertical" text="Vertical" /></options></settings></field><field column="RepeatLayout" fieldcaption="Repeat layout" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="table" text="Table" /><item value="flow" text="Flow" /></options></settings></field><category name="Paging" /><field column="EnablePaging" fieldcaption="Enable paging" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="PagingMode" fieldcaption="Paging mode" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="10" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="querystring" text="Query string" /><item value="postback" text="Postback" /></options></settings></field><field column="PagerPosition" fieldcaption="Pager position" visible="true" columntype="text" fieldtype="dropdownlist" allowempty="false" columnsize="50" fielddescription="" defaultvalue="0" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="bottom" text="Bottom" /><item value="top" text="Top" /></options></settings></field><field column="PageSize" fieldcaption="Page size" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="10"><settings /></field><field column="QueryStringKey" fieldcaption="Query string key" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowFirstLast" fieldcaption="Show first and last buttons" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Relationships" /><field column="RelationshipWithNodeGuid" fieldcaption="Main document" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>relationshipconfiguration</controlname></settings></field><field column="RelatedNodeIsOnTheLeftSide" fieldcaption="Main document is on the left side" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="RelationshipName" fieldcaption="Relationship name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="100" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectrelationshipname</controlname></settings></field><category name="System settings" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="No data behavior" /><field column="HideControlForZeroRows" fieldcaption="Hide if no record found" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ZeroRowsText" fieldcaption="No record found text" visible="true" defaultvalue="No data found" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Editing buttons" /><field column="ShowNewButton" fieldcaption="Show New button" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="NewButtonText" fieldcaption="New button text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowEditDeleteButtons" fieldcaption="Show edit and delete buttons" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmsdatalist'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsite</controlname></settings></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectTopN" fieldcaption="Select top N documents" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="Transformations" /><field column="TransformationName" fieldcaption="Transformation name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><field column="SelectedItemTransformationName" fieldcaption="Selected item transformation name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="10" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><category name="Relationships" /><field column="RelationshipWithNodeGuid" fieldcaption="Main document" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>relationshipconfiguration</controlname></settings></field><field column="RelatedNodeIsOnTheLeftSide" fieldcaption="Main document is on the left side" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="RelationshipName" fieldcaption="Relationship  name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectrelationshipname</controlname></settings></field><category name="System settings" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"></field><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="No data behavior" /><field column="HideControlForZeroRows" fieldcaption="Hide if no record found" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ZeroRowsText" fieldcaption="No record found text" visible="true" defaultvalue="No data found" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmsxsltlist'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectTopN" fieldcaption="Select top N documents" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="FilterOutDuplicates" fieldcaption="Filter out duplicate documents" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Design" /><field column="ColumnSelector" fieldcaption="Displayed columns" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcolumns</controlname></settings></field><field column="ShowHeader" fieldcaption="Show header" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ToolTip" fieldcaption="Tool tip" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SkinID" fieldcaption="Skin ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Transformations" /><field column="SelectedItemTransformationName" fieldcaption="Selected item transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><category name="Paging" /><field column="AllowPaging" fieldcaption="Enable paging" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="PageSize" fieldcaption="Page size" visible="true" defaultvalue="10" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="Mode" fieldcaption="Pager style" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="nextprev" text="Previous-Next buttons" /><item value="numericpages" text="Page numbers" /></options></settings></field><category name="Sorting" /><field column="AllowSorting" fieldcaption="Enable sorting" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SortAscending" fieldcaption="Sort ascending" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SortField" fieldcaption="Default sort field" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Relationships" /><field column="RelationshipWithNodeGuid" fieldcaption="Main document" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="10" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>relationshipconfiguration</controlname></settings></field><field column="RelationshipName" fieldcaption="Relationship  name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectrelationshipname</controlname></settings></field><field column="RelatedNodeIsOnTheLeftSide" fieldcaption="Main document is on the left side" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="System settings" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"></field><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="No data behavior" /><field column="HideControlForZeroRows" fieldcaption="Hide if no record found" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ZeroRowsText" fieldcaption="No record found text" visible="true" defaultvalue="No data found" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="New button" /><field column="ShowNewButton" fieldcaption="Show New button" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="NewButtonText" fieldcaption="New button text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmsdatagrid'


UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Selected path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><field column="DefaultPath" fieldcaption="Default path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><field column="SelectNodesStartPath" fieldcaption="Starting path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="/" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><field column="ClassNames" fieldcaption="Class names" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><category name="Content filter" /><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="Where condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" publicfield="false" spellcheck="true" /><category name="Design" /><field column="BreadCrumbSeparator" fieldcaption="Breadcrumb separator" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="&amp;gt;" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="BreadCrumbSeparatorRTL" fieldcaption="Breadcrumb separator RTL" visible="true" defaultvalue="&amp;lt;" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowCurrentItem" fieldcaption="Show current item" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="ShowCurrentItemAsLink" fieldcaption="Show current item as a link" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="UrlTarget" fieldcaption="Target frame" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="ApplyMenuDesign" fieldcaption="Apply menu design" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="RenderLinkTitle" fieldcaption="Render link title" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="If true, renders the accessibility title attribute." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="UseRtlBehaviour" fieldcaption="Use RTL  behaviour" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="System settings" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'breadcrumbs'



UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectpath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="Design" /><field column="UrlTarget" fieldcaption="Target frame" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="RenderLinkTitle" fieldcaption="Render link title" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="If true, renders the accessibility title attribute." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmssitemap' 



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<a><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="450" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectpath</controlname></settings></field><field column="HighlightedNodePath" fieldcaption="Highlighted document path" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><field column="UseClientScript" fieldcaption="Use client script" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="UrlTarget" fieldcaption="Url target" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" defaultvalue="" columntype="text" fieldtype="radiobuttons" allowempty="true" isPK="false" system="false" columnsize="4" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="20" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" defaultvalue="1" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="SiteName" fieldcaption="Site name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><category name="Design" /><field column="UseAlternatingStyles" fieldcaption="Use alternating styles" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="TabControlLayout" fieldcaption="Tab control layout" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><options><item value="horizontal" text="Horizontal" /><item value="vertical" text="Vertical" /></options></settings></field><field column="UseItemImagesForHiglightedItem" fieldcaption="Use item images for higlighted item" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ApplyMenuDesign" fieldcaption="Apply menu design" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="RenderImageAlt" fieldcaption="Render image alt" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="TabControlIdPrefix" fieldcaption="Item id prefix" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="RenderLinkTitle" fieldcaption="Render link title" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="If true, renders the accessibility title attribute." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="SelectFirstItemByDefault" fieldcaption="Select first item by default" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>largetextarea</controlname></settings></field></a>' WHERE WebPartName = 'cmstabcontrol'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectpath</controlname></settings></field><field column="HighlightedNodePath" fieldcaption="Highlighted document path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsinglepath</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="Design" /><field column="CSSPrefix" fieldcaption="CSS prefix" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="DisplayHighlightedItemAsLink" fieldcaption="Display highlighted item as link" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="DisplayOnlySelectedPath" fieldcaption="Display only selected path" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="FirstItemCssClass" fieldcaption="First item CSS class" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="HighlightAllItemsInPath" fieldcaption="Highlight all items in path" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="HoverCSSClassName" fieldcaption="LI hover CSS class name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="LastItemCssClass" fieldcaption="Last item CSS class" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OnMouseOutScript" fieldcaption="OnMouseOut script" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="OnMouseOverScript" fieldcaption="OnMouseOver script" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="RenderCssClasses" fieldcaption="Render CSS classes" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="RenderItemID" fieldcaption="Render item ID" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="RenderLinkTitle" fieldcaption="Render link title" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="If true, renders the accessibility title attribute." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="RenderImageAlt" fieldcaption="Render image alt" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ItemIdPrefix" fieldcaption="Item ID prefix" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SubmenuIndicator" fieldcaption="Sub-menu indicator image" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="UrlTarget" fieldcaption="Target frame" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="UseAlternatingStyles" fieldcaption="Use alternating styles" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="0"><settings /></field><field column="UseItemImagesForHiglightedItem" fieldcaption="Use item images for higlighted items" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ApplyMenuDesign" fieldcaption="Apply menu design" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmslistmenu'




UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="450" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpath</controlname></settings></field><field column="DayField" fieldcaption="Day field" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" columnsize="4" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="20" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="-1" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="true" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions=""></field><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="500" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="Design" /><field column="SkinID" fieldcaption="Skin ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Transformations" /><field column="TransformationName" fieldcaption="Transformation" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><field column="NoEventTransformationName" fieldcaption="No event transformation" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><category name="Relationships" /><field column="RelationshipName" fieldcaption="Relationship name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectrelationshipname</controlname></settings></field><field column="RelationshipWithNodeGuid" fieldcaption="Main document" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" columnsize="50" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>relationshipconfiguration</controlname></settings></field><field column="RelatedNodeIsOnTheLeftSide" fieldcaption="Main document is on the left side" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="System settings" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="false" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"></field><field column="CacheItemName" fieldcaption="Cache item name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" columnsize="200" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" columnsize="" fielddescription="" defaultvalue="" isPK="false" system="false" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'cmscalendar'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Registration form settings" /><field column="FirstNameText" fieldcaption="First name text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="LastNameText" fieldcaption="Last name text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="EmailText" fieldcaption="E-mail text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="PasswordText" fieldcaption="Password text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ConfirmPasswordText" fieldcaption="Confirmation password text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ButtonText" fieldcaption="Button text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="AssignToRoles" fieldcaption="Assign user to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>roleselector</controlname></settings></field><field column="RedirectToURL" fieldcaption="Redirect to URL" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SkinID" fieldcaption="Skin ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Extended settings" /><field column="EnableUserAfterRegistration" fieldcaption="Enable user after registration" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="NotifyAdministrator" fieldcaption="Notify administrator about new registrations" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="FromAddress" fieldcaption="From e-mail address" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ToAddress" fieldcaption="To e-mail address:" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="DisplayMessage" fieldcaption="Display message after registration" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Conversion tracking" /><field column="TrackConversionName" fieldcaption="Track conversion name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="400" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'registrationform'



UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Dialog settings" /><field column="NewsletterName" fieldcaption="Newsletter code name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="400" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="DisplayFirstName" fieldcaption="Display first name" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="FirstNameText" fieldcaption="First name label text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="DisplayLastName" fieldcaption="Display last name" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="LastNameText" fieldcaption="Last name label text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="EmailText" fieldcaption="E-mail label text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ButtonText" fieldcaption="Submit button text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SkinID" fieldcaption="Skin ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="Conversion tracking" /><field column="TrackConversionName" fieldcaption="Track conversion name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="400" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'NewsletterSubscription'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="BizForm settings" /><field column="BizFormName" fieldcaption="Form name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="false" isPK="false" system="false" columnsize="100" publicfield="false" spellcheck="true"><settings><controlname>bizformselector</controlname></settings></field><field column="UseColonBehindLabel" fieldcaption="Use colon (:) in labels" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'bizform'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="General" /><field column="PasswordRetrieval" fieldcaption="Allow forgotten password retrieval" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="RedirectAfterPurchase" fieldcaption="Default URL after purchase" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpath</controlname></settings></field><category name="Conversion tracking" /><field column="RegistrationTrackConversionName" fieldcaption="Registration conversion name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="400" publicfield="false" spellcheck="true" /><field column="OrderTrackConversionName" fieldcaption="Order conversion name" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="400" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'shoppingcart'




UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Shopping cart preview properties" /><field column="ShoppingCartLinkUrl" fieldcaption="Shopping cart link URL" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"></field><field column="ShoppingCartLinkText" fieldcaption="Shopping cart link text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="WishlistLinkUrl" fieldcaption="Wishlist link URL" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true" /><field column="WishlistLinkText" fieldcaption="Wishlist link text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="TotalPriceTitleText" fieldcaption="Total price text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="MyAccountLinkUrl" fieldcaption="My Account link URL" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="MyAccountLinkText" fieldcaption="My Account link text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'shoppingcartminipreview'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpath</controlname></settings></field><field column="SiteName" fieldcaption="Site name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectsite</controlname></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" defaultvalue="-1" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ClassNames" fieldcaption="Document type" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="TransformationName" fieldcaption="Transformation name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selecttransformation</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" defaultvalue="" columntype="text" fieldtype="radiobuttons" allowempty="true" isPK="false" system="false" columnsize="5" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><category name="Cache" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'Randomdocument'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="HTMLCode" fieldcaption="HTML code" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'headhtml'




UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="ImageWidth" fieldcaption="Image width" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ImageHeight" fieldcaption="Image height" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ImageTitle" fieldcaption="Image title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="AlternateText" fieldcaption="Alternate text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="DisplaySelectorTextBox" fieldcaption="Display image page path" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Design" /><field column="ImageCssClass" fieldcaption="Image CSS class" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ImageStyle" fieldcaption="Image style" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Security" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'Editableimage'



UPDATE [CMS_WebPart] SET  [WebPartProperties] =  '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="Path to the document" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectsinglepath</controlname></settings></field><field column="ColumnName" fieldcaption="Text field name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="Document field that should be used as a source of the text." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Content filter" /><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" defaultvalue="" columntype="text" fieldtype="radiobuttons" allowempty="true" isPK="false" system="false" columnsize="5" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="20" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectculture</controlname></settings></field><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="SiteName" fieldcaption="Site name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Paging" /><field column="PagingMode" fieldcaption="Paging mode" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="20" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="querystring" text="Query string" /><item value="postback" text="Postback" /></options></settings></field><field column="PagerPosition" fieldcaption="Pager position" visible="true" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="bottom" text="Bottom" /><item value="top" text="Top" /></options></settings></field><field column="QueryStringKey" fieldcaption="Query string key" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowFirstLast" fieldcaption="Show first and last buttons" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="PageSize" fieldcaption="Page size (characters)" visible="true" defaultvalue="1000" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="PagerFormat" fieldcaption="Pager format" visible="true" defaultvalue="Page {0} of {2}" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="You can use the following expressions: {0} for current page, {2} for total number of pages." regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="System settings" /><field column="CacheItemName" fieldcaption="Cache item name" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" defaultvalue="" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="Design" /><field column="TextCSSClass" fieldcaption="Text CSS Class" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="PagerCSSClass" fieldcaption="Pager CSS Class" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="PagerSeparator" fieldcaption="Pager separator" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="450" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'PagedText'



UPDATE [CMS_WebPart] SET  [WebPartProperties] = '<form><field column="WebPartControlID" fieldcaption="ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" /><field column="HideOnSubPages" fieldcaption="Hide on sub-pages" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Behavior" /><field column="PageTemplate" fieldcaption="Default page template" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectpagetemplate</controlname></settings></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="CacheMinutes" fieldcaption="Cache minutes" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false"><settings><controlname>largetextarea</controlname></settings></field></form>' WHERE WebPartName = 'PagePlaceHolder'

GO
----- New webpart categories

INSERT [CMS_WebPartCategory] ([CategoryDisplayName], [CategoryParentID]) VALUES ('Polls', NULL)
INSERT [CMS_WebPartCategory] ([CategoryDisplayName], [CategoryParentID]) VALUES ( 'Reporting', NULL)
INSERT [CMS_WebPartCategory] ([CategoryDisplayName], [CategoryParentID]) VALUES ( 'Blogs', NULL)
INSERT [CMS_WebPartCategory] ([CategoryDisplayName], [CategoryParentID]) VALUES ( 'User contributions', NULL)

GO
----- New webparts
Declare @pollCatId int
Declare @repCatId int
Declare @blogCatId int
Declare @uconCatId int
Declare @ecomCatId int



SET @pollCatId = (Select TOP 1 CategoryID FROM CMS_WebPartCategory Where CategoryDisplayName='Polls')
SET @repCatId = (Select TOP 1 CategoryID FROM CMS_WebPartCategory Where CategoryDisplayName='Reporting')
SET @blogCatId = (Select TOP 1 CategoryID FROM CMS_WebPartCategory Where CategoryDisplayName='Blogs')
SET @uconCatId = (Select TOP 1 CategoryID FROM CMS_WebPartCategory Where CategoryDisplayName='User contributions')
SET @ecomCatId = (Select TOP 1 CategoryID FROM CMS_WebPartCategory Where CategoryDisplayName='E-commerce')

if @pollCatId<>0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ( 'poll', 'Poll', 'The Poll web part allows you to insert your own Poll on the page.', 'Polls/Poll.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Poll settings" /><field column="PollCodeName" fieldcaption="Poll name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="false" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>pollselector</controlname></settings></field><field column="ShowGraph" fieldcaption="Show graph" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CountType" fieldcaption="Count type" visible="true" defaultvalue="" columntype="integer" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><options><item value="0" text="None" /><item value="1" text="Absolute" /><item value="2" text="Percentage" /></options></settings></field><field column="ShowResultsAfterVote" fieldcaption="Show results after vote" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ButtonText" fieldcaption="Button text" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CheckVoted" fieldcaption="Check if user voted" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideWhenNotAuthorized" fieldcaption="Hide to unauthorized users" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideWhenNotOpened" fieldcaption="Hide if closed" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @pollCatId)
end


if @repCatId<>0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ('Report', 'Report', '', 'Reporting/report.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Report properties" /><field column="ReportName" fieldcaption="Report name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectreport</controlname></settings></field><field column="DisplayFilter" fieldcaption="Display filter" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @repCatId)
end


if @blogCatId<>0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ( 'CommentView', 'Comment view', 'Displays all comments of the specified blog post.', 'Blogs/BlogCommentView.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Security" /><field column="ShowEditButton" fieldcaption="Show edit button" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowDeleteButton" fieldcaption="Show delete button" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><category name="User pictures" /><field column="EnableUserPictures" fieldcaption="Enable user pictures" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="UserPictureMaxWidth" fieldcaption="User picture width" visible="true" defaultvalue="60" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="UserPictureMaxHeight" fieldcaption="User picture height" visible="true" defaultvalue="50" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @blogCatId)
end


if @ecomCatId<> 0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ( 'Wishlist', 'Wishlist', '', 'Ecommerce/Wishlist.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><field column="TransformationName" fieldcaption="Transformation name" visible="true" defaultvalue="cms.root.wishlist" columntype="text" fieldtype="usercontrol" allowempty="false" isPK="false" system="false" columnsize="100" publicfield="false" spellcheck="true"><settings><controlname>selecttransformation</controlname></settings></field><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @ecomCatId)
end

if @uconCatId<>0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ('ContributionList', 'Contribution list', 'Displays a list of contributions or only the New document button.', 'UserContributions/ContributionList.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="450" publicfield="false" spellcheck="true"><settings><controlname>selectpath</controlname></settings></field><category name="User contributions" /><field column="NewDocumentPath" fieldcaption="Path for new documents" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="450" publicfield="false" spellcheck="true"><settings><controlname>selectpath</controlname></settings></field><field column="AllowedChildClasses" fieldcaption="Allowed new document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayList" fieldcaption="Display list of documents" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="NewItemPageTemplate" fieldcaption="New document page template" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectpagetemplate</controlname></settings></field><category name="Content filter" /><field column="ClassNames" fieldcaption="Document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="CombineWithDefaultCulture" fieldcaption="Combine with default culture" visible="true" columntype="text" fieldtype="radiobuttons" allowempty="true" isPK="false" system="false" columnsize="5" publicfield="false" spellcheck="true"><settings><options><item value="true" text="Yes" /><item value="false" text="No" /><item value="" text="Use site settings" /></options></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="true"><settings><controlname>selectculture</controlname></settings></field><field column="MaxRelativeLevel" fieldcaption="Maximum nesting level" visible="true" defaultvalue="-1" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="OrderBy" fieldcaption="ORDER BY expression" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" publicfield="false" spellcheck="true" /><field column="SelectOnlyPublished" fieldcaption="Select only published" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="SiteName" fieldcaption="Site name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectsite</controlname></settings></field><field column="WhereCondition" fieldcaption="WHERE condition" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="500" publicfield="false" spellcheck="true" /><category name="Security" /><field column="AllowInsert" fieldcaption="Allow insert" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="AllowEdit" fieldcaption="Allow edit" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="AllowDelete" fieldcaption="Allow delete" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="AllowUsers" fieldcaption="Allow editing by users" visible="true" defaultvalue="2" columntype="integer" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true"><settings><options><item value="0" text="All" /><item value="1" text="Authenticated" /><item value="2" text="Document owner" /></options></settings></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @uconCatId)
end

if @uconCatId<>0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ( 'editContribution', 'Edit contribution', 'Enables editing of user contributions.', 'usercontributions/editcontribution.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="\w+" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="Control ID must match identificator format." captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" defaultvalue="" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Content" /><field column="Path" fieldcaption="Path" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectsinglepath</controlname></settings></field><field column="SiteName" fieldcaption="Site name" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectsite</controlname></settings></field><field column="CultureCode" fieldcaption="Culture code" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="100" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectculture</controlname></settings></field><category name="Security" /><field column="AllowDelete" fieldcaption="Allow delete" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="AllowUsers" fieldcaption="Allow editing by users" visible="true" columntype="integer" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" defaultvalue="2"><settings><options><item value="0" text="All" /><item value="1" text="Authenticated" /><item value="2" text="Document owner" /></options></settings></field><field column="CheckPermissions" fieldcaption="Check permissions" visible="true" defaultvalue="false" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" defaultvalue="" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" defaultvalue="" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" defaultvalue="" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @uconCatId)
end

if @blogCatId<>0
begin
INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ( 'RecentPosts', 'Recent posts', 'Displays blog recent posts.', 'Blogs/RecentPosts.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" regularexpression="\w+" validationerrormessage="Control ID must match identificator format." publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Recent posts" /><field column="TransformationName" fieldcaption="Transformation name:" visible="true" columntype="text" fieldtype="usercontrol" allowempty="false" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true" defaultvalue="cms.blogpost.recentposts"><settings><controlname>selecttransformation</controlname></settings></field><field column="SelectTopN" fieldcaption="Select top N" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @blogCatId)


INSERT [CMS_WebPart] ( [WebPartName], [WebPartDisplayName], [WebPartDescription], [WebPartFileName], [WebPartProperties], [WebPartCategoryID]) VALUES ( 'PostArchive', 'Post archive', 'Displays post summary per each month.', 'Blogs/PostArchive.ascx', '<form><field column="WebPartControlID" fieldcaption="Web part control ID" visible="true" columntype="text" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="50" regularexpression="\w+" validationerrormessage="Control ID must match identificator format." publicfield="false" spellcheck="true" /><field column="Visible" fieldcaption="Visible" visible="true" defaultvalue="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="HideOnSubPages" fieldcaption="Hide on subpages" visible="true" columntype="boolean" fieldtype="checkbox" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="true" /><field column="ShowForDocumentTypes" fieldcaption="Show for document types" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectclassnames</controlname></settings></field><field column="DisplayToRoles" fieldcaption="Display to roles" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>rolecheckboxselector</controlname></settings></field><category name="Archive" /><field column="TransformationName" fieldcaption="Transformation name" visible="true" columntype="text" fieldtype="usercontrol" allowempty="false" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true" defaultvalue="cms.blogpost.archive"><settings><controlname>selecttransformation</controlname></settings></field><field column="SelectTopN" fieldcaption="Select top N" visible="true" columntype="integer" fieldtype="textbox" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true" /><category name="HTML Envelope" /><field column="Container" fieldcaption="Web part container" visible="true" columntype="text" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true"><settings><controlname>selectcontainer</controlname></settings></field><field column="ContainerTitle" fieldcaption="Web part container title" visible="true" columntype="text" fieldtype="textbox" allowempty="true" isPK="false" system="false" columnsize="200" publicfield="false" spellcheck="true" /><field column="ContentBefore" fieldcaption="Content before" visible="true" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field><field column="ContentAfter" fieldcaption="Content after" visible="true" columntype="longtext" fieldtype="usercontrol" allowempty="true" isPK="false" system="false" publicfield="false" spellcheck="true"><settings><controlname>largetextarea</controlname></settings></field></form>', @blogCatId)
end
GO

------------------ Report categories

INSERT [Reporting_ReportCategory] ( [CategoryDisplayName], [CategoryCodeName]) VALUES ( 'Web Analytics', 'WebAnalytics')
INSERT [Reporting_ReportCategory] ( [CategoryDisplayName], [CategoryCodeName]) VALUES ( 'Document reports', 'DocumentReports')


-------------------- Reports

Declare @DocRepCatId int
SET @DocRepCatId = (SELECT TOP 1 CategoryID FROM Reporting_ReportCategory WHERE CategoryCodeName = 'DocumentReports' )

Declare @WaRepCatId int
SET @WaRepCatId = (SELECT TOP 1 CategoryID FROM Reporting_ReportCategory WHERE CategoryCodeName = 'WebAnalytics' )


if @DocRepCatId<>0
begin
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'RecentlyModifiedDocuments', 'Recently modified documents', '<table cellspacing="1" cellpadding="1" border="0">
    <tbody>
        <tr>
            <td>
            <h1 style="text-align: center;"><font><font size="5" style="color: rgb(128, 128, 0);"><span style="font-weight: bold;">Recently modified documents</span></font></font></h1>
            </td>
        </tr>
        <tr>
            <td>%%control:ReportTable?RecentlyModifiedDocsTable%%</td>
        </tr>
    </tbody>
</table>', '<form><field column="ModifiedSince" fieldcaption="Modified since" visible="true" defaultvalue="1/1/2007 4:00:00 PM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field></form>', @DocRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'CheckedOutDocuments', 'Checked-out documents', '<table cellspacing="1" cellpadding="1" border="0">
    <tbody>
        <tr>
            <td>
            <h1 style="text-align: center;"><font><font size="5" style="color: rgb(128, 128, 0);"><span style="font-weight: bold;">Checked-out documents</span></font></font></h1>
            </td>
        </tr>
        <tr>
            <td>%%control:ReportTable?CheckedOutDocsTable%%</td>
        </tr>
    </tbody>
</table>', '', @DocRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'ExpiredDocuments', 'Expired documents', '<table cellspacing="1" cellpadding="1" border="0">
    <tbody>
        <tr>
            <td>
            <h1 style="text-align: center;"><font><font size="5" style="color: rgb(128, 128, 0);"><span style="font-weight: bold;">Expired documents</span></font></font></h1>
            </td>
        </tr>
        <tr>
            <td>%%control:ReportTable?ExpiredDocsTable%%</td>
        </tr>
    </tbody>
</table>', '', @DocRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'ArchivedDocuments', 'Archived documents', '<table cellspacing="1" cellpadding="1" border="0">
    <tbody>
        <tr>
            <td>
            <h1 style="text-align: center;"><font><font size="5" style="color: rgb(128, 128, 0);"><span style="font-weight: bold;">Archived documents</span></font></font></h1>
            </td>
        </tr>
        <tr>
            <td>%%control:ReportTable?ArchivedDocsTable%%</td>
        </tr>
    </tbody>
</table>', '', @DocRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'DocumentsWaitingForApproval', 'Documents waiting for approval', '<table cellspacing="1" cellpadding="1" border="0">
    <tbody>
        <tr>
            <td>
            <h1 style="text-align: center;"><font><font size="5" style="color: rgb(128, 128, 0);"><span style="font-weight: bold;">Documents waiting for approval</span></font></font></h1>
            </td>
        </tr>
        <tr>
            <td>%%control:ReportTable?DocsWaitingForApproval%%</td>
        </tr>
    </tbody>
</table>', '', @DocRepCatId, 0)
end

if @WaRepCatId<>0
begin
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.dayreport', 'File downloads - Daily report', '<h1>{$reports_filedownloads.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayFileDownloads%%<br />
<br />
%%control:ReportTable?TableDayFileDownloads%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="8/31/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="FromDayFirst" fieldcaption="" visible="false" defaultvalue="1" columntype="integer" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDayFirst" fieldcaption="" visible="false" defaultvalue="31" columntype="integer" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDaySecond" fieldcaption="" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.monthreport', 'File downloads - Monthly report', '<h1>{$reports_filedownloads.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthFileDownloads%%<br />
<br />
%%control:ReportTable?TableMonthFileDownloads%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.yearreport', 'File downloads - Yearly report', '<h1>{$reports_filedownloads.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearFileDownloads%%<br />
<br />
%%control:ReportTable?TableYearFileDownloads%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2003 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.hourreport', 'File downloads - Hourly report', '<h1>{$reports_filedownloads.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourFileDownloads%%<br />
<br />
%%control:ReportTable?TableHourFileDownloads%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.dayreport', 'Page views - Daily report', '<h1>{$reports_pageviews.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayPageViews%%<br />
<br />
%%control:ReportTable?TableDayPageViews%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="FromDayFirst" fieldcaption="" visible="false" defaultvalue="1" columntype="integer" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDayFirst" fieldcaption="" visible="false" defaultvalue="31" columntype="integer" fieldtype="textbox" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDaySecond" fieldcaption="" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.monthreport', 'Page views - Monthly report', '<h1>{$reports_pageviews.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthPageViews%%<br />
<br />
%%control:ReportTable?TableMonthPageViews%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.yearreport', 'Page views - Yearly report', '<h1>{$reports_pageviews.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearPageViews%%<br />
<br />
%%control:ReportTable?TableYearPageViews%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2003 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.hourreport', 'Page views -  Hourly report', '<h1>{$reports_pageviews.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHoursPageViews%%<br />
<br />
%%control:ReportTable?TableHourPageViews%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="40" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pagenotfound.dayreport', 'Invalid pages - Daily report', '<h1>{$reports_pagenotfound.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayPageNotFound%%<br />
<br />
%%control:ReportTable?TableDayPageNotFound%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pagenotfound" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="FromDayFirst" fieldcaption="" visible="false" defaultvalue="1" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDayFirst" fieldcaption="" visible="false" defaultvalue="31" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDaySecond" fieldcaption="" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pagenotfound.monthreport', 'Invalid pages - Monthly report', '<h1>{$reports_pagenotfound.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthPageNotFound%%<br />
<br />
%%control:ReportTable?TableMonthPageNotFound%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pagenotfound" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pagenotfound.yearreport', 'Invalid pages - Yearly report', '<h1>{$reports_pagenotfound.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearPageNotFound%%<br />
<br />
%%control:ReportTable?TableYearPageNotFound%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2003 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pagenotfound" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pagenotfound.hourreport', 'Invalid pages - Hourly report', '<h1>{$reports_pagenotfound.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourPageNotFound%%<br />
<br />
%%control:ReportTable?TableHourPageNotFound%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="pagenotfound" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'urlreferrals.dayreport', 'Referring URLs - Daily report', '<h1>{$reports_urlrefferals.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportTable?TableDayReferrals%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="urlreferrals" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'urlreferrals.monthreport', 'Referring URLs - Monthly report', '<h1>{$reports_urlrefferals.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportTable?TableMonthReferrals%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="urlreferrals" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'urlreferrals.yearreport', 'Referring URLs - Yearly report', '<h1>{$reports_urlrefferals.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportTable?TableYearReferrals%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2003 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="urlreferrals" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'urlreferrals.hourreport', 'Referring URLs - Hourly report', '<h1>{$reports_urlrefferals.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportTable?TableHourReferrals%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" fieldcaption="Code Name" visible="false" defaultvalue="urlreferrals" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="40" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'visitors.dayreport', 'Visits - Daily report', '<h1>{$reports_visits.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayVisitors%%<br />
<br />
%%control:ReportGraph?GraphDayNewReturnVisitors%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="10/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="FirstCategory" fieldcaption="First category" visible="false" defaultvalue="visitfirst" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="SecondCategory" fieldcaption="Second category" visible="false" defaultvalue="visitreturn" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="FromDayFirst" fieldcaption="" visible="false" defaultvalue="1" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDayFirst" fieldcaption="" visible="false" defaultvalue="31" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /><field column="ToDaySecond" fieldcaption="" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'visitors.monthreport', 'Visits - Monthly report', '<h1>{$reports_visits.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthVisitors%%<br />
<br />
%%control:ReportGraph?GraphMonthNewReturnVisitors%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="FirstCategory" fieldcaption="First category" visible="false" defaultvalue="visitfirst" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="SecondCategory" fieldcaption="Second category" visible="false" defaultvalue="visitreturn" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'visitors.yearreport', 'Visits - Yearly report', '<h1>{$reports_visits.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearVisitors%%<br />
<br />
%%control:ReportGraph?GraphYearNewReturnVisitors%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="1/1/2003 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="FirstCategory" fieldcaption="First category" visible="false" defaultvalue="visitfirst" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="SecondCategory" fieldcaption="Second category" visible="false" defaultvalue="visitreturn" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'visitors.hourreport', 'Visits - Hourly report', '<h1>{$reports_visits.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourVisitors%%<br />
<br />
%%control:ReportGraph?GraphHourNewReturnVisitors%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" fieldcaption="From Date" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" fieldcaption="To Date" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" columnsize="" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="FirstCategory" fieldcaption="First category" visible="false" defaultvalue="visitfirst" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field><field column="SecondCategory" fieldcaption="Second category" visible="false" defaultvalue="visitreturn" columntype="text" fieldtype="dropdownlist" allowempty="false" isPK="false" system="false" columnsize="50" fielddescription="" regularexpression="" minstringlength="" maxstringlength="" minnumericvalue="" maxnumericvalue="" mindatetimevalue="" maxdatetimevalue="" validationerrormessage="" captionstyle="" inputcontrolstyle="" fileextensions="" publicfield="false" spellcheck="false"><settings><query>SELECT DISTINCT StatisticsCode, StatisticsCode FROM Analytics_Statistics</query></settings></field></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.multilingual.dayreport', 'File downloads (multilingual) - Daily report', '<h1>{$reports_filedownloadscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayFileDownloadsCulture%%<br />
<br />
%%control:ReportTable?TableDayFileDownloadsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieDayFileDownloadsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="8/31/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /><field column="FromDayFirst" visible="false" defaultvalue="1" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDayFirst" visible="false" defaultvalue="31" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDaySecond" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.multilingual.monthreport', 'File downloads (multilingual) - Monthly report', '<h1>{$reports_filedownloadscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthFileDownloadsCulture%%<br />
<br />
%%control:ReportTable?TableMonthFileDownloadsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieMonthFileDownloadsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.multilingual.yearreport', 'File downloads (multilingual) - Yearly report', '<h1>{$reports_filedownloadscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearFileDownloadsCulture%%<br />
<br />
%%control:ReportTable?TableYearFileDownloadsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieYearFileDownloadsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'filedownloads.multilingual.hourreport', 'File downloads (multilingual) - Hourly report', '<h1>{$reports_filedownloadscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourFileDownloadsCulture%%<br />
<br />
%%control:ReportTable?TableHourFileDownloadsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieHourFileDownloadsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/30/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="8/31/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="filedownloads" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.multilingual.dayreport', 'Page views (multilingual) - Daily report', '<h1>{$reports_pageviewscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayPageViewsCulture%%<br />
<br />
%%control:ReportTable?TableDayPageViewsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieDayPageViewsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /><field column="ToDayFirst" visible="false" defaultvalue="31" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="FromDayFirst" visible="false" defaultvalue="1" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDaySecond" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.multilingual.monthreport', 'Page views (multilingual) -  Monthly report', '<h1>{$reports_pageviewscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthPageViewsCulture%%<br />
<br />
%%control:ReportTable?TableMonthPageViewsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieMonthPageViewsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.multilingual.yearreport', 'Page views (multilingual) - Yearly report', '<h1>{$reports_pageviewscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearPageViewsCulture%%<br />
<br />
%%control:ReportTable?TableYearFileDownloadsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieYearPageViewsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'pageviews.multilingual.hourreport', 'Page views (multilingual) - Hourly report', '<h1>{$reports_pageviewscult.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourPageViewsCulture%%<br />
<br />
%%control:ReportTable?TableHourFilePageViewsCulture%%<br />
<br />
%%control:ReportGraph?GraphPieHourPageViewsCulture%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="pageviews" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'campaign.dayreport', 'Campaign - Daily report', '<h1>{$reports_campaign.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayCampaign%%<br />
<br />
%%control:ReportTable?TableDayCampaign%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="campaign" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /><field column="FromDayFirst" visible="false" defaultvalue="1" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDayFirst" visible="false" defaultvalue="31" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDaySecond" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'campaign.monthreport', 'Campaign - Monthly report', '<h1>{$reports_campaign.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthCampaign%%<br />
<br />
%%control:ReportTable?TableMonthCampaign%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="campaign" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'campaign.yearreport', 'Campaign - Yearly report', '<h1>{$reports_campaign.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearCampaign%%<br />
<br />
%%control:ReportTable?TableYearCampaign%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="1/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="campaign" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'campaign.hourreport', 'Campaign - Hourly report', '<h1>{$reports_campaign.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourCampaign%%<br />
<br />
%%control:ReportTable?TableHourCampaign%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="campaign" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'conversion.dayreport', 'Conversion - Daily report', '<h1>{$reports_conversion.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphDayConversion%%<br />
<br />
%%control:ReportTable?TableDayConversion%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="9/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="conversion" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /><field column="FromDayFirst" visible="false" defaultvalue="1" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDayFirst" visible="false" defaultvalue="31" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDaySecond" visible="false" defaultvalue="0" columntype="integer" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'conversion.monthreport', 'Conversion - Monthly report', '<h1>{$reports_conversion.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphMonthConversion%%<br />
<br />
%%control:ReportTable?TableMonthConversion%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="ToDate" visible="false" defaultvalue="8/31/2007 12:00:00 AM" columntype="datetime" fieldtype="label" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false" /><field column="CodeName" visible="false" defaultvalue="conversion" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="20" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'conversion.yearreport', 'Conversion - Yearly report', '<h1>{$reports_conversion.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphYearConversion%%<br />
<br />
%%control:ReportTable?TableYearConversion%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="1/1/2003 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="1/1/2008 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="conversion" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
INSERT [Reporting_Report] ( [ReportName], [ReportDisplayName], [ReportLayout], [ReportParameters], [ReportCategoryID], [ReportAccess]) VALUES ( 'conversion.hourreport', 'Conversion - Hourly report', '<h1>{$reports_conversion.stats_caption$}</h1>
({$reports_general.from$} {%FromDate%} {$reports_general.to$} {%ToDate%})<br />
<br />
%%control:ReportGraph?GraphHourConversion%%<br />
<br />
%%control:ReportTable?TableHourConversion%%<br />
<br />
{$reports_general.created$} {%CMSContextCurrentTime%} {$reports_general.by$} {%CMSContextCurrentUserName%}', '<form><field column="FromDate" visible="false" defaultvalue="8/1/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="ToDate" visible="false" defaultvalue="8/2/2007 12:00:00 AM" columntype="datetime" fieldtype="calendar" allowempty="false" isPK="false" system="false" publicfield="false" spellcheck="false"><settings><editTime>true</editTime></settings></field><field column="CodeName" visible="false" defaultvalue="conversion" columntype="text" fieldtype="label" allowempty="false" isPK="false" system="false" columnsize="50" publicfield="false" spellcheck="false" /></form>', @WaRepCatId, 0)
end
GO

-------------------------- Report graphs

Declare @grReportId int

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayFileDownloads', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthFileDownloads', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearFileDownloads', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourFileDownloads', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayPageViews', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthPageViews', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearPageViews', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHoursPageViews', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayPageNotFound', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_pagenotfound.label_numoffaults$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthPageNotFound', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_pagenotfound.label_numoffaults$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearPageNotFound', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_pagenotfound.label_numoffaults$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourPageNotFound', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_pagenotfound.label_numoffaults$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayVisitors', 'visitors', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode=@FirstCategory) OR (StatisticsCode=@SecondCategory))
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode=@FirstCategory) OR (StatisticsCode=@SecondCategory))
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_visits.label_numofvisits$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayNewReturnVisitors', 'new and returning visitors', 'SELECT ''{''+''$analytics_codename.'' + StatisticsCode + ''$}'' AS Name, SUM(HitsCount) FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode = @FirstCategory) OR (StatisticsCode = @SecondCategory)) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsCode', 0, 'pie', @grReportId, '{$reports_visits.label_newandreturningvisitors$}', '', '', 450, 300, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthVisitors', 'visitors', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_visits.label_numofvisits$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthNewReturnVisitors', 'new and returning visitors', 'SELECT ''{''+''$analytics_codename.'' + StatisticsCode + ''$}'', SUM(HitsCount) FROM Analytics_Statistics, Analytics_MonthHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode = @FirstCategory) OR (StatisticsCode = @SecondCategory)) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsCode', 0, 'pie', @grReportId, '{$reports_visits.label_newandreturningvisitors$}', '', '', 450, 300, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearVisitors', 'visitors', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode = @FirstCategory) OR (StatisticsCode = @SecondCategory)) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_visits.label_numofvisits$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearNewReturnVisitors', 'new and returning visitors', 'SELECT ''{''+''$analytics_codename.'' + StatisticsCode + ''$}'', SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode = @FirstCategory) OR (StatisticsCode = @SecondCategory)) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsCode', 0, 'pie', @grReportId, '{$reports_visits.label_newandreturningvisitors$}', '', '', 450, 300, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourVisitors', 'visitors', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode=@FirstCategory) OR (StatisticsCode=@SecondCategory))AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_visits.label_numofvisits$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='visitors.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourNewReturnVisitors', 'new and returning visitors', 'SELECT ''{''+''$analytics_codename.'' + StatisticsCode + ''$}'', SUM(HitsCount) FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND ((StatisticsCode = @FirstCategory) OR (StatisticsCode = @SecondCategory)) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsCode', 0, 'pie', @grReportId, '{$reports_visits.label_newandreturningvisitors$}', '', '', 450, 300, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayFileDownloadsCulture', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieDayFileDownloadsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_DayHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount) DESC', 0, 'pie', @grReportId, '{$reports_filedownloadscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthFileDownloadsCulture', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieMonthFileDownloadsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_MonthHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount) DESC', 0, 'pie', @grReportId, '{$reports_filedownloadscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearFileDownloadsCulture', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieYearFileDownloadsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_YearHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount) DESC', 0, 'pie', @grReportId, '{$reports_filedownloadscult.piechart_caption$}', '', '', 500, 350, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourFileDownloadsCulture', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_filedownloads.label_numofdownloads$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieHourFileDownloadsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_HourHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount)', 0, 'pie', @grReportId, '{$reports_filedownloadscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayPageViewsCulture', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieDayPageViewsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_DayHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount) DESC', 0, 'pie', @grReportId, '{$reports_pageviewscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthPageViewsCulture', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieMonthPageViewsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_MonthHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount) DESC', 0, 'pie', @grReportId, '{$reports_pageviewscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearPageViewsCulture', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieYearPageViewsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_YearHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount) DESC', 0, 'pie', @grReportId, '{$reports_pageviewscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourPageViewsCulture', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_pageviews.label_numofpageviews$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphPieHourPageViewsCulture', 'graph pie', 'SELECT StatisticsObjectCulture, SUM(HitsCount) FROM 
Analytics_Statistics, Analytics_HourHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture ORDER BY SUM(HitsCount)', 0, 'pie', @grReportId, '{$reports_pageviewscult.piechart_caption$}', '', '', 500, 350, 5)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayCampaign', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_campaign.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthCampaign', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_campaign.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearCampaign', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_campaign.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourCampaign', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_campaign.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.dayreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphDayConversion', 'graph', 'SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE ((IndexID >= @FromDayFirst) AND (IndexID <=@ToDayFirst))
GROUP BY IndexID
UNION ALL
SELECT IndexID, SUM(T1.HitsCount)
FROM Analytics_Index 
LEFT JOIN (
SELECT DATENAME(day,HitsStartTime) AS days, HitsStartTime, HitsEndTime, HitsCount
FROM Analytics_Statistics, Analytics_DayHits
WHERE
 (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName)
 AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate)
 AND (HitsEndTime <= @ToDate)
) AS T1 ON Analytics_Index.IndexID=T1.days
WHERE (IndexID <= @ToDaySecond)
GROUP BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_days$}', '{$reports_conversion.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.monthreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphMonthConversion', 'graph', 'SELECT IndexMonthName, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(month,HitsStartTime) AS months, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(month,HitsStartTime)) AS T1
ON Analytics_Index.IndexMonthName=T1.months WHERE (IndexID>=1) AND (IndexID<=12)
ORDER BY IndexID', 0, 'bar', @grReportId, '', '{$reports_general.label_months$}', '{$reports_conversion.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.yearreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphYearConversion', 'graph', 'SELECT DATENAME(year,HitsStartTime), SUM(HitsCount) FROM Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(year,HitsStartTime)
ORDER BY MIN(HitsStartTime)', 0, 'bar', @grReportId, '', '{$reports_general.label_years$}', '{$reports_conversion.label_num$}', 700, 300, -1)
end

SET @grReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.hourreport')
if (@grReportId) <> 0
begin
INSERT [Reporting_ReportGraph] ( [GraphName], [GraphDisplayName], [GraphQuery], [GraphQueryIsStoredProcedure], [GraphType], [GraphReportID], [GraphTitle], [GraphXAxisTitle], [GraphYAxisTitle], [GraphWidth], [GraphHeight], [GraphLegendPosition]) VALUES ( 'GraphHourConversion', 'graph', 'SELECT IndexZero, T1.hits
FROM Analytics_Index LEFT JOIN
(SELECT DATENAME(hour,HitsStartTime) AS hours, SUM(HitsCount) AS hits FROM Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DATENAME(hour,HitsStartTime)) AS T1
ON Analytics_Index.IndexZero=T1.hours WHERE (IndexZero>=0) AND (IndexZero<24) ORDER BY IndexZero', 0, 'bar', @grReportId, '', '{$reports_general.label_hours$}', '{$reports_conversion.label_num$}', 700, 300, -1)
end
GO

---------------------- reporting table
Declare @tabReportId int

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayFileDownloads', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_day.path_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_day.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthFileDownloads', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_month.path_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_month.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearFileDownloads', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_year.path_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_year.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourFileDownloads', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_hour.path_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_hour.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='RecentlyModifiedDocuments')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'RecentlyModifiedDocsTable', 'Recently modified docs table', 'Select DocumentName AS ''Document name'', NodeAliasPath AS ''Document alias path'', DocumentModifiedWhen AS ''Last modification date'', FirstName + '' ''  + LastName + '' ('' + UserName +'')'' AS ''Last modified by'', StepDisplayName AS ''Current workflow step''  FROM View_CMS_Tree_Joined LEFT JOIN CMS_User ON View_CMS_Tree_Joined.DocumentModifiedByUserID=CMS_User.UserID LEFT JOIN CMS_WorkflowStep ON View_CMS_Tree_Joined.DocumentWorkflowStepID = CMS_WorkflowStep.StepID Where (DocumentModifiedWhen >= @ModifiedSince) AND (NodeSiteID=@CMSContextCurrentSiteID) ORDER BY DocumentModifiedWhen DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayPageViews', 'table', 'SELECT TOP 100 NodeAlias AS ''{$reports_pageviews_day.path_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_day.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND(StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY NodeAlias ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthPageViews', 'table', 'SELECT DISTINCT TOP 100 NodeAlias AS ''{$reports_pageviews_month.path_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_month.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY NodeAlias ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='CheckedOutDocuments')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'CheckedOutDocsTable', 'Checked out docs table', 'Select DocumentName AS ''Document name'', NodeAliasPath AS ''Document alias path'', FirstName + '' '' + LastName + '' ('' +UserName+'')'' AS ''Checked out by'', DocumentCheckedOutWhen AS ''Checked out on'', FirstName + '' ''  + LastName + '' ('' + UserName +'')'' AS ''Last modified by'', StepDisplayName AS ''Current workflow step'' FROM View_CMS_Tree_Joined LEFT JOIN CMS_User ON CMS_User.UserID = View_CMS_Tree_Joined.DocumentCheckedOutByUserID  LEFT JOIN CMS_WorkflowStep ON View_CMS_Tree_Joined.DocumentWorkflowStepID = CMS_WorkflowStep.StepID  Where (DocumentCheckedOutByUserID IS NOT NULL) AND (NodeSiteID=@CMSContextCurrentSiteID) ORDER BY DocumentCheckedOutWhen DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearPageViews', 'table', 'SELECT TOP 100 NodeAlias AS ''{$reports_pageviews_year.path_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_year.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY NodeAlias ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='ExpiredDocuments')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'ExpiredDocsTable', 'Expired docs table', 'Select DocumentName AS ''Document name'', NodeAliasPath AS ''Document alias path'', DocumentPublishTo AS ''Expiration date'', FirstName + '' ''  + LastName + '' ('' + UserName +'')'' AS ''Last modified by'', StepDisplayName AS ''Current workflow step'' FROM View_CMS_Tree_Joined LEFT JOIN CMS_User ON View_CMS_Tree_Joined.DocumentModifiedByUserID=CMS_User.UserID LEFT JOIN CMS_WorkflowStep ON View_CMS_Tree_Joined.DocumentWorkflowStepID = CMS_WorkflowStep.StepID Where (DocumentPublishTo IS NOT NULL) AND (DocumentPublishTo < @CMSContextCurrentTime) AND (NodeSiteID=@CMSContextCurrentSiteID) ORDER BY DocumentPublishTo DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='ArchivedDocuments')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'ArchivedDocsTable', 'Archived docs table', 'Select DocumentName AS ''Documnet name'', NodeAliasPath AS ''Document alias path'', FirstName + '' ''  + LastName + '' ('' + UserName +'')'' AS ''Last modified by'', StepDisplayName AS ''Current workflow step'' FROM View_CMS_Tree_Joined LEFT JOIN CMS_User ON View_CMS_Tree_Joined.DocumentModifiedByUserID=CMS_User.UserID LEFT JOIN CMS_WorkflowStep ON View_CMS_Tree_Joined.DocumentWorkflowStepID = CMS_WorkflowStep.StepID WHERE (DocumentWorkflowStepID IN (SELECT StepID From CMS_WorkflowStep WHERE StepName=''archived'') AND (NodeSiteID=@CMSContextCurrentSiteID)) ORDER BY NodeAliasPath', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='DocumentsWaitingForApproval')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'DocsWaitingForApproval', 'Docs waiting for approval', 'Select DocumentName AS ''Document name'', NodeAliasPath AS ''Document alias path'', FirstName + '' ''  + LastName + '' ('' + UserName +'')'' AS ''Last modified by'', StepDisplayName AS ''Current workflow step'' FROM View_CMS_Tree_Joined_Versions LEFT JOIN CMS_User ON View_CMS_Tree_Joined_Versions.DocumentModifiedByUserID=CMS_User.UserID LEFT JOIN CMS_WorkflowStep ON View_CMS_Tree_Joined_Versions.DocumentWorkflowStepID = CMS_WorkflowStep.StepID WHERE View_CMS_Tree_Joined_Versions.DocumentWorkflowStepID IN (SELECT StepID FROM CMS_WorkflowStep WHERE (StepName <> ''published'' and StepName <>''archived'')) AND (NodeSiteID=@CMSContextCurrentSiteID) ORDER BY NodeAliasPath', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourPageViews', 'table', 'SELECT TOP 100 NodeAlias AS ''{$reports_pageviews_hour.path_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_hour.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY NodeAlias ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayPageNotFound', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_pagenotfound_day.name_header$}'', SUM(HitsCount) AS ''{$reports_pagenotfound_day.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthPageNotFound', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_pagenotfound_month.name_header$}'', SUM(HitsCount) AS ''{$reports_pagenotfound_month.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearPageNotFound', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_pagenotfound_year.name_header$}'', SUM(HitsCount) AS ''{$reports_pagenotfound_year.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pagenotfound.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourPageNotFound', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_pagenotfound_hour.path_header$}'', SUM(HitsCount) AS ''{$reports_pagenotfound_hour.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='urlreferrals.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayReferrals', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_referrals_day.name_header$}'', SUM(HitsCount) AS ''{$reports_referrals_day.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='urlreferrals.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthReferrals', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_referrals_month.name_header$}'', SUM(HitsCount) AS ''{$reports_referrals_month.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='urlreferrals.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearReferrals', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_referrals_year.name_header$}'', SUM(HitsCount) AS ''{$reports_referrals_year.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='urlreferrals.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourReferrals', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_referrals_hour.name_header$}'', SUM(HitsCount) AS ''{$reports_referrals_hour.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayFileDownloadsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_day.path_header$}'',  StatisticsObjectCulture AS ''{$reports_filedownloads_day.cult_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_day.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthFileDownloadsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_month.path_header$}'', StatisticsObjectCulture AS   ''{$reports_filedownloads_month.cult_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_month.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearFileDownloadsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_year.path_header$}'', StatisticsObjectCulture AS
''{$reports_filedownloads_year.cult_header$}'',
SUM(HitsCount) AS ''{$reports_filedownloads_year.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC, StatisticsObjectCulture', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='filedownloads.multilingual.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourFileDownloadsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_filedownloads_hour.path_header$}'', StatisticsObjectCulture AS ''{$reports_filedownloads_hour.cult_header$}'', SUM(HitsCount) AS ''{$reports_filedownloads_hour.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC, StatisticsObjectCulture', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayPageViewsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_pageviews_day.path_header$}'',  StatisticsObjectCulture AS ''{$reports_pageviews_day.cult_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_day.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthPageViewsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_pageviews_month.path_header$}'', StatisticsObjectCulture AS   ''{$reports_pageviews_month.cult_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_month.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearPageViewsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_pageviews_year.path_header$}'', StatisticsObjectCulture AS
''{$reports_pageviews_year.cult_header$}'',
SUM(HitsCount) AS ''{$reports_pageviews_year.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC, StatisticsObjectCulture', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='pageviews.multilingual.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourFilePageViewsCulture', 'table', 'SELECT TOP 100 DocumentNamePath AS ''{$reports_pageviews_hour.path_header$}'', StatisticsObjectCulture AS ''{$reports_pageviews_hour.cult_header$}'', SUM(HitsCount) AS ''{$reports_pageviews_hour.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits, View_CMS_Tree_Joined WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (StatisticsObjectID = NodeID) AND (StatisticsObjectCulture = DocumentCulture) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectCulture, DocumentNamePath ORDER BY SUM(HitsCount) DESC, StatisticsObjectCulture', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayCampaign', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_campaign.name_header$}'', SUM(HitsCount) AS ''{$reports_campaign.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthCampaign', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_campaign.name_header$}'', SUM(HitsCount) AS ''{$reports_campaign.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearCampaign', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_campaign.name_header$}'', SUM(HitsCount) AS ''{$reports_campaign.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='campaign.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourCampaign', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_campaign.path_header$}'', SUM(HitsCount) AS ''{$reports_campaign.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.dayreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableDayConversion', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_conversion.name_header$}'', SUM(HitsCount) AS ''{$reports_conversion.hits_header$}'' FROM 
Analytics_Statistics, Analytics_DayHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.monthreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableMonthConversion', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_conversion.name_header$}'', SUM(HitsCount) AS ''{$reports_conversion.hits_header$}'' FROM 
Analytics_Statistics, Analytics_MonthHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.yearreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableYearConversion', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_conversion.name_header$}'', SUM(HitsCount) AS ''{$reports_conversion.hits_header$}'' FROM 
Analytics_Statistics, Analytics_YearHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

SET @tabReportId = (SELECT TOP 1 ReportID From Reporting_Report WHERE ReportName='conversion.hourreport')
if (@tabReportId) <> 0
begin
INSERT [Reporting_ReportTable] ([TableName], [TableDisplayName], [TableQuery], [TableQueryIsStoredProcedure], [TableReportID]) VALUES ( 'TableHourConversion', 'table', 'SELECT TOP 100 StatisticsObjectName AS ''{$reports_conversion.path_header$}'', SUM(HitsCount) AS ''{$reports_conversion.hits_header$}'' FROM 
Analytics_Statistics, Analytics_HourHits WHERE (StatisticsSiteID = @CMSContextCurrentSiteID) AND (StatisticsCode=@CodeName) AND (StatisticsID = HitsStatisticsID) AND (HitsStartTime >= @FromDate) AND (HitsEndTime <= @ToDate) GROUP BY StatisticsObjectName ORDER BY SUM(HitsCount) DESC', 0, @tabReportId)
end

GO